-- #########################################################
-- #########################################################
-- ConfigEnv.sql
-- #########################################################
-- #########################################################

SPOOL spool.txt
WHENEVER SQLERROR EXIT SQL.SQLCODE ROLLBACK
WHENEVER OSERROR EXIT FAILURE ROLLBACK

-- #########################################################
-- #########################################################
-- VersionCheck.sql
-- #########################################################
-- #########################################################

declare
  Major$ NUMBER(10);
  Minor$ NUMBER(10);
begin
  select max(Major) into Major$ from DatabaseVersion;
  select max(Minor) into Minor$ from DatabaseVersion where Major = Major$;
  if (Major$ <> 1300) or (Minor$ <> 00) then
    raise_application_error(-20000, '  [' || TO_CHAR(Major$) || '.' || TO_CHAR(Minor$, 'FM00') || ']    [1300.00]');
  end if;
end;
/

-- #########################################################
-- #########################################################
-- AddProtocolReason.sql
-- #########################################################
-- #########################################################

CREATE OR REPLACE procedure AddEnumValue(EnumName$ VARCHAR2,EnumVal$ NUMBER,ValName$ VARCHAR2)
AS
  EnumID$ NUMBER(10);
  CNT$1 NUMBER(10);
BEGIN
  BEGIN
    select ID into EnumID$ from Enums where Name = EnumName$  ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (EnumID$  is not null) then
    SELECT COUNT(Id ) INTO CNT$1
    from EnumValues where ((EnumRef = EnumID$)and(Val = EnumVal$) ) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      Update EnumValues ev set
      ev.Name = ValName$

      where (ev.EnumRef = EnumID$)and(ev.Val = EnumVal$);
          
    else
      insert into EnumValues(EnumRef, Val, Name) values (EnumID$, EnumVal$, ValName$);
      
    END IF;
  END IF;
END;
/
CALL AddEnumValue('', 21, '    ') 
/
CALL AddEnumValue('', 22, '      ') 
/
CALL AddEnumValue('', 23, '    ') 
/
CALL AddEnumValue('', 24, '    ') 
/
CALL AddEnumValue('', 25, '    ') 
/
CALL AddEnumValue('', 21, '    ') 
/
CALL AddEnumValue('', 22, '      ') 
/
CALL AddEnumValue('', 23, '    ') 
/
CALL AddEnumValue('', 24, '    ') 
/
CALL AddEnumValue('', 25, '    ') 
/
drop procedure AddEnumValue
/
/* ***************************************
  ''
****************************************/
CREATE OR REPLACE procedure AddProtocolReason(ID$ NUMBER,Name$ VARCHAR2)
AS
  CNT$1 NUMBER(10);
BEGIN
  SELECT COUNT(id ) INTO CNT$1
  from ProtocolReason where (id = ID$) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    update ProtocolReason set Name = Name$  where id = ID$;
      
  else
    insert into ProtocolReason(ID, Name) values (ID$, Name$);
  END IF;
END;
/
-- ALTER TRIGGER TR_ProtocolReason_BI
CREATE OR REPLACE TRIGGER TR_PROTOCOLREASON_BI
  BEFORE INSERT
  ON PROTOCOLREASON
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ProtocolReason_BI)
-- Create 27.10.2009
-- - - - - - - - - - - - -
  NULL;
--   RaiseException('EX_PR_BanInsert');

-- - - - - - - - - - - - -
-- BI_500 (TR_PROTOCOLREASON_BI_500)
-- Create 20.05.2009
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;    

END;
/
-- ALTER TRIGGER TR_ProtocolReason_BU
CREATE OR REPLACE TRIGGER TR_PROTOCOLREASON_BU
  BEFORE UPDATE
  ON PROTOCOLREASON
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ProtocolReason_BU)
-- Create 27.10.2009
-- - - - - - - - - - - - -
  NULL;
--   RaiseException('EX_PR_BanUpdate');

END;
/
-- ALTER TRIGGER TR_ProtocolReason_BD
CREATE OR REPLACE TRIGGER TR_PROTOCOLREASON_BD
  BEFORE DELETE
  ON PROTOCOLREASON
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_ProtocolReason_BD)
-- Create 27.10.2009
-- - - - - - - - - - - - -
  NULL;
--   RaiseException('EX_PR_BanDelete');

END;
/
CALL AddProtocolReason(105, '. 83.1 . 2 . 1 44-  05.04.2013.')
/
CALL AddProtocolReason(106, '. 83.1 . 2 . 2 44-  05.04.2013.')
/
CALL AddProtocolReason(107, '. 83.1 . 2 . 3 44-  05.04.2013.')
/
CALL AddProtocolReason(108, '. 83.1 . 2 . 4 44-  05.04.2013.')
/
CALL AddProtocolReason(109, '. 83.1 . 2 . 5 44-  05.04.2013.')
/
CALL AddProtocolReason(110, '. 83.1 . 2 . 6 44-  05.04.2013.')
/
-- ALTER TRIGGER TR_ProtocolReason_BI
CREATE OR REPLACE TRIGGER TR_PROTOCOLREASON_BI
  BEFORE INSERT
  ON PROTOCOLREASON
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ProtocolReason_BI)
-- Create 27.10.2009
-- - - - - - - - - - - - -

  RaiseException('EX_PR_BanInsert');

-- - - - - - - - - - - - -
-- BI_500 (TR_PROTOCOLREASON_BI_500)
-- Create 20.05.2009
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;    

END;
/
-- ALTER TRIGGER TR_ProtocolReason_BU
CREATE OR REPLACE TRIGGER TR_PROTOCOLREASON_BU
  BEFORE UPDATE
  ON PROTOCOLREASON
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ProtocolReason_BU)
-- Create 27.10.2009
-- - - - - - - - - - - - -

  RaiseException('EX_PR_BanUpdate');

END;
/
-- ALTER TRIGGER TR_ProtocolReason_BD
CREATE OR REPLACE TRIGGER TR_PROTOCOLREASON_BD
  BEFORE DELETE
  ON PROTOCOLREASON
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_ProtocolReason_BD)
-- Create 27.10.2009
-- - - - - - - - - - - - -

  RaiseException('EX_PR_BanDelete');

END;
/
drop procedure AddProtocolReason
/
commit work
/

-- #########################################################
-- #########################################################
-- DeleteReserveFunds.sql
-- #########################################################
-- #########################################################

/* 
        (29)  .

*/
drop table ReserveFunds
/
-- drop trigger TR_COMPOUNDCLS_BD
DROP TRIGGER TR_COMPOUNDCLS_BD
/
drop table CompoundClsDetail
/
drop table CompoundCls
/
commit work
/

-- #########################################################
-- #########################################################
-- AlterEnumSaleType_Ora.sql
-- #########################################################
-- #########################################################


create or replace procedure AddEnumValue(EnumName$ VarChar2, EnumVal$ Number, ValName$ VarChar2)
as
  EnumID$ Number(10);
  cnt$ Number(10);
begin
  select ID into EnumID$
  from Enums where Name = EnumName$;

  if (EnumID$ is not null) then
    select count(*) into cnt$
      from EnumValues where (EnumRef = EnumID$)and(Val = EnumVal$);

    if cnt$ = 0 then
      insert into EnumValues(EnumRef, Val, Name) values (EnumID$, EnumVal$, ValName$);
    else
      Update EnumValues ev set
        ev.Name = ValName$
      where (ev.EnumRef = EnumID$)and(ev.Val = EnumVal$);
    end if;
  end if;
end;
/

call AddEnumValue('', 0, ' ')
/

drop procedure AddEnumValue
/

commit work
/


-- #########################################################
-- #########################################################
-- Alter_ATCheck.sql
-- #########################################################
-- #########################################################

-- CREATE TRIGGER tr_tendercaption_bu_10
CREATE OR REPLACE TRIGGER TR_TENDERCAPTION_IU
  INSTEAD OF UPDATE
  ON TENDERCAPTION
  FOR EACH ROW
DECLARE
  new$ID TENDERCAPTION.ID%TYPE := :NEW.ID;
  new$BUDGETREF TENDERCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FACIALACCCLS TENDERCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$MULTIPURPOSE TENDERCAPTION.MULTIPURPOSE%TYPE := :NEW.MULTIPURPOSE;
  new$DOCUMENTDATE TENDERCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE TENDERCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PERIOD TENDERCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$ACCEPTSUMMA TENDERCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$SALETYPE TENDERCAPTION.SALETYPE%TYPE := :NEW.SALETYPE;
  new$REJECTCLS TENDERCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS TENDERCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID TENDERCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID TENDERCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCSTATEREF TENDERCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CREATERUSER TENDERCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TENDERCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE TENDERCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER TENDERCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$LASTADJUSTMENT TENDERCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED TENDERCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$ADJUSTMENTREF TENDERCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ACCEPTED TENDERCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$EXPORTDATE TENDERCAPTION.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$YEARACCEPTSUMMA TENDERCAPTION.YEARACCEPTSUMMA%TYPE := :NEW.YEARACCEPTSUMMA;
  new$TENDEROPTION TENDERCAPTION.TENDEROPTION%TYPE := :NEW.TENDEROPTION;
  new$TENDERTARGET TENDERCAPTION.TENDERTARGET%TYPE := :NEW.TENDERTARGET;
  new$RVERSION TENDERCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$ALLOWANCE TENDERCAPTION.ALLOWANCE%TYPE := :NEW.ALLOWANCE;
  new$REFINEMENTCAUSE TENDERCAPTION.REFINEMENTCAUSE%TYPE := :NEW.REFINEMENTCAUSE;
  new$PREFERENCE TENDERCAPTION.PREFERENCE%TYPE := :NEW.PREFERENCE;
  new$PREFERENCESIZE TENDERCAPTION.PREFERENCESIZE%TYPE := :NEW.PREFERENCESIZE;
  new$SECURITY TENDERCAPTION.SECURITY%TYPE := :NEW.SECURITY;
  new$UNKNOWNAMOUNT TENDERCAPTION.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PERIODYEAR TENDERCAPTION.PERIODYEAR%TYPE := :NEW.PERIODYEAR;
  new$SUPPORTUNDERTAKER TENDERCAPTION.SUPPORTUNDERTAKER%TYPE := :NEW.SUPPORTUNDERTAKER;
  new$AYEAR TENDERCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$REWORKCAUSE TENDERCAPTION.REWORKCAUSE%TYPE := :NEW.REWORKCAUSE;
  new$NOTE TENDERCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$REALID TENDERCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER TENDERCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTNUMBER TENDERCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$SENDERIDKEY TENDERCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY TENDERCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$PROTOCOLREASON TENDERCAPTION.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$PROGINDEX TENDERCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER TENDERCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SECURITYTSIZE TENDERCAPTION.SECURITYTSIZE%TYPE := :NEW.SECURITYTSIZE;
  new$SECURITYASIZE TENDERCAPTION.SECURITYASIZE%TYPE := :NEW.SECURITYASIZE;
  new$AVANSSIZE TENDERCAPTION.AVANSSIZE%TYPE := :NEW.AVANSSIZE;
  new$PREFERENCECRIPPLE TENDERCAPTION.PREFERENCECRIPPLE%TYPE := :NEW.PREFERENCECRIPPLE;
  new$PREFERENCERUSPRODUCT TENDERCAPTION.PREFERENCERUSPRODUCT%TYPE := :NEW.PREFERENCERUSPRODUCT;
  new$PREFERENCEPRISON TENDERCAPTION.PREFERENCEPRISON%TYPE := :NEW.PREFERENCEPRISON;
  new$AGREEMENTEXECUTIONDATE TENDERCAPTION.AGREEMENTEXECUTIONDATE%TYPE := :NEW.AGREEMENTEXECUTIONDATE;
  new$PURCHASECODE TENDERCAPTION.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$PURCHASESOCIALNKO TENDERCAPTION.PURCHASESOCIALNKO%TYPE := :NEW.PURCHASESOCIALNKO;
  new$AVERSION TENDERCAPTION.AVERSION%TYPE := :NEW.AVERSION;
  new$PARENTREF TENDERCAPTION.PARENTREF%TYPE := :NEW.PARENTREF;
  new$REJECTCAUSE TENDERCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$PARENTINNERNUMBER TENDERCAPTION.PARENTINNERNUMBER%TYPE := :NEW.PARENTINNERNUMBER;
--
  DetCount1$ NUMBER(10);
  ParentProgIndex1$ NUMBER(10);
  AdjParentRef1$ NUMBER(10);
  AdjParentInnerNumber1$ NUMBER(10);
  countLastAdj$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TENDERCAPTION_BU_0)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*   13.0*/
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  /*         ( ) */
  if (new$ProgIndex = 230 and new$Multipurpose is null) then
    new$Multipurpose := 0;
  END IF;
  if (new$AcceptSumma is null) then
    new$AcceptSumma := 0;
  END IF;
  if (new$YearAcceptSumma is null) then
    new$YearAcceptSumma := 0;
  END IF;
  if (new$Allowance is null) then
    new$Allowance := 0;
  END IF;
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if (not((new$BudgetRef is null) and (:old.BudgetRef is null))) then
      select count(ID)         into DetCount1$ from TENDERSOURCEORG where RecordIndex = :old.ID
      ;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount1$ from TENDERCONTACTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount1$ from TENDERSUPDOCUMENT where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount1$ from TENDERSUPPLEMENTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount1$ from TENDERYARDSTICKS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount1$ from TenderLot where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  if (new$SaleType is null) then
    new$SaleType := 0;
  END IF;
  if (new$TenderOption is null) then
    new$TenderOption := 0;
  END IF;
  if (new$RefinementCause is Null) then
    new$RefinementCause := 0;
  END IF;
  if (new$Preference is Null) then
    new$Preference := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$SupportUndertaker is null) then
    new$SupportUndertaker := 0;
  END IF;
  /*     ,        */
  if (new$InnerNumber is null) then
    new$InnerNumber := :old.InnerNumber;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_TENDERCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_TENDERCAPTION_BU_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  if ((new$InnerNumber <> :old.InnerNumber) or
  (new$AdjustmentRef <> :old.AdjustmentRef) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber)) then
    RaiseException('EX_AGR_ChangeInnerNums');
  END IF;
      
  /*   !!!*/
  if (:old.AcceptDate is not null and :old.Accepted = 0 and (new$Accepted = 1 or new$AcceptDate is null)) then
    /* :  */
    if (new$AdjustmentRef is not null) then
      RaiseException('EX_RollbackCancel');
    END IF;
    /*      ,
             , ,          */
    select count(ID)
    into countLastAdj$       from TenderCaption
    where InnerNumber=new$InnerNumber and LastAdjustment = 1
    ;
    if (countLastAdj$ = 0) then
      new$LastAdjustment := 1;
        
    END IF;
  END IF;
  /*  ,     LastAccepted*/
  if (:old.AcceptDate is null and new$AcceptDate is not null and new$Accepted = 1) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;
            
    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;
  /*   ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;
            
    else
      RaiseException('EX_Ten_ChangeStateAdjust');    
    END IF;
  END IF;
  /*   ,     LastAdjustment*/
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment <> 1) then
      RaiseException('EX_Ten_ChangeStateAdjust');
    else
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
        
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_TENDERCAPTION_BU_30)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  new$ParentInnerNumber := null;
  if (new$ParentRef is not null) then
    BEGIN
      select InnerNumber
      into new$ParentInnerNumber     from TenderCaption
      where ID=new$ParentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /* :  /    / */
  if (new$ParentRef is not null
  /*  ,   */
  and  (:old.ParentRef is null
  or (:old.ParentRef is not null and :old.ParentRef <> new$ParentRef)))
  then
    /* :     ParentRef  */
    if (new$LastAdjustment = 0) then
      RaiseException('EX_ChangeAdjTenderParentRef');
    END IF;
    BEGIN
      select ProgIndex
      into ParentProgIndex1$     from TenderCaption
      where ID=new$ParentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /* :  /    / */
    if  ((new$ProgIndex=243 and ParentProgIndex1$ <> 242)
    or (new$ProgIndex=241 and ParentProgIndex1$ <> 240))
    then
      RaiseException('EX_IncorrectTenderParentRef');
    END IF;
    /* :       /     ( ,    ) */
    if (new$AdjustmentRef is not null) then
      BEGIN
        select ParentRef
        into AdjParentRef1$       from TenderCaption
        where ID=new$AdjustmentRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (AdjParentRef1$ is not null) then
        BEGIN
          select InnerNumber
          into AdjParentInnerNumber1$         from TenderCaption
          where ID=AdjParentRef1$

          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        if (AdjParentInnerNumber1$ <> new$ParentInnerNumber) then
          RaiseException('EX_IncorrectAdjTenderParentRef');
        END IF;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_TENDERCAPTION_BU_200)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*        */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
        VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef);
   END IF;

-- - - - - - - - - - - - -
-- BU_600 (tendercaption_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_TENDERCAPTION_BU_700)
-- Create 14.10.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TENDERCAPTION SET
    ID = new$ID,
    BUDGETREF = new$BUDGETREF,
    FACIALACCCLS = new$FACIALACCCLS,
    MULTIPURPOSE = new$MULTIPURPOSE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    PERIOD = new$PERIOD,
    ACCEPTSUMMA = new$ACCEPTSUMMA,
    SALETYPE = new$SALETYPE,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DOCSTATEREF = new$DOCSTATEREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    ACCEPTED = new$ACCEPTED,
    EXPORTDATE = new$EXPORTDATE,
    YEARACCEPTSUMMA = new$YEARACCEPTSUMMA,
    TENDEROPTION = new$TENDEROPTION,
    TENDERTARGET = new$TENDERTARGET,
    RVERSION = new$RVERSION,
    ALLOWANCE = new$ALLOWANCE,
    REFINEMENTCAUSE = new$REFINEMENTCAUSE,
    PREFERENCE = new$PREFERENCE,
    PREFERENCESIZE = new$PREFERENCESIZE,
    SECURITY = new$SECURITY,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PERIODYEAR = new$PERIODYEAR,
    SUPPORTUNDERTAKER = new$SUPPORTUNDERTAKER,
    AYEAR = new$AYEAR,
    REWORKCAUSE = new$REWORKCAUSE,
    NOTE = new$NOTE,
    REALID = new$REALID,
    INNERNUMBER = new$INNERNUMBER,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    PROTOCOLREASON = new$PROTOCOLREASON,
    PROGINDEX = new$PROGINDEX,
    DOCNUMBER = new$DOCNUMBER,
    SECURITYTSIZE = new$SECURITYTSIZE,
    SECURITYASIZE = new$SECURITYASIZE,
    AVANSSIZE = new$AVANSSIZE,
    PREFERENCECRIPPLE = new$PREFERENCECRIPPLE,
    PREFERENCERUSPRODUCT = new$PREFERENCERUSPRODUCT,
    PREFERENCEPRISON = new$PREFERENCEPRISON,
    AGREEMENTEXECUTIONDATE = new$AGREEMENTEXECUTIONDATE,
    PURCHASECODE = new$PURCHASECODE,
    PURCHASESOCIALNKO = new$PURCHASESOCIALNKO,
    AVERSION = new$AVERSION,
    PARENTREF = new$PARENTREF,
    REJECTCAUSE = new$REJECTCAUSE,
    PARENTINNERNUMBER = new$PARENTINNERNUMBER
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_TENDERCAPTION_AU_10)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*   13.0*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update TenderCaption set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

  /*       LastAdjustment    */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update TenderCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_TENDERCAPTION_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   2.0*/
  /*       ,      */
  if (:old.FacialAccCls <> new$FacialAccCls) then
    update TenderProduct set
    RVersion = -1,
    FacialAccCls = new$FacialAccCls
    where
    (RecordIndex = new$ID) and (ProgIndex = 230);
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (tr_TenderCaption_au_30)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) /*      */
  and ((new$ProgIndex = 240) /* */ or (new$ProgIndex = 242) /* */))
  then
    if ((new$Accepted <> :old.Accepted)
    or (new$AcceptDate is not null and :old.AcceptDate is null)
    or (new$AcceptDate is null and :old.AcceptDate is not null)
    or (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))
    then
      update TenderCaption set
      RejectCls = new$RejectCls,
      AcceptDate = new$AcceptDate
      where ParentRef=new$ID;
      /*          */
      if (:old.Accepted=1 and new$Accepted=0) then
        update TenderCaption set
        RejectCause = '   : ' || new$RejectCause
        where ParentRef=new$ID;
      END IF;
      /*             */
      if (:old.Accepted=0 and new$Accepted=1) then
        update TenderCaption set
        RejectCls = null,
        RejectCause = null
        where ParentRef=new$ID;

      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_TENDERCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
           VALUES (139, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
            WHERE (TableID = 139) AND (RecordId = new$ID);
   END IF;

END;
/
-- CREATE TRIGGER tr_execdoccaption_bu_10
CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_IU
  INSTEAD OF UPDATE
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  new$ID EXECUTIONDOCUMENTSCAPTION.ID%TYPE := :NEW.ID;
  new$DOCTYPE EXECUTIONDOCUMENTSCAPTION.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$DOCUMENTDATE EXECUTIONDOCUMENTSCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE EXECUTIONDOCUMENTSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SUMMA EXECUTIONDOCUMENTSCAPTION.SUMMA%TYPE := :NEW.SUMMA;
  new$CREATERUSER EXECUTIONDOCUMENTSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE EXECUTIONDOCUMENTSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE EXECUTIONDOCUMENTSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER EXECUTIONDOCUMENTSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF EXECUTIONDOCUMENTSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$STEPNUMBER EXECUTIONDOCUMENTSCAPTION.STEPNUMBER%TYPE := :NEW.STEPNUMBER;
  new$FACIALACC_CLS EXECUTIONDOCUMENTSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$RECIPIENT_REF EXECUTIONDOCUMENTSCAPTION.RECIPIENT_REF%TYPE := :NEW.RECIPIENT_REF;
  new$REGISTRATIONTYPE EXECUTIONDOCUMENTSCAPTION.REGISTRATIONTYPE%TYPE := :NEW.REGISTRATIONTYPE;
  new$REESTRNUMBER EXECUTIONDOCUMENTSCAPTION.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$AGREEMENTINNERNUMBER EXECUTIONDOCUMENTSCAPTION.AGREEMENTINNERNUMBER%TYPE := :NEW.AGREEMENTINNERNUMBER;
  new$REJECTCLS EXECUTIONDOCUMENTSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS EXECUTIONDOCUMENTSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID EXECUTIONDOCUMENTSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID EXECUTIONDOCUMENTSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REVIEWNOTE EXECUTIONDOCUMENTSCAPTION.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF EXECUTIONDOCUMENTSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION EXECUTIONDOCUMENTSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$EXECDOCFINSUMMA EXECUTIONDOCUMENTSCAPTION.EXECDOCFINSUMMA%TYPE := :NEW.EXECDOCFINSUMMA;
  new$FACT EXECUTIONDOCUMENTSCAPTION.FACT%TYPE := :NEW.FACT;
  new$DOCNUMBER EXECUTIONDOCUMENTSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SENDERIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REALID EXECUTIONDOCUMENTSCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER EXECUTIONDOCUMENTSCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTREF EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ADJUSTMENTNUMBER EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$ACCEPTED EXECUTIONDOCUMENTSCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED EXECUTIONDOCUMENTSCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$LASTADJUSTMENT EXECUTIONDOCUMENTSCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$AGREEMENTREF EXECUTIONDOCUMENTSCAPTION.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$NOTE EXECUTIONDOCUMENTSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$SUPPLIERSTOREDPROPS EXECUTIONDOCUMENTSCAPTION.SUPPLIERSTOREDPROPS%TYPE := :NEW.SUPPLIERSTOREDPROPS;
  new$SUPPLIER_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$SUPPLIERACC_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIERACC_REF%TYPE := :NEW.SUPPLIERACC_REF;
  new$REJECTCAUSE EXECUTIONDOCUMENTSCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$INFONUMBER EXECUTIONDOCUMENTSCAPTION.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$NOTIFYDATE EXECUTIONDOCUMENTSCAPTION.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$MONEYPROMISENUMBER EXECUTIONDOCUMENTSCAPTION.MONEYPROMISENUMBER%TYPE := :NEW.MONEYPROMISENUMBER;
  new$PURPORTDOC EXECUTIONDOCUMENTSCAPTION.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$STOREDCONTENT EXECUTIONDOCUMENTSCAPTION.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
  new$PAYDATE EXECUTIONDOCUMENTSCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  CntAgr$ NUMBER(10);
  CntStep$ NUMBER(10);
  agr_accepted$ NUMBER(10);
  agr_acceptdate$ NUMBER(10);
  CountExecDoc$ NUMBER(10);
  countLastAdj1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_EXECDOCCAPTION_BU)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$ExecDocFinSumma is null) then
    new$ExecDocFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$RegistrationType is null) then
    new$RegistrationType := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      SELECT COUNT(                   Id
      ) INTO CNT$1
      from ExecutionDocumentsDetail
      where
      (                   RecordIndex = :old.Id
      ) AND (ROWNUM = 1)                ;
      if ((CNT$1<> 0)         ) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      SELECT COUNT(                   Id
      ) INTO CNT$2
      from PaymentSchedule
      where
      (                   ExecutionRef = :old.Id
      ) AND (ROWNUM = 1)                ;
      if ((CNT$2<> 0)         ) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*     ,        */
  if (new$InnerNumber is null) then
    new$InnerNumber := :old.InnerNumber;
  END IF;
  /* c,           */
  /* ,    */
  if (new$InnerNumber <> :old.InnerNumber or
  new$AdjustmentRef <> :old.AdjustmentRef or
  new$AdjustmentNumber <> :old.AdjustmentNumber) then
    RaiseException('EX_Agr_ChangeInnerNums');
  END IF;
  /*      id */
  new$agreementinnernumber := null;
  if (new$agreementref is not null) then
    BEGIN
      select
      innernumber
      into new$agreementinnernumber     from agreements
      where
      id = new$agreementref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_EXECDOCCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_EXECDOCCAPTION_BU_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*     */
  if (:old.AcceptDate is not null and :old.Accepted = 0 and (new$Accepted = 1 or new$AcceptDate is null)) then
    /* :  */
    if (new$AdjustmentRef is not null) then
      RaiseException('EX_RollbackCancel');
    END IF;
    /*      ,
           , ,          */
    select count(ID)
    into countLastAdj1$     from ExecutionDocumentsCaption
    where InnerNumber=new$InnerNumber and LastAdjustment = 1
    ;
    if (countLastAdj1$ = 0) then
      new$LastAdjustment := 1;
      
    END IF;
  END IF;
  /*   ,     LastAccepted*/
  if (:old.AcceptDate is null and new$AcceptDate is not null and new$Accepted = 1) then 
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
  END IF;
      
  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');   
    END IF;
  END IF;
  /*   ,     LastAdjustment  LastAccepted */
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment <> 1) then
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    else
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_40 (tr_execdoccaption_bu_40)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  if ((:old.AcceptDate is not null) and (new$AcceptDate is null)) then
    select count(ID) into CntAgr$ from Agreements where (CloseDoc = :old.ID) ;
    select count(ID) into CntStep$ from AgreementSteps where (CloseDoc = :old.ID) ;
    if ((CntAgr$ > 0) or (CntStep$ > 0)) then
      RaiseException('ex_CannotUpdateCloseDoc');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_60 (tr_execdoccaption_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$agreementinnernumber is not null) then
    BEGIN
      /*        , .. 
             ,    ,   
            ,     */
      select accepted, acceptdate     into
      agr_accepted$, agr_acceptdate$ from agreements
      where
      innernumber = new$agreementinnernumber and adjustmentnumber = 0
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*        */
    if (new$acceptdate is null and agr_accepted$ = 0 and agr_acceptdate$ is not null) then
      RaiseException('EX_Agr_Rejected');
    END IF;
    /*        */
    if (new$accepted = 1 and new$acceptdate is not null and
    (agr_accepted$ = 0 or agr_acceptdate$ is null)) then
      RaiseException('EX_Agr_NotAccepted');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_EXECDOCCAPTION_BU_200)
-- Create 04.10.2004
-- - - - - - - - - - - - -

  /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_EXECDOCCAPTION_BU_210)
-- Version 11.20.00.1
-- - - - - - - - - - - - -

  /*   */
  if (new$rejectcls is not null and new$accepted = 0) then
    /*         */
    select
    count(ffd.id)
    into CountExecDoc$     from
    facialfindetail ffd
    left join facialfincaption ffc on ffc.id = ffd.recordindex
    where
    (ffc.acceptdate is not null and (ffd.sourceexecdoc = new$id or ffd.destexecdoc = new$id))
    ;
    /*       */
    if (CountExecDoc$ <> 0) then
      RaiseException('ex_exedoc_useinfacialfindetail');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_EDCAPTION_BU_700)
-- Create 14.10.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_EXECUTIONDOCUMENTSCAPTION SET
    ID = new$ID,
    DOCTYPE = new$DOCTYPE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    SUMMA = new$SUMMA,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    STEPNUMBER = new$STEPNUMBER,
    FACIALACC_CLS = new$FACIALACC_CLS,
    RECIPIENT_REF = new$RECIPIENT_REF,
    REGISTRATIONTYPE = new$REGISTRATIONTYPE,
    REESTRNUMBER = new$REESTRNUMBER,
    AGREEMENTINNERNUMBER = new$AGREEMENTINNERNUMBER,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXECDOCFINSUMMA = new$EXECDOCFINSUMMA,
    FACT = new$FACT,
    DOCNUMBER = new$DOCNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REALID = new$REALID,
    INNERNUMBER = new$INNERNUMBER,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    ACCEPTED = new$ACCEPTED,
    LASTACCEPTED = new$LASTACCEPTED,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    AGREEMENTREF = new$AGREEMENTREF,
    NOTE = new$NOTE,
    SUPPLIERSTOREDPROPS = new$SUPPLIERSTOREDPROPS,
    SUPPLIER_REF = new$SUPPLIER_REF,
    SUPPLIERACC_REF = new$SUPPLIERACC_REF,
    REJECTCAUSE = new$REJECTCAUSE,
    INFONUMBER = new$INFONUMBER,
    NOTIFYDATE = new$NOTIFYDATE,
    MONEYPROMISENUMBER = new$MONEYPROMISENUMBER,
    PURPORTDOC = new$PURPORTDOC,
    STOREDCONTENT = new$STOREDCONTENT,
    PAYDATE = new$PAYDATE
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_0 (TR_ExecDocCaption_AU)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*       */
  /*     ,       */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update ExecutionDocuMENTSCaption set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update ExecutionDocuMENTSCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_EXECDOCCAPTION_AU_30)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$Accepted <> :old.Accepted) or
  (new$AcceptDate is not null and :old.AcceptDate is null) or
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where ExecutionRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_EXECDOCCAPTION_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (114, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=114) and (RecordId=new$ID);
  end if;

END;
/
-- CREATE TRIGGER tr_agreements_bu_10
CREATE OR REPLACE TRIGGER TR_AGREEMENTS_IU
  INSTEAD OF UPDATE
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
  new$EXECUTERSTOREDPROPS AGREEMENTS.EXECUTERSTOREDPROPS%TYPE := :NEW.EXECUTERSTOREDPROPS;
  new$AUTOSANCTION AGREEMENTS.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$PURCHASECODE AGREEMENTS.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$DOCUMENTNUMBER AGREEMENTS.DOCUMENTNUMBER%TYPE := :NEW.DOCUMENTNUMBER;
  new$REJECTCAUSE AGREEMENTS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$TENDERREF AGREEMENTS.TENDERREF%TYPE := :NEW.TENDERREF;
  new$TENDERINNERNUMBER AGREEMENTS.TENDERINNERNUMBER%TYPE := :NEW.TENDERINNERNUMBER;
  new$STOREDCONTENT AGREEMENTS.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
--
  CNT$1 NUMBER(10);
  CountAcc$ NUMBER(10);
  rnClientID1$ VARCHAR2(15);
  rnYear1$ VARCHAR2(15);
  rnNumber1$ VARCHAR2(15);
  ReestrVersion1$ VARCHAR2(15);
  DetCount$ NUMBER(10);
  countLastAdj1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_AGREEMENTS_BU)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*   13.0*/
  /*    -*/
  if (new$CardAdvancePercent is null) then
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then
    new$FinCardAdvance := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$client_ref is null) then
    new$client_ref := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from AgreementSteps where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      select count(ID)       into DetCount$ from Estimate where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*     ,        */
  if (new$InnerNumber is null) then
    new$InnerNumber := :old.InnerNumber;
  END IF;
  /*   */
  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  /*    .  */

  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*     30.  id */

  new$TenderInnerNumber := null;
  if (new$TenderRef is not null) then
    BEGIN
      select InnerNumber
      into new$TenderInnerNumber     from TenderCaption
      where id = new$TenderRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_AGREEMENTS_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_AGREEMENTS_BU_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  /* ,      ,   */
  if ((new$InnerNumber <> :old.InnerNumber) or
  (new$AdjustmentRef <> :old.AdjustmentRef) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber) or
  (new$AgreementType <> :old.AgreementType)) then
    RaiseException('EX_AGR_ChangeInnerNums');
  END IF;
      
  /*    !!!*/
  if (:old.AcceptDate is not null and :old.Accepted = 0 and (new$Accepted = 1 or new$AcceptDate is null)) then
    /* :  */
    if (new$AdjustmentRef is not null) then
      RaiseException('EX_RollbackCancel');
    END IF;
    /*      ,
             , ,          */
    select count(ID)
    into countLastAdj1$       from Agreements
    where InnerNumber=new$InnerNumber and LastAdjustment = 1
    ;
    if (countLastAdj1$ = 0) then
      new$LastAdjustment := 1;
      
    END IF;
  END IF;
  /*  ,     LastAccepted*/
  if (:old.AcceptDate is null and new$AcceptDate is not null and new$Accepted = 1) then 
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;
          
    else
      RaiseException('EX_AGR_ChangeStateAdjust');
    END IF;
  END IF;
  /*   ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;
          
    else
      RaiseException('EX_AGR_ChangeStateAdjust');  
    END IF;
  END IF;
  /*   ,     LastAdjustment  LastAccepted */
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment <> 1) then
      RaiseException('EX_AGR_ChangeStateAdjust');
    else
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_20 (TR_AGREEMENTS_BU_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,      */
  if ((new$Client_Ref <> :old.Client_Ref) and
      (((new$Client_INN is null) and
        (:old.Client_INN is null)) or
       (new$Client_INN = :old.Client_INN)) and
      (((new$Client_INN20 is null) and
        (:old.Client_INN20 is null)) or
       (new$Client_INN20 = :old.Client_INN20)) and
      (new$Client_Name = :old.Client_Name)) then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;

  /*    -,      */
  if ((new$Executer_Ref <> :old.Executer_Ref) and
      (((new$Executer_INN is null) and
        (:old.Executer_INN is null)) or
       (new$Executer_INN = :old.Executer_INN)) and
      (((new$Executer_INN20 is null) and
        (:old.Executer_INN20 is null)) or
       (new$Executer_INN20 = :old.Executer_INN20)) and
      (new$Executer_Name = :old.Executer_Name) and
      (((new$Executer_Status is null) and
        (:old.Executer_Status is null)) or
       (new$Executer_Status = :old.Executer_Status)) and
      (((new$Executer_Country is null) and
        (:old.Executer_Country is null)) or
       (new$Executer_Country = :old.Executer_Country)) and
      (((new$Executer_Address is null) and
        (:old.Executer_Address is null)) or
       (new$Executer_Address = :old.Executer_Address)) and
      (((new$Executer_Phone is null) and
        (:old.Executer_Phone is null)) or
       (new$Executer_Phone = :old.Executer_Phone))) then
     BEGIN
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_60 (tr_agreements_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*        ,     */
  if (:old.accepted = 1 and new$accepted = 0 and new$acceptdate is not null and new$adjustmentnumber = 0) then
    SELECT COUNT(*) INTO CNT$1
    from executiondocumentscaption
    where
    (            agreementinnernumber = new$innernumber
    and (accepted <> 0 or acceptdate is null)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_Agr_CannotReject');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_AGREEMENTS_BU_200)
-- Create 04.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$id, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (tr_agreements_bu_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$ExecuterAccRef is not null) then
    select count(ID)
    into CountAcc$     from org_accounts oa
    where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
    ;
    if (CountAcc$ = 0) then
      RaiseException('EX_AGR_ACCORGCHECK');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (TR_AGREEMENTS_BU_400)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (((new$rnClientID <> :old.rnClientID) or (new$rnYear <> :old.rnYear) or
  (new$rnNumber <> :old.rnNumber) or (new$ReestrVersion <> :old.ReestrVersion)) and
  (new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID1$ := new$rnClientID;
    rnYear1$ := new$rnYear;
    rnNumber1$ := new$rnNumber;
    ReestrVersion1$ := new$ReestrVersion;
    while (LENGTH(rnClientID1$) < 11) LOOP
      rnClientID1$ := '0' || rnClientID1$;
    END LOOP;
    while (LENGTH(rnNumber1$) < 6) LOOP
      rnNumber1$ := '0' || rnNumber1$;
    END LOOP;
    if (LENGTH(ReestrVersion1$) < 2) then
      ReestrVersion1$ := '0' || ReestrVersion1$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$;

    else
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$ || ReestrVersion1$;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_600 (agreements_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_AGREEMENTS_BU_700)
-- Create 14.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_AGREEMENTS SET
    ID = new$ID,
    SUMMA = new$SUMMA,
    AGREEMENTDATE = new$AGREEMENTDATE,
    AGREEMENTENDDATE = new$AGREEMENTENDDATE,
    EXECUTER_REF = new$EXECUTER_REF,
    CLIENT_REF = new$CLIENT_REF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    AGREEMENTTYPE = new$AGREEMENTTYPE,
    ACCEPTED = new$ACCEPTED,
    ACCEPTDATE = new$ACCEPTDATE,
    CARDADVANCEPERCENT = new$CARDADVANCEPERCENT,
    CARDADVANCE = new$CARDADVANCE,
    CLOSEDOC = new$CLOSEDOC,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    FACT = new$FACT,
    REGION = new$REGION,
    CLOSEDATE = new$CLOSEDATE,
    DELIVERYRULES = new$DELIVERYRULES,
    AGREEMENTSUMMA = new$AGREEMENTSUMMA,
    AGREEMENTFINSUMMA = new$AGREEMENTFINSUMMA,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    REESTRNUMBER = new$REESTRNUMBER,
    PAYMENTDATE = new$PAYMENTDATE,
    AGREEMENTCARDADVANCE = new$AGREEMENTCARDADVANCE,
    FINCARDADVANCE = new$FINCARDADVANCE,
    STATEORDERREF = new$STATEORDERREF,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    AGREEMENTBEGINDATE = new$AGREEMENTBEGINDATE,
    PROTOCOLNUMBER = new$PROTOCOLNUMBER,
    PROTOCOLDATE = new$PROTOCOLDATE,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXPORTDATE = new$EXPORTDATE,
    FSORGAN = new$FSORGAN,
    FSBUDGETNAME = new$FSBUDGETNAME,
    FSOFFBUDGET = new$FSOFFBUDGET,
    RNYEAR = new$RNYEAR,
    RNNUMBER = new$RNNUMBER,
    RNDATE = new$RNDATE,
    PROTOCOLNOTICE = new$PROTOCOLNOTICE,
    PROTOCOLRESULTDATE = new$PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE = new$PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE = new$PROTOCOLSALETYPE,
    NOTIFYDATE = new$NOTIFYDATE,
    EXECUTERACCREF = new$EXECUTERACCREF,
    DOCBASEDATE = new$DOCBASEDATE,
    DOCBASENOTIFYDATE = new$DOCBASENOTIFYDATE,
    DOCBASETEXT = new$DOCBASETEXT,
    DOCBASETYPE = new$DOCBASETYPE,
    DOCBASESUMMA = new$DOCBASESUMMA,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PROTOCOLREASON = new$PROTOCOLREASON,
    DOCNUMBER = new$DOCNUMBER,
    ADJUSTMENTDOCNUMBER = new$ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER = new$OLDDOCNUMBER,
    LOTMAXSUM = new$LOTMAXSUM,
    CLIENT_INN = new$CLIENT_INN,
    CLIENT_INN20 = new$CLIENT_INN20,
    CLIENT_NAME = new$CLIENT_NAME,
    EXECUTER_INN = new$EXECUTER_INN,
    EXECUTER_INN20 = new$EXECUTER_INN20,
    EXECUTER_NAME = new$EXECUTER_NAME,
    EXECUTER_STATUS = new$EXECUTER_STATUS,
    EXECUTER_COUNTRY = new$EXECUTER_COUNTRY,
    EXECUTER_ADDRESS = new$EXECUTER_ADDRESS,
    EXECUTER_PHONE = new$EXECUTER_PHONE,
    REALID = new$REALID,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    INNERNUMBER = new$INNERNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REESTRVERSION = new$REESTRVERSION,
    DOCTYPE = new$DOCTYPE,
    RNCLIENTID = new$RNCLIENTID,
    INFONUMBER = new$INFONUMBER,
    STATEORDERINNERNUMBER = new$STATEORDERINNERNUMBER,
    PROGINDEX = new$PROGINDEX,
    NOTE = new$NOTE,
    PURPORTDOC = new$PURPORTDOC,
    REESTRRECORDNUMBER = new$REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS = new$EXECUTERSTOREDPROPS,
    AUTOSANCTION = new$AUTOSANCTION,
    PURCHASECODE = new$PURCHASECODE,
    DOCUMENTNUMBER = new$DOCUMENTNUMBER,
    REJECTCAUSE = new$REJECTCAUSE,
    TENDERREF = new$TENDERREF,
    TENDERINNERNUMBER = new$TENDERINNERNUMBER,
    STOREDCONTENT = new$STOREDCONTENT
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_AGREEMENTS_AU_10)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*   13.0*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update Agreements set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update Agreements set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*          */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 304)or(new$ProgIndex = 314)))then
    update Estimate
    set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    (RecordIndex = new$Id);
  END IF;
  /*         */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 305) or (new$ProgIndex = 314))) then
    update paymentschedule set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    AgreementRef = new$ID and
    ProgIndex in (317, 318);
  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_AGREEMENTS_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*      */
  if ((new$ProgIndex = 305) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null
    where
    StateOrder = :old.ID;
  END IF;
  /*      */
  if ((new$ProgIndex = 314) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null,
    Agreement = null
    where
    StateOrder = :old.ID;
  END IF;
  /*     */
  if ((:old.ProgIndex = 304) and (new$AdjustmentNumber = 0) and (new$Accepted = 0) and
  (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    Agreement = null
    where
    Agreement = :old.ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_AGREEMENTS_AU_30)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$ProgIndex = 304) or (new$ProgIndex = 314)) and
  ((new$Accepted <> :old.Accepted) or
  (new$AcceptDate is not null and :old.AcceptDate is null) or
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where AgreementRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_AGREEMENTS_AU_500)
-- Create 28.04.2005
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes
                  (TableID, RecordId, DeleteDate
                  )
           VALUES (110, :OLD.ID, SYSDATE
                  );

      DELETE FROM DelRecIndexes
            WHERE (TableID = 110) AND (RecordId = new$ID);
   END IF;

END;
/
DELETE FROM SqlExceptions WHERE UPPER(Name) = UPPER('EX_PRIMARYDOCHASADJUSTMENT')
/
commit
/

-- #########################################################
-- #########################################################
-- Add_CreateUser_MailMessages.sql
-- #########################################################
-- #########################################################

ALTER TABLE RemoteMailMessages ADD (
  CreaterUser VARCHAR2(30),
  Updatedate DATE,
  UpdaterUser VARCHAR2(30)
)
/
commit work 
/
-- CREATE TRIGGER Tr_RemoteMailMessages_bi_500
CREATE OR REPLACE TRIGGER TR_REMOTEMAILMESSAGES_BI
  BEFORE INSERT
  ON REMOTEMAILMESSAGES
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_REMOTEMAILMESSAGES_BI)
-- - - - - - - - - - - - -

  if (:new.ID is null) then select g_Shared.NextVal into :new.ID from dual; end if;

-- - - - - - - - - - - - -
-- BI_500 (TR_REMOTEMAILMESSAGES_BI_500)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  :new.createdate := SYSDATE;
  :new.CreaterUser := User;

END;
/
-- CREATE TRIGGER TR_RemoteMailMessages_BU_500
CREATE OR REPLACE TRIGGER TR_RemoteMailMessages_BU_500
  BEFORE UPDATE
  ON REMOTEMAILMESSAGES
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_RemoteMailMessages_BU_500)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  :new.Updatedate := SYSDATE;
  :new.CreaterUser := User;

END;
/





-- #########################################################
-- #########################################################
-- Fix_Grant1300.sql
-- #########################################################
-- #########################################################

/*   13.00  */
GRANT SELECT, INSERT, UPDATE ON EPBSEXPORTLOGCAPTION TO BUDGET_USERS
/
GRANT SELECT, INSERT, UPDATE ON EPBSExportLogDetail TO BUDGET_USERS
/
GRANT SELECT, INSERT, UPDATE ON OOS_ATTACHMENTS TO BUDGET_USERS
/
GRANT SELECT, INSERT, UPDATE ON SysNotify TO BUDGET_USERS
/
GRANT SELECT, INSERT, UPDATE ON SysNotifyHit TO BUDGET_USERS
/
COMMIT WORK 
/


-- #########################################################
-- #########################################################
-- GRANT_OOS_Attachments.sql
-- #########################################################
-- #########################################################


GRANT ALL ON OOS_ATTACHMENTS TO PUBLIC
/

commit work
/




-- #########################################################
-- #########################################################
-- Fix_BudStruct_TargetCls_Unique.sql
-- #########################################################
-- #########################################################

/*   TR_BUDSTRUCT_BI_100, TR_BUDSTRUCT_BU_100. 
         (TargetCls).
*/
-- ALTER TRIGGER TR_BUDSTRUCT_BI_100
CREATE OR REPLACE TRIGGER TR_BUDSTRUCT_II
  INSTEAD OF INSERT
  ON BUDSTRUCT
  FOR EACH ROW
DECLARE
  new$ID BUDSTRUCT.ID%TYPE := :NEW.ID;
  new$KFSR BUDSTRUCT.KFSR%TYPE := :NEW.KFSR;
  new$KVSR BUDSTRUCT.KVSR%TYPE := :NEW.KVSR;
  new$KCSR BUDSTRUCT.KCSR%TYPE := :NEW.KCSR;
  new$KVR BUDSTRUCT.KVR%TYPE := :NEW.KVR;
  new$KESR BUDSTRUCT.KESR%TYPE := :NEW.KESR;
  new$SUBKESR BUDSTRUCT.SUBKESR%TYPE := :NEW.SUBKESR;
  new$REGIONCLS BUDSTRUCT.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$FACT BUDSTRUCT.FACT%TYPE := :NEW.FACT;
  new$FINTYPE BUDSTRUCT.FINTYPE%TYPE := :NEW.FINTYPE;
  new$MEANSTYPE BUDSTRUCT.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$ACTUALDATE BUDSTRUCT.ACTUALDATE%TYPE := :NEW.ACTUALDATE;
  new$CREATEDATE BUDSTRUCT.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$CREATERUSER BUDSTRUCT.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATEDATE BUDSTRUCT.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER BUDSTRUCT.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$DIRECTIONCLS BUDSTRUCT.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$BUDGETREF BUDSTRUCT.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$TRANSFERTCLS BUDSTRUCT.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$STARTDATE BUDSTRUCT.STARTDATE%TYPE := :NEW.STARTDATE;
  new$ISLIMITSPEND BUDSTRUCT.ISLIMITSPEND%TYPE := :NEW.ISLIMITSPEND;
  new$BUDALLOCATIONCLS BUDSTRUCT.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS BUDSTRUCT.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$SUBSIDYCLS BUDSTRUCT.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$ASSIGNMENTKIND BUDSTRUCT.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$TARGETCLS BUDSTRUCT.TARGETCLS%TYPE := :NEW.TARGETCLS;
--
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_BUDSTRUCT_BI_0)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$BudgetRef is null) then
    new$BudgetRef := 0;
  END IF;
  if (new$KVSR is null) then
    new$KVSR := 0;
  END IF;
  if (new$KCSR is null) then
    new$KCSR := 0;
  END IF;
  if (new$KFSR is null) then
    new$KFSR := 0;
  END IF;
  if (new$KVR is null) then
    new$KVR := 0;
  END IF;
  if (new$KESR is null) then
    new$KESR := 0;
  END IF;
  if (new$SubKESR is null) then
    new$SubKESR := 0;
  END IF;
  if (new$RegionCls is null) then
    new$RegionCls := 0;
  END IF;
  if (new$DirectionCls is null) then
    new$DirectionCls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$FinType is null) then
    new$FinType := 0;
  END IF;
  if (new$MeansType is null) then
    new$MeansType := 0;
  END IF;
  if (new$AssignMentKind is null) then
    new$AssignMentKind := 0;
  END IF;
  if (new$IsLimitSpend is null) then
    new$IsLimitSpend := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (tr_budstruct_bi_100)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(id ) INTO CNT$1
  from BudStruct
  where
  (        (BUDGETREF = new$BUDGETREF) and
  (KFSR = new$KFSR) and
  (KVSR = new$KVSR) and
  (KCSR = new$KCSR) and
  (KVR = new$KVR) and
  (KESR = new$KESR) and
  (SUBKESR = new$SUBKESR) and
  (REGIONCLS = new$REGIONCLS) and
  (FACT = new$FACT) and
  (FINTYPE = new$FINTYPE) and
  (MEANSTYPE = new$MEANSTYPE) and
  (DIRECTIONCLS = new$DIRECTIONCLS) and
  ((TRANSFERTCLS = new$TRANSFERTCLS) or ((TRANSFERTCLS is null) and (new$TRANSFERTCLS is null))) and
  ((BUDALLOCATIONCLS = new$BUDALLOCATIONCLS) or ((BUDALLOCATIONCLS is null) and (new$BUDALLOCATIONCLS is null))) and
  ((PAYPROMISECLS = new$PAYPROMISECLS) or ((PAYPROMISECLS is null) and (new$PAYPROMISECLS is null))) and
  ((SUBSIDYCLS = new$SUBSIDYCLS) or ((SUBSIDYCLS is null) and (new$SUBSIDYCLS is null))) and
  (ASSIGNMENTKIND = new$ASSIGNMENTKIND) and
  ((TARGETCLS = new$TARGETCLS) or ((TARGETCLS is null) and (new$TARGETCLS is null)))
  ) AND (ROWNUM = 1)      ;
  if ((CNT$1<> 0))
  then
    RaiseException('EX_BUDSTRUCT_UNIQUE');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_BUDSTRUCT_BI_500)
-- Last update 22.02.2004
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_BUDSTRUCT (
    ID,
    KFSR,
    KVSR,
    KCSR,
    KVR,
    KESR,
    SUBKESR,
    REGIONCLS,
    FACT,
    FINTYPE,
    MEANSTYPE,
    ACTUALDATE,
    CREATEDATE,
    CREATERUSER,
    UPDATEDATE,
    UPDATERUSER,
    DIRECTIONCLS,
    BUDGETREF,
    TRANSFERTCLS,
    STARTDATE,
    ISLIMITSPEND,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    SUBSIDYCLS,
    ASSIGNMENTKIND,
    TARGETCLS
  ) VALUES (
    new$ID,
    new$KFSR,
    new$KVSR,
    new$KCSR,
    new$KVR,
    new$KESR,
    new$SUBKESR,
    new$REGIONCLS,
    new$FACT,
    new$FINTYPE,
    new$MEANSTYPE,
    new$ACTUALDATE,
    new$CREATEDATE,
    new$CREATERUSER,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$DIRECTIONCLS,
    new$BUDGETREF,
    new$TRANSFERTCLS,
    new$STARTDATE,
    new$ISLIMITSPEND,
    new$BUDALLOCATIONCLS,
    new$PAYPROMISECLS,
    new$SUBSIDYCLS,
    new$ASSIGNMENTKIND,
    new$TARGETCLS);

END;
/
-- ALTER TRIGGER TR_BUDSTRUCT_BU_100
CREATE OR REPLACE TRIGGER TR_BUDSTRUCT_IU
  INSTEAD OF UPDATE
  ON BUDSTRUCT
  FOR EACH ROW
DECLARE
  new$ID BUDSTRUCT.ID%TYPE := :NEW.ID;
  new$KFSR BUDSTRUCT.KFSR%TYPE := :NEW.KFSR;
  new$KVSR BUDSTRUCT.KVSR%TYPE := :NEW.KVSR;
  new$KCSR BUDSTRUCT.KCSR%TYPE := :NEW.KCSR;
  new$KVR BUDSTRUCT.KVR%TYPE := :NEW.KVR;
  new$KESR BUDSTRUCT.KESR%TYPE := :NEW.KESR;
  new$SUBKESR BUDSTRUCT.SUBKESR%TYPE := :NEW.SUBKESR;
  new$REGIONCLS BUDSTRUCT.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$FACT BUDSTRUCT.FACT%TYPE := :NEW.FACT;
  new$FINTYPE BUDSTRUCT.FINTYPE%TYPE := :NEW.FINTYPE;
  new$MEANSTYPE BUDSTRUCT.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$ACTUALDATE BUDSTRUCT.ACTUALDATE%TYPE := :NEW.ACTUALDATE;
  new$CREATEDATE BUDSTRUCT.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$CREATERUSER BUDSTRUCT.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATEDATE BUDSTRUCT.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER BUDSTRUCT.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$DIRECTIONCLS BUDSTRUCT.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$BUDGETREF BUDSTRUCT.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$TRANSFERTCLS BUDSTRUCT.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$STARTDATE BUDSTRUCT.STARTDATE%TYPE := :NEW.STARTDATE;
  new$ISLIMITSPEND BUDSTRUCT.ISLIMITSPEND%TYPE := :NEW.ISLIMITSPEND;
  new$BUDALLOCATIONCLS BUDSTRUCT.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS BUDSTRUCT.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$SUBSIDYCLS BUDSTRUCT.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$ASSIGNMENTKIND BUDSTRUCT.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$TARGETCLS BUDSTRUCT.TARGETCLS%TYPE := :NEW.TARGETCLS;
--
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDSTRUCT_BU_0)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (new$BudgetRef is null) then
    new$BudgetRef := 0;
  END IF;
  if (new$KVSR is null) then
    new$KVSR := 0;
  END IF;
  if (new$KCSR is null) then
    new$KCSR := 0;
  END IF;
  if (new$KFSR is null) then
    new$KFSR := 0;
  END IF;
  if (new$KVR is null) then
    new$KVR := 0;
  END IF;
  if (new$KESR is null) then
    new$KESR := 0;
  END IF;
  if (new$SubKESR is null) then
    new$SubKESR := 0;
  END IF;
  if (new$RegionCls is null) then
    new$RegionCls := 0;
  END IF;
  if (new$DirectionCls is null) then
    new$DirectionCls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$FinType is null) then
    new$FinType := 0;
  END IF;
  if (new$MeansType is null) then
    new$MeansType := 0;
  END IF;
  if (new$AssignMentKind is null) then
    new$AssignMentKind := 0;
  END IF;
  if (new$IsLimitSpend is null) then
    new$IsLimitSpend := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (tr_budstruct_bu_100)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(id ) INTO CNT$1
  from BudStruct
  where
  (        (BUDGETREF = new$BUDGETREF) and
  (KFSR = new$KFSR) and
  (KVSR = new$KVSR) and
  (KCSR = new$KCSR) and
  (KVR = new$KVR) and
  (KESR = new$KESR) and
  (SUBKESR = new$SUBKESR) and
  (REGIONCLS = new$REGIONCLS) and
  (FACT = new$FACT) and
  (FINTYPE = new$FINTYPE) and
  (MEANSTYPE = new$MEANSTYPE) and
  (DIRECTIONCLS = new$DIRECTIONCLS) and
  ((TRANSFERTCLS = new$TRANSFERTCLS) or ((TRANSFERTCLS is null) and (new$TRANSFERTCLS is null))) and
  ((BUDALLOCATIONCLS = new$BUDALLOCATIONCLS) or ((BUDALLOCATIONCLS is null) and (new$BUDALLOCATIONCLS is null))) and
  ((PAYPROMISECLS = new$PAYPROMISECLS) or ((PAYPROMISECLS is null) and (new$PAYPROMISECLS is null))) and
  ((SUBSIDYCLS = new$SUBSIDYCLS) or ((SUBSIDYCLS is null) and (new$SUBSIDYCLS is null))) and
  (ASSIGNMENTKIND = new$ASSIGNMENTKIND) and
  ((TARGETCLS = new$TARGETCLS) or ((TARGETCLS is null) and (new$TARGETCLS is null))) and
  (id <> :old.id)
  ) AND (ROWNUM = 1)      ;
  if ((CNT$1<> 0))
  then
    RaiseException('EX_BUDSTRUCT_UNIQUE');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_BUDSTRUCT SET
    ID = new$ID,
    KFSR = new$KFSR,
    KVSR = new$KVSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    KESR = new$KESR,
    SUBKESR = new$SUBKESR,
    REGIONCLS = new$REGIONCLS,
    FACT = new$FACT,
    FINTYPE = new$FINTYPE,
    MEANSTYPE = new$MEANSTYPE,
    ACTUALDATE = new$ACTUALDATE,
    CREATEDATE = new$CREATEDATE,
    CREATERUSER = new$CREATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    DIRECTIONCLS = new$DIRECTIONCLS,
    BUDGETREF = new$BUDGETREF,
    TRANSFERTCLS = new$TRANSFERTCLS,
    STARTDATE = new$STARTDATE,
    ISLIMITSPEND = new$ISLIMITSPEND,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    PAYPROMISECLS = new$PAYPROMISECLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    ASSIGNMENTKIND = new$ASSIGNMENTKIND,
    TARGETCLS = new$TARGETCLS
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_BUDSTRUCT_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (141, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=141) and (RecordId=new$ID);
  end if;

END;
/
commit work 
/

-- #########################################################
-- #########################################################
-- Alter_AnalyticalGroupTables_NSI.sql
-- #########################################################
-- #########################################################

/*      .   */
ALTER TABLE analyticalgroupifs DROP CONSTRAINT UQ_ANALYTICALGROUPIFS DROP INDEX
/
ALTER TABLE analyticalgroupkd DROP CONSTRAINT UQ_ANALYTICALGROUPKD DROP INDEX
/
ALTER TABLE analyticalgroupifs ADD (
  Extrootid VARCHAR2(50),/*   */
  constraint Uk_analyticalgroupifs_Ver_Key unique (Code, Budgetref, Extid)
)
/
ALTER TABLE analyticalgroupkd ADD (
  Extrootid VARCHAR2(50),/*   */
  constraint Uk_analyticalgroupkd_Ver_Key unique (Code, Budgetref, Extid)
)
/
commit work 
/

-- #########################################################
-- #########################################################
-- alter_RejectCls_Add_DateClose_ora.sql
-- #########################################################
-- #########################################################


/* <TRANS_COMMAND>
ALTER TABLE REJECTCLS
  ADD (DELETEDATE Date, STARTDATE Date)
/
COMMIT WORK
/
*/
-- <TRANS_IGNORE>

DECLARE 
  v_exists integer;
BEGIN
  SELECT count(*) 
    INTO v_exists
    FROM USER_TAB_COLUMNS 
    WHERE TABLE_NAME='REJECTCLS' AND COLUMN_NAME='DELETEDATE';
  IF (v_exists=0) THEN
    EXECUTE IMMEDIATE 'ALTER TABLE REJECTCLS
      ADD (DELETEDATE Date, STARTDATE Date)';
    EXECUTE IMMEDIATE 'COMMIT WORK';
  END IF;
END;
/



-- #########################################################
-- #########################################################
-- Alter_facialacc_cls_NSI.sql
-- #########################################################
-- #########################################################

/*          facialacc_cls */
ALTER TABLE TB_facialacc_cls ADD (
  Extid VARCHAR2(50),/*        */
  Extrootid VARCHAR2(50)/*   */
)
/

CREATE OR REPLACE VIEW facialacc_cls (
  ID,
  CODE1,
  CODE2,
  CODE3,
  CODE4,
  KVSR,
  KCSR,
  KFSR,
  KVR,
  KESR,
  FINTYPE,
  ORG_REF,
  DATEOPEN,
  SERVICEACCOUNT,
  STATUSACCOUNT,
  HARACTERACCOUNT,
  REGIONCLS,
  CREATEDATE,
  UPDATEDATE,
  FACIALCODE,
  MEANSTYPE,
  GENERALORG_REF,
  DEPARTMENTCLS,
  RVERSION,
  CLOSEDOCNUMBER,
  HIGHERORG_REF,
  BUDGETREF,
  FCACCOUNT,
  CLOSECODE,
  DATECLOSE,
  CREATERUSER,
  UPDATERUSER,
  NOTE,
  NAME,
  ISRBS,
  ISPBS,
  ISBU,
  ISSEPARATEBU,
  ISPROXY,
  OPENDOCNUMBER,
  ISOMS,
  CHANGEDOCNUMBER,
  DATECHANGE,
  GENERALORGFACIALACC,
  GRANTEEORG_REF,
  PREVCLS,
  FACIALCODEEX,
  EXTID,
  EXTROOTID)
AS
  SELECT
    ID,
    CODE1,
    CODE2,
    CODE3,
    CODE4,
    KVSR,
    KCSR,
    KFSR,
    KVR,
    KESR,
    FINTYPE,
    ORG_REF,
    DATEOPEN,
    SERVICEACCOUNT,
    STATUSACCOUNT,
    HARACTERACCOUNT,
    REGIONCLS,
    CREATEDATE,
    UPDATEDATE,
    FACIALCODE,
    MEANSTYPE,
    GENERALORG_REF,
    DEPARTMENTCLS,
    RVERSION,
    CLOSEDOCNUMBER,
    HIGHERORG_REF,
    BUDGETREF,
    FCACCOUNT,
    CLOSECODE,
    DATECLOSE,
    CREATERUSER,
    UPDATERUSER,
    NOTE,
    NAME,
    ISRBS,
    ISPBS,
    ISBU,
    ISSEPARATEBU,
    ISPROXY,
    OPENDOCNUMBER,
    ISOMS,
    CHANGEDOCNUMBER,
    DATECHANGE,
    GENERALORGFACIALACC,
    GRANTEEORG_REF,
    PREVCLS,
    FACIALCODEEX,
    EXTID,
    EXTROOTID
  FROM TB_facialacc_cls
/

CREATE OR REPLACE TRIGGER TR_FACIALACC_CLS_ID
  INSTEAD OF DELETE
  ON FACIALACC_CLS
  FOR EACH ROW
DECLARE
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (facialacc_cls_bd0)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(CONSTVALUE ) INTO CNT$1
  from INTCONST where ((CONSTVALUE = :old.id)) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    RaiseException('EX_CANNOTDELETE_FACIAL_ACC');
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_FACIALACC_CLS
  WHERE ID = :OLD.ID
       AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AD_500 (TR_FACIALACC_CLS_AD_500)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
     VALUES (19, :OLD.ID, SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALACC_CLS_II
  INSTEAD OF INSERT
  ON FACIALACC_CLS
  FOR EACH ROW
DECLARE
  new$ID FACIALACC_CLS.ID%TYPE := :NEW.ID;
  new$CODE1 FACIALACC_CLS.CODE1%TYPE := :NEW.CODE1;
  new$CODE2 FACIALACC_CLS.CODE2%TYPE := :NEW.CODE2;
  new$CODE3 FACIALACC_CLS.CODE3%TYPE := :NEW.CODE3;
  new$CODE4 FACIALACC_CLS.CODE4%TYPE := :NEW.CODE4;
  new$KVSR FACIALACC_CLS.KVSR%TYPE := :NEW.KVSR;
  new$KCSR FACIALACC_CLS.KCSR%TYPE := :NEW.KCSR;
  new$KFSR FACIALACC_CLS.KFSR%TYPE := :NEW.KFSR;
  new$KVR FACIALACC_CLS.KVR%TYPE := :NEW.KVR;
  new$KESR FACIALACC_CLS.KESR%TYPE := :NEW.KESR;
  new$FINTYPE FACIALACC_CLS.FINTYPE%TYPE := :NEW.FINTYPE;
  new$ORG_REF FACIALACC_CLS.ORG_REF%TYPE := :NEW.ORG_REF;
  new$DATEOPEN FACIALACC_CLS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$SERVICEACCOUNT FACIALACC_CLS.SERVICEACCOUNT%TYPE := :NEW.SERVICEACCOUNT;
  new$STATUSACCOUNT FACIALACC_CLS.STATUSACCOUNT%TYPE := :NEW.STATUSACCOUNT;
  new$HARACTERACCOUNT FACIALACC_CLS.HARACTERACCOUNT%TYPE := :NEW.HARACTERACCOUNT;
  new$REGIONCLS FACIALACC_CLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATEDATE FACIALACC_CLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALACC_CLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$FACIALCODE FACIALACC_CLS.FACIALCODE%TYPE := :NEW.FACIALCODE;
  new$MEANSTYPE FACIALACC_CLS.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$GENERALORG_REF FACIALACC_CLS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$DEPARTMENTCLS FACIALACC_CLS.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$RVERSION FACIALACC_CLS.RVERSION%TYPE := :NEW.RVERSION;
  new$CLOSEDOCNUMBER FACIALACC_CLS.CLOSEDOCNUMBER%TYPE := :NEW.CLOSEDOCNUMBER;
  new$HIGHERORG_REF FACIALACC_CLS.HIGHERORG_REF%TYPE := :NEW.HIGHERORG_REF;
  new$BUDGETREF FACIALACC_CLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FCACCOUNT FACIALACC_CLS.FCACCOUNT%TYPE := :NEW.FCACCOUNT;
  new$CLOSECODE FACIALACC_CLS.CLOSECODE%TYPE := :NEW.CLOSECODE;
  new$DATECLOSE FACIALACC_CLS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$CREATERUSER FACIALACC_CLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER FACIALACC_CLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE FACIALACC_CLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME FACIALACC_CLS.NAME%TYPE := :NEW.NAME;
  new$ISRBS FACIALACC_CLS.ISRBS%TYPE := :NEW.ISRBS;
  new$ISPBS FACIALACC_CLS.ISPBS%TYPE := :NEW.ISPBS;
  new$ISBU FACIALACC_CLS.ISBU%TYPE := :NEW.ISBU;
  new$ISSEPARATEBU FACIALACC_CLS.ISSEPARATEBU%TYPE := :NEW.ISSEPARATEBU;
  new$ISPROXY FACIALACC_CLS.ISPROXY%TYPE := :NEW.ISPROXY;
  new$OPENDOCNUMBER FACIALACC_CLS.OPENDOCNUMBER%TYPE := :NEW.OPENDOCNUMBER;
  new$ISOMS FACIALACC_CLS.ISOMS%TYPE := :NEW.ISOMS;
  new$CHANGEDOCNUMBER FACIALACC_CLS.CHANGEDOCNUMBER%TYPE := :NEW.CHANGEDOCNUMBER;
  new$DATECHANGE FACIALACC_CLS.DATECHANGE%TYPE := :NEW.DATECHANGE;
  new$GENERALORGFACIALACC FACIALACC_CLS.GENERALORGFACIALACC%TYPE := :NEW.GENERALORGFACIALACC;
  new$GRANTEEORG_REF FACIALACC_CLS.GRANTEEORG_REF%TYPE := :NEW.GRANTEEORG_REF;
  new$PREVCLS FACIALACC_CLS.PREVCLS%TYPE := :NEW.PREVCLS;
  new$FACIALCODEEX FACIALACC_CLS.FACIALCODEEX%TYPE := :NEW.FACIALCODEEX;
  new$EXTID FACIALACC_CLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTROOTID FACIALACC_CLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
--
  OrgDateClose$ Number;
  id_org$ NUMBER(10);
  id_reg$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALACC_CLS_BI_0)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  facialacc_clsdiv(new$id,new$code1,new$code2,new$code3,new$code4);
  if (new$kvsr is null) then
    new$kvsr := 0;
  END IF;
  if (new$kcsr is null) then
    new$kcsr := 0;
  END IF;
  if (new$kfsr is null) then
    new$kfsr := 0;
  END IF;
  if (new$kvr is null) then
    new$kvr := 0;
  END IF;
  if (new$kesr is null) then
    new$kesr := 0;
  END IF;
  if (new$fintype is null) then
    new$fintype := 0;
  END IF;
  if (new$meanstype is null) then
    new$meanstype := 0;
  END IF;
  if (new$haracteraccount is null) then
    new$haracteraccount := 0;
  END IF;
  if (new$org_ref is null) then
    new$org_ref := 0; -- ,   select min (...)
  END IF;
  BEGIN

    --     
    select o.generalorg_ref
    into id_org$     from organizations o
    where o.id = new$org_ref
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (id_org$  is null) then
    id_org$ := new$org_ref;
  END IF;
  new$generalorg_ref := id_org$;
  BEGIN

    --      
    --  -
    --   --------------------------
    select o.RegionCLS
    into id_reg$     from Organizations o
    where o.ID = new$Org_Ref
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  new$regioncls := id_reg$;

-- - - - - - - - - - - - -
-- BI_100 (TR_FACIALACC_CLS_BI_100)
-- Create 01.12.2005
-- - - - - - - - - - - - -

/*    -    */
   IF (    (   (new$ID = 0)
            OR (new$serviceaccount = 0)
            OR (new$serviceaccount IS NULL)
           )
       AND (new$budgetref IS NULL)
      ) THEN
      new$budgetRef := 0;
   END IF;

   IF (    (new$ID <> 0)
       AND (new$serviceaccount = 1)
       AND ((new$budgetref IS NULL) OR (new$budgetref = 0))
      ) THEN
      getintconst (-1, 3, new$budgetRef);
   END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_FACIALACC_CLS_BI_200)
-- Create 27.07.2007
-- - - - - - - - - - - - -

    if (new$Org_Ref is not null) then
      select DateClose into OrgDateClose$ from organizations where Id = new$Org_ref;
      if (OrgDateClose$ is not null) then
         if ((new$DateClose is null) or (new$DateClose > OrgDateClose$)) then
           new$DateClose := OrgDateClose$;
         end if;
         new$StatusAccount := 1;
         new$CloseCode := 10; /*   */
      end if;
    end if;

    if ((new$DateClose is not null) and (new$StatusAccount = 0)) then
      new$StatusAccount := 1;
      new$CloseCode := 1;
    end if;

    if (new$CloseCode is null) then new$CloseCode := 0; end if;

-- - - - - - - - - - - - -
-- BI_400 (TR_FACIALACC_CLS_BI_400)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$IsRBS is null) then
    if (new$HaracterAccount in (1, 2)) then
      new$IsRBS := 1;

    else
      new$IsRBS := 0;

    END IF;
  END IF;
  if (new$IsPBS is null) then
    if (new$HaracterAccount in (0, 2)) then
      new$IsPBS := 1;

    else
      new$IsPBS := 0;

    END IF;
  END IF;
  if (new$IsBU is null) then
    new$IsBU := 0;
  END IF;
  if (new$IsOMS is null) then
    new$IsOMS := 0;
  END IF;
  if (new$IsSeparateBU is null) then
    new$IsSeparateBU := 0;
  END IF;
  if (new$IsProxy is null) then
    new$IsProxy := 0;
  END IF;
  if ((new$IsRBS + new$IsPBS + new$IsBU + new$IsOMS + new$IsSeparateBU + new$IsProxy) = 0) then
    new$HaracterAccount := 3;

  else
    if ((new$IsBU + new$IsOMS + new$IsSeparateBU + new$IsProxy) > 0) then
      new$HaracterAccount := 0;

    else
      if (new$IsRBS = 1) then
        new$HaracterAccount := new$IsRBS + new$IsPBS;

      else
        new$HaracterAccount := 0;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALACC_CLS_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALACC_CLS (
    ID,
    CODE1,
    CODE2,
    CODE3,
    CODE4,
    KVSR,
    KCSR,
    KFSR,
    KVR,
    KESR,
    FINTYPE,
    ORG_REF,
    DATEOPEN,
    SERVICEACCOUNT,
    STATUSACCOUNT,
    HARACTERACCOUNT,
    REGIONCLS,
    CREATEDATE,
    UPDATEDATE,
    FACIALCODE,
    MEANSTYPE,
    GENERALORG_REF,
    DEPARTMENTCLS,
    RVERSION,
    CLOSEDOCNUMBER,
    HIGHERORG_REF,
    BUDGETREF,
    FCACCOUNT,
    CLOSECODE,
    DATECLOSE,
    CREATERUSER,
    UPDATERUSER,
    NOTE,
    NAME,
    ISRBS,
    ISPBS,
    ISBU,
    ISSEPARATEBU,
    ISPROXY,
    OPENDOCNUMBER,
    ISOMS,
    CHANGEDOCNUMBER,
    DATECHANGE,
    GENERALORGFACIALACC,
    GRANTEEORG_REF,
    PREVCLS,
    FACIALCODEEX,
    EXTID,
    EXTROOTID
  ) VALUES (
    new$ID,
    new$CODE1,
    new$CODE2,
    new$CODE3,
    new$CODE4,
    new$KVSR,
    new$KCSR,
    new$KFSR,
    new$KVR,
    new$KESR,
    new$FINTYPE,
    new$ORG_REF,
    new$DATEOPEN,
    new$SERVICEACCOUNT,
    new$STATUSACCOUNT,
    new$HARACTERACCOUNT,
    new$REGIONCLS,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$FACIALCODE,
    new$MEANSTYPE,
    new$GENERALORG_REF,
    new$DEPARTMENTCLS,
    new$RVERSION,
    new$CLOSEDOCNUMBER,
    new$HIGHERORG_REF,
    new$BUDGETREF,
    new$FCACCOUNT,
    new$CLOSECODE,
    new$DATECLOSE,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$NOTE,
    new$NAME,
    new$ISRBS,
    new$ISPBS,
    new$ISBU,
    new$ISSEPARATEBU,
    new$ISPROXY,
    new$OPENDOCNUMBER,
    new$ISOMS,
    new$CHANGEDOCNUMBER,
    new$DATECHANGE,
    new$GENERALORGFACIALACC,
    new$GRANTEEORG_REF,
    new$PREVCLS,
    new$FACIALCODEEX,
    new$EXTID,
    new$EXTROOTID);

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALACC_CLS_AI_500)
-- Last update 15.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 19) AND (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALACC_CLS_IU
  INSTEAD OF UPDATE
  ON FACIALACC_CLS
  FOR EACH ROW
DECLARE
  new$ID FACIALACC_CLS.ID%TYPE := :NEW.ID;
  new$CODE1 FACIALACC_CLS.CODE1%TYPE := :NEW.CODE1;
  new$CODE2 FACIALACC_CLS.CODE2%TYPE := :NEW.CODE2;
  new$CODE3 FACIALACC_CLS.CODE3%TYPE := :NEW.CODE3;
  new$CODE4 FACIALACC_CLS.CODE4%TYPE := :NEW.CODE4;
  new$KVSR FACIALACC_CLS.KVSR%TYPE := :NEW.KVSR;
  new$KCSR FACIALACC_CLS.KCSR%TYPE := :NEW.KCSR;
  new$KFSR FACIALACC_CLS.KFSR%TYPE := :NEW.KFSR;
  new$KVR FACIALACC_CLS.KVR%TYPE := :NEW.KVR;
  new$KESR FACIALACC_CLS.KESR%TYPE := :NEW.KESR;
  new$FINTYPE FACIALACC_CLS.FINTYPE%TYPE := :NEW.FINTYPE;
  new$ORG_REF FACIALACC_CLS.ORG_REF%TYPE := :NEW.ORG_REF;
  new$DATEOPEN FACIALACC_CLS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$SERVICEACCOUNT FACIALACC_CLS.SERVICEACCOUNT%TYPE := :NEW.SERVICEACCOUNT;
  new$STATUSACCOUNT FACIALACC_CLS.STATUSACCOUNT%TYPE := :NEW.STATUSACCOUNT;
  new$HARACTERACCOUNT FACIALACC_CLS.HARACTERACCOUNT%TYPE := :NEW.HARACTERACCOUNT;
  new$REGIONCLS FACIALACC_CLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATEDATE FACIALACC_CLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALACC_CLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$FACIALCODE FACIALACC_CLS.FACIALCODE%TYPE := :NEW.FACIALCODE;
  new$MEANSTYPE FACIALACC_CLS.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$GENERALORG_REF FACIALACC_CLS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$DEPARTMENTCLS FACIALACC_CLS.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$RVERSION FACIALACC_CLS.RVERSION%TYPE := :NEW.RVERSION;
  new$CLOSEDOCNUMBER FACIALACC_CLS.CLOSEDOCNUMBER%TYPE := :NEW.CLOSEDOCNUMBER;
  new$HIGHERORG_REF FACIALACC_CLS.HIGHERORG_REF%TYPE := :NEW.HIGHERORG_REF;
  new$BUDGETREF FACIALACC_CLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FCACCOUNT FACIALACC_CLS.FCACCOUNT%TYPE := :NEW.FCACCOUNT;
  new$CLOSECODE FACIALACC_CLS.CLOSECODE%TYPE := :NEW.CLOSECODE;
  new$DATECLOSE FACIALACC_CLS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$CREATERUSER FACIALACC_CLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER FACIALACC_CLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE FACIALACC_CLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME FACIALACC_CLS.NAME%TYPE := :NEW.NAME;
  new$ISRBS FACIALACC_CLS.ISRBS%TYPE := :NEW.ISRBS;
  new$ISPBS FACIALACC_CLS.ISPBS%TYPE := :NEW.ISPBS;
  new$ISBU FACIALACC_CLS.ISBU%TYPE := :NEW.ISBU;
  new$ISSEPARATEBU FACIALACC_CLS.ISSEPARATEBU%TYPE := :NEW.ISSEPARATEBU;
  new$ISPROXY FACIALACC_CLS.ISPROXY%TYPE := :NEW.ISPROXY;
  new$OPENDOCNUMBER FACIALACC_CLS.OPENDOCNUMBER%TYPE := :NEW.OPENDOCNUMBER;
  new$ISOMS FACIALACC_CLS.ISOMS%TYPE := :NEW.ISOMS;
  new$CHANGEDOCNUMBER FACIALACC_CLS.CHANGEDOCNUMBER%TYPE := :NEW.CHANGEDOCNUMBER;
  new$DATECHANGE FACIALACC_CLS.DATECHANGE%TYPE := :NEW.DATECHANGE;
  new$GENERALORGFACIALACC FACIALACC_CLS.GENERALORGFACIALACC%TYPE := :NEW.GENERALORGFACIALACC;
  new$GRANTEEORG_REF FACIALACC_CLS.GRANTEEORG_REF%TYPE := :NEW.GRANTEEORG_REF;
  new$PREVCLS FACIALACC_CLS.PREVCLS%TYPE := :NEW.PREVCLS;
  new$FACIALCODEEX FACIALACC_CLS.FACIALCODEEX%TYPE := :NEW.FACIALCODEEX;
  new$EXTID FACIALACC_CLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTROOTID FACIALACC_CLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
--
  id_org$ NUMBER(10);
  vOrgType$ NUMBER(10);
  id_org1$ NUMBER(10);
  id_reg1$ NUMBER(10);
  DiffCode$ NUMBER(10);
  Code1$ NUMBER(10);
  Code2$ NUMBER(10);
  Code51$ NUMBER(10);
  CodeX$ NUMBER(10);
  vOrgType1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALACC_CLS_BU_0)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$id <> :old.id) then
    facialacc_clsdiv(new$id,new$code1,new$code2,new$code3,new$code4);
  END IF;
  if (new$kvsr is null) then
    new$kvsr := 0;
  END IF;
  if (new$kcsr is null) then
    new$kcsr := 0;
  END IF;
  if (new$kfsr is null) then
    new$kfsr := 0;
  END IF;
  if (new$kvr is null) then
    new$kvr := 0;
  END IF;
  if (new$kesr is null) then
    new$kesr := 0;
  END IF;
  if (new$fintype is null) then
    new$fintype := 0;
  END IF;
  if (new$regioncls is null) then
    new$regioncls := 0;
  END IF;
  if (new$meanstype is null) then
    new$meanstype := 0;
  END IF;
  if (new$haracteraccount is null) then
    new$haracteraccount := 0;
  END IF;
  if (new$org_ref is null) then
    new$org_ref := 0; -- ,   select min (...)
  END IF;
  if ((new$org_ref <> :old.org_ref) and not(new$fcaccount is null)) then
    BEGIN
      select org_ref      into id_org1$ from org_accounts
      where id = new$fcaccount
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (id_org1$ <> new$org_ref) then
      new$fcaccount := null;

    END IF;
  END IF;
  if (:old.Org_Ref <> new$Org_Ref) then
    BEGIN
      --   --------------------------
      select o.RegionCLS
      into id_reg1$        from Organizations o
      where o.ID = new$Org_Ref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    --   -----------------

    new$regioncls := id_reg1$;
    BEGIN
      --       /----
      select o.Org_Type
      into vOrgType$      from Organizations o
      where o.ID = :old.Org_Ref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if ((vOrgType$  >= 10800)and(vOrgType$  <= 10900)) then
      update org_accounts
      set facialacc_cls = null
      where facialacc_cls = :old.id;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_FACIALACC_CLS_BU_100)
-- Create 01.12.2005
-- - - - - - - - - - - - -

   IF (    (   (new$ID = 0)
            OR (new$serviceaccount = 0)
            OR (new$serviceaccount IS NULL)
           )
       AND (new$budgetref IS NULL)
      ) THEN
      new$budgetRef := 0;
   END IF;

   IF (    (new$ID <> 0)
       AND (new$serviceaccount = 1)
       AND ((new$budgetref IS NULL) OR (new$budgetref = 0))
      ) THEN
      getintconst (-1, 3, new$budgetRef);
   END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALACC_CLS_BU_200)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /* /  ??     ??   AU   */
  if ((((new$DateClose is not null) and (:old.DateClose is null)) or
  ((new$DateClose is null) and (:old.DateClose is not null)))
  and (new$CloseCode = :old.CloseCode))
  then
    BEGIN
      /*      /    .
                / ??    ?
          */
      select o.Org_Type     into vOrgType1$ from Organizations o where o.id = new$org_ref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if ((vOrgType1$  >= 10800)and(vOrgType1$  <= 10900)) then
      if (new$DateClose is not null or (new$statusaccount = 1 and :old.statusaccount=0))
      then
        update org_accounts set
        CloseCode = CloseCode + 10000,
        DateClose = new$DateClose
        where facialacc_cls = new$id;

      END IF;
      if (new$DateClose is null or (new$statusaccount = 0 and :old.statusaccount=1))
      then
        update org_accounts set
        CloseCode = CloseCode - 10000
        where facialacc_cls = new$id;

      END IF;
    END IF;
    if (new$DateClose is not null) then
      new$CloseCode := 1;
    END IF;
    if (new$DateClose is null) then
      new$CloseCode := 0;

    END IF;
  END IF;

  /* /   (only      ) */
  if (new$CloseCode <> :old.CloseCode)
  then
    DiffCode$ := new$CloseCode - :old.CloseCode; /* >0 -  , <0 -  */
    CloseOrgCls_Div(:old.CloseCode,Code1$, Code2$, CodeX$, CodeX$, Code51$);

    /*   "" */
    if (DiffCode$ = 1) then
      Code1$ := 1;
    END IF;
    if (DiffCode$ = 10) then
      Code2$ := 1;
    END IF;
    if (DiffCode$ = 10000) then
      Code51$ := 1;
    END IF;
    if (DiffCode$ = -1) then
      Code1$ := 0;
    END IF;
    if (DiffCode$ = -10) then
      Code2$ := 0;
    END IF;
    if (DiffCode$ = -10000) then
      Code51$ := 0;
    END IF;
    new$CloseCode := Code1$ + Code2$*10 + Code51$*10000;

    if (new$CloseCode <> 0) then
      new$StatusAccount := 1;
    END IF;

    /*     ??      -  - !*/
    if (((new$CloseCode <> 0) and (new$DateClose is null)) or (new$DateClose >= :old.DateClose)) then
      new$DateClose := :old.DateClose;

    else
      if (new$CloseCode = 0) then
        new$DateClose := null;
        if (new$StatusAccount <> 0) then
          new$StatusAccount := 0;

        END IF;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (TR_FACIALACC_CLS_BU_400)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$IsRBS is null) then
    if (new$HaracterAccount in (1, 2)) then
      new$IsRBS := 1;

    else
      new$IsRBS := 0;

    END IF;
  END IF;
  if (new$IsPBS is null) then
    if (new$HaracterAccount in (0, 2)) then
      new$IsPBS := 1;

    else
      new$IsPBS := 0;

    END IF;
  END IF;
  if (new$IsBU is null) then
    new$IsBU := 0;
  END IF;
  if (new$IsOMS is null) then
    new$IsOMS := 0;
  END IF;
  if (new$IsSeparateBU is null) then
    new$IsSeparateBU := 0;
  END IF;
  if (new$IsProxy is null) then
    new$IsProxy := 0;
  END IF;
  if ((new$IsRBS + new$IsPBS + new$IsBU + new$IsOMS + new$IsSeparateBU + new$IsProxy) = 0) then
    new$HaracterAccount := 3;

  else
    if ((new$IsBU + new$IsOMS + new$IsSeparateBU + new$IsProxy) > 0) then
      new$HaracterAccount := 0;

    else
      if (new$IsRBS = 1) then
        new$HaracterAccount := new$IsRBS + new$IsPBS;

      else
        new$HaracterAccount := 0;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_550 (TR_FACIALACC_CLS_BU_550)
-- Last update 15.05.2005
-- - - - - - - - - - - - -

   IF ((new$GeneralOrg_ref IS NULL)or(new$Org_Ref <> :old.Org_Ref)) THEN
     select
       o.GeneralOrg_Ref
     into
       id_org$
     from
       Organizations o
     where
       o.id = new$Org_Ref;
      /*      */
     if (id_org$ is Null)
       then id_org$ := new$Org_Ref;
     end if;
     new$GeneralOrg_ref := id_org$;

   END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALACC_CLS_BU_700)
-- Create 19.09.2004
-- Last update 15.05.2005
-- - - - - - - - - - - - -

   IF (NEW$RVersion IS NULL) THEN
      NEW$RVersion := 1;
   ELSIF ((NEW$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      NEW$RVersion := :OLD.RVersion;
   ELSE
      NEW$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALACC_CLS SET
    ID = new$ID,
    CODE1 = new$CODE1,
    CODE2 = new$CODE2,
    CODE3 = new$CODE3,
    CODE4 = new$CODE4,
    KVSR = new$KVSR,
    KCSR = new$KCSR,
    KFSR = new$KFSR,
    KVR = new$KVR,
    KESR = new$KESR,
    FINTYPE = new$FINTYPE,
    ORG_REF = new$ORG_REF,
    DATEOPEN = new$DATEOPEN,
    SERVICEACCOUNT = new$SERVICEACCOUNT,
    STATUSACCOUNT = new$STATUSACCOUNT,
    HARACTERACCOUNT = new$HARACTERACCOUNT,
    REGIONCLS = new$REGIONCLS,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    FACIALCODE = new$FACIALCODE,
    MEANSTYPE = new$MEANSTYPE,
    GENERALORG_REF = new$GENERALORG_REF,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    RVERSION = new$RVERSION,
    CLOSEDOCNUMBER = new$CLOSEDOCNUMBER,
    HIGHERORG_REF = new$HIGHERORG_REF,
    BUDGETREF = new$BUDGETREF,
    FCACCOUNT = new$FCACCOUNT,
    CLOSECODE = new$CLOSECODE,
    DATECLOSE = new$DATECLOSE,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    NAME = new$NAME,
    ISRBS = new$ISRBS,
    ISPBS = new$ISPBS,
    ISBU = new$ISBU,
    ISSEPARATEBU = new$ISSEPARATEBU,
    ISPROXY = new$ISPROXY,
    OPENDOCNUMBER = new$OPENDOCNUMBER,
    ISOMS = new$ISOMS,
    CHANGEDOCNUMBER = new$CHANGEDOCNUMBER,
    DATECHANGE = new$DATECHANGE,
    GENERALORGFACIALACC = new$GENERALORGFACIALACC,
    GRANTEEORG_REF = new$GRANTEEORG_REF,
    PREVCLS = new$PREVCLS,
    FACIALCODEEX = new$FACIALCODEEX,
    EXTID = new$EXTID,
    EXTROOTID = new$EXTROOTID
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALACC_CLS_AU_500)
-- Create 28.04.2005
-- Last update 15.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (19, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
            WHERE (TableID = 19) AND (RecordId = new$ID);
   END IF;

END;
/
commit work 
/

-- #########################################################
-- #########################################################
-- Add_TR_QuotesTitle_JumpHistory.sql
-- #########################################################
-- #########################################################

/*    QuotesTitle , /     . */
-- CREATE TRIGGER TR_QUOTESTITLE_BU_200
CREATE OR REPLACE TRIGGER TR_QUOTESTITLE_IU
  INSTEAD OF UPDATE
  ON QUOTESTITLE
  FOR EACH ROW
DECLARE
  new$ID QUOTESTITLE.ID%TYPE := :NEW.ID;
  new$BUILDDATE QUOTESTITLE.BUILDDATE%TYPE := :NEW.BUILDDATE;
  new$ACCEPTDATE QUOTESTITLE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$INCACCOUNT QUOTESTITLE.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$BUDGETREF QUOTESTITLE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER QUOTESTITLE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE QUOTESTITLE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE QUOTESTITLE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER QUOTESTITLE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$RECORDINDEX QUOTESTITLE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$PROGINDEX QUOTESTITLE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER QUOTESTITLE.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$TYPEOPERATIONCLS QUOTESTITLE.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$RVERSION QUOTESTITLE.RVERSION%TYPE := :NEW.RVERSION;
  new$REESTRDATE QUOTESTITLE.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$REESTRNUMBER QUOTESTITLE.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$SENDERID QUOTESTITLE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID QUOTESTITLE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$FACIALACCCLS QUOTESTITLE.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$REJECTCLS QUOTESTITLE.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS QUOTESTITLE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$STIMATEID QUOTESTITLE.STIMATEID%TYPE := :NEW.STIMATEID;
  new$SUMMA QUOTESTITLE.SUMMA%TYPE := :NEW.SUMMA;
  new$DOCSTATEREF QUOTESTITLE.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$DEPARTMENTCLS QUOTESTITLE.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$DOCCHANGEDATE QUOTESTITLE.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$REJECTCAUSE QUOTESTITLE.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  IsReject$ NUMBER(10);
  DetCount1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (T_QUOTESTITLE_BU)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if (not((new$BudgetRef is null) and (:old.BudgetRef is null))) then
      select count(ID)       into DetCount1$ from Incomes32 where RecordIndex = :old.ID
      ;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  if (new$IncAccount is null) then
    GetDefDFAccRefForBudget(new$BudgetRef,new$IncAccount);
  END IF;
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  if (new$DepartmentCls is null) then
    new$DepartmentCls := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_QUOTESTITLE_BU_200)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  if (new$DOCSTATEREF <> :old.DOCSTATEREF) then
    insert into StateJumpHistory(DocID, BeginStateRef, EndStateRef)
    values(new$id, :old.DOCSTATEREF, new$DOCSTATEREF);
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (T_QUOTESTITLE_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(new$RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(new$RejectCLS is null)) then
    IsReject$ := 0;
  end if;
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = new$ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = new$id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_QUOTESTITLE_BU_700)
-- Create 19.09.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_QUOTESTITLE SET
    ID = new$ID,
    BUILDDATE = new$BUILDDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    INCACCOUNT = new$INCACCOUNT,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    RECORDINDEX = new$RECORDINDEX,
    PROGINDEX = new$PROGINDEX,
    DOCNUMBER = new$DOCNUMBER,
    TYPEOPERATIONCLS = new$TYPEOPERATIONCLS,
    RVERSION = new$RVERSION,
    REESTRDATE = new$REESTRDATE,
    REESTRNUMBER = new$REESTRNUMBER,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    FACIALACCCLS = new$FACIALACCCLS,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    STIMATEID = new$STIMATEID,
    SUMMA = new$SUMMA,
    DOCSTATEREF = new$DOCSTATEREF,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_20 (T_QUOTESTITLE_AU_20)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*    .        */

   /*           / */
   /*       */
   /*     else, ..    null  UNKNOWN,   then  */

      /*    ,     */
      /*     else, ..    null  UNKNOWN,   then  */
      IF (
              /*    /     */
              (new$IncAccount = :OLD.IncAccount)
          AND
              /*    /     */
              (   (new$AcceptDate = :OLD.AcceptDate)
               OR ((new$AcceptDate IS NULL) AND (:OLD.AcceptDate IS NULL))
              )
          AND
              /*    /     */
              (   (new$DocNumber = :OLD.DocNumber)
               OR ((new$DocNumber IS NULL) AND (:OLD.DocNumber IS NULL))
              )
          AND
              /*      */
              (   (new$ReestrNumber = :OLD.ReestrNumber)
               OR ((new$ReestrNumber IS NULL) AND (:OLD.ReestrNumber IS NULL)
                  )
              )
         ) THEN
         /*   */
         NULL;                        /*  new$AcceptDate := :old.AcceptDate; */
      ELSE
         /*      (    )*/
         /*       update Incomes32,   */
         UPDATE Incomes32 i
            SET i.iDate = new$AcceptDate,
                i.IncAccount = new$IncAccount,
                i.RVersion = -1
          WHERE i.RecordIndex = new$ID;
      END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_QUOTESTITLE_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (:NEW.ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes
                  (TableID, RecordId, DeleteDate
                  )
           VALUES (160, :OLD.ID, SYSDATE
                  );

      DELETE FROM DelRecIndexes
            WHERE (TableID = 160) AND (RecordId = :NEW.ID);
   END IF;

END;
/
-- CREATE TRIGGER TR_QUOTESTITLE_AD_200
CREATE OR REPLACE TRIGGER TR_QUOTESTITLE_ID
  INSTEAD OF DELETE
  ON QUOTESTITLE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (T_QUOTESTITLE_BD)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  delete from Incomes32 where (ProgIndex = 45 or ProgIndex =140) and (RecordIndex = :old.ID);

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_QUOTESTITLE
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_200 (TR_QUOTESTITLE_AD_200)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  delete 
  from 
  StateJumpHistory
  where 
  DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_QUOTESTITLE_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordID, DeleteDate, ProgIndex, SUMMA) values (160, :old.ID, SYSDATE, :old.ProgIndex, :old.SUMMA);

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- Add_UQ_DOCLOCKFIELDS_FIELD.sql
-- #########################################################
-- #########################################################

/*       ,    ,   , 
      . ,       DOCLOCKREF, FIELDREF
   DOCLOCKFIELDS,          */
delete from DOCLOCKFIELDS
where id in (
  select dlf.id
  from DOCLOCKFIELDS dlf
  left join (
    select dlf1.DOCLOCKREF, dlf1.FIELDREF, MAX(dlf1.ID) MAXID
    from DOCLOCKFIELDS dlf1
    left join (
      select DOCLOCKREF, FIELDREF, Max(ISSYSTEM) MAXISSYSTEM
      from DOCLOCKFIELDS
      group by DOCLOCKREF, FIELDREF
    ) dlf2 on dlf1.DOCLOCKREF = dlf2.DOCLOCKREF and dlf1.FIELDREF = dlf2.FIELDREF
    where ((dlf1.ISSYSTEM is null) and (dlf2.MAXISSYSTEM is null)) or (dlf1.ISSYSTEM = dlf2.MAXISSYSTEM)
    group by dlf1.DOCLOCKREF, dlf1.FIELDREF
  ) dlf3 on dlf.DOCLOCKREF = dlf3.DOCLOCKREF and dlf.FIELDREF = dlf3.FIELDREF
  where dlf.id <> dlf3.MAXID
) 
/
  
commit work
/
ALTER TABLE DOCLOCKFIELDS ADD (
  constraint UQ_DOCLOCKFIELDS_FIELD unique (DOCLOCKREF, FIELDREF)
)
/
commit work
/

-- #########################################################
-- #########################################################
-- Alter_ClsCorrespondents_NSI.sql
-- #########################################################
-- #########################################################

/*          */
ALTER TABLE ClsCorrespondents ADD (
  Extid VARCHAR2(50),/*        */
  Extrootid VARCHAR2(50),/*   */
  StartDate DATE,/*    */
  DeleteDate DATE/*    */
)
/
commit work 
/

-- #########################################################
-- #########################################################
-- AlterProtocolNames2.sql
-- #########################################################
-- #########################################################

/*           */
CREATE OR REPLACE procedure AddProtocolDocType(ID$ NUMBER,Name$ VARCHAR2,AType$ NUMBER)
AS
  CNT$1 NUMBER(10);
BEGIN
  SELECT COUNT(id ) INTO CNT$1
  from ProtocolDoctype where (id = ID$) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    update ProtocolDocType set Name = Name$, AType = AType$  where id = ID$;
      
  else
    insert into ProtocolDocType(ID, Name, AType) 
    values(ID$, Name$, AType$);
  END IF;
END;
/
-- ALTER TRIGGER TR_ProtocolDocType_BU
CREATE OR REPLACE TRIGGER TR_PROTOCOLDOCTYPE_BU
  BEFORE UPDATE
  ON PROTOCOLDOCTYPE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ProtocolDocType_BU)
-- Version 8.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (not ((:new.id in (7,12)) and (:old.id in (7,12)) and (:new.AType = :old.AType))) then
--     RaiseException('EX_PDT_BanUpdate');
--   END IF;

END;
/
-- ALTER TRIGGER TR_PROTOCOLDOCTYPE_BI
CREATE OR REPLACE TRIGGER TR_PROTOCOLDOCTYPE_BI
  BEFORE INSERT
  ON PROTOCOLDOCTYPE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ProtocolDocType_BI)
-- Create 27.10.2009
-- - - - - - - - - - - - -
  NULL;
--   RaiseException('EX_PDT_BanInsert');

-- - - - - - - - - - - - -
-- BI_500 (TR_PROTOCOLDOCTYPE_BI_500)
-- Create 20.05.2009
-- - - - - - - - - - - - -

    :new.CreateDate := SYSDATE;
    :new.UpdateDate := :new.CreateDate;    

END;
/
CALL AddProtocolDocType(6, '         ', 124)
/
CALL AddProtocolDocType(10, '   ', 124)
/
CALL AddProtocolDocType(11, '    ', 124)
/
CALL AddProtocolDocType(19, '        ', 124)
/
-- ALTER TRIGGER TR_ProtocolDocType_BU
CREATE OR REPLACE TRIGGER TR_PROTOCOLDOCTYPE_BU
  BEFORE UPDATE
  ON PROTOCOLDOCTYPE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ProtocolDocType_BU)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (not ((:new.id in (7,12)) and (:old.id in (7,12)) and (:new.AType = :old.AType))) then
    RaiseException('EX_PDT_BanUpdate');
  END IF;

END;
/
-- ALTER TRIGGER TR_PROTOCOLDOCTYPE_BI
CREATE OR REPLACE TRIGGER TR_PROTOCOLDOCTYPE_BI
  BEFORE INSERT
  ON PROTOCOLDOCTYPE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ProtocolDocType_BI)
-- Create 27.10.2009
-- - - - - - - - - - - - -

  RaiseException('EX_PDT_BanInsert');

-- - - - - - - - - - - - -
-- BI_500 (TR_PROTOCOLDOCTYPE_BI_500)
-- Create 20.05.2009
-- - - - - - - - - - - - -

    :new.CreateDate := SYSDATE;
    :new.UpdateDate := :new.CreateDate;    

END;
/
drop procedure AddProtocolDocType
/
commit work
/

-- #########################################################
-- #########################################################
-- Add_TR_BD_SignCertificate.sql
-- #########################################################
-- #########################################################

-- CREATE TRIGGER tr_signcert_bd_400
CREATE OR REPLACE TRIGGER TR_signcertificate_BD
  BEFORE DELETE
  ON signcertificate
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (tr_signcert_bd_400)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*      */
  delete from signprofiledetail where certificateref = :old.id;

END;
/
commit work
/


-- #########################################################
-- #########################################################
-- Add20Persent_Ora.sql
-- #########################################################
-- #########################################################


create or replace procedure AddEnumValue(EnumName$ VarChar2, EnumVal$ Number, ValName$ VarChar2)
as
  EnumID$ Number(10);
  cnt$ Number(10);
begin
  select ID into EnumID$
  from Enums where Name = EnumName$;

  if (EnumID$ is not null) then
    select count(*) into cnt$
      from EnumValues where (EnumRef = EnumID$)and(Val = EnumVal$);

    if cnt$ = 0 then
      insert into EnumValues(EnumRef, Val, Name) values (EnumID$, EnumVal$, ValName$);
    else
      Update EnumValues ev set
        ev.Name = ValName$
      where (ev.EnumRef = EnumID$)and(ev.Val = EnumVal$);
    end if;
  end if;
end;
/

call AddEnumValue('', 20, '20,00')
/

drop procedure AddEnumValue
/

commit work
/


-- #########################################################
-- #########################################################
-- Alter_column_placingway_code.sql
-- #########################################################
-- #########################################################

/*   placingway_code  50  */
ALTER TABLE oos_contract_finances MODIFY (placingway_code VARCHAR2(50))
/
COMMIT WORK
/



-- #########################################################
-- #########################################################
-- alter_TransfertCls_ReceiveKESR.sql
-- #########################################################
-- #########################################################

/*    " ()"     */
/*    ReceiveKESR */
-- drop trigger TR_TRANSFERTCLS_BI
CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_II
  INSTEAD OF INSERT
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
  new$EXTROOTID TRANSFERTCLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION TRANSFERTCLS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE TRANSFERTCLS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
--
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_200 (TR_TRANSFERTCLS_BI_200)
-- Version 12.10.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(*) INTO CNT$1
  from TransfertCls t where
  (        (t.ID <> new$ID) and
  (t.CODE=new$CODE) and
  (t.RECEIVEKVSR=new$RECEIVEKVSR) and
  (t.RECEIVEKFSR=new$RECEIVEKFSR) and
  (t.RECEIVEKCSR=new$RECEIVEKCSR) and
  (t.RECEIVEKVR=new$RECEIVEKVR) and
  (t.RECEIVEKESR=new$RECEIVEKESR) and
  (t.RECEIVEKD=new$RECEIVEKD) and
  (t.TRANSFERKVSR=new$TRANSFERKVSR) and
  (t.TRANSFERKFSR=new$TRANSFERKFSR) and
  (t.TRANSFERKCSR=new$TRANSFERKCSR) and
  (t.TRANSFERKVR=new$TRANSFERKVR) and
  (t.TRANSFERKESR=new$TRANSFERKESR) and
  (t.TRANSFERKDVALUE=new$TRANSFERKDVALUE) and
  (t.TARGETMEANSSIGN=new$TARGETMEANSSIGN) and
  (t.REGIONCLS=new$REGIONCLS) and
  (t.DESTLEVEL=new$DESTLEVEL) and
  (t.BUDGETREF=new$BUDGETREF) and
  ((t.EXTID is null and new$EXTID is null) or (t.EXTID = new$EXTID)) and
  (t.FACT=new$FACT)) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    RaiseException('EX_DUPLICATE_TRANSFERT');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_TRANSFERTCLS_BI_500)
-- Create 24.09.2007
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_TRANSFERTCLS (
    ID,
    REGIONCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    CODE,
    RECEIVEKVSR,
    RECEIVEKFSR,
    RECEIVEKVR,
    RECEIVEKESR,
    RECEIVEKD,
    TRANSFERKVSR,
    TRANSFERKFSR,
    TRANSFERKCSR,
    TRANSFERKVR,
    TRANSFERKESR,
    TRANSFERKDVALUE,
    TARGETMEANSSIGN,
    TARGETCLS,
    STARTDATE,
    DELETEDATE,
    NOTE,
    NAME,
    BUDGETREF,
    RECEIVEKCSR,
    SOURCELEVEL,
    DESTLEVEL,
    TRANSFERTKIND,
    GRANTKIND,
    TRANSFERTYEAR,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    FACT,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE
  ) VALUES (
    new$ID,
    new$REGIONCLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$CODE,
    new$RECEIVEKVSR,
    new$RECEIVEKFSR,
    new$RECEIVEKVR,
    new$RECEIVEKESR,
    new$RECEIVEKD,
    new$TRANSFERKVSR,
    new$TRANSFERKFSR,
    new$TRANSFERKCSR,
    new$TRANSFERKVR,
    new$TRANSFERKESR,
    new$TRANSFERKDVALUE,
    new$TARGETMEANSSIGN,
    new$TARGETCLS,
    new$STARTDATE,
    new$DELETEDATE,
    new$NOTE,
    new$NAME,
    new$BUDGETREF,
    new$RECEIVEKCSR,
    new$SOURCELEVEL,
    new$DESTLEVEL,
    new$TRANSFERTKIND,
    new$GRANTKIND,
    new$TRANSFERTYEAR,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$FACT,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE);

-- - - - - - - - - - - - -
-- AI_500 (TR_TRANSFERTCLS_AI_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);

END;
/
-- drop trigger TR_TRANSFERTCLS_BI_200
CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_II
  INSTEAD OF INSERT
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
  new$EXTROOTID TRANSFERTCLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION TRANSFERTCLS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE TRANSFERTCLS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
BEGIN
-- - - - - - - - - - - - -
-- BI_500 (TR_TRANSFERTCLS_BI_500)
-- Create 24.09.2007
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_TRANSFERTCLS (
    ID,
    REGIONCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    CODE,
    RECEIVEKVSR,
    RECEIVEKFSR,
    RECEIVEKVR,
    RECEIVEKESR,
    RECEIVEKD,
    TRANSFERKVSR,
    TRANSFERKFSR,
    TRANSFERKCSR,
    TRANSFERKVR,
    TRANSFERKESR,
    TRANSFERKDVALUE,
    TARGETMEANSSIGN,
    TARGETCLS,
    STARTDATE,
    DELETEDATE,
    NOTE,
    NAME,
    BUDGETREF,
    RECEIVEKCSR,
    SOURCELEVEL,
    DESTLEVEL,
    TRANSFERTKIND,
    GRANTKIND,
    TRANSFERTYEAR,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    FACT,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE
  ) VALUES (
    new$ID,
    new$REGIONCLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$CODE,
    new$RECEIVEKVSR,
    new$RECEIVEKFSR,
    new$RECEIVEKVR,
    new$RECEIVEKESR,
    new$RECEIVEKD,
    new$TRANSFERKVSR,
    new$TRANSFERKFSR,
    new$TRANSFERKCSR,
    new$TRANSFERKVR,
    new$TRANSFERKESR,
    new$TRANSFERKDVALUE,
    new$TARGETMEANSSIGN,
    new$TARGETCLS,
    new$STARTDATE,
    new$DELETEDATE,
    new$NOTE,
    new$NAME,
    new$BUDGETREF,
    new$RECEIVEKCSR,
    new$SOURCELEVEL,
    new$DESTLEVEL,
    new$TRANSFERTKIND,
    new$GRANTKIND,
    new$TRANSFERTYEAR,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$FACT,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE);

-- - - - - - - - - - - - -
-- AI_500 (TR_TRANSFERTCLS_AI_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);

END;
/
-- drop trigger TR_TRANSFERTCLS_BU
CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_IU
  INSTEAD OF UPDATE
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
  new$EXTROOTID TRANSFERTCLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION TRANSFERTCLS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE TRANSFERTCLS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
--
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_100 (TR_TRANSFERTCLS_BU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if ((new$id = 0) and (new$Code <> :old.Code)) then
    RaiseException('EX_CANTMODIFY_ZEROTRANFERTSCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_TRANSFERTCLS_BU_200)
-- Version 12.10.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(*) INTO CNT$1
  from TransfertCls t where
  (        (t.ID <> new$ID) and
  (t.CODE=new$CODE) and
  (t.RECEIVEKVSR=new$RECEIVEKVSR) and
  (t.RECEIVEKFSR=new$RECEIVEKFSR) and
  (t.RECEIVEKCSR=new$RECEIVEKCSR) and
  (t.RECEIVEKVR=new$RECEIVEKVR) and
  (t.RECEIVEKESR=new$RECEIVEKESR) and
  (t.RECEIVEKD=new$RECEIVEKD) and
  (t.TRANSFERKVSR=new$TRANSFERKVSR) and
  (t.TRANSFERKFSR=new$TRANSFERKFSR) and
  (t.TRANSFERKCSR=new$TRANSFERKCSR) and
  (t.TRANSFERKVR=new$TRANSFERKVR) and
  (t.TRANSFERKESR=new$TRANSFERKESR) and
  (t.TRANSFERKDVALUE=new$TRANSFERKDVALUE) and
  (t.TARGETMEANSSIGN=new$TARGETMEANSSIGN) and
  (t.REGIONCLS=new$REGIONCLS) and
  (t.DESTLEVEL=new$DESTLEVEL) and
  (t.BUDGETREF=new$BUDGETREF) and
  ((t.EXTID is null and new$EXTID is null) or (t.EXTID = new$EXTID)) and
  (t.FACT=new$FACT)) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    RaiseException('EX_DUPLICATE_TRANSFERT');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TRANSFERTCLS SET
    ID = new$ID,
    REGIONCLS = new$REGIONCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    CODE = new$CODE,
    RECEIVEKVSR = new$RECEIVEKVSR,
    RECEIVEKFSR = new$RECEIVEKFSR,
    RECEIVEKVR = new$RECEIVEKVR,
    RECEIVEKESR = new$RECEIVEKESR,
    RECEIVEKD = new$RECEIVEKD,
    TRANSFERKVSR = new$TRANSFERKVSR,
    TRANSFERKFSR = new$TRANSFERKFSR,
    TRANSFERKCSR = new$TRANSFERKCSR,
    TRANSFERKVR = new$TRANSFERKVR,
    TRANSFERKESR = new$TRANSFERKESR,
    TRANSFERKDVALUE = new$TRANSFERKDVALUE,
    TARGETMEANSSIGN = new$TARGETMEANSSIGN,
    TARGETCLS = new$TARGETCLS,
    STARTDATE = new$STARTDATE,
    DELETEDATE = new$DELETEDATE,
    NOTE = new$NOTE,
    NAME = new$NAME,
    BUDGETREF = new$BUDGETREF,
    RECEIVEKCSR = new$RECEIVEKCSR,
    SOURCELEVEL = new$SOURCELEVEL,
    DESTLEVEL = new$DESTLEVEL,
    TRANSFERTKIND = new$TRANSFERTKIND,
    GRANTKIND = new$GRANTKIND,
    TRANSFERTYEAR = new$TRANSFERTYEAR,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    FACT = new$FACT,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_TRANSFERTCLS_AU_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  if (new$Id <> :old.Id) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (203, :Old.Id, SYSDATE);
    delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);
  end if;

END;
/
-- drop trigger TR_TRANSFERTCLS_BU_200
CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_IU
  INSTEAD OF UPDATE
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
  new$EXTROOTID TRANSFERTCLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION TRANSFERTCLS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE TRANSFERTCLS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
BEGIN
-- - - - - - - - - - - - -
-- BU_100 (TR_TRANSFERTCLS_BU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if ((new$id = 0) and (new$Code <> :old.Code)) then
    RaiseException('EX_CANTMODIFY_ZEROTRANFERTSCLS');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TRANSFERTCLS SET
    ID = new$ID,
    REGIONCLS = new$REGIONCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    CODE = new$CODE,
    RECEIVEKVSR = new$RECEIVEKVSR,
    RECEIVEKFSR = new$RECEIVEKFSR,
    RECEIVEKVR = new$RECEIVEKVR,
    RECEIVEKESR = new$RECEIVEKESR,
    RECEIVEKD = new$RECEIVEKD,
    TRANSFERKVSR = new$TRANSFERKVSR,
    TRANSFERKFSR = new$TRANSFERKFSR,
    TRANSFERKCSR = new$TRANSFERKCSR,
    TRANSFERKVR = new$TRANSFERKVR,
    TRANSFERKESR = new$TRANSFERKESR,
    TRANSFERKDVALUE = new$TRANSFERKDVALUE,
    TARGETMEANSSIGN = new$TARGETMEANSSIGN,
    TARGETCLS = new$TARGETCLS,
    STARTDATE = new$STARTDATE,
    DELETEDATE = new$DELETEDATE,
    NOTE = new$NOTE,
    NAME = new$NAME,
    BUDGETREF = new$BUDGETREF,
    RECEIVEKCSR = new$RECEIVEKCSR,
    SOURCELEVEL = new$SOURCELEVEL,
    DESTLEVEL = new$DESTLEVEL,
    TRANSFERTKIND = new$TRANSFERTKIND,
    GRANTKIND = new$GRANTKIND,
    TRANSFERTYEAR = new$TRANSFERTYEAR,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    FACT = new$FACT,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_TRANSFERTCLS_AU_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  if (new$Id <> :old.Id) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (203, :Old.Id, SYSDATE);
    delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);
  end if;

END;
/
commit work 
/
ALTER TRIGGER TR_TRANSFERTCLS_BU_500 DISABLE
/
ALTER TABLE TB_TransfertCls ADD (
  TempReceiveKESR VARCHAR2(20)
)
/

CREATE OR REPLACE VIEW TransfertCls (
  ID,
  REGIONCLS,
  CREATERUSER,
  CREATEDATE,
  UPDATERUSER,
  UPDATEDATE,
  CODE,
  RECEIVEKVSR,
  RECEIVEKFSR,
  RECEIVEKVR,
  RECEIVEKESR,
  RECEIVEKD,
  TRANSFERKVSR,
  TRANSFERKFSR,
  TRANSFERKCSR,
  TRANSFERKVR,
  TRANSFERKESR,
  TRANSFERKDVALUE,
  TARGETMEANSSIGN,
  TARGETCLS,
  STARTDATE,
  DELETEDATE,
  NOTE,
  NAME,
  BUDGETREF,
  RECEIVEKCSR,
  SOURCELEVEL,
  DESTLEVEL,
  TRANSFERTKIND,
  GRANTKIND,
  TRANSFERTYEAR,
  EXTID,
  EXTOWNER,
  EXTSYNCDATE,
  FACT,
  EXTROOTID,
  EXTVERSION,
  EXTVERSIONDATE,
  TEMPRECEIVEKESR)
AS
  SELECT
    ID,
    REGIONCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    CODE,
    RECEIVEKVSR,
    RECEIVEKFSR,
    RECEIVEKVR,
    RECEIVEKESR,
    RECEIVEKD,
    TRANSFERKVSR,
    TRANSFERKFSR,
    TRANSFERKCSR,
    TRANSFERKVR,
    TRANSFERKESR,
    TRANSFERKDVALUE,
    TARGETMEANSSIGN,
    TARGETCLS,
    STARTDATE,
    DELETEDATE,
    NOTE,
    NAME,
    BUDGETREF,
    RECEIVEKCSR,
    SOURCELEVEL,
    DESTLEVEL,
    TRANSFERTKIND,
    GRANTKIND,
    TRANSFERTYEAR,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    FACT,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    TEMPRECEIVEKESR
  FROM TB_TransfertCls
/

CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_ID
  INSTEAD OF DELETE
  ON TRANSFERTCLS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_TRANSFERTCLS
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_500 (TR_TRANSFERTCLS_AD_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate)
  values(203,:old.ID,SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_II
  INSTEAD OF INSERT
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
  new$EXTROOTID TRANSFERTCLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION TRANSFERTCLS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE TRANSFERTCLS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$TEMPRECEIVEKESR TRANSFERTCLS.TEMPRECEIVEKESR%TYPE := :NEW.TEMPRECEIVEKESR;
BEGIN
-- - - - - - - - - - - - -
-- BI_500 (TR_TRANSFERTCLS_BI_500)
-- Create 24.09.2007
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_TRANSFERTCLS (
    ID,
    REGIONCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    CODE,
    RECEIVEKVSR,
    RECEIVEKFSR,
    RECEIVEKVR,
    RECEIVEKESR,
    RECEIVEKD,
    TRANSFERKVSR,
    TRANSFERKFSR,
    TRANSFERKCSR,
    TRANSFERKVR,
    TRANSFERKESR,
    TRANSFERKDVALUE,
    TARGETMEANSSIGN,
    TARGETCLS,
    STARTDATE,
    DELETEDATE,
    NOTE,
    NAME,
    BUDGETREF,
    RECEIVEKCSR,
    SOURCELEVEL,
    DESTLEVEL,
    TRANSFERTKIND,
    GRANTKIND,
    TRANSFERTYEAR,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    FACT,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    TEMPRECEIVEKESR
  ) VALUES (
    new$ID,
    new$REGIONCLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$CODE,
    new$RECEIVEKVSR,
    new$RECEIVEKFSR,
    new$RECEIVEKVR,
    new$RECEIVEKESR,
    new$RECEIVEKD,
    new$TRANSFERKVSR,
    new$TRANSFERKFSR,
    new$TRANSFERKCSR,
    new$TRANSFERKVR,
    new$TRANSFERKESR,
    new$TRANSFERKDVALUE,
    new$TARGETMEANSSIGN,
    new$TARGETCLS,
    new$STARTDATE,
    new$DELETEDATE,
    new$NOTE,
    new$NAME,
    new$BUDGETREF,
    new$RECEIVEKCSR,
    new$SOURCELEVEL,
    new$DESTLEVEL,
    new$TRANSFERTKIND,
    new$GRANTKIND,
    new$TRANSFERTYEAR,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$FACT,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$TEMPRECEIVEKESR);

-- - - - - - - - - - - - -
-- AI_500 (TR_TRANSFERTCLS_AI_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_IU
  INSTEAD OF UPDATE
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
  new$EXTROOTID TRANSFERTCLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION TRANSFERTCLS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE TRANSFERTCLS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$TEMPRECEIVEKESR TRANSFERTCLS.TEMPRECEIVEKESR%TYPE := :NEW.TEMPRECEIVEKESR;
BEGIN
-- - - - - - - - - - - - -
-- BU_100 (TR_TRANSFERTCLS_BU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if ((new$id = 0) and (new$Code <> :old.Code)) then
    RaiseException('EX_CANTMODIFY_ZEROTRANFERTSCLS');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TRANSFERTCLS SET
    ID = new$ID,
    REGIONCLS = new$REGIONCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    CODE = new$CODE,
    RECEIVEKVSR = new$RECEIVEKVSR,
    RECEIVEKFSR = new$RECEIVEKFSR,
    RECEIVEKVR = new$RECEIVEKVR,
    RECEIVEKESR = new$RECEIVEKESR,
    RECEIVEKD = new$RECEIVEKD,
    TRANSFERKVSR = new$TRANSFERKVSR,
    TRANSFERKFSR = new$TRANSFERKFSR,
    TRANSFERKCSR = new$TRANSFERKCSR,
    TRANSFERKVR = new$TRANSFERKVR,
    TRANSFERKESR = new$TRANSFERKESR,
    TRANSFERKDVALUE = new$TRANSFERKDVALUE,
    TARGETMEANSSIGN = new$TARGETMEANSSIGN,
    TARGETCLS = new$TARGETCLS,
    STARTDATE = new$STARTDATE,
    DELETEDATE = new$DELETEDATE,
    NOTE = new$NOTE,
    NAME = new$NAME,
    BUDGETREF = new$BUDGETREF,
    RECEIVEKCSR = new$RECEIVEKCSR,
    SOURCELEVEL = new$SOURCELEVEL,
    DESTLEVEL = new$DESTLEVEL,
    TRANSFERTKIND = new$TRANSFERTKIND,
    GRANTKIND = new$GRANTKIND,
    TRANSFERTYEAR = new$TRANSFERTYEAR,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    FACT = new$FACT,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    TEMPRECEIVEKESR = new$TEMPRECEIVEKESR
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_TRANSFERTCLS_AU_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  if (new$Id <> :old.Id) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (203, :Old.Id, SYSDATE);
    delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);
  end if;

END;
/
commit work 
/
update TransfertCls set
  TempReceiveKESR = ReceiveKESR
/
ALTER TABLE TB_TransfertCls DROP (ReceiveKESR)
/

CREATE OR REPLACE VIEW TransfertCls (
  ID,
  REGIONCLS,
  CREATERUSER,
  CREATEDATE,
  UPDATERUSER,
  UPDATEDATE,
  CODE,
  RECEIVEKVSR,
  RECEIVEKFSR,
  RECEIVEKVR,
  RECEIVEKD,
  TRANSFERKVSR,
  TRANSFERKFSR,
  TRANSFERKCSR,
  TRANSFERKVR,
  TRANSFERKESR,
  TRANSFERKDVALUE,
  TARGETMEANSSIGN,
  TARGETCLS,
  STARTDATE,
  DELETEDATE,
  NOTE,
  NAME,
  BUDGETREF,
  RECEIVEKCSR,
  SOURCELEVEL,
  DESTLEVEL,
  TRANSFERTKIND,
  GRANTKIND,
  TRANSFERTYEAR,
  EXTID,
  EXTOWNER,
  EXTSYNCDATE,
  FACT,
  EXTROOTID,
  EXTVERSION,
  EXTVERSIONDATE,
  TEMPRECEIVEKESR)
AS
  SELECT
    ID,
    REGIONCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    CODE,
    RECEIVEKVSR,
    RECEIVEKFSR,
    RECEIVEKVR,
    RECEIVEKD,
    TRANSFERKVSR,
    TRANSFERKFSR,
    TRANSFERKCSR,
    TRANSFERKVR,
    TRANSFERKESR,
    TRANSFERKDVALUE,
    TARGETMEANSSIGN,
    TARGETCLS,
    STARTDATE,
    DELETEDATE,
    NOTE,
    NAME,
    BUDGETREF,
    RECEIVEKCSR,
    SOURCELEVEL,
    DESTLEVEL,
    TRANSFERTKIND,
    GRANTKIND,
    TRANSFERTYEAR,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    FACT,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    TEMPRECEIVEKESR
  FROM TB_TransfertCls
/

CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_ID
  INSTEAD OF DELETE
  ON TRANSFERTCLS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_TRANSFERTCLS
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_500 (TR_TRANSFERTCLS_AD_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate)
  values(203,:old.ID,SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_II
  INSTEAD OF INSERT
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
  new$EXTROOTID TRANSFERTCLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION TRANSFERTCLS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE TRANSFERTCLS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$TEMPRECEIVEKESR TRANSFERTCLS.TEMPRECEIVEKESR%TYPE := :NEW.TEMPRECEIVEKESR;
BEGIN
-- - - - - - - - - - - - -
-- BI_500 (TR_TRANSFERTCLS_BI_500)
-- Create 24.09.2007
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_TRANSFERTCLS (
    ID,
    REGIONCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    CODE,
    RECEIVEKVSR,
    RECEIVEKFSR,
    RECEIVEKVR,
    RECEIVEKD,
    TRANSFERKVSR,
    TRANSFERKFSR,
    TRANSFERKCSR,
    TRANSFERKVR,
    TRANSFERKESR,
    TRANSFERKDVALUE,
    TARGETMEANSSIGN,
    TARGETCLS,
    STARTDATE,
    DELETEDATE,
    NOTE,
    NAME,
    BUDGETREF,
    RECEIVEKCSR,
    SOURCELEVEL,
    DESTLEVEL,
    TRANSFERTKIND,
    GRANTKIND,
    TRANSFERTYEAR,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    FACT,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    TEMPRECEIVEKESR
  ) VALUES (
    new$ID,
    new$REGIONCLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$CODE,
    new$RECEIVEKVSR,
    new$RECEIVEKFSR,
    new$RECEIVEKVR,
    new$RECEIVEKD,
    new$TRANSFERKVSR,
    new$TRANSFERKFSR,
    new$TRANSFERKCSR,
    new$TRANSFERKVR,
    new$TRANSFERKESR,
    new$TRANSFERKDVALUE,
    new$TARGETMEANSSIGN,
    new$TARGETCLS,
    new$STARTDATE,
    new$DELETEDATE,
    new$NOTE,
    new$NAME,
    new$BUDGETREF,
    new$RECEIVEKCSR,
    new$SOURCELEVEL,
    new$DESTLEVEL,
    new$TRANSFERTKIND,
    new$GRANTKIND,
    new$TRANSFERTYEAR,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$FACT,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$TEMPRECEIVEKESR);

-- - - - - - - - - - - - -
-- AI_500 (TR_TRANSFERTCLS_AI_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_IU
  INSTEAD OF UPDATE
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
  new$EXTROOTID TRANSFERTCLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION TRANSFERTCLS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE TRANSFERTCLS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$TEMPRECEIVEKESR TRANSFERTCLS.TEMPRECEIVEKESR%TYPE := :NEW.TEMPRECEIVEKESR;
BEGIN
-- - - - - - - - - - - - -
-- BU_100 (TR_TRANSFERTCLS_BU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if ((new$id = 0) and (new$Code <> :old.Code)) then
    RaiseException('EX_CANTMODIFY_ZEROTRANFERTSCLS');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TRANSFERTCLS SET
    ID = new$ID,
    REGIONCLS = new$REGIONCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    CODE = new$CODE,
    RECEIVEKVSR = new$RECEIVEKVSR,
    RECEIVEKFSR = new$RECEIVEKFSR,
    RECEIVEKVR = new$RECEIVEKVR,
    RECEIVEKD = new$RECEIVEKD,
    TRANSFERKVSR = new$TRANSFERKVSR,
    TRANSFERKFSR = new$TRANSFERKFSR,
    TRANSFERKCSR = new$TRANSFERKCSR,
    TRANSFERKVR = new$TRANSFERKVR,
    TRANSFERKESR = new$TRANSFERKESR,
    TRANSFERKDVALUE = new$TRANSFERKDVALUE,
    TARGETMEANSSIGN = new$TARGETMEANSSIGN,
    TARGETCLS = new$TARGETCLS,
    STARTDATE = new$STARTDATE,
    DELETEDATE = new$DELETEDATE,
    NOTE = new$NOTE,
    NAME = new$NAME,
    BUDGETREF = new$BUDGETREF,
    RECEIVEKCSR = new$RECEIVEKCSR,
    SOURCELEVEL = new$SOURCELEVEL,
    DESTLEVEL = new$DESTLEVEL,
    TRANSFERTKIND = new$TRANSFERTKIND,
    GRANTKIND = new$GRANTKIND,
    TRANSFERTYEAR = new$TRANSFERTYEAR,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    FACT = new$FACT,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    TEMPRECEIVEKESR = new$TEMPRECEIVEKESR
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_TRANSFERTCLS_AU_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  if (new$Id <> :old.Id) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (203, :Old.Id, SYSDATE);
    delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);
  end if;

END;
/
commit work 
/
ALTER TABLE TB_TransfertCls ADD (
  ReceiveKESR VARCHAR2(20)
)
/

CREATE OR REPLACE VIEW TransfertCls (
  ID,
  REGIONCLS,
  CREATERUSER,
  CREATEDATE,
  UPDATERUSER,
  UPDATEDATE,
  CODE,
  RECEIVEKVSR,
  RECEIVEKFSR,
  RECEIVEKVR,
  RECEIVEKD,
  TRANSFERKVSR,
  TRANSFERKFSR,
  TRANSFERKCSR,
  TRANSFERKVR,
  TRANSFERKESR,
  TRANSFERKDVALUE,
  TARGETMEANSSIGN,
  TARGETCLS,
  STARTDATE,
  DELETEDATE,
  NOTE,
  NAME,
  BUDGETREF,
  RECEIVEKCSR,
  SOURCELEVEL,
  DESTLEVEL,
  TRANSFERTKIND,
  GRANTKIND,
  TRANSFERTYEAR,
  EXTID,
  EXTOWNER,
  EXTSYNCDATE,
  FACT,
  EXTROOTID,
  EXTVERSION,
  EXTVERSIONDATE,
  TEMPRECEIVEKESR,
  RECEIVEKESR)
AS
  SELECT
    ID,
    REGIONCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    CODE,
    RECEIVEKVSR,
    RECEIVEKFSR,
    RECEIVEKVR,
    RECEIVEKD,
    TRANSFERKVSR,
    TRANSFERKFSR,
    TRANSFERKCSR,
    TRANSFERKVR,
    TRANSFERKESR,
    TRANSFERKDVALUE,
    TARGETMEANSSIGN,
    TARGETCLS,
    STARTDATE,
    DELETEDATE,
    NOTE,
    NAME,
    BUDGETREF,
    RECEIVEKCSR,
    SOURCELEVEL,
    DESTLEVEL,
    TRANSFERTKIND,
    GRANTKIND,
    TRANSFERTYEAR,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    FACT,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    TEMPRECEIVEKESR,
    RECEIVEKESR
  FROM TB_TransfertCls
/

CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_ID
  INSTEAD OF DELETE
  ON TRANSFERTCLS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_TRANSFERTCLS
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_500 (TR_TRANSFERTCLS_AD_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate)
  values(203,:old.ID,SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_II
  INSTEAD OF INSERT
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
  new$EXTROOTID TRANSFERTCLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION TRANSFERTCLS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE TRANSFERTCLS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$TEMPRECEIVEKESR TRANSFERTCLS.TEMPRECEIVEKESR%TYPE := :NEW.TEMPRECEIVEKESR;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
BEGIN
-- - - - - - - - - - - - -
-- BI_500 (TR_TRANSFERTCLS_BI_500)
-- Create 24.09.2007
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_TRANSFERTCLS (
    ID,
    REGIONCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    CODE,
    RECEIVEKVSR,
    RECEIVEKFSR,
    RECEIVEKVR,
    RECEIVEKD,
    TRANSFERKVSR,
    TRANSFERKFSR,
    TRANSFERKCSR,
    TRANSFERKVR,
    TRANSFERKESR,
    TRANSFERKDVALUE,
    TARGETMEANSSIGN,
    TARGETCLS,
    STARTDATE,
    DELETEDATE,
    NOTE,
    NAME,
    BUDGETREF,
    RECEIVEKCSR,
    SOURCELEVEL,
    DESTLEVEL,
    TRANSFERTKIND,
    GRANTKIND,
    TRANSFERTYEAR,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    FACT,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    TEMPRECEIVEKESR,
    RECEIVEKESR
  ) VALUES (
    new$ID,
    new$REGIONCLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$CODE,
    new$RECEIVEKVSR,
    new$RECEIVEKFSR,
    new$RECEIVEKVR,
    new$RECEIVEKD,
    new$TRANSFERKVSR,
    new$TRANSFERKFSR,
    new$TRANSFERKCSR,
    new$TRANSFERKVR,
    new$TRANSFERKESR,
    new$TRANSFERKDVALUE,
    new$TARGETMEANSSIGN,
    new$TARGETCLS,
    new$STARTDATE,
    new$DELETEDATE,
    new$NOTE,
    new$NAME,
    new$BUDGETREF,
    new$RECEIVEKCSR,
    new$SOURCELEVEL,
    new$DESTLEVEL,
    new$TRANSFERTKIND,
    new$GRANTKIND,
    new$TRANSFERTYEAR,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$FACT,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$TEMPRECEIVEKESR,
    new$RECEIVEKESR);

-- - - - - - - - - - - - -
-- AI_500 (TR_TRANSFERTCLS_AI_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_IU
  INSTEAD OF UPDATE
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
  new$EXTROOTID TRANSFERTCLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION TRANSFERTCLS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE TRANSFERTCLS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$TEMPRECEIVEKESR TRANSFERTCLS.TEMPRECEIVEKESR%TYPE := :NEW.TEMPRECEIVEKESR;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
BEGIN
-- - - - - - - - - - - - -
-- BU_100 (TR_TRANSFERTCLS_BU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if ((new$id = 0) and (new$Code <> :old.Code)) then
    RaiseException('EX_CANTMODIFY_ZEROTRANFERTSCLS');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TRANSFERTCLS SET
    ID = new$ID,
    REGIONCLS = new$REGIONCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    CODE = new$CODE,
    RECEIVEKVSR = new$RECEIVEKVSR,
    RECEIVEKFSR = new$RECEIVEKFSR,
    RECEIVEKVR = new$RECEIVEKVR,
    RECEIVEKD = new$RECEIVEKD,
    TRANSFERKVSR = new$TRANSFERKVSR,
    TRANSFERKFSR = new$TRANSFERKFSR,
    TRANSFERKCSR = new$TRANSFERKCSR,
    TRANSFERKVR = new$TRANSFERKVR,
    TRANSFERKESR = new$TRANSFERKESR,
    TRANSFERKDVALUE = new$TRANSFERKDVALUE,
    TARGETMEANSSIGN = new$TARGETMEANSSIGN,
    TARGETCLS = new$TARGETCLS,
    STARTDATE = new$STARTDATE,
    DELETEDATE = new$DELETEDATE,
    NOTE = new$NOTE,
    NAME = new$NAME,
    BUDGETREF = new$BUDGETREF,
    RECEIVEKCSR = new$RECEIVEKCSR,
    SOURCELEVEL = new$SOURCELEVEL,
    DESTLEVEL = new$DESTLEVEL,
    TRANSFERTKIND = new$TRANSFERTKIND,
    GRANTKIND = new$GRANTKIND,
    TRANSFERTYEAR = new$TRANSFERTYEAR,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    FACT = new$FACT,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    TEMPRECEIVEKESR = new$TEMPRECEIVEKESR,
    RECEIVEKESR = new$RECEIVEKESR
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_TRANSFERTCLS_AU_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  if (new$Id <> :old.Id) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (203, :Old.Id, SYSDATE);
    delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);
  end if;

END;
/
commit work 
/
update TransfertCls set
  ReceiveKESR = TempReceiveKESR
where
  TempReceiveKESR like '___'
/
update TransfertCls set
  ReceiveKESR = '0' || TempReceiveKESR
where
  TempReceiveKESR like '__'
/
update TransfertCls set
  ReceiveKESR = '00' || TempReceiveKESR
where
  TempReceiveKESR like '_'
/
ALTER TABLE TB_TransfertCls DROP (TempReceiveKESR)
/

CREATE OR REPLACE VIEW TransfertCls (
  ID,
  REGIONCLS,
  CREATERUSER,
  CREATEDATE,
  UPDATERUSER,
  UPDATEDATE,
  CODE,
  RECEIVEKVSR,
  RECEIVEKFSR,
  RECEIVEKVR,
  RECEIVEKD,
  TRANSFERKVSR,
  TRANSFERKFSR,
  TRANSFERKCSR,
  TRANSFERKVR,
  TRANSFERKESR,
  TRANSFERKDVALUE,
  TARGETMEANSSIGN,
  TARGETCLS,
  STARTDATE,
  DELETEDATE,
  NOTE,
  NAME,
  BUDGETREF,
  RECEIVEKCSR,
  SOURCELEVEL,
  DESTLEVEL,
  TRANSFERTKIND,
  GRANTKIND,
  TRANSFERTYEAR,
  EXTID,
  EXTOWNER,
  EXTSYNCDATE,
  FACT,
  EXTROOTID,
  EXTVERSION,
  EXTVERSIONDATE,
  RECEIVEKESR)
AS
  SELECT
    ID,
    REGIONCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    CODE,
    RECEIVEKVSR,
    RECEIVEKFSR,
    RECEIVEKVR,
    RECEIVEKD,
    TRANSFERKVSR,
    TRANSFERKFSR,
    TRANSFERKCSR,
    TRANSFERKVR,
    TRANSFERKESR,
    TRANSFERKDVALUE,
    TARGETMEANSSIGN,
    TARGETCLS,
    STARTDATE,
    DELETEDATE,
    NOTE,
    NAME,
    BUDGETREF,
    RECEIVEKCSR,
    SOURCELEVEL,
    DESTLEVEL,
    TRANSFERTKIND,
    GRANTKIND,
    TRANSFERTYEAR,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    FACT,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    RECEIVEKESR
  FROM TB_TransfertCls
/

CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_ID
  INSTEAD OF DELETE
  ON TRANSFERTCLS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_TRANSFERTCLS
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_500 (TR_TRANSFERTCLS_AD_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate)
  values(203,:old.ID,SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_II
  INSTEAD OF INSERT
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
  new$EXTROOTID TRANSFERTCLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION TRANSFERTCLS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE TRANSFERTCLS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
BEGIN
-- - - - - - - - - - - - -
-- BI_500 (TR_TRANSFERTCLS_BI_500)
-- Create 24.09.2007
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_TRANSFERTCLS (
    ID,
    REGIONCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    CODE,
    RECEIVEKVSR,
    RECEIVEKFSR,
    RECEIVEKVR,
    RECEIVEKD,
    TRANSFERKVSR,
    TRANSFERKFSR,
    TRANSFERKCSR,
    TRANSFERKVR,
    TRANSFERKESR,
    TRANSFERKDVALUE,
    TARGETMEANSSIGN,
    TARGETCLS,
    STARTDATE,
    DELETEDATE,
    NOTE,
    NAME,
    BUDGETREF,
    RECEIVEKCSR,
    SOURCELEVEL,
    DESTLEVEL,
    TRANSFERTKIND,
    GRANTKIND,
    TRANSFERTYEAR,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    FACT,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    RECEIVEKESR
  ) VALUES (
    new$ID,
    new$REGIONCLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$CODE,
    new$RECEIVEKVSR,
    new$RECEIVEKFSR,
    new$RECEIVEKVR,
    new$RECEIVEKD,
    new$TRANSFERKVSR,
    new$TRANSFERKFSR,
    new$TRANSFERKCSR,
    new$TRANSFERKVR,
    new$TRANSFERKESR,
    new$TRANSFERKDVALUE,
    new$TARGETMEANSSIGN,
    new$TARGETCLS,
    new$STARTDATE,
    new$DELETEDATE,
    new$NOTE,
    new$NAME,
    new$BUDGETREF,
    new$RECEIVEKCSR,
    new$SOURCELEVEL,
    new$DESTLEVEL,
    new$TRANSFERTKIND,
    new$GRANTKIND,
    new$TRANSFERTYEAR,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$FACT,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$RECEIVEKESR);

-- - - - - - - - - - - - -
-- AI_500 (TR_TRANSFERTCLS_AI_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_IU
  INSTEAD OF UPDATE
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
  new$EXTROOTID TRANSFERTCLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION TRANSFERTCLS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE TRANSFERTCLS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
BEGIN
-- - - - - - - - - - - - -
-- BU_100 (TR_TRANSFERTCLS_BU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if ((new$id = 0) and (new$Code <> :old.Code)) then
    RaiseException('EX_CANTMODIFY_ZEROTRANFERTSCLS');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TRANSFERTCLS SET
    ID = new$ID,
    REGIONCLS = new$REGIONCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    CODE = new$CODE,
    RECEIVEKVSR = new$RECEIVEKVSR,
    RECEIVEKFSR = new$RECEIVEKFSR,
    RECEIVEKVR = new$RECEIVEKVR,
    RECEIVEKD = new$RECEIVEKD,
    TRANSFERKVSR = new$TRANSFERKVSR,
    TRANSFERKFSR = new$TRANSFERKFSR,
    TRANSFERKCSR = new$TRANSFERKCSR,
    TRANSFERKVR = new$TRANSFERKVR,
    TRANSFERKESR = new$TRANSFERKESR,
    TRANSFERKDVALUE = new$TRANSFERKDVALUE,
    TARGETMEANSSIGN = new$TARGETMEANSSIGN,
    TARGETCLS = new$TARGETCLS,
    STARTDATE = new$STARTDATE,
    DELETEDATE = new$DELETEDATE,
    NOTE = new$NOTE,
    NAME = new$NAME,
    BUDGETREF = new$BUDGETREF,
    RECEIVEKCSR = new$RECEIVEKCSR,
    SOURCELEVEL = new$SOURCELEVEL,
    DESTLEVEL = new$DESTLEVEL,
    TRANSFERTKIND = new$TRANSFERTKIND,
    GRANTKIND = new$GRANTKIND,
    TRANSFERTYEAR = new$TRANSFERTYEAR,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    FACT = new$FACT,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    RECEIVEKESR = new$RECEIVEKESR
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_TRANSFERTCLS_AU_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  if (new$Id <> :old.Id) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (203, :Old.Id, SYSDATE);
    delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);
  end if;

END;
/
ALTER TRIGGER TR_TRANSFERTCLS_BU_500 ENABLE
/
commit work 
/
-- CREATE TRIGGER TR_TRANSFERTCLS_BI
CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_II
  INSTEAD OF INSERT
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
  new$EXTROOTID TRANSFERTCLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION TRANSFERTCLS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE TRANSFERTCLS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
--
  CurrentDate$ NUMBER;
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_TRANSFERTCLS_BI)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$ID from dual;
  END IF;
   
  if (new$BUDGETREF is null) then 
    new$BUDGETREF := 0;
  END IF;
  if (new$RECEIVEKVSR is null) then 
    new$RECEIVEKVSR := 0;
  END IF;
  if (new$RECEIVEKCSR is null) then 
    new$RECEIVEKCSR := 0;
  END IF;
  if (new$RECEIVEKFSR is null) then 
    new$RECEIVEKFSR := 0;
  END IF;
  if (new$RECEIVEKD is null) then 
    new$RECEIVEKD := 0;
  END IF;
  if ((new$RECEIVEKVR is null) or (new$RECEIVEKVR  is null)) then 
    new$RECEIVEKVR := '000';
  END IF;
  if ((new$RECEIVEKESR is null) or (new$RECEIVEKESR  is null)) then 
    new$RECEIVEKESR := '000';
  END IF;
  if (new$TRANSFERKVSR is null) then 
    new$TRANSFERKVSR := 0;
  END IF;
  if (new$TRANSFERKCSR is null) then 
    new$TRANSFERKCSR := 0;
  END IF;
  if (new$TRANSFERKFSR is null) then 
    new$TRANSFERKFSR := 0;
  END IF;
  if (new$TRANSFERKVR is null) then 
    new$TRANSFERKVR := 0;
  END IF;
  if (new$TRANSFERKESR is null) then 
    new$TRANSFERKESR := 0;
  END IF;
  if ((new$TRANSFERKDVALUE is null) or (new$TRANSFERKDVALUE  is null)) then 
    new$TRANSFERKDVALUE := '00000000000000000000';
  END IF;
  if (new$TARGETMEANSSIGN is null) then 
    new$TARGETMEANSSIGN := 1;
  END IF;
  if (new$REGIONCLS is null) then 
    new$REGIONCLS := 0;
  END IF;
  if (new$FACT is null) then 
    new$FACT := 0;
  END IF;
  if (new$SourceLevel is null) then 
    new$SourceLevel := 0;
  END IF;
  if (new$GrantKind is null) then 
    new$GrantKind := 0;
  END IF;
  if (new$GrantKind = 2) then /*   "" */
    new$DestLevel := 1; /*    */
     
  else
    /*   ""  " "   */
    if ((new$GrantKind = 1) or (new$DestLevel is null)) then
      new$DestLevel := 0; /*   */
    END IF;
  END IF;
  if (new$TransfertKind is null) then 
    new$TransfertKind  := 0; 
  END IF;
  if (new$TransfertYear is null) then
    CurDateToDouble(CurrentDate$);
    new$TransfertYear := CurrentDate$ / 10000;
     
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_TRANSFERTCLS_BI_500)
-- Create 24.09.2007
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_TRANSFERTCLS (
    ID,
    REGIONCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    CODE,
    RECEIVEKVSR,
    RECEIVEKFSR,
    RECEIVEKVR,
    RECEIVEKD,
    TRANSFERKVSR,
    TRANSFERKFSR,
    TRANSFERKCSR,
    TRANSFERKVR,
    TRANSFERKESR,
    TRANSFERKDVALUE,
    TARGETMEANSSIGN,
    TARGETCLS,
    STARTDATE,
    DELETEDATE,
    NOTE,
    NAME,
    BUDGETREF,
    RECEIVEKCSR,
    SOURCELEVEL,
    DESTLEVEL,
    TRANSFERTKIND,
    GRANTKIND,
    TRANSFERTYEAR,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    FACT,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    RECEIVEKESR
  ) VALUES (
    new$ID,
    new$REGIONCLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$CODE,
    new$RECEIVEKVSR,
    new$RECEIVEKFSR,
    new$RECEIVEKVR,
    new$RECEIVEKD,
    new$TRANSFERKVSR,
    new$TRANSFERKFSR,
    new$TRANSFERKCSR,
    new$TRANSFERKVR,
    new$TRANSFERKESR,
    new$TRANSFERKDVALUE,
    new$TARGETMEANSSIGN,
    new$TARGETCLS,
    new$STARTDATE,
    new$DELETEDATE,
    new$NOTE,
    new$NAME,
    new$BUDGETREF,
    new$RECEIVEKCSR,
    new$SOURCELEVEL,
    new$DESTLEVEL,
    new$TRANSFERTKIND,
    new$GRANTKIND,
    new$TRANSFERTYEAR,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$FACT,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$RECEIVEKESR);

-- - - - - - - - - - - - -
-- AI_500 (TR_TRANSFERTCLS_AI_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);

END;
/
-- CREATE TRIGGER TR_TRANSFERTCLS_BI_200
CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_II
  INSTEAD OF INSERT
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
  new$EXTROOTID TRANSFERTCLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION TRANSFERTCLS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE TRANSFERTCLS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
--
  CurrentDate$ NUMBER;
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_TRANSFERTCLS_BI)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$ID from dual;
  END IF;
   
  if (new$BUDGETREF is null) then 
    new$BUDGETREF := 0;
  END IF;
  if (new$RECEIVEKVSR is null) then 
    new$RECEIVEKVSR := 0;
  END IF;
  if (new$RECEIVEKCSR is null) then 
    new$RECEIVEKCSR := 0;
  END IF;
  if (new$RECEIVEKFSR is null) then 
    new$RECEIVEKFSR := 0;
  END IF;
  if (new$RECEIVEKD is null) then 
    new$RECEIVEKD := 0;
  END IF;
  if ((new$RECEIVEKVR is null) or (new$RECEIVEKVR  is null)) then 
    new$RECEIVEKVR := '000';
  END IF;
  if ((new$RECEIVEKESR is null) or (new$RECEIVEKESR  is null)) then 
    new$RECEIVEKESR := '000';
  END IF;
  if (new$TRANSFERKVSR is null) then 
    new$TRANSFERKVSR := 0;
  END IF;
  if (new$TRANSFERKCSR is null) then 
    new$TRANSFERKCSR := 0;
  END IF;
  if (new$TRANSFERKFSR is null) then 
    new$TRANSFERKFSR := 0;
  END IF;
  if (new$TRANSFERKVR is null) then 
    new$TRANSFERKVR := 0;
  END IF;
  if (new$TRANSFERKESR is null) then 
    new$TRANSFERKESR := 0;
  END IF;
  if ((new$TRANSFERKDVALUE is null) or (new$TRANSFERKDVALUE  is null)) then 
    new$TRANSFERKDVALUE := '00000000000000000000';
  END IF;
  if (new$TARGETMEANSSIGN is null) then 
    new$TARGETMEANSSIGN := 1;
  END IF;
  if (new$REGIONCLS is null) then 
    new$REGIONCLS := 0;
  END IF;
  if (new$FACT is null) then 
    new$FACT := 0;
  END IF;
  if (new$SourceLevel is null) then 
    new$SourceLevel := 0;
  END IF;
  if (new$GrantKind is null) then 
    new$GrantKind := 0;
  END IF;
  if (new$GrantKind = 2) then /*   "" */
    new$DestLevel := 1; /*    */
     
  else
    /*   ""  " "   */
    if ((new$GrantKind = 1) or (new$DestLevel is null)) then
      new$DestLevel := 0; /*   */
    END IF;
  END IF;
  if (new$TransfertKind is null) then 
    new$TransfertKind  := 0; 
  END IF;
  if (new$TransfertYear is null) then
    CurDateToDouble(CurrentDate$);
    new$TransfertYear := CurrentDate$ / 10000;
     
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_TRANSFERTCLS_BI_200)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(*) INTO CNT$1
  from TransfertCls t where
  (        (t.ID <> new$ID) and
  (t.CODE=new$CODE) and
  (t.RECEIVEKVSR=new$RECEIVEKVSR) and
  (t.RECEIVEKFSR=new$RECEIVEKFSR) and
  (t.RECEIVEKCSR=new$RECEIVEKCSR) and
  (t.RECEIVEKVR=new$RECEIVEKVR) and
  (t.RECEIVEKESR=new$RECEIVEKESR) and
  (t.RECEIVEKD=new$RECEIVEKD) and
  (t.TRANSFERKVSR=new$TRANSFERKVSR) and
  (t.TRANSFERKFSR=new$TRANSFERKFSR) and
  (t.TRANSFERKCSR=new$TRANSFERKCSR) and
  (t.TRANSFERKVR=new$TRANSFERKVR) and
  (t.TRANSFERKESR=new$TRANSFERKESR) and
  (t.TRANSFERKDVALUE=new$TRANSFERKDVALUE) and
  (t.TARGETMEANSSIGN=new$TARGETMEANSSIGN) and
  (t.REGIONCLS=new$REGIONCLS) and
  (t.DESTLEVEL=new$DESTLEVEL) and
  (t.BUDGETREF=new$BUDGETREF) and
  ((t.EXTID is null and new$EXTID is null) or (t.EXTID = new$EXTID)) and
  (t.FACT=new$FACT)) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    RaiseException('EX_DUPLICATE_TRANSFERT');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_TRANSFERTCLS_BI_500)
-- Create 24.09.2007
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_TRANSFERTCLS (
    ID,
    REGIONCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    CODE,
    RECEIVEKVSR,
    RECEIVEKFSR,
    RECEIVEKVR,
    RECEIVEKD,
    TRANSFERKVSR,
    TRANSFERKFSR,
    TRANSFERKCSR,
    TRANSFERKVR,
    TRANSFERKESR,
    TRANSFERKDVALUE,
    TARGETMEANSSIGN,
    TARGETCLS,
    STARTDATE,
    DELETEDATE,
    NOTE,
    NAME,
    BUDGETREF,
    RECEIVEKCSR,
    SOURCELEVEL,
    DESTLEVEL,
    TRANSFERTKIND,
    GRANTKIND,
    TRANSFERTYEAR,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    FACT,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    RECEIVEKESR
  ) VALUES (
    new$ID,
    new$REGIONCLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$CODE,
    new$RECEIVEKVSR,
    new$RECEIVEKFSR,
    new$RECEIVEKVR,
    new$RECEIVEKD,
    new$TRANSFERKVSR,
    new$TRANSFERKFSR,
    new$TRANSFERKCSR,
    new$TRANSFERKVR,
    new$TRANSFERKESR,
    new$TRANSFERKDVALUE,
    new$TARGETMEANSSIGN,
    new$TARGETCLS,
    new$STARTDATE,
    new$DELETEDATE,
    new$NOTE,
    new$NAME,
    new$BUDGETREF,
    new$RECEIVEKCSR,
    new$SOURCELEVEL,
    new$DESTLEVEL,
    new$TRANSFERTKIND,
    new$GRANTKIND,
    new$TRANSFERTYEAR,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$FACT,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$RECEIVEKESR);

-- - - - - - - - - - - - -
-- AI_500 (TR_TRANSFERTCLS_AI_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);

END;
/
-- CREATE TRIGGER TR_TRANSFERTCLS_BU
CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_IU
  INSTEAD OF UPDATE
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
  new$EXTROOTID TRANSFERTCLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION TRANSFERTCLS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE TRANSFERTCLS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
--
  CurrentDate$ NUMBER;
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TRANSFERTCLS_BU)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  if (new$BUDGETREF is null) then 
    new$BUDGETREF := 0;
  END IF;
  if (new$RECEIVEKVSR is null) then 
    new$RECEIVEKVSR := 0;
  END IF;
  if (new$RECEIVEKCSR is null) then 
    new$RECEIVEKCSR := 0;
  END IF;
  if (new$RECEIVEKFSR is null) then 
    new$RECEIVEKFSR := 0;
  END IF;
  if (new$RECEIVEKD is null) then 
    new$RECEIVEKD := 0;
  END IF;
  if ((new$RECEIVEKVR is null) or (new$RECEIVEKVR  is null)) then 
    new$RECEIVEKVR := '000';
  END IF;
  if ((new$RECEIVEKESR is null) or (new$RECEIVEKESR  is null)) then 
    new$RECEIVEKESR := '000';
  END IF;
  if (new$TRANSFERKVSR is null) then 
    new$TRANSFERKVSR := 0;
  END IF;
  if (new$TRANSFERKCSR is null) then 
    new$TRANSFERKCSR := 0;
  END IF;
  if (new$TRANSFERKFSR is null) then 
    new$TRANSFERKFSR := 0;
  END IF;
  if (new$TRANSFERKVR is null) then 
    new$TRANSFERKVR := 0;
  END IF;
  if (new$TRANSFERKESR is null) then 
    new$TRANSFERKESR := 0;
  END IF;
  if ((new$TRANSFERKDVALUE is null) or (new$TRANSFERKDVALUE  is null)) then 
    new$TRANSFERKDVALUE := '00000000000000000000';
  END IF;
  if (new$TARGETMEANSSIGN is null) then 
    new$TARGETMEANSSIGN := 1;
  END IF;
  if (new$REGIONCLS is null) then 
    new$REGIONCLS := 0;
  END IF;
  if (new$FACT is null) then 
    new$FACT := 0;
  END IF;
  if (new$SourceLevel is null) then 
    new$SourceLevel := 0;
  END IF;
  if (new$GrantKind is null) then 
    new$GrantKind := 0;
  END IF;
  if (new$GrantKind = 2) then /*   "" */
    new$DestLevel := 1; /*    */
     
  else
    /*   ""  " "   */
    if ((new$GrantKind = 1) or (new$DestLevel is null)) then
      new$DestLevel := 0; /*   */
    END IF;
  END IF;
  if (new$TransfertKind is null) then 
    new$TransfertKind  := 0;
  END IF;
  if (new$TransfertYear is null) then
    CurDateToDouble(CurrentDate$);
    new$TransfertYear := CurrentDate$ / 10000;
     
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_TRANSFERTCLS_BU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if ((new$id = 0) and (new$Code <> :old.Code)) then
    RaiseException('EX_CANTMODIFY_ZEROTRANFERTSCLS');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TRANSFERTCLS SET
    ID = new$ID,
    REGIONCLS = new$REGIONCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    CODE = new$CODE,
    RECEIVEKVSR = new$RECEIVEKVSR,
    RECEIVEKFSR = new$RECEIVEKFSR,
    RECEIVEKVR = new$RECEIVEKVR,
    RECEIVEKD = new$RECEIVEKD,
    TRANSFERKVSR = new$TRANSFERKVSR,
    TRANSFERKFSR = new$TRANSFERKFSR,
    TRANSFERKCSR = new$TRANSFERKCSR,
    TRANSFERKVR = new$TRANSFERKVR,
    TRANSFERKESR = new$TRANSFERKESR,
    TRANSFERKDVALUE = new$TRANSFERKDVALUE,
    TARGETMEANSSIGN = new$TARGETMEANSSIGN,
    TARGETCLS = new$TARGETCLS,
    STARTDATE = new$STARTDATE,
    DELETEDATE = new$DELETEDATE,
    NOTE = new$NOTE,
    NAME = new$NAME,
    BUDGETREF = new$BUDGETREF,
    RECEIVEKCSR = new$RECEIVEKCSR,
    SOURCELEVEL = new$SOURCELEVEL,
    DESTLEVEL = new$DESTLEVEL,
    TRANSFERTKIND = new$TRANSFERTKIND,
    GRANTKIND = new$GRANTKIND,
    TRANSFERTYEAR = new$TRANSFERTYEAR,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    FACT = new$FACT,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    RECEIVEKESR = new$RECEIVEKESR
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_TRANSFERTCLS_AU_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  if (new$Id <> :old.Id) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (203, :Old.Id, SYSDATE);
    delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);
  end if;

END;
/
-- CREATE TRIGGER TR_TRANSFERTCLS_BU_200
CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_IU
  INSTEAD OF UPDATE
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
  new$EXTROOTID TRANSFERTCLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION TRANSFERTCLS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE TRANSFERTCLS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
--
  CurrentDate$ NUMBER;
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TRANSFERTCLS_BU)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  if (new$BUDGETREF is null) then 
    new$BUDGETREF := 0;
  END IF;
  if (new$RECEIVEKVSR is null) then 
    new$RECEIVEKVSR := 0;
  END IF;
  if (new$RECEIVEKCSR is null) then 
    new$RECEIVEKCSR := 0;
  END IF;
  if (new$RECEIVEKFSR is null) then 
    new$RECEIVEKFSR := 0;
  END IF;
  if (new$RECEIVEKD is null) then 
    new$RECEIVEKD := 0;
  END IF;
  if ((new$RECEIVEKVR is null) or (new$RECEIVEKVR  is null)) then 
    new$RECEIVEKVR := '000';
  END IF;
  if ((new$RECEIVEKESR is null) or (new$RECEIVEKESR  is null)) then 
    new$RECEIVEKESR := '000';
  END IF;
  if (new$TRANSFERKVSR is null) then 
    new$TRANSFERKVSR := 0;
  END IF;
  if (new$TRANSFERKCSR is null) then 
    new$TRANSFERKCSR := 0;
  END IF;
  if (new$TRANSFERKFSR is null) then 
    new$TRANSFERKFSR := 0;
  END IF;
  if (new$TRANSFERKVR is null) then 
    new$TRANSFERKVR := 0;
  END IF;
  if (new$TRANSFERKESR is null) then 
    new$TRANSFERKESR := 0;
  END IF;
  if ((new$TRANSFERKDVALUE is null) or (new$TRANSFERKDVALUE  is null)) then 
    new$TRANSFERKDVALUE := '00000000000000000000';
  END IF;
  if (new$TARGETMEANSSIGN is null) then 
    new$TARGETMEANSSIGN := 1;
  END IF;
  if (new$REGIONCLS is null) then 
    new$REGIONCLS := 0;
  END IF;
  if (new$FACT is null) then 
    new$FACT := 0;
  END IF;
  if (new$SourceLevel is null) then 
    new$SourceLevel := 0;
  END IF;
  if (new$GrantKind is null) then 
    new$GrantKind := 0;
  END IF;
  if (new$GrantKind = 2) then /*   "" */
    new$DestLevel := 1; /*    */
     
  else
    /*   ""  " "   */
    if ((new$GrantKind = 1) or (new$DestLevel is null)) then
      new$DestLevel := 0; /*   */
    END IF;
  END IF;
  if (new$TransfertKind is null) then 
    new$TransfertKind  := 0;
  END IF;
  if (new$TransfertYear is null) then
    CurDateToDouble(CurrentDate$);
    new$TransfertYear := CurrentDate$ / 10000;
     
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_TRANSFERTCLS_BU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if ((new$id = 0) and (new$Code <> :old.Code)) then
    RaiseException('EX_CANTMODIFY_ZEROTRANFERTSCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_TRANSFERTCLS_BU_200)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(*) INTO CNT$1
  from TransfertCls t where
  (        (t.ID <> new$ID) and
  (t.CODE=new$CODE) and
  (t.RECEIVEKVSR=new$RECEIVEKVSR) and
  (t.RECEIVEKFSR=new$RECEIVEKFSR) and
  (t.RECEIVEKCSR=new$RECEIVEKCSR) and
  (t.RECEIVEKVR=new$RECEIVEKVR) and
  (t.RECEIVEKESR=new$RECEIVEKESR) and
  (t.RECEIVEKD=new$RECEIVEKD) and
  (t.TRANSFERKVSR=new$TRANSFERKVSR) and
  (t.TRANSFERKFSR=new$TRANSFERKFSR) and
  (t.TRANSFERKCSR=new$TRANSFERKCSR) and
  (t.TRANSFERKVR=new$TRANSFERKVR) and
  (t.TRANSFERKESR=new$TRANSFERKESR) and
  (t.TRANSFERKDVALUE=new$TRANSFERKDVALUE) and
  (t.TARGETMEANSSIGN=new$TARGETMEANSSIGN) and
  (t.REGIONCLS=new$REGIONCLS) and
  (t.DESTLEVEL=new$DESTLEVEL) and
  (t.BUDGETREF=new$BUDGETREF) and
  ((t.EXTID is null and new$EXTID is null) or (t.EXTID = new$EXTID)) and
  (t.FACT=new$FACT)) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    RaiseException('EX_DUPLICATE_TRANSFERT');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TRANSFERTCLS SET
    ID = new$ID,
    REGIONCLS = new$REGIONCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    CODE = new$CODE,
    RECEIVEKVSR = new$RECEIVEKVSR,
    RECEIVEKFSR = new$RECEIVEKFSR,
    RECEIVEKVR = new$RECEIVEKVR,
    RECEIVEKD = new$RECEIVEKD,
    TRANSFERKVSR = new$TRANSFERKVSR,
    TRANSFERKFSR = new$TRANSFERKFSR,
    TRANSFERKCSR = new$TRANSFERKCSR,
    TRANSFERKVR = new$TRANSFERKVR,
    TRANSFERKESR = new$TRANSFERKESR,
    TRANSFERKDVALUE = new$TRANSFERKDVALUE,
    TARGETMEANSSIGN = new$TARGETMEANSSIGN,
    TARGETCLS = new$TARGETCLS,
    STARTDATE = new$STARTDATE,
    DELETEDATE = new$DELETEDATE,
    NOTE = new$NOTE,
    NAME = new$NAME,
    BUDGETREF = new$BUDGETREF,
    RECEIVEKCSR = new$RECEIVEKCSR,
    SOURCELEVEL = new$SOURCELEVEL,
    DESTLEVEL = new$DESTLEVEL,
    TRANSFERTKIND = new$TRANSFERTKIND,
    GRANTKIND = new$GRANTKIND,
    TRANSFERTYEAR = new$TRANSFERTYEAR,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    FACT = new$FACT,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    RECEIVEKESR = new$RECEIVEKESR
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_TRANSFERTCLS_AU_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  if (new$Id <> :old.Id) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (203, :Old.Id, SYSDATE);
    delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);
  end if;

END;
/
commit work 
/


ALTER TABLE TB_TransfertCls MODIFY(ReceiveKESR NOT NULL)
/

-- #########################################################
-- #########################################################
-- Add_BankExch_Index.sql
-- #########################################################
-- #########################################################

/* ,     PacketNumber  bankexch_merdoc
*/
CREATE INDEX BANKEXCH_MERDOC_PACKETNAME on bankexch_merdoc (PacketNumber)
/
commit work 
/

-- #########################################################
-- #########################################################
-- create_IDX_ORG_GENERALORG.sql
-- #########################################################
-- #########################################################

/*    GENERALORG_REF  ORGANIZATIONS */
CREATE INDEX IDX_ORG_GENERALORG ON TB_ORGANIZATIONS (GENERALORG_REF)
/
COMMIT WORK
/

-- #########################################################
-- #########################################################
-- Create_IDX_PE_EPN.sql
-- #########################################################
-- #########################################################

/* Создает индекс для поля ELPACKETNUMBER таблицы PAYDOCEXCHANGE */
CREATE INDEX IND_PE_EPN ON PAYDOCEXCHANGE (ELPACKETNUMBER)
/
commit work 
/

-- #########################################################
-- #########################################################
-- Add_Bank_Sub_UniversalReplace.sql
-- #########################################################
-- #########################################################

/*        */
ALTER TABLE bankexch_substitution ADD (
  DestUniversalReplace VARCHAR2(4000)
)
/
commit work
/




-- #########################################################
-- #########################################################
-- Alter_KESRUpdateOn_KD_IFS.sql
-- #########################################################
-- #########################################################

/* 
1.    ,  -  ,       .
2.     -        .
3.        .
*/
-- CREATE TRIGGER tr_kesr_ad_0
CREATE OR REPLACE TRIGGER TR_KESR_AD
  AFTER DELETE
  ON KESR
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AD_0 (tr_kesr_ad_0)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*     KESR. */
  update kd
  set kesr = 0
  where (kesr = :old.id);

  update innerfinsource
  set kesr = 0
  where (kesr = :old.id);

-- - - - - - - - - - - - -
-- AD_500 (TR_KESR_AD_500)
-- - - - - - - - - - - - -

 insert into DelRecIndexes(TableID,RecordId,DeleteDate)
 values(6,:old.ID,SYSDATE);

END;
/
COMMIT WORK 
/
/*         */
CREATE OR REPLACE procedure GetKesr(    Sanalyticalgroup$ VARCHAR2,    Budget_Ref$ NUMBER,
        Id$ out NUMBER)
AS
BEGIN
  select max(id)   into
  Id$ from kesr
  where
  (CODE = Sanalyticalgroup$)
  and ((deletedate is null) or (deletedate > current_date))
  and (BudgetRef = Budget_Ref$)
  ;
  if (Id$ is null) then
    select max(id)     into
    Id$ from kesr
    where
    (CODE = Sanalyticalgroup$)
    and ((deletedate is null) or (deletedate > current_date))
    and (BudgetRef = 0)
    ;
  END IF;
  if (Id$ is null) then
    Id$ := 0;
  END IF;
END;
/
COMMIT WORK 
/
GRANT EXECUTE ON GetKesr TO BUDGET_USERS
/
COMMIT WORK 
/
-- ALTER TRIGGER tr_innerfinsource_au_100
CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_IU
  INSTEAD OF UPDATE
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  new$ID INNERFINSOURCE.ID%TYPE := :NEW.ID;
  new$CREATEDATE INNERFINSOURCE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INNERFINSOURCE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$DIRECTION INNERFINSOURCE.DIRECTION%TYPE := :NEW.DIRECTION;
  new$KVSR INNERFINSOURCE.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE INNERFINSOURCE.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE INNERFINSOURCE.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE INNERFINSOURCE.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE INNERFINSOURCE.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR INNERFINSOURCE.KESR%TYPE := :NEW.KESR;
  new$FINSOURCEVALUE INNERFINSOURCE.FINSOURCEVALUE%TYPE := :NEW.FINSOURCEVALUE;
  new$UNIONFLAG INNERFINSOURCE.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$REMOTEFLAG INNERFINSOURCE.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$BUDGETREF INNERFINSOURCE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE INNERFINSOURCE.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME INNERFINSOURCE.NAME%TYPE := :NEW.NAME;
  new$STARTDATE INNERFINSOURCE.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME INNERFINSOURCE.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CLSASPECT INNERFINSOURCE.CLSASPECT%TYPE := :NEW.CLSASPECT;
  new$CREATERUSER INNERFINSOURCE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER INNERFINSOURCE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$IFS_LEVEL INNERFINSOURCE.IFS_LEVEL%TYPE := :NEW.IFS_LEVEL;
  new$EXTID INNERFINSOURCE.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER INNERFINSOURCE.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE INNERFINSOURCE.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID INNERFINSOURCE.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION INNERFINSOURCE.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE INNERFINSOURCE.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPIFS INNERFINSOURCE.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
--
  tmp$ NUMBER(15,0);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  tmp_Double1$ NUMBER;
  DescrCode11$ NUMBER(10);
  DescrCode21$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKVSR1$ VARCHAR2(3);
  sDescrCode11$ VARCHAR2(7);
  sDescrCode21$ VARCHAR2(7);
  sAnalyticalGroupIFS1$ VARCHAR2(3);
  sIFSLevel1$ NUMBER(10);
  sDirection1$ NUMBER(10);
  AGIFS1$ NUMBER(10);
  vName1$ VARCHAR2(1024);
  vShortName1$ VARCHAR2(1024);
  vIFSLevel1$ NUMBER(10);
  vDirection1$ NUMBER(10);
  vDeleteDate1$ DATE;
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INNERFINSOURCE_BU_0)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$KVSR is null) then
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupIFS is null) then
    new$AnalyticalGroupIFS := 0;
  END IF;
  if (new$ClsAspect is null) then
    new$ClsAspect := 0;
  END IF;
  if (new$UnionFlag is null) then
    new$UnionFlag := 0;
  END IF;
  if (new$RemoteFlag is null) then
    new$RemoteFlag := 0;
  END IF;
  if (new$BudgetRef is null) then
    new$BudgetRef := 0;
  END IF;
  /*     */
  if (new$KVSR <> 0) then
    select max(IFS_Level), max(Direction)
    into sIFSLevel1$, sDirection1$     from innerfinsource
    where ((AnalyticalGroupIFS = new$AnalyticalGroupIFS) and (BudgetRef=new$BudgetRef) and
    (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))
    ;
  END IF;
  if (sIFSLevel1$ is not null) then
    new$IFS_Level := sIFSLevel1$;
  END IF;
  if (sDirection1$ is not null) then
    new$Direction := sDirection1$;
  END IF;
  /*         
            =3,5,8 */
  if (new$Direction is null) then
    if ((new$AnalyticalGroupIFS between 300 and 399) or
    (new$AnalyticalGroupIFS between 500 and 599) or
    (new$AnalyticalGroupIFS between 800 and 899)) then
      new$Direction := -1;

    else
      new$Direction := 1;
    END IF;
    GetIntConst(60, 9,AGIFS1$);
    if (new$AnalyticalGroupIFS = AGIFS1$) then
      new$Direction := 1;
    END IF;
    GetIntConst(60, 10,AGIFS1$);
    if (new$AnalyticalGroupIFS = AGIFS1$) then
      new$Direction := -1;

    END IF;
  END IF;
  BEGIN


    /*      */
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-    */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR1$ := '000';

  else
    if (KVSRCode1$ < 10) then
      sKVSR1$ := '00' || KVSRCode1$;

    else
      if (KVSRCode1$ < 100) then
        sKVSR1$ := '0' || KVSRCode1$;

      else
        sKVSR1$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*    , ,  */

  tmp$ := new$DescriptionCode;
  tmp_Double1$ := tmp$ / 1000000;
  DescrCode11$ := tmp_Double1$;
  /*      ,
          ,    1 */
  if (DescrCode11$  > tmp_Double1$) then
    DescrCode11$ := DescrCode11$ - 1;
  END IF;
  new$MainDescriptionCode := DescrCode11$; /*    */
  /*       */
  tmp_Double1$ := DescrCode11$;
  tmp_Double1$ := tmp$ - tmp_Double1$ * 1000000;
  DescrCode21$ := tmp_Double1$;
  tmp_Double1$ := DescrCode21$ / 10000;
  DescrCode11$ := tmp_Double1$;
  /*      */
  if (DescrCode11$ > tmp_Double1$) then
    DescrCode11$ := DescrCode11$ - 1;
  END IF;
  new$ItemCode := DescrCode11$; /* */
  tmp_Double1$ := DescrCode21$ - DescrCode11$ * 10000;
  new$ProgramCode := tmp_Double1$; /* */
  /*       */

  tmp_Double1$ := tmp$ / 10000000;
  DescrCode11$ := tmp_Double1$;
  if (DescrCode11$ > tmp_Double1$) then
    DescrCode11$ := DescrCode11$ - 1;
  END IF;
  tmp_Double1$ := DescrCode11$;
  tmp_Double1$ := tmp$ - tmp_Double1$ * 10000000;
  DescrCode21$ := tmp_Double1$;
  if (DescrCode11$ = 0) then
    sDescrCode11$ := '0000000';

  else
    if (DescrCode11$ < 10) then
      sDescrCode11$ := '000000' || DescrCode11$;

    else
      if (DescrCode11$ < 100) then
        sDescrCode11$ := '00000' || DescrCode11$;

      else
        if (DescrCode11$ < 1000) then
          sDescrCode11$ := '0000' || DescrCode11$;

        else
          if (DescrCode11$ < 10000) then
            sDescrCode11$ := '000' || DescrCode11$;

          else
            if (DescrCode11$ < 100000) then
              sDescrCode11$ := '00' || DescrCode11$;

            else
              if (DescrCode11$ < 1000000) then
                sDescrCode11$ := '0' || DescrCode11$;

              else
                sDescrCode11$ := DescrCode11$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  if (DescrCode21$ = 0) then
    sDescrCode21$ := '0000000';

  else
    if (DescrCode21$ < 10) then
      sDescrCode21$ := '000000' || DescrCode21$;

    else
      if (DescrCode21$ < 100) then
        sDescrCode21$ := '00000' || DescrCode21$;

      else
        if (DescrCode21$ < 1000) then
          sDescrCode21$ := '0000' || DescrCode21$;

        else
          if (DescrCode21$ < 10000) then
            sDescrCode21$ := '000' || DescrCode21$;

          else
            if (DescrCode21$ < 100000) then
              sDescrCode21$ := '00' || DescrCode21$;

            else
              if (DescrCode21$ < 1000000) then
                sDescrCode21$ := '0' || DescrCode21$;

              else
                sDescrCode21$ := DescrCode21$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */
    select Code into sAnalyticalGroupIFS1$ from AnalyticalGroupIFS where (ID = new$AnalyticalGroupIFS) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    BEGIN
      select id into new$KESR from KESR where (CODE = sAnalyticalGroupIFS1$) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$KESR is null) then
      new$KESR := 0;

    END IF;
  END IF;
  /*      */

  new$FinSourceValue := sKVSR1$ || sDescrCode11$ || sDescrCode21$ || sAnalyticalGroupIFS1$;

  if ((new$ID = 0) and (new$FinSourceValue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroIFS');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INNERFINSOURCE SET
    ID = new$ID,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    DIRECTION = new$DIRECTION,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    FINSOURCEVALUE = new$FINSOURCEVALUE,
    UNIONFLAG = new$UNIONFLAG,
    REMOTEFLAG = new$REMOTEFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CLSASPECT = new$CLSASPECT,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    IFS_LEVEL = new$IFS_LEVEL,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPIFS = new$ANALYTICALGROUPIFS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_INNERFINSOURCE_AU_100)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from InnerFinSource ifs1
    inner join analyticalgroupifs ag on (ag.id = ifs1.analyticalgroupifs)
    where ((ifs1.kvsr = 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ag.code = (select ag1.code
    from analyticalgroupifs ag1
    where (ag1.id = new$analyticalgroupifs))) and
    (ifs1.BudgetRef = new$BudgetRef)
    ) AND (ROWNUM = 1)                   ;
    /*    0,        =0 */
    if (not (CNT$1<> 0))
    then  
      insert into InnerFinSource (KVSR, DescriptionCode, AnalyticalGroupIFS, Name, ShortName, CLSAspect, RemoteFlag, IFS_Level, BudgetRef, ExtID)
      values (0, new$DescriptionCode, new$AnalyticalGroupIFS, new$Name, new$ShortName, new$CLSAspect, new$RemoteFlag, new$IFS_Level, new$BudgetRef, new$ExtID);
      
    END IF;
  else
    /*   = 0,         ,     */      
    vName1$ := new$Name;
    vShortName1$ := new$ShortName;
    vIFSLevel1$ := new$IFS_Level;
    vDeleteDate1$ := new$DeleteDate;
    vDirection1$ := new$Direction;
    /* ,      .  ,        .    ,   . */
    if ((new$DeleteDate is not null) and (new$DeleteDate < current_date)) then
      SELECT COUNT(*) INTO CNT$2
      from InnerFinSource ifs1
      where ((ifs1.kvsr = 0) and
      ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
      (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
      (ifs1.BudgetRef = new$BudgetRef) and ((ifs1.DeleteDate is null) or (ifs1.DeleteDate > current_date))
      ) AND (ROWNUM = 1)                    ;
      if ((CNT$2<> 0))
      then
        BEGIN
          select ifs2.Name, ifs2.ShortName, ifs2.IFS_Level, ifs2.Direction, ifs2.DeleteDate                 into
          vName1$, vShortName1$, vIFSLevel1$, vDirection1$, vDeleteDate1$ from InnerFinSource ifs2
          where ifs2.id = (select max(id) from InnerFinSource ifs1
          where (ifs1.kvsr = 0) and
          ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
          (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
          (ifs1.BudgetRef = new$BudgetRef) and ((ifs1.DeleteDate is null) or (ifs1.DeleteDate > current_date)))
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;    
      END IF;
    END IF;
    update InnerFinSource ifs1 set
    name = vName1$,
    ShortName = vShortName1$,
    IFS_level = vIFSLevel1$,
    Direction = vDirection1$,
    deletedate = vDeleteDate1$

    where
    (ifs1.kvsr <> 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
    (ifs1.BudgetRef = new$BudgetRef);
      
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INNERFINSOURCE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (145, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=145) and (RecordId=new$ID);
  end if;

END;
/
COMMIT WORK 
/
-- ALTER TRIGGER tr_kd_au_100
CREATE OR REPLACE TRIGGER TR_KD_IU
  INSTEAD OF UPDATE
  ON KD
  FOR EACH ROW
DECLARE
  new$ID KD.ID%TYPE := :NEW.ID;
  new$REPCODE KD.REPCODE%TYPE := :NEW.REPCODE;
  new$CREATEDATE KD.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE KD.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$KVSR KD.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE KD.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE KD.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE KD.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE KD.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR KD.KESR%TYPE := :NEW.KESR;
  new$KDVALUE KD.KDVALUE%TYPE := :NEW.KDVALUE;
  new$REMOTEFLAG KD.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$UNIONFLAG KD.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$BUDGETREF KD.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE KD.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME KD.NAME%TYPE := :NEW.NAME;
  new$KD_LEVEL KD.KD_LEVEL%TYPE := :NEW.KD_LEVEL;
  new$STARTDATE KD.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME KD.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CREATERUSER KD.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER KD.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$EXTID KD.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER KD.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE KD.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID KD.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION KD.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE KD.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPKD KD.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
--
  tmp$ NUMBER(15,0);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  tmp_Double1$ NUMBER;
  DescrCode11$ NUMBER(10);
  DescrCode21$ NUMBER(10);
  KVSRCode$ NUMBER(10);
  sKVSR1$ VARCHAR2(3);
  sDescrCode11$ VARCHAR2(5);
  sDescrCode21$ VARCHAR2(5);
  sProgCode1$ VARCHAR2(4);
  sAnalyticalGroupKD1$ VARCHAR2(3);
  sKDLevel1$ NUMBER(10);
  vName1$ VARCHAR2(1024);
  vShortName1$ VARCHAR2(1024);
  vKDLevel1$ NUMBER(10);
  vDeleteDate1$ DATE;
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_KD_BU_0)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*     */
  if (new$KVSR is null) then
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupKD is null) then
    new$AnalyticalGroupKD := 0;
  END IF;
  if (new$ProgramCode is null) then
    new$ProgramCode := 0;
  END IF;
  if (new$RemoteFlag is null) then
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then
    new$BudgetRef := 0;
  END IF;
  if (new$KVSR <> 0) then
    select max(kd_level) into sKDLevel1$ from KD where ((AnalyticalGroupKD = new$AnalyticalGroupKD) and (ProgramCode=new$ProgramCode)and (BudgetRef=new$BudgetRef)
    and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
  END IF;
  if (sKDLevel1$ is not null) then
    new$kd_Level := sKDLevel1$;
  END IF;
  /*          */

  tmp$ := new$DescriptionCode;
  tmp_Double1$ := tmp$ / 100;
  new$MainDescriptionCode := tmp_Double1$;
  if (new$MainDescriptionCode > tmp_Double1$) then
    new$MainDescriptionCode := new$MainDescriptionCode - 1;
  END IF;
  tmp_Double1$ := new$MainDescriptionCode;
  tmp_Double1$ := tmp_Double1$ * 100;
  new$ItemCode := tmp$ - tmp_Double1$;
  BEGIN

    /*      */
    select Code into KVSRCode$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-   */
  /*      */
  if (KVSRCode$ = 0) then
    sKVSR1$ := '000';

  else
    if (KVSRCode$ < 10) then
      sKVSR1$ := '00' || KVSRCode$;

    else
      if (KVSRCode$ < 100) then
        sKVSR1$ := '0' || KVSRCode$;

      else
        sKVSR1$ := KVSRCode$;
      END IF;
    END IF;
  END IF;
  /*       */

  tmp$ := new$DescriptionCode;
  tmp_Double1$ := tmp$ / 100000;
  DescrCode11$ := tmp_Double1$;
  if (DescrCode11$ > tmp_Double1$) then
    DescrCode11$ := DescrCode11$ - 1;
  END IF;
  tmp_Double1$ := DescrCode11$;
  tmp_Double1$ := tmp$ - tmp_Double1$ * 100000;
  DescrCode21$ := tmp_Double1$;

  if (DescrCode11$ = 0) then
    sDescrCode11$ := '00000';

  else
    if (DescrCode11$ < 10) then
      sDescrCode11$ := '0000' || DescrCode11$;

    else
      if (DescrCode11$ < 100) then
        sDescrCode11$ := '000' || DescrCode11$;

      else
        if (DescrCode11$ < 1000) then
          sDescrCode11$ := '00' || DescrCode11$;

        else
          if (DescrCode11$ < 10000) then
            sDescrCode11$ := '0' || DescrCode11$;

          else
            sDescrCode11$ := DescrCode11$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;

  if (DescrCode21$ = 0) then
    sDescrCode21$ := '00000';

  else
    if (DescrCode21$ < 10) then
      sDescrCode21$ := '0000' || DescrCode21$;

    else
      if (DescrCode21$ < 100) then
        sDescrCode21$ := '000' || DescrCode21$;

      else
        if (DescrCode21$ < 1000) then
          sDescrCode21$ := '00' || DescrCode21$;

        else
          if (DescrCode21$ < 10000) then
            sDescrCode21$ := '0' || DescrCode21$;

          else
            sDescrCode21$ := DescrCode21$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;

  /*      */
  if (new$programcode = 0) then
    sProgCode1$ := '0000';

  else
    if (new$programcode < 10) then
      sProgCode1$ := '000' || new$programcode;

    else
      if (new$programcode < 100) then
        sProgCode1$ := '00' || new$programcode;

      else
        if (new$programcode < 1000) then
          sProgCode1$ := '0' || new$programcode;

        else
          sProgCode1$ := new$programcode;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */
    select Code into sAnalyticalGroupKD1$ from AnalyticalGroupKD where (ID = new$AnalyticalGroupKD) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    BEGIN
      select id into new$KESR from KESR where (CODE = sAnalyticalGroupKD1$) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$KESR is null) then
      new$KESR := 0;

    END IF;
  END IF;
  /*      */

  new$kdvalue := sKVSR1$ || sDescrCode11$ || sDescrCode21$ || sProgCode1$ || sAnalyticalGroupKD1$;

  if ((new$ID = 0) and (new$kdvalue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroKD');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_KD SET
    ID = new$ID,
    REPCODE = new$REPCODE,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    KDVALUE = new$KDVALUE,
    REMOTEFLAG = new$REMOTEFLAG,
    UNIONFLAG = new$UNIONFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    KD_LEVEL = new$KD_LEVEL,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPKD = new$ANALYTICALGROUPKD
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AU_100 (TR_KD_AU_100)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from kd kd1
    inner join analyticalgroupkd ag on (ag.id = kd1.analyticalgroupkd)
    where ((kd1.kvsr = 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (ag.code = (select ag1.code
    from analyticalgroupkd ag1
    where (ag1.id = new$AnalyticalGroupKD))) and
    (kd1.BudgetRef = new$BudgetRef)
    ) AND (ROWNUM = 1)                   ;
    /*    0,        =0 */
    if (not (CNT$1<> 0))
    then
      insert into KD (KVSR, DescriptionCode, ProgramCode, AnalyticalGroupKD, Name, ShortName, RemoteFlag, kd_level, budgetref, extid)
      values (0, new$DescriptionCode, new$ProgramCode, new$AnalyticalGroupKD, new$Name, new$ShortName, new$RemoteFlag, new$kd_level, new$budgetref, new$extid);
      
    END IF;
  else
    /*   = 0,         ,     */    
    vName1$ := new$Name;
    vShortName1$ := new$ShortName;
    vKDLevel1$ := new$KD_Level;
    vDeleteDate1$ := new$DeleteDate;
    /* ,      .  ,        .    ,   . */
    if ((new$DeleteDate is not null) and (new$DeleteDate < current_date)) then
      SELECT COUNT(*) INTO CNT$2
      from kd kd1
      where ((kd1.kvsr = 0) and
      ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
      (kd1.programcode = new$programcode) and
      (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and (kd1.BudgetRef = new$BudgetRef) and ((kd1.DeleteDate is null) or (kd1.DeleteDate > current_date))
      ) AND (ROWNUM = 1)                    ;
      if ((CNT$2<> 0))
      then
        BEGIN
          select kd2.Name, kd2.ShortName, kd2.KD_Level, kd2.DeleteDate                 into
          vName1$, vShortName1$, vKDLevel1$, vDeleteDate1$ from kd kd2
          where kd2.id = (select max(id) from kd kd1
          where (kd1.kvsr = 0) and
          ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
          (kd1.programcode = new$programcode) and
          (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and (kd1.BudgetRef = new$BudgetRef) and ((kd1.DeleteDate is null) or (kd1.DeleteDate > current_date)))
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;    
      END IF;
    END IF;
    update kd kd1 set
    name = vName1$,
    ShortName = vShortName1$,
    kd_level = vKDLevel1$,
    deletedate = vDeleteDate1$

    where
    (kd1.kvsr <> 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and
    (kd1.BudgetRef = new$BudgetRef);
      
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_KD_AU_500)
-- Create 28.04.2005
-- Last update 14.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (80, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=80) and (RecordId=new$ID);
  end if;

END;
/
COMMIT WORK 
/
-- ALTER TRIGGER tr_innerfinsource_bi_0
CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_II
  INSTEAD OF INSERT
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  new$ID INNERFINSOURCE.ID%TYPE := :NEW.ID;
  new$CREATEDATE INNERFINSOURCE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INNERFINSOURCE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$DIRECTION INNERFINSOURCE.DIRECTION%TYPE := :NEW.DIRECTION;
  new$KVSR INNERFINSOURCE.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE INNERFINSOURCE.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE INNERFINSOURCE.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE INNERFINSOURCE.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE INNERFINSOURCE.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR INNERFINSOURCE.KESR%TYPE := :NEW.KESR;
  new$FINSOURCEVALUE INNERFINSOURCE.FINSOURCEVALUE%TYPE := :NEW.FINSOURCEVALUE;
  new$UNIONFLAG INNERFINSOURCE.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$REMOTEFLAG INNERFINSOURCE.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$BUDGETREF INNERFINSOURCE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE INNERFINSOURCE.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME INNERFINSOURCE.NAME%TYPE := :NEW.NAME;
  new$STARTDATE INNERFINSOURCE.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME INNERFINSOURCE.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CLSASPECT INNERFINSOURCE.CLSASPECT%TYPE := :NEW.CLSASPECT;
  new$CREATERUSER INNERFINSOURCE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER INNERFINSOURCE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$IFS_LEVEL INNERFINSOURCE.IFS_LEVEL%TYPE := :NEW.IFS_LEVEL;
  new$EXTID INNERFINSOURCE.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER INNERFINSOURCE.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE INNERFINSOURCE.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID INNERFINSOURCE.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION INNERFINSOURCE.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE INNERFINSOURCE.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPIFS INNERFINSOURCE.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
--
  tmp$ NUMBER(15,0);
  CNT$1 NUMBER(10);
  vName$ VARCHAR2(1024);
  vShortName$ VARCHAR2(1024);
  vIFSLevel$ NUMBER(10);
  vDirection$ NUMBER(10);
  vDeleteDate$ DATE;
  CNT$2 NUMBER(10);
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(7);
  sDescrCode2$ VARCHAR2(7);
  sAnalyticalGroupIFS$ VARCHAR2(3);
  sIFSLevel1$ NUMBER(10);
  sDirection1$ NUMBER(10);
  AGIFS$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_INNERFINSOURCE_BI_0)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupIFS is null) then 
    new$AnalyticalGroupIFS := 0;
  END IF;
  if (new$ClsAspect is null) then 
    new$ClsAspect := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  /*     */
  if (new$KVSR <> 0) then
    select max(IFS_Level), max(Direction)
    into sIFSLevel1$, sDirection1$     from innerfinsource 
    where ((AnalyticalGroupIFS = new$AnalyticalGroupIFS) and (BudgetRef=new$BudgetRef) and 
    (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0)) 
    ;
  END IF;
  if (sIFSLevel1$ is not null) then
    new$IFS_Level := sIFSLevel1$;
  END IF;
  if (sDirection1$ is not null) then
    new$Direction := sDirection1$;
  END IF;
  /*         
            =3,5,8 */
  if (new$Direction is null) then
    if ((new$AnalyticalGroupIFS between 300 and 399) or 
    (new$AnalyticalGroupIFS between 500 and 599) or 
    (new$AnalyticalGroupIFS between 800 and 899)) then
      new$Direction := -1;
          
    else
      new$Direction := 1;
    END IF;
    GetIntConst(60, 9,AGIFS$);
    if (new$AnalyticalGroupIFS = AGIFS$) then
      new$Direction := 1;
    END IF;
    GetIntConst(60, 10,AGIFS$);
    if (new$AnalyticalGroupIFS = AGIFS$) then
      new$Direction := -1;  
      
    END IF;
  END IF;
  BEGIN
      

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-    */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*    , ,  */
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 1000000;
  DescrCode1$ := tmp_Double$;
  /*      ,
          ,    1 */
  if (DescrCode1$  > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$MainDescriptionCode := DescrCode1$; /*    */
  /*       */    
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 1000000;
  DescrCode2$ := tmp_Double$;
  tmp_Double$ := DescrCode2$ / 10000;
  DescrCode1$ := tmp_Double$;
  /*      */
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$ItemCode := DescrCode1$; /* */
  tmp_Double$ := DescrCode2$ - DescrCode1$ * 10000;
  new$ProgramCode := tmp_Double$; /* */
  /*       */
      
  tmp_Double$ := tmp$ / 10000000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 10000000;
  DescrCode2$ := tmp_Double$;
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '0000000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '000000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '00000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '0000' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '000' || DescrCode1$;
                
          else
            if (DescrCode1$ < 100000) then
              sDescrCode1$ := '00' || DescrCode1$;
                  
            else
              if (DescrCode1$ < 1000000) then
                sDescrCode1$ := '0' || DescrCode1$;
                    
              else
                sDescrCode1$ := DescrCode1$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '0000000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '000000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '00000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '0000' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '000' || DescrCode2$;
                
          else
            if (DescrCode2$ < 100000) then
              sDescrCode2$ := '00' || DescrCode2$;
                  
            else
              if (DescrCode2$ < 1000000) then
                sDescrCode2$ := '0' || DescrCode2$;
                    
              else
                sDescrCode2$ := DescrCode2$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN
    /*        */     
    select Code into sAnalyticalGroupIFS$ from AnalyticalGroupIFS where (ID = new$AnalyticalGroupIFS) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    getkesr(sAnalyticalGroupIFS$, new$BudgetRef,new$KESR);
  END IF;
  /*      */
      
  new$FinSourceValue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sAnalyticalGroupIFS$;
      
  if ((new$ID = 0) and (new$FinSourceValue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroIFS');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_INNERFINSOURCE_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_INNERFINSOURCE (
    ID,
    CREATEDATE,
    UPDATEDATE,
    DIRECTION,
    KVSR,
    DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE,
    ITEMCODE,
    PROGRAMCODE,
    KESR,
    FINSOURCEVALUE,
    UNIONFLAG,
    REMOTEFLAG,
    BUDGETREF,
    DELETEDATE,
    NAME,
    STARTDATE,
    SHORTNAME,
    CLSASPECT,
    CREATERUSER,
    UPDATERUSER,
    IFS_LEVEL,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    ANALYTICALGROUPIFS
  ) VALUES (
    new$ID,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$DIRECTION,
    new$KVSR,
    new$DESCRIPTIONCODE,
    new$MAINDESCRIPTIONCODE,
    new$ITEMCODE,
    new$PROGRAMCODE,
    new$KESR,
    new$FINSOURCEVALUE,
    new$UNIONFLAG,
    new$REMOTEFLAG,
    new$BUDGETREF,
    new$DELETEDATE,
    new$NAME,
    new$STARTDATE,
    new$SHORTNAME,
    new$CLSASPECT,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$IFS_LEVEL,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$ANALYTICALGROUPIFS);

-- - - - - - - - - - - - -
-- AI_100 (TR_INNERFINSOURCE_AI_100)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from InnerFinSource ifs1
    where ((ifs1.kvsr = 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
    (ifs1.BudgetRef = new$BudgetRef)
    ) AND (ROWNUM = 1)                   ;
    /*    0,        =0 */
    if (not (CNT$1<> 0))
    then
      insert into InnerFinSource (KVSR, DescriptionCode, AnalyticalGroupIFS, Name, ShortName, CLSAspect, RemoteFlag, IFS_Level, BudgetRef, ExtID)
      values (0, new$DescriptionCode, new$AnalyticalGroupIFS, new$Name, new$ShortName, new$CLSAspect, new$RemoteFlag, new$IFS_Level, new$BudgetRef, new$ExtID);

    END IF;
  else
    /*   = 0,         ,     */
    vName$ := new$Name;
    vShortName$ := new$ShortName;
    vIFSLevel$ := new$IFS_Level;
    vDeleteDate$ := new$DeleteDate;
    vDirection$ := new$Direction;
    /* ,      .  ,        .    ,   . */
    if ((new$DeleteDate is not null) and (new$DeleteDate < current_date)) then
      SELECT COUNT(*) INTO CNT$2
      from InnerFinSource ifs1
      where ((ifs1.kvsr = 0) and
      ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
      (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
      (ifs1.BudgetRef = new$BudgetRef) and ((ifs1.DeleteDate is null) or (ifs1.DeleteDate > current_date))
      ) AND (ROWNUM = 1)                    ;
      if ((CNT$2<> 0))
      then
        BEGIN
          select ifs2.Name, ifs2.ShortName, ifs2.IFS_Level, ifs2.Direction, ifs2.DeleteDate                 into
          vName$, vShortName$, vIFSLevel$, vDirection$, vDeleteDate$ from InnerFinSource ifs2
          where ifs2.id = (select max(id) from InnerFinSource ifs1
          where (ifs1.kvsr = 0) and
          ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
          (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
          (ifs1.BudgetRef = new$BudgetRef) and ((ifs1.DeleteDate is null) or (ifs1.DeleteDate > current_date)))
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
      END IF;
    END IF;
    update InnerFinSource ifs1 set
    name = vName$,
    ShortName = vShortName$,
    IFS_level = vIFSLevel$,
    Direction = vDirection$,
    deletedate = vDeleteDate$

    where
    (ifs1.kvsr <> 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
    (ifs1.BudgetRef = new$BudgetRef);

  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_INNERFINSOURCE_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 145) and (RecordId = new$ID);

END;
/
-- ALTER TRIGGER tr_innerfinsource_bu_0
CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_IU
  INSTEAD OF UPDATE
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  new$ID INNERFINSOURCE.ID%TYPE := :NEW.ID;
  new$CREATEDATE INNERFINSOURCE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INNERFINSOURCE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$DIRECTION INNERFINSOURCE.DIRECTION%TYPE := :NEW.DIRECTION;
  new$KVSR INNERFINSOURCE.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE INNERFINSOURCE.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE INNERFINSOURCE.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE INNERFINSOURCE.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE INNERFINSOURCE.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR INNERFINSOURCE.KESR%TYPE := :NEW.KESR;
  new$FINSOURCEVALUE INNERFINSOURCE.FINSOURCEVALUE%TYPE := :NEW.FINSOURCEVALUE;
  new$UNIONFLAG INNERFINSOURCE.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$REMOTEFLAG INNERFINSOURCE.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$BUDGETREF INNERFINSOURCE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE INNERFINSOURCE.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME INNERFINSOURCE.NAME%TYPE := :NEW.NAME;
  new$STARTDATE INNERFINSOURCE.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME INNERFINSOURCE.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CLSASPECT INNERFINSOURCE.CLSASPECT%TYPE := :NEW.CLSASPECT;
  new$CREATERUSER INNERFINSOURCE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER INNERFINSOURCE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$IFS_LEVEL INNERFINSOURCE.IFS_LEVEL%TYPE := :NEW.IFS_LEVEL;
  new$EXTID INNERFINSOURCE.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER INNERFINSOURCE.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE INNERFINSOURCE.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID INNERFINSOURCE.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION INNERFINSOURCE.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE INNERFINSOURCE.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPIFS INNERFINSOURCE.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
--
  tmp$ NUMBER(15,0);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  vName1$ VARCHAR2(1024);
  vShortName1$ VARCHAR2(1024);
  vIFSLevel1$ NUMBER(10);
  vDirection1$ NUMBER(10);
  vDeleteDate1$ DATE;
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(7);
  sDescrCode2$ VARCHAR2(7);
  sAnalyticalGroupIFS$ VARCHAR2(3);
  sIFSLevel$ NUMBER(10);
  sDirection$ NUMBER(10);
  AGIFS$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INNERFINSOURCE_BU_0)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupIFS is null) then 
    new$AnalyticalGroupIFS := 0;
  END IF;
  if (new$ClsAspect is null) then 
    new$ClsAspect := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  /*     */
  if (new$KVSR <> 0) then
    select max(IFS_Level), max(Direction) 
    into sIFSLevel$, sDirection$     from innerfinsource 
    where ((AnalyticalGroupIFS = new$AnalyticalGroupIFS) and (BudgetRef=new$BudgetRef) and 
    (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0)) 
    ;
  END IF;
  if (sIFSLevel$ is not null) then
    new$IFS_Level := sIFSLevel$;
  END IF;
  if (sDirection$ is not null) then
    new$Direction := sDirection$;
  END IF;
  /*         
            =3,5,8 */
  if (new$Direction is null) then
    if ((new$AnalyticalGroupIFS between 300 and 399) or 
    (new$AnalyticalGroupIFS between 500 and 599) or 
    (new$AnalyticalGroupIFS between 800 and 899)) then
      new$Direction := -1;
          
    else
      new$Direction := 1;
    END IF;
    GetIntConst(60, 9,AGIFS$);
    if (new$AnalyticalGroupIFS = AGIFS$) then
      new$Direction := 1;
    END IF;
    GetIntConst(60, 10,AGIFS$);
    if (new$AnalyticalGroupIFS = AGIFS$) then
      new$Direction := -1;  
      
    END IF;
  END IF;
  BEGIN
      

    /*      */ 
    select Code into KVSRCode$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-    */
  /*      */
  if (KVSRCode$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode$ < 10) then
      sKVSR$ := '00' || KVSRCode$;
          
    else
      if (KVSRCode$ < 100) then
        sKVSR$ := '0' || KVSRCode$;
            
      else
        sKVSR$ := KVSRCode$;
      END IF;
    END IF;
  END IF;
  /*    , ,  */
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 1000000;
  DescrCode1$ := tmp_Double$;
  /*      ,
          ,    1 */
  if (DescrCode1$  > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$MainDescriptionCode := DescrCode1$; /*    */
  /*       */    
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 1000000;
  DescrCode2$ := tmp_Double$;
  tmp_Double$ := DescrCode2$ / 10000;
  DescrCode1$ := tmp_Double$;
  /*      */
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$ItemCode := DescrCode1$; /* */
  tmp_Double$ := DescrCode2$ - DescrCode1$ * 10000;
  new$ProgramCode := tmp_Double$; /* */
  /*       */
      
  tmp_Double$ := tmp$ / 10000000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 10000000;
  DescrCode2$ := tmp_Double$;
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '0000000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '000000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '00000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '0000' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '000' || DescrCode1$;
                
          else
            if (DescrCode1$ < 100000) then
              sDescrCode1$ := '00' || DescrCode1$;
                  
            else
              if (DescrCode1$ < 1000000) then
                sDescrCode1$ := '0' || DescrCode1$;
                    
              else
                sDescrCode1$ := DescrCode1$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '0000000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '000000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '00000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '0000' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '000' || DescrCode2$;
                
          else
            if (DescrCode2$ < 100000) then
              sDescrCode2$ := '00' || DescrCode2$;
                  
            else
              if (DescrCode2$ < 1000000) then
                sDescrCode2$ := '0' || DescrCode2$;
                    
              else
                sDescrCode2$ := DescrCode2$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupIFS$ from AnalyticalGroupIFS where (ID = new$AnalyticalGroupIFS) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    getkesr(sAnalyticalGroupIFS$, new$BudgetRef,new$KESR);
  END IF;
  /*      */
      
  new$FinSourceValue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sAnalyticalGroupIFS$;
      
  if ((new$ID = 0) and (new$FinSourceValue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroIFS');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INNERFINSOURCE SET
    ID = new$ID,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    DIRECTION = new$DIRECTION,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    FINSOURCEVALUE = new$FINSOURCEVALUE,
    UNIONFLAG = new$UNIONFLAG,
    REMOTEFLAG = new$REMOTEFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CLSASPECT = new$CLSASPECT,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    IFS_LEVEL = new$IFS_LEVEL,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPIFS = new$ANALYTICALGROUPIFS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_INNERFINSOURCE_AU_100)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from InnerFinSource ifs1
    inner join analyticalgroupifs ag on (ag.id = ifs1.analyticalgroupifs)
    where ((ifs1.kvsr = 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ag.code = (select ag1.code
    from analyticalgroupifs ag1
    where (ag1.id = new$analyticalgroupifs))) and
    (ifs1.BudgetRef = new$BudgetRef)
    ) AND (ROWNUM = 1)                   ;
    /*    0,        =0 */
    if (not (CNT$1<> 0))
    then  
      insert into InnerFinSource (KVSR, DescriptionCode, AnalyticalGroupIFS, Name, ShortName, CLSAspect, RemoteFlag, IFS_Level, BudgetRef, ExtID)
      values (0, new$DescriptionCode, new$AnalyticalGroupIFS, new$Name, new$ShortName, new$CLSAspect, new$RemoteFlag, new$IFS_Level, new$BudgetRef, new$ExtID);
      
    END IF;
  else
    /*   = 0,         ,     */      
    vName1$ := new$Name;
    vShortName1$ := new$ShortName;
    vIFSLevel1$ := new$IFS_Level;
    vDeleteDate1$ := new$DeleteDate;
    vDirection1$ := new$Direction;
    /* ,      .  ,        .    ,   . */
    if ((new$DeleteDate is not null) and (new$DeleteDate < current_date)) then
      SELECT COUNT(*) INTO CNT$2
      from InnerFinSource ifs1
      where ((ifs1.kvsr = 0) and
      ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
      (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
      (ifs1.BudgetRef = new$BudgetRef) and ((ifs1.DeleteDate is null) or (ifs1.DeleteDate > current_date))
      ) AND (ROWNUM = 1)                    ;
      if ((CNT$2<> 0))
      then
        BEGIN
          select ifs2.Name, ifs2.ShortName, ifs2.IFS_Level, ifs2.Direction, ifs2.DeleteDate                 into
          vName1$, vShortName1$, vIFSLevel1$, vDirection1$, vDeleteDate1$ from InnerFinSource ifs2
          where ifs2.id = (select max(id) from InnerFinSource ifs1
          where (ifs1.kvsr = 0) and
          ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
          (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
          (ifs1.BudgetRef = new$BudgetRef) and ((ifs1.DeleteDate is null) or (ifs1.DeleteDate > current_date)))
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;    
      END IF;
    END IF;
    update InnerFinSource ifs1 set
    name = vName1$,
    ShortName = vShortName1$,
    IFS_level = vIFSLevel1$,
    Direction = vDirection1$,
    deletedate = vDeleteDate1$

    where
    (ifs1.kvsr <> 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
    (ifs1.BudgetRef = new$BudgetRef);
      
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INNERFINSOURCE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (145, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=145) and (RecordId=new$ID);
  end if;

END;
/
COMMIT WORK 
/
-- ALTER TRIGGER tr_kd_bi_0
CREATE OR REPLACE TRIGGER TR_KD_II
  INSTEAD OF INSERT
  ON KD
  FOR EACH ROW
DECLARE
  new$ID KD.ID%TYPE := :NEW.ID;
  new$REPCODE KD.REPCODE%TYPE := :NEW.REPCODE;
  new$CREATEDATE KD.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE KD.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$KVSR KD.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE KD.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE KD.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE KD.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE KD.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR KD.KESR%TYPE := :NEW.KESR;
  new$KDVALUE KD.KDVALUE%TYPE := :NEW.KDVALUE;
  new$REMOTEFLAG KD.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$UNIONFLAG KD.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$BUDGETREF KD.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE KD.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME KD.NAME%TYPE := :NEW.NAME;
  new$KD_LEVEL KD.KD_LEVEL%TYPE := :NEW.KD_LEVEL;
  new$STARTDATE KD.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME KD.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CREATERUSER KD.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER KD.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$EXTID KD.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER KD.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE KD.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID KD.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION KD.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE KD.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPKD KD.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
--
  tmp$ NUMBER(15,0);
  CNT$1 NUMBER(10);
  vName$ VARCHAR2(1024);
  vShortName$ VARCHAR2(1024);
  vKDLevel$ NUMBER(10);
  vDeleteDate$ DATE;
  CNT$2 NUMBER(10);
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(5);
  sDescrCode2$ VARCHAR2(5);
  sProgCode$ VARCHAR2(4);
  sAnalyticalGroupKD$ VARCHAR2(3);
  sKDLevel$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_KD_BI_0)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupKD is null) then 
    new$AnalyticalGroupKD := 0;
  END IF;
  if (new$ProgramCode is null) then 
    new$ProgramCode := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  if (new$KVSR <> 0) then
    select max(kd_level) into sKDLevel$ from KD where ((AnalyticalGroupKD = new$AnalyticalGroupKD) and (ProgramCode=new$ProgramCode)and (BudgetRef=new$BudgetRef)
    and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
  END IF;
  if (sKDLevel$ is not null) then
    new$kd_Level := sKDLevel$;
  END IF;
  /*          */
    
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100;
  new$MainDescriptionCode := tmp_Double$;
  if (new$MainDescriptionCode > tmp_Double$) then 
    new$MainDescriptionCode := new$MainDescriptionCode - 1;
  END IF;
  tmp_Double$ := new$MainDescriptionCode;
  tmp_Double$ := tmp_Double$ * 100;
  new$ItemCode := tmp$ - tmp_Double$; 
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-   */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*       */    
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 100000;
  DescrCode2$ := tmp_Double$;
      
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '00000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '0000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '00' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '0' || DescrCode1$;
                
          else
            sDescrCode1$ := DescrCode1$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '00000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '0000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '00' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '0' || DescrCode2$;
                
          else
            sDescrCode2$ := DescrCode2$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  /*      */
  if (new$programcode = 0) then
    sProgCode$ := '0000';
        
  else
    if (new$programcode < 10) then
      sProgCode$ := '000' || new$programcode;
          
    else
      if (new$programcode < 100) then
        sProgCode$ := '00' || new$programcode;
            
      else
        if (new$programcode < 1000) then
          sProgCode$ := '0' || new$programcode;
              
        else
          sProgCode$ := new$programcode;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */     
    select Code into sAnalyticalGroupKD$ from AnalyticalGroupKD where (ID = new$AnalyticalGroupKD) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    getkesr(sAnalyticalGroupKD$, new$BudgetRef,new$KESR);
  END IF;
  /*      */    
      
  new$kdvalue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sProgCode$ || sAnalyticalGroupKD$;
      
  if ((new$ID = 0) and (new$kdvalue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroKD');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_KD_BI_500)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_KD (
    ID,
    REPCODE,
    CREATEDATE,
    UPDATEDATE,
    KVSR,
    DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE,
    ITEMCODE,
    PROGRAMCODE,
    KESR,
    KDVALUE,
    REMOTEFLAG,
    UNIONFLAG,
    BUDGETREF,
    DELETEDATE,
    NAME,
    KD_LEVEL,
    STARTDATE,
    SHORTNAME,
    CREATERUSER,
    UPDATERUSER,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    ANALYTICALGROUPKD
  ) VALUES (
    new$ID,
    new$REPCODE,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$KVSR,
    new$DESCRIPTIONCODE,
    new$MAINDESCRIPTIONCODE,
    new$ITEMCODE,
    new$PROGRAMCODE,
    new$KESR,
    new$KDVALUE,
    new$REMOTEFLAG,
    new$UNIONFLAG,
    new$BUDGETREF,
    new$DELETEDATE,
    new$NAME,
    new$KD_LEVEL,
    new$STARTDATE,
    new$SHORTNAME,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$ANALYTICALGROUPKD);

-- - - - - - - - - - - - -
-- AI_100 (TR_KD_AI_100)
-- Version 12.20.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from kd kd1
    where ((kd1.kvsr = 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and (kd1.BudgetRef = new$BudgetRef)
    ) AND (ROWNUM = 1)                   ;
    if (not (CNT$1<> 0))
    then
      insert into KD (KVSR, DescriptionCode, ProgramCode, AnalyticalGroupKD, Name, ShortName, RemoteFlag, kd_level, budgetref, extid)
      values (0, new$DescriptionCode, new$ProgramCode, new$AnalyticalGroupKD, new$Name, new$ShortName, new$RemoteFlag, new$kd_level, new$budgetref, new$extid);

    END IF;
  else
    /*   = 0,         ,     */
    vName$ := new$Name;
    vShortName$ := new$ShortName;
    vKDLevel$ := new$KD_Level;
    vDeleteDate$ := new$DeleteDate;
    /* ,      .  ,        .    ,   . */
    if ((new$DeleteDate is not null) and (new$DeleteDate < current_date)) then
      SELECT COUNT(*) INTO CNT$2
      from kd kd1
      where ((kd1.kvsr = 0) and
      ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
      (kd1.programcode = new$programcode) and
      (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and (kd1.BudgetRef = new$BudgetRef) and ((kd1.DeleteDate is null) or (kd1.DeleteDate > current_date))
      ) AND (ROWNUM = 1)                    ;
      if ((CNT$2<> 0))
      then
        BEGIN
          select kd2.Name, kd2.ShortName, kd2.KD_Level, kd2.DeleteDate                 into
          vName$, vShortName$, vKDLevel$, vDeleteDate$ from kd kd2
          where kd2.id = (select max(id) from kd kd1
          where (kd1.kvsr = 0) and
          ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
          (kd1.programcode = new$programcode) and
          (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and (kd1.BudgetRef = new$BudgetRef) and ((kd1.DeleteDate is null) or (kd1.DeleteDate > current_date)))
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
      END IF;
    END IF;
    update kd kd1 set
    name = vName$,
    ShortName = vShortName$,
    kd_level = vKDLevel$,
    deletedate = vDeleteDate$

    where
    (kd1.kvsr <> 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and
    (kd1.BudgetRef = new$BudgetRef);

  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_KD_AI_500)
-- Last update 14.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 80)  and (RecordID = new$ID);

END;
/
-- ALTER TRIGGER tr_kd_bu_0
CREATE OR REPLACE TRIGGER TR_KD_IU
  INSTEAD OF UPDATE
  ON KD
  FOR EACH ROW
DECLARE
  new$ID KD.ID%TYPE := :NEW.ID;
  new$REPCODE KD.REPCODE%TYPE := :NEW.REPCODE;
  new$CREATEDATE KD.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE KD.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$KVSR KD.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE KD.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE KD.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE KD.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE KD.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR KD.KESR%TYPE := :NEW.KESR;
  new$KDVALUE KD.KDVALUE%TYPE := :NEW.KDVALUE;
  new$REMOTEFLAG KD.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$UNIONFLAG KD.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$BUDGETREF KD.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE KD.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME KD.NAME%TYPE := :NEW.NAME;
  new$KD_LEVEL KD.KD_LEVEL%TYPE := :NEW.KD_LEVEL;
  new$STARTDATE KD.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME KD.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CREATERUSER KD.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER KD.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$EXTID KD.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER KD.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE KD.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID KD.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION KD.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE KD.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPKD KD.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
--
  tmp$ NUMBER(15,0);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  vName1$ VARCHAR2(1024);
  vShortName1$ VARCHAR2(1024);
  vKDLevel1$ NUMBER(10);
  vDeleteDate1$ DATE;
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(5);
  sDescrCode2$ VARCHAR2(5);
  sProgCode$ VARCHAR2(4);
  sAnalyticalGroupKD$ VARCHAR2(3);
  sKDLevel$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_KD_BU_0)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*     */
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupKD is null) then 
    new$AnalyticalGroupKD := 0;
  END IF;
  if (new$ProgramCode is null) then 
    new$ProgramCode := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  if (new$KVSR <> 0) then
    select max(kd_level) into sKDLevel$ from KD where ((AnalyticalGroupKD = new$AnalyticalGroupKD) and (ProgramCode=new$ProgramCode)and (BudgetRef=new$BudgetRef)
    and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
  END IF;
  if (sKDLevel$ is not null) then
    new$kd_Level := sKDLevel$;
  END IF;
  /*          */
    
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100;
  new$MainDescriptionCode := tmp_Double$;
  if (new$MainDescriptionCode > tmp_Double$) then 
    new$MainDescriptionCode := new$MainDescriptionCode - 1;
  END IF;
  tmp_Double$ := new$MainDescriptionCode;
  tmp_Double$ := tmp_Double$ * 100;
  new$ItemCode := tmp$ - tmp_Double$; 
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-   */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*       */    
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 100000;
  DescrCode2$ := tmp_Double$;
      
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '00000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '0000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '00' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '0' || DescrCode1$;
                
          else
            sDescrCode1$ := DescrCode1$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '00000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '0000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '00' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '0' || DescrCode2$;
                
          else
            sDescrCode2$ := DescrCode2$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  /*      */
  if (new$programcode = 0) then
    sProgCode$ := '0000';
        
  else
    if (new$programcode < 10) then
      sProgCode$ := '000' || new$programcode;
          
    else
      if (new$programcode < 100) then
        sProgCode$ := '00' || new$programcode;
            
      else
        if (new$programcode < 1000) then
          sProgCode$ := '0' || new$programcode;
              
        else
          sProgCode$ := new$programcode;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupKD$ from AnalyticalGroupKD where (ID = new$AnalyticalGroupKD) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    getkesr(sAnalyticalGroupKD$, new$BudgetRef,new$KESR);
  END IF;
  /*      */
      
  new$kdvalue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sProgCode$ || sAnalyticalGroupKD$;
      
  if ((new$ID = 0) and (new$kdvalue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroKD');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_KD SET
    ID = new$ID,
    REPCODE = new$REPCODE,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    KDVALUE = new$KDVALUE,
    REMOTEFLAG = new$REMOTEFLAG,
    UNIONFLAG = new$UNIONFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    KD_LEVEL = new$KD_LEVEL,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPKD = new$ANALYTICALGROUPKD
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AU_100 (TR_KD_AU_100)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from kd kd1
    inner join analyticalgroupkd ag on (ag.id = kd1.analyticalgroupkd)
    where ((kd1.kvsr = 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (ag.code = (select ag1.code
    from analyticalgroupkd ag1
    where (ag1.id = new$AnalyticalGroupKD))) and
    (kd1.BudgetRef = new$BudgetRef)
    ) AND (ROWNUM = 1)                   ;
    /*    0,        =0 */
    if (not (CNT$1<> 0))
    then
      insert into KD (KVSR, DescriptionCode, ProgramCode, AnalyticalGroupKD, Name, ShortName, RemoteFlag, kd_level, budgetref, extid)
      values (0, new$DescriptionCode, new$ProgramCode, new$AnalyticalGroupKD, new$Name, new$ShortName, new$RemoteFlag, new$kd_level, new$budgetref, new$extid);
      
    END IF;
  else
    /*   = 0,         ,     */    
    vName1$ := new$Name;
    vShortName1$ := new$ShortName;
    vKDLevel1$ := new$KD_Level;
    vDeleteDate1$ := new$DeleteDate;
    /* ,      .  ,        .    ,   . */
    if ((new$DeleteDate is not null) and (new$DeleteDate < current_date)) then
      SELECT COUNT(*) INTO CNT$2
      from kd kd1
      where ((kd1.kvsr = 0) and
      ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
      (kd1.programcode = new$programcode) and
      (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and (kd1.BudgetRef = new$BudgetRef) and ((kd1.DeleteDate is null) or (kd1.DeleteDate > current_date))
      ) AND (ROWNUM = 1)                    ;
      if ((CNT$2<> 0))
      then
        BEGIN
          select kd2.Name, kd2.ShortName, kd2.KD_Level, kd2.DeleteDate                 into
          vName1$, vShortName1$, vKDLevel1$, vDeleteDate1$ from kd kd2
          where kd2.id = (select max(id) from kd kd1
          where (kd1.kvsr = 0) and
          ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
          (kd1.programcode = new$programcode) and
          (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and (kd1.BudgetRef = new$BudgetRef) and ((kd1.DeleteDate is null) or (kd1.DeleteDate > current_date)))
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;    
      END IF;
    END IF;
    update kd kd1 set
    name = vName1$,
    ShortName = vShortName1$,
    kd_level = vKDLevel1$,
    deletedate = vDeleteDate1$

    where
    (kd1.kvsr <> 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and
    (kd1.BudgetRef = new$BudgetRef);
      
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_KD_AU_500)
-- Create 28.04.2005
-- Last update 14.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (80, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=80) and (RecordId=new$ID);
  end if;

END;
/
-- ALTER TRIGGER TR_KD_BU_0
CREATE OR REPLACE TRIGGER TR_KD_IU
  INSTEAD OF UPDATE
  ON KD
  FOR EACH ROW
DECLARE
  new$ID KD.ID%TYPE := :NEW.ID;
  new$REPCODE KD.REPCODE%TYPE := :NEW.REPCODE;
  new$CREATEDATE KD.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE KD.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$KVSR KD.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE KD.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE KD.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE KD.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE KD.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR KD.KESR%TYPE := :NEW.KESR;
  new$KDVALUE KD.KDVALUE%TYPE := :NEW.KDVALUE;
  new$REMOTEFLAG KD.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$UNIONFLAG KD.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$BUDGETREF KD.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE KD.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME KD.NAME%TYPE := :NEW.NAME;
  new$KD_LEVEL KD.KD_LEVEL%TYPE := :NEW.KD_LEVEL;
  new$STARTDATE KD.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME KD.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CREATERUSER KD.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER KD.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$EXTID KD.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER KD.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE KD.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID KD.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION KD.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE KD.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPKD KD.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
--
  tmp$ NUMBER(15,0);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  vName1$ VARCHAR2(1024);
  vShortName1$ VARCHAR2(1024);
  vKDLevel1$ NUMBER(10);
  vDeleteDate1$ DATE;
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(5);
  sDescrCode2$ VARCHAR2(5);
  sProgCode$ VARCHAR2(4);
  sAnalyticalGroupKD$ VARCHAR2(3);
  sKDLevel$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_KD_BU_0)
-- Version 13.10.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*     */
--   if (new$KVSR is null) then 
--     new$KVSR := 0;
--   END IF;
--   if (new$AnalyticalGroupKD is null) then 
--     new$AnalyticalGroupKD := 0;
--   END IF;
--   if (new$ProgramCode is null) then 
--     new$ProgramCode := 0;
--   END IF;
--   if (new$RemoteFlag is null) then 
--     new$RemoteFlag := 0;
--   END IF;
--   if (new$UnionFlag is null) then 
--     new$UnionFlag := 0;
--   END IF;
--   if (new$BudgetRef is null) then 
--     new$BudgetRef := 0;
--   END IF;
--   if (new$KVSR <> 0) then
--     select max(kd_level) into sKDLevel$ from KD where ((AnalyticalGroupKD = new$AnalyticalGroupKD) and (ProgramCode=new$ProgramCode)and (BudgetRef=new$BudgetRef)
--     and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
--   END IF;
--   if (sKDLevel$ is not null) then
--     new$kd_Level := sKDLevel$;
--   END IF;
--   /*          */
--     
--   tmp$ := new$DescriptionCode;
--   tmp_Double$ := tmp$ / 100;
--   new$MainDescriptionCode := tmp_Double$;
--   if (new$MainDescriptionCode > tmp_Double$) then 
--     new$MainDescriptionCode := new$MainDescriptionCode - 1;
--   END IF;
--   tmp_Double$ := new$MainDescriptionCode;
--   tmp_Double$ := tmp_Double$ * 100;
--   new$ItemCode := tmp$ - tmp_Double$; 
--   BEGIN
-- 
--     /*      */ 
--     select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   /*  20-   */
--   /*      */
--   if (KVSRCode1$ = 0) then
--     sKVSR$ := '000';
--         
--   else
--     if (KVSRCode1$ < 10) then
--       sKVSR$ := '00' || KVSRCode1$;
--           
--     else
--       if (KVSRCode1$ < 100) then
--         sKVSR$ := '0' || KVSRCode1$;
--             
--       else
--         sKVSR$ := KVSRCode1$;
--       END IF;
--     END IF;
--   END IF;
--   /*       */    
--       
--   tmp$ := new$DescriptionCode;
--   tmp_Double$ := tmp$ / 100000;
--   DescrCode1$ := tmp_Double$;
--   if (DescrCode1$ > tmp_Double$) then 
--     DescrCode1$ := DescrCode1$ - 1;
--   END IF;
--   tmp_Double$ := DescrCode1$;
--   tmp_Double$ := tmp$ - tmp_Double$ * 100000;
--   DescrCode2$ := tmp_Double$;
--       
--   if (DescrCode1$ = 0) then
--     sDescrCode1$ := '00000';
--         
--   else
--     if (DescrCode1$ < 10) then
--       sDescrCode1$ := '0000' || DescrCode1$;
--           
--     else
--       if (DescrCode1$ < 100) then
--         sDescrCode1$ := '000' || DescrCode1$;
--             
--       else
--         if (DescrCode1$ < 1000) then
--           sDescrCode1$ := '00' || DescrCode1$;
--               
--         else
--           if (DescrCode1$ < 10000) then
--             sDescrCode1$ := '0' || DescrCode1$;
--                 
--           else
--             sDescrCode1$ := DescrCode1$;
--           END IF;
--         END IF;
--       END IF;
--     END IF;
--   END IF;
--       
--   if (DescrCode2$ = 0) then
--     sDescrCode2$ := '00000';
--         
--   else
--     if (DescrCode2$ < 10) then
--       sDescrCode2$ := '0000' || DescrCode2$;
--           
--     else
--       if (DescrCode2$ < 100) then
--         sDescrCode2$ := '000' || DescrCode2$;
--             
--       else
--         if (DescrCode2$ < 1000) then
--           sDescrCode2$ := '00' || DescrCode2$;
--               
--         else
--           if (DescrCode2$ < 10000) then
--             sDescrCode2$ := '0' || DescrCode2$;
--                 
--           else
--             sDescrCode2$ := DescrCode2$;
--           END IF;
--         END IF;
--       END IF;
--     END IF;
--   END IF;
--       
--   /*      */
--   if (new$programcode = 0) then
--     sProgCode$ := '0000';
--         
--   else
--     if (new$programcode < 10) then
--       sProgCode$ := '000' || new$programcode;
--           
--     else
--       if (new$programcode < 100) then
--         sProgCode$ := '00' || new$programcode;
--             
--       else
--         if (new$programcode < 1000) then
--           sProgCode$ := '0' || new$programcode;
--               
--         else
--           sProgCode$ := new$programcode;
--         END IF;
--       END IF;
--     END IF;
--   END IF;
--   BEGIN
-- 
--     /*        */ 
--     select Code into sAnalyticalGroupKD$ from AnalyticalGroupKD where (ID = new$AnalyticalGroupKD) ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   if (new$KESR is null) then
--     getkesr(sAnalyticalGroupKD$, new$BudgetRef,new$KESR);
--   END IF;
--   /*      */
--       
--   new$kdvalue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sProgCode$ || sAnalyticalGroupKD$;
--       
--   if ((new$ID = 0) and (new$kdvalue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
--     RaiseException('ex_CantModify_ZeroKD');
--   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_KD SET
    ID = new$ID,
    REPCODE = new$REPCODE,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    KDVALUE = new$KDVALUE,
    REMOTEFLAG = new$REMOTEFLAG,
    UNIONFLAG = new$UNIONFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    KD_LEVEL = new$KD_LEVEL,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPKD = new$ANALYTICALGROUPKD
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AU_100 (TR_KD_AU_100)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from kd kd1
    inner join analyticalgroupkd ag on (ag.id = kd1.analyticalgroupkd)
    where ((kd1.kvsr = 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (ag.code = (select ag1.code
    from analyticalgroupkd ag1
    where (ag1.id = new$AnalyticalGroupKD))) and
    (kd1.BudgetRef = new$BudgetRef)
    ) AND (ROWNUM = 1)                   ;
    /*    0,        =0 */
    if (not (CNT$1<> 0))
    then
      insert into KD (KVSR, DescriptionCode, ProgramCode, AnalyticalGroupKD, Name, ShortName, RemoteFlag, kd_level, budgetref, extid)
      values (0, new$DescriptionCode, new$ProgramCode, new$AnalyticalGroupKD, new$Name, new$ShortName, new$RemoteFlag, new$kd_level, new$budgetref, new$extid);
      
    END IF;
  else
    /*   = 0,         ,     */    
    vName1$ := new$Name;
    vShortName1$ := new$ShortName;
    vKDLevel1$ := new$KD_Level;
    vDeleteDate1$ := new$DeleteDate;
    /* ,      .  ,        .    ,   . */
    if ((new$DeleteDate is not null) and (new$DeleteDate < current_date)) then
      SELECT COUNT(*) INTO CNT$2
      from kd kd1
      where ((kd1.kvsr = 0) and
      ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
      (kd1.programcode = new$programcode) and
      (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and (kd1.BudgetRef = new$BudgetRef) and ((kd1.DeleteDate is null) or (kd1.DeleteDate > current_date))
      ) AND (ROWNUM = 1)                    ;
      if ((CNT$2<> 0))
      then
        BEGIN
          select kd2.Name, kd2.ShortName, kd2.KD_Level, kd2.DeleteDate                 into
          vName1$, vShortName1$, vKDLevel1$, vDeleteDate1$ from kd kd2
          where kd2.id = (select max(id) from kd kd1
          where (kd1.kvsr = 0) and
          ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
          (kd1.programcode = new$programcode) and
          (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and (kd1.BudgetRef = new$BudgetRef) and ((kd1.DeleteDate is null) or (kd1.DeleteDate > current_date)))
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;    
      END IF;
    END IF;
    update kd kd1 set
    name = vName1$,
    ShortName = vShortName1$,
    kd_level = vKDLevel1$,
    deletedate = vDeleteDate1$

    where
    (kd1.kvsr <> 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and
    (kd1.BudgetRef = new$BudgetRef);
      
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_KD_AU_500)
-- Create 28.04.2005
-- Last update 14.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (80, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=80) and (RecordId=new$ID);
  end if;

END;
/
ALTER TRIGGER TR_KD_BU_500 DISABLE
/
-- ALTER TRIGGER TR_KD_AU_100
CREATE OR REPLACE TRIGGER TR_KD_IU
  INSTEAD OF UPDATE
  ON KD
  FOR EACH ROW
DECLARE
  new$ID KD.ID%TYPE := :NEW.ID;
  new$REPCODE KD.REPCODE%TYPE := :NEW.REPCODE;
  new$CREATEDATE KD.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE KD.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$KVSR KD.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE KD.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE KD.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE KD.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE KD.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR KD.KESR%TYPE := :NEW.KESR;
  new$KDVALUE KD.KDVALUE%TYPE := :NEW.KDVALUE;
  new$REMOTEFLAG KD.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$UNIONFLAG KD.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$BUDGETREF KD.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE KD.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME KD.NAME%TYPE := :NEW.NAME;
  new$KD_LEVEL KD.KD_LEVEL%TYPE := :NEW.KD_LEVEL;
  new$STARTDATE KD.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME KD.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CREATERUSER KD.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER KD.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$EXTID KD.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER KD.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE KD.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID KD.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION KD.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE KD.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPKD KD.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
--
  tmp$ NUMBER(15,0);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  vName1$ VARCHAR2(1024);
  vShortName1$ VARCHAR2(1024);
  vKDLevel1$ NUMBER(10);
  vDeleteDate1$ DATE;
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(5);
  sDescrCode2$ VARCHAR2(5);
  sProgCode$ VARCHAR2(4);
  sAnalyticalGroupKD$ VARCHAR2(3);
  sKDLevel$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_KD_BU_0)
-- Version 13.10.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*     */
--   if (new$KVSR is null) then 
--     new$KVSR := 0;
--   END IF;
--   if (new$AnalyticalGroupKD is null) then 
--     new$AnalyticalGroupKD := 0;
--   END IF;
--   if (new$ProgramCode is null) then 
--     new$ProgramCode := 0;
--   END IF;
--   if (new$RemoteFlag is null) then 
--     new$RemoteFlag := 0;
--   END IF;
--   if (new$UnionFlag is null) then 
--     new$UnionFlag := 0;
--   END IF;
--   if (new$BudgetRef is null) then 
--     new$BudgetRef := 0;
--   END IF;
--   if (new$KVSR <> 0) then
--     select max(kd_level) into sKDLevel$ from KD where ((AnalyticalGroupKD = new$AnalyticalGroupKD) and (ProgramCode=new$ProgramCode)and (BudgetRef=new$BudgetRef)
--     and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
--   END IF;
--   if (sKDLevel$ is not null) then
--     new$kd_Level := sKDLevel$;
--   END IF;
--   /*          */
--     
--   tmp$ := new$DescriptionCode;
--   tmp_Double$ := tmp$ / 100;
--   new$MainDescriptionCode := tmp_Double$;
--   if (new$MainDescriptionCode > tmp_Double$) then 
--     new$MainDescriptionCode := new$MainDescriptionCode - 1;
--   END IF;
--   tmp_Double$ := new$MainDescriptionCode;
--   tmp_Double$ := tmp_Double$ * 100;
--   new$ItemCode := tmp$ - tmp_Double$; 
--   BEGIN
-- 
--     /*      */ 
--     select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   /*  20-   */
--   /*      */
--   if (KVSRCode1$ = 0) then
--     sKVSR$ := '000';
--         
--   else
--     if (KVSRCode1$ < 10) then
--       sKVSR$ := '00' || KVSRCode1$;
--           
--     else
--       if (KVSRCode1$ < 100) then
--         sKVSR$ := '0' || KVSRCode1$;
--             
--       else
--         sKVSR$ := KVSRCode1$;
--       END IF;
--     END IF;
--   END IF;
--   /*       */    
--       
--   tmp$ := new$DescriptionCode;
--   tmp_Double$ := tmp$ / 100000;
--   DescrCode1$ := tmp_Double$;
--   if (DescrCode1$ > tmp_Double$) then 
--     DescrCode1$ := DescrCode1$ - 1;
--   END IF;
--   tmp_Double$ := DescrCode1$;
--   tmp_Double$ := tmp$ - tmp_Double$ * 100000;
--   DescrCode2$ := tmp_Double$;
--       
--   if (DescrCode1$ = 0) then
--     sDescrCode1$ := '00000';
--         
--   else
--     if (DescrCode1$ < 10) then
--       sDescrCode1$ := '0000' || DescrCode1$;
--           
--     else
--       if (DescrCode1$ < 100) then
--         sDescrCode1$ := '000' || DescrCode1$;
--             
--       else
--         if (DescrCode1$ < 1000) then
--           sDescrCode1$ := '00' || DescrCode1$;
--               
--         else
--           if (DescrCode1$ < 10000) then
--             sDescrCode1$ := '0' || DescrCode1$;
--                 
--           else
--             sDescrCode1$ := DescrCode1$;
--           END IF;
--         END IF;
--       END IF;
--     END IF;
--   END IF;
--       
--   if (DescrCode2$ = 0) then
--     sDescrCode2$ := '00000';
--         
--   else
--     if (DescrCode2$ < 10) then
--       sDescrCode2$ := '0000' || DescrCode2$;
--           
--     else
--       if (DescrCode2$ < 100) then
--         sDescrCode2$ := '000' || DescrCode2$;
--             
--       else
--         if (DescrCode2$ < 1000) then
--           sDescrCode2$ := '00' || DescrCode2$;
--               
--         else
--           if (DescrCode2$ < 10000) then
--             sDescrCode2$ := '0' || DescrCode2$;
--                 
--           else
--             sDescrCode2$ := DescrCode2$;
--           END IF;
--         END IF;
--       END IF;
--     END IF;
--   END IF;
--       
--   /*      */
--   if (new$programcode = 0) then
--     sProgCode$ := '0000';
--         
--   else
--     if (new$programcode < 10) then
--       sProgCode$ := '000' || new$programcode;
--           
--     else
--       if (new$programcode < 100) then
--         sProgCode$ := '00' || new$programcode;
--             
--       else
--         if (new$programcode < 1000) then
--           sProgCode$ := '0' || new$programcode;
--               
--         else
--           sProgCode$ := new$programcode;
--         END IF;
--       END IF;
--     END IF;
--   END IF;
--   BEGIN
-- 
--     /*        */ 
--     select Code into sAnalyticalGroupKD$ from AnalyticalGroupKD where (ID = new$AnalyticalGroupKD) ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   if (new$KESR is null) then
--     getkesr(sAnalyticalGroupKD$, new$BudgetRef,new$KESR);
--   END IF;
--   /*      */
--       
--   new$kdvalue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sProgCode$ || sAnalyticalGroupKD$;
--       
--   if ((new$ID = 0) and (new$kdvalue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
--     RaiseException('ex_CantModify_ZeroKD');
--   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_KD SET
    ID = new$ID,
    REPCODE = new$REPCODE,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    KDVALUE = new$KDVALUE,
    REMOTEFLAG = new$REMOTEFLAG,
    UNIONFLAG = new$UNIONFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    KD_LEVEL = new$KD_LEVEL,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPKD = new$ANALYTICALGROUPKD
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AU_100 (TR_KD_AU_100)
-- Version 13.10.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$kvsr <> 0) then
--     SELECT COUNT(*) INTO CNT$1
--     from kd kd1
--     inner join analyticalgroupkd ag on (ag.id = kd1.analyticalgroupkd)
--     where ((kd1.kvsr = 0) and
--     ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
--     (kd1.programcode = new$programcode) and
--     (ag.code = (select ag1.code
--     from analyticalgroupkd ag1
--     where (ag1.id = new$AnalyticalGroupKD))) and
--     (kd1.BudgetRef = new$BudgetRef)
--     ) AND (ROWNUM = 1)                   ;
--     /*    0,        =0 */
--     if (not (CNT$1<> 0))
--     then
--       insert into KD (KVSR, DescriptionCode, ProgramCode, AnalyticalGroupKD, Name, ShortName, RemoteFlag, kd_level, budgetref, extid)
--       values (0, new$DescriptionCode, new$ProgramCode, new$AnalyticalGroupKD, new$Name, new$ShortName, new$RemoteFlag, new$kd_level, new$budgetref, new$extid);
--       
--     END IF;
--   else
--     /*   = 0,         ,     */    
--     vName1$ := new$Name;
--     vShortName1$ := new$ShortName;
--     vKDLevel1$ := new$KD_Level;
--     vDeleteDate1$ := new$DeleteDate;
--     /* ,      .  ,        .    ,   . */
--     if ((new$DeleteDate is not null) and (new$DeleteDate < current_date)) then
--       SELECT COUNT(*) INTO CNT$2
--       from kd kd1
--       where ((kd1.kvsr = 0) and
--       ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
--       (kd1.programcode = new$programcode) and
--       (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and (kd1.BudgetRef = new$BudgetRef) and ((kd1.DeleteDate is null) or (kd1.DeleteDate > current_date))
--       ) AND (ROWNUM = 1)                    ;
--       if ((CNT$2<> 0))
--       then
--         BEGIN
--           select kd2.Name, kd2.ShortName, kd2.KD_Level, kd2.DeleteDate                 into
--           vName1$, vShortName1$, vKDLevel1$, vDeleteDate1$ from kd kd2
--           where kd2.id = (select max(id) from kd kd1
--           where (kd1.kvsr = 0) and
--           ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
--           (kd1.programcode = new$programcode) and
--           (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and (kd1.BudgetRef = new$BudgetRef) and ((kd1.DeleteDate is null) or (kd1.DeleteDate > current_date)))
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;    
--       END IF;
--     END IF;
--     update kd kd1 set
--     name = vName1$,
--     ShortName = vShortName1$,
--     kd_level = vKDLevel1$,
--     deletedate = vDeleteDate1$
-- 
--     where
--     (kd1.kvsr <> 0) and
--     ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
--     (kd1.programcode = new$programcode) and
--     (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and
--     (kd1.BudgetRef = new$BudgetRef);
--       
--   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_KD_AU_500)
-- Create 28.04.2005
-- Last update 14.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (80, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=80) and (RecordId=new$ID);
  end if;

END;
/
commit work
/
update kd set
  KESR = (
    select max(k.id)
    from KESR k
    where
      k.CODE = (select CODE from AnalyticalGroupKD a where a.id = kd.AnalyticalGroupKD) and
      (k.BudgetRef = kd.BudgetRef) and ((k.deletedate is null) or (k.deletedate > current_date))
  )
where
  (not exists (select * from KESR where KESR.id = kd.KESR)) and
  exists (
    select *
    from KESR k
    where
      k.CODE = (select CODE from AnalyticalGroupKD a where a.id = kd.AnalyticalGroupKD) and
      (k.BudgetRef = kd.BudgetRef) and ((k.deletedate is null) or (k.deletedate > current_date))
  )
/
update kd set
  KESR = (
    select max(k.id)
    from KESR k
    where
      k.CODE = (select CODE from AnalyticalGroupKD a where a.id = kd.AnalyticalGroupKD) and
      (k.BudgetRef = 0) and ((k.deletedate is null) or (k.deletedate > current_date))
  )
where
  (not exists (select * from KESR where KESR.id = kd.KESR)) and
  exists (
    select *
    from KESR k
    where
      k.CODE = (select CODE from AnalyticalGroupKD a where a.id = kd.AnalyticalGroupKD) and
      (k.BudgetRef = 0) and ((k.deletedate is null) or (k.deletedate > current_date))
  )
/
update kd set
  KESR = 0
where
  not exists (select * from KESR where KESR.id = kd.KESR)
/
commit work
/
-- ALTER TRIGGER TR_KD_BU_0
CREATE OR REPLACE TRIGGER TR_KD_IU
  INSTEAD OF UPDATE
  ON KD
  FOR EACH ROW
DECLARE
  new$ID KD.ID%TYPE := :NEW.ID;
  new$REPCODE KD.REPCODE%TYPE := :NEW.REPCODE;
  new$CREATEDATE KD.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE KD.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$KVSR KD.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE KD.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE KD.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE KD.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE KD.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR KD.KESR%TYPE := :NEW.KESR;
  new$KDVALUE KD.KDVALUE%TYPE := :NEW.KDVALUE;
  new$REMOTEFLAG KD.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$UNIONFLAG KD.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$BUDGETREF KD.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE KD.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME KD.NAME%TYPE := :NEW.NAME;
  new$KD_LEVEL KD.KD_LEVEL%TYPE := :NEW.KD_LEVEL;
  new$STARTDATE KD.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME KD.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CREATERUSER KD.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER KD.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$EXTID KD.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER KD.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE KD.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID KD.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION KD.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE KD.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPKD KD.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
--
  tmp$ NUMBER(15,0);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  vName1$ VARCHAR2(1024);
  vShortName1$ VARCHAR2(1024);
  vKDLevel1$ NUMBER(10);
  vDeleteDate1$ DATE;
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(5);
  sDescrCode2$ VARCHAR2(5);
  sProgCode$ VARCHAR2(4);
  sAnalyticalGroupKD$ VARCHAR2(3);
  sKDLevel$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_KD_BU_0)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*     */
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupKD is null) then 
    new$AnalyticalGroupKD := 0;
  END IF;
  if (new$ProgramCode is null) then 
    new$ProgramCode := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  if (new$KVSR <> 0) then
    select max(kd_level) into sKDLevel$ from KD where ((AnalyticalGroupKD = new$AnalyticalGroupKD) and (ProgramCode=new$ProgramCode)and (BudgetRef=new$BudgetRef)
    and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
  END IF;
  if (sKDLevel$ is not null) then
    new$kd_Level := sKDLevel$;
  END IF;
  /*          */
    
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100;
  new$MainDescriptionCode := tmp_Double$;
  if (new$MainDescriptionCode > tmp_Double$) then 
    new$MainDescriptionCode := new$MainDescriptionCode - 1;
  END IF;
  tmp_Double$ := new$MainDescriptionCode;
  tmp_Double$ := tmp_Double$ * 100;
  new$ItemCode := tmp$ - tmp_Double$; 
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-   */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*       */    
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 100000;
  DescrCode2$ := tmp_Double$;
      
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '00000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '0000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '00' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '0' || DescrCode1$;
                
          else
            sDescrCode1$ := DescrCode1$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '00000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '0000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '00' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '0' || DescrCode2$;
                
          else
            sDescrCode2$ := DescrCode2$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  /*      */
  if (new$programcode = 0) then
    sProgCode$ := '0000';
        
  else
    if (new$programcode < 10) then
      sProgCode$ := '000' || new$programcode;
          
    else
      if (new$programcode < 100) then
        sProgCode$ := '00' || new$programcode;
            
      else
        if (new$programcode < 1000) then
          sProgCode$ := '0' || new$programcode;
              
        else
          sProgCode$ := new$programcode;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupKD$ from AnalyticalGroupKD where (ID = new$AnalyticalGroupKD) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    getkesr(sAnalyticalGroupKD$, new$BudgetRef,new$KESR);
  END IF;
  /*      */
      
  new$kdvalue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sProgCode$ || sAnalyticalGroupKD$;
      
  if ((new$ID = 0) and (new$kdvalue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroKD');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_KD SET
    ID = new$ID,
    REPCODE = new$REPCODE,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    KDVALUE = new$KDVALUE,
    REMOTEFLAG = new$REMOTEFLAG,
    UNIONFLAG = new$UNIONFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    KD_LEVEL = new$KD_LEVEL,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPKD = new$ANALYTICALGROUPKD
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AU_100 (TR_KD_AU_100)
-- Version 13.10.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$kvsr <> 0) then
--     SELECT COUNT(*) INTO CNT$1
--     from kd kd1
--     inner join analyticalgroupkd ag on (ag.id = kd1.analyticalgroupkd)
--     where ((kd1.kvsr = 0) and
--     ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
--     (kd1.programcode = new$programcode) and
--     (ag.code = (select ag1.code
--     from analyticalgroupkd ag1
--     where (ag1.id = new$AnalyticalGroupKD))) and
--     (kd1.BudgetRef = new$BudgetRef)
--     ) AND (ROWNUM = 1)                   ;
--     /*    0,        =0 */
--     if (not (CNT$1<> 0))
--     then
--       insert into KD (KVSR, DescriptionCode, ProgramCode, AnalyticalGroupKD, Name, ShortName, RemoteFlag, kd_level, budgetref, extid)
--       values (0, new$DescriptionCode, new$ProgramCode, new$AnalyticalGroupKD, new$Name, new$ShortName, new$RemoteFlag, new$kd_level, new$budgetref, new$extid);
--       
--     END IF;
--   else
--     /*   = 0,         ,     */    
--     vName1$ := new$Name;
--     vShortName1$ := new$ShortName;
--     vKDLevel1$ := new$KD_Level;
--     vDeleteDate1$ := new$DeleteDate;
--     /* ,      .  ,        .    ,   . */
--     if ((new$DeleteDate is not null) and (new$DeleteDate < current_date)) then
--       SELECT COUNT(*) INTO CNT$2
--       from kd kd1
--       where ((kd1.kvsr = 0) and
--       ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
--       (kd1.programcode = new$programcode) and
--       (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and (kd1.BudgetRef = new$BudgetRef) and ((kd1.DeleteDate is null) or (kd1.DeleteDate > current_date))
--       ) AND (ROWNUM = 1)                    ;
--       if ((CNT$2<> 0))
--       then
--         BEGIN
--           select kd2.Name, kd2.ShortName, kd2.KD_Level, kd2.DeleteDate                 into
--           vName1$, vShortName1$, vKDLevel1$, vDeleteDate1$ from kd kd2
--           where kd2.id = (select max(id) from kd kd1
--           where (kd1.kvsr = 0) and
--           ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
--           (kd1.programcode = new$programcode) and
--           (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and (kd1.BudgetRef = new$BudgetRef) and ((kd1.DeleteDate is null) or (kd1.DeleteDate > current_date)))
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;    
--       END IF;
--     END IF;
--     update kd kd1 set
--     name = vName1$,
--     ShortName = vShortName1$,
--     kd_level = vKDLevel1$,
--     deletedate = vDeleteDate1$
-- 
--     where
--     (kd1.kvsr <> 0) and
--     ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
--     (kd1.programcode = new$programcode) and
--     (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and
--     (kd1.BudgetRef = new$BudgetRef);
--       
--   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_KD_AU_500)
-- Create 28.04.2005
-- Last update 14.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (80, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=80) and (RecordId=new$ID);
  end if;

END;
/
ALTER TRIGGER TR_KD_BU_500 ENABLE
/
-- ALTER TRIGGER TR_KD_AU_100
CREATE OR REPLACE TRIGGER TR_KD_IU
  INSTEAD OF UPDATE
  ON KD
  FOR EACH ROW
DECLARE
  new$ID KD.ID%TYPE := :NEW.ID;
  new$REPCODE KD.REPCODE%TYPE := :NEW.REPCODE;
  new$CREATEDATE KD.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE KD.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$KVSR KD.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE KD.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE KD.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE KD.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE KD.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR KD.KESR%TYPE := :NEW.KESR;
  new$KDVALUE KD.KDVALUE%TYPE := :NEW.KDVALUE;
  new$REMOTEFLAG KD.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$UNIONFLAG KD.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$BUDGETREF KD.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE KD.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME KD.NAME%TYPE := :NEW.NAME;
  new$KD_LEVEL KD.KD_LEVEL%TYPE := :NEW.KD_LEVEL;
  new$STARTDATE KD.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME KD.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CREATERUSER KD.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER KD.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$EXTID KD.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER KD.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE KD.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID KD.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION KD.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE KD.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPKD KD.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
--
  tmp$ NUMBER(15,0);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  vName1$ VARCHAR2(1024);
  vShortName1$ VARCHAR2(1024);
  vKDLevel1$ NUMBER(10);
  vDeleteDate1$ DATE;
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(5);
  sDescrCode2$ VARCHAR2(5);
  sProgCode$ VARCHAR2(4);
  sAnalyticalGroupKD$ VARCHAR2(3);
  sKDLevel$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_KD_BU_0)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*     */
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupKD is null) then 
    new$AnalyticalGroupKD := 0;
  END IF;
  if (new$ProgramCode is null) then 
    new$ProgramCode := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  if (new$KVSR <> 0) then
    select max(kd_level) into sKDLevel$ from KD where ((AnalyticalGroupKD = new$AnalyticalGroupKD) and (ProgramCode=new$ProgramCode)and (BudgetRef=new$BudgetRef)
    and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
  END IF;
  if (sKDLevel$ is not null) then
    new$kd_Level := sKDLevel$;
  END IF;
  /*          */
    
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100;
  new$MainDescriptionCode := tmp_Double$;
  if (new$MainDescriptionCode > tmp_Double$) then 
    new$MainDescriptionCode := new$MainDescriptionCode - 1;
  END IF;
  tmp_Double$ := new$MainDescriptionCode;
  tmp_Double$ := tmp_Double$ * 100;
  new$ItemCode := tmp$ - tmp_Double$; 
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-   */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*       */    
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 100000;
  DescrCode2$ := tmp_Double$;
      
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '00000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '0000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '00' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '0' || DescrCode1$;
                
          else
            sDescrCode1$ := DescrCode1$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '00000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '0000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '00' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '0' || DescrCode2$;
                
          else
            sDescrCode2$ := DescrCode2$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  /*      */
  if (new$programcode = 0) then
    sProgCode$ := '0000';
        
  else
    if (new$programcode < 10) then
      sProgCode$ := '000' || new$programcode;
          
    else
      if (new$programcode < 100) then
        sProgCode$ := '00' || new$programcode;
            
      else
        if (new$programcode < 1000) then
          sProgCode$ := '0' || new$programcode;
              
        else
          sProgCode$ := new$programcode;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupKD$ from AnalyticalGroupKD where (ID = new$AnalyticalGroupKD) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    getkesr(sAnalyticalGroupKD$, new$BudgetRef,new$KESR);
  END IF;
  /*      */
      
  new$kdvalue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sProgCode$ || sAnalyticalGroupKD$;
      
  if ((new$ID = 0) and (new$kdvalue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroKD');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_KD SET
    ID = new$ID,
    REPCODE = new$REPCODE,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    KDVALUE = new$KDVALUE,
    REMOTEFLAG = new$REMOTEFLAG,
    UNIONFLAG = new$UNIONFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    KD_LEVEL = new$KD_LEVEL,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPKD = new$ANALYTICALGROUPKD
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AU_100 (TR_KD_AU_100)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from kd kd1
    inner join analyticalgroupkd ag on (ag.id = kd1.analyticalgroupkd)
    where ((kd1.kvsr = 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (ag.code = (select ag1.code
    from analyticalgroupkd ag1
    where (ag1.id = new$AnalyticalGroupKD))) and
    (kd1.BudgetRef = new$BudgetRef)
    ) AND (ROWNUM = 1)                   ;
    /*    0,        =0 */
    if (not (CNT$1<> 0))
    then
      insert into KD (KVSR, DescriptionCode, ProgramCode, AnalyticalGroupKD, Name, ShortName, RemoteFlag, kd_level, budgetref, extid)
      values (0, new$DescriptionCode, new$ProgramCode, new$AnalyticalGroupKD, new$Name, new$ShortName, new$RemoteFlag, new$kd_level, new$budgetref, new$extid);
      
    END IF;
  else
    /*   = 0,         ,     */    
    vName1$ := new$Name;
    vShortName1$ := new$ShortName;
    vKDLevel1$ := new$KD_Level;
    vDeleteDate1$ := new$DeleteDate;
    /* ,      .  ,        .    ,   . */
    if ((new$DeleteDate is not null) and (new$DeleteDate < current_date)) then
      SELECT COUNT(*) INTO CNT$2
      from kd kd1
      where ((kd1.kvsr = 0) and
      ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
      (kd1.programcode = new$programcode) and
      (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and (kd1.BudgetRef = new$BudgetRef) and ((kd1.DeleteDate is null) or (kd1.DeleteDate > current_date))
      ) AND (ROWNUM = 1)                    ;
      if ((CNT$2<> 0))
      then
        BEGIN
          select kd2.Name, kd2.ShortName, kd2.KD_Level, kd2.DeleteDate                 into
          vName1$, vShortName1$, vKDLevel1$, vDeleteDate1$ from kd kd2
          where kd2.id = (select max(id) from kd kd1
          where (kd1.kvsr = 0) and
          ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
          (kd1.programcode = new$programcode) and
          (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and (kd1.BudgetRef = new$BudgetRef) and ((kd1.DeleteDate is null) or (kd1.DeleteDate > current_date)))
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;    
      END IF;
    END IF;
    update kd kd1 set
    name = vName1$,
    ShortName = vShortName1$,
    kd_level = vKDLevel1$,
    deletedate = vDeleteDate1$

    where
    (kd1.kvsr <> 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and
    (kd1.BudgetRef = new$BudgetRef);
      
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_KD_AU_500)
-- Create 28.04.2005
-- Last update 14.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (80, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=80) and (RecordId=new$ID);
  end if;

END;
/
commit work
/
-- ALTER TRIGGER TR_INNERFINSOURCE_BU_0
CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_IU
  INSTEAD OF UPDATE
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  new$ID INNERFINSOURCE.ID%TYPE := :NEW.ID;
  new$CREATEDATE INNERFINSOURCE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INNERFINSOURCE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$DIRECTION INNERFINSOURCE.DIRECTION%TYPE := :NEW.DIRECTION;
  new$KVSR INNERFINSOURCE.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE INNERFINSOURCE.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE INNERFINSOURCE.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE INNERFINSOURCE.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE INNERFINSOURCE.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR INNERFINSOURCE.KESR%TYPE := :NEW.KESR;
  new$FINSOURCEVALUE INNERFINSOURCE.FINSOURCEVALUE%TYPE := :NEW.FINSOURCEVALUE;
  new$UNIONFLAG INNERFINSOURCE.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$REMOTEFLAG INNERFINSOURCE.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$BUDGETREF INNERFINSOURCE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE INNERFINSOURCE.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME INNERFINSOURCE.NAME%TYPE := :NEW.NAME;
  new$STARTDATE INNERFINSOURCE.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME INNERFINSOURCE.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CLSASPECT INNERFINSOURCE.CLSASPECT%TYPE := :NEW.CLSASPECT;
  new$CREATERUSER INNERFINSOURCE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER INNERFINSOURCE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$IFS_LEVEL INNERFINSOURCE.IFS_LEVEL%TYPE := :NEW.IFS_LEVEL;
  new$EXTID INNERFINSOURCE.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER INNERFINSOURCE.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE INNERFINSOURCE.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID INNERFINSOURCE.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION INNERFINSOURCE.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE INNERFINSOURCE.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPIFS INNERFINSOURCE.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
--
  tmp$ NUMBER(15,0);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  vName1$ VARCHAR2(1024);
  vShortName1$ VARCHAR2(1024);
  vIFSLevel1$ NUMBER(10);
  vDirection1$ NUMBER(10);
  vDeleteDate1$ DATE;
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(7);
  sDescrCode2$ VARCHAR2(7);
  sAnalyticalGroupIFS$ VARCHAR2(3);
  sIFSLevel$ NUMBER(10);
  sDirection$ NUMBER(10);
  AGIFS$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INNERFINSOURCE_BU_0)
-- Version 13.10.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*  Id,     */
--   if (new$id is null) then 
--     select g_shared.nextval into new$id from dual;
--   END IF;
--   if (new$KVSR is null) then 
--     new$KVSR := 0;
--   END IF;
--   if (new$AnalyticalGroupIFS is null) then 
--     new$AnalyticalGroupIFS := 0;
--   END IF;
--   if (new$ClsAspect is null) then 
--     new$ClsAspect := 0;
--   END IF;
--   if (new$UnionFlag is null) then 
--     new$UnionFlag := 0;
--   END IF;
--   if (new$RemoteFlag is null) then 
--     new$RemoteFlag := 0;
--   END IF;
--   if (new$BudgetRef is null) then 
--     new$BudgetRef := 0;
--   END IF;
--   /*     */
--   if (new$KVSR <> 0) then
--     select max(IFS_Level), max(Direction) 
--     into sIFSLevel$, sDirection$     from innerfinsource 
--     where ((AnalyticalGroupIFS = new$AnalyticalGroupIFS) and (BudgetRef=new$BudgetRef) and 
--     (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0)) 
--     ;
--   END IF;
--   if (sIFSLevel$ is not null) then
--     new$IFS_Level := sIFSLevel$;
--   END IF;
--   if (sDirection$ is not null) then
--     new$Direction := sDirection$;
--   END IF;
--   /*         
--             =3,5,8 */
--   if (new$Direction is null) then
--     if ((new$AnalyticalGroupIFS between 300 and 399) or 
--     (new$AnalyticalGroupIFS between 500 and 599) or 
--     (new$AnalyticalGroupIFS between 800 and 899)) then
--       new$Direction := -1;
--           
--     else
--       new$Direction := 1;
--     END IF;
--     GetIntConst(60, 9,AGIFS$);
--     if (new$AnalyticalGroupIFS = AGIFS$) then
--       new$Direction := 1;
--     END IF;
--     GetIntConst(60, 10,AGIFS$);
--     if (new$AnalyticalGroupIFS = AGIFS$) then
--       new$Direction := -1;  
--       
--     END IF;
--   END IF;
--   BEGIN
--       
-- 
--     /*      */ 
--     select Code into KVSRCode$ from KVSR where (ID = new$KVSR) ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   /*  20-    */
--   /*      */
--   if (KVSRCode$ = 0) then
--     sKVSR$ := '000';
--         
--   else
--     if (KVSRCode$ < 10) then
--       sKVSR$ := '00' || KVSRCode$;
--           
--     else
--       if (KVSRCode$ < 100) then
--         sKVSR$ := '0' || KVSRCode$;
--             
--       else
--         sKVSR$ := KVSRCode$;
--       END IF;
--     END IF;
--   END IF;
--   /*    , ,  */
--       
--   tmp$ := new$DescriptionCode;
--   tmp_Double$ := tmp$ / 1000000;
--   DescrCode1$ := tmp_Double$;
--   /*      ,
--           ,    1 */
--   if (DescrCode1$  > tmp_Double$) then 
--     DescrCode1$ := DescrCode1$ - 1;
--   END IF;
--   new$MainDescriptionCode := DescrCode1$; /*    */
--   /*       */    
--   tmp_Double$ := DescrCode1$;
--   tmp_Double$ := tmp$ - tmp_Double$ * 1000000;
--   DescrCode2$ := tmp_Double$;
--   tmp_Double$ := DescrCode2$ / 10000;
--   DescrCode1$ := tmp_Double$;
--   /*      */
--   if (DescrCode1$ > tmp_Double$) then 
--     DescrCode1$ := DescrCode1$ - 1;
--   END IF;
--   new$ItemCode := DescrCode1$; /* */
--   tmp_Double$ := DescrCode2$ - DescrCode1$ * 10000;
--   new$ProgramCode := tmp_Double$; /* */
--   /*       */
--       
--   tmp_Double$ := tmp$ / 10000000;
--   DescrCode1$ := tmp_Double$;
--   if (DescrCode1$ > tmp_Double$) then 
--     DescrCode1$ := DescrCode1$ - 1;
--   END IF;
--   tmp_Double$ := DescrCode1$;
--   tmp_Double$ := tmp$ - tmp_Double$ * 10000000;
--   DescrCode2$ := tmp_Double$;
--   if (DescrCode1$ = 0) then
--     sDescrCode1$ := '0000000';
--         
--   else
--     if (DescrCode1$ < 10) then
--       sDescrCode1$ := '000000' || DescrCode1$;
--           
--     else
--       if (DescrCode1$ < 100) then
--         sDescrCode1$ := '00000' || DescrCode1$;
--             
--       else
--         if (DescrCode1$ < 1000) then
--           sDescrCode1$ := '0000' || DescrCode1$;
--               
--         else
--           if (DescrCode1$ < 10000) then
--             sDescrCode1$ := '000' || DescrCode1$;
--                 
--           else
--             if (DescrCode1$ < 100000) then
--               sDescrCode1$ := '00' || DescrCode1$;
--                   
--             else
--               if (DescrCode1$ < 1000000) then
--                 sDescrCode1$ := '0' || DescrCode1$;
--                     
--               else
--                 sDescrCode1$ := DescrCode1$;
--               END IF;
--             END IF;
--           END IF;
--         END IF;
--       END IF;
--     END IF;
--   END IF;
--   if (DescrCode2$ = 0) then
--     sDescrCode2$ := '0000000';
--         
--   else
--     if (DescrCode2$ < 10) then
--       sDescrCode2$ := '000000' || DescrCode2$;
--           
--     else
--       if (DescrCode2$ < 100) then
--         sDescrCode2$ := '00000' || DescrCode2$;
--             
--       else
--         if (DescrCode2$ < 1000) then
--           sDescrCode2$ := '0000' || DescrCode2$;
--               
--         else
--           if (DescrCode2$ < 10000) then
--             sDescrCode2$ := '000' || DescrCode2$;
--                 
--           else
--             if (DescrCode2$ < 100000) then
--               sDescrCode2$ := '00' || DescrCode2$;
--                   
--             else
--               if (DescrCode2$ < 1000000) then
--                 sDescrCode2$ := '0' || DescrCode2$;
--                     
--               else
--                 sDescrCode2$ := DescrCode2$;
--               END IF;
--             END IF;
--           END IF;
--         END IF;
--       END IF;
--     END IF;
--   END IF;
--   BEGIN
-- 
--     /*        */ 
--     select Code into sAnalyticalGroupIFS$ from AnalyticalGroupIFS where (ID = new$AnalyticalGroupIFS) ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   if (new$KESR is null) then
--     getkesr(sAnalyticalGroupIFS$, new$BudgetRef,new$KESR);
--   END IF;
--   /*      */
--       
--   new$FinSourceValue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sAnalyticalGroupIFS$;
--       
--   if ((new$ID = 0) and (new$FinSourceValue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
--     RaiseException('ex_CantModify_ZeroIFS');
--   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INNERFINSOURCE SET
    ID = new$ID,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    DIRECTION = new$DIRECTION,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    FINSOURCEVALUE = new$FINSOURCEVALUE,
    UNIONFLAG = new$UNIONFLAG,
    REMOTEFLAG = new$REMOTEFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CLSASPECT = new$CLSASPECT,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    IFS_LEVEL = new$IFS_LEVEL,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPIFS = new$ANALYTICALGROUPIFS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_INNERFINSOURCE_AU_100)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from InnerFinSource ifs1
    inner join analyticalgroupifs ag on (ag.id = ifs1.analyticalgroupifs)
    where ((ifs1.kvsr = 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ag.code = (select ag1.code
    from analyticalgroupifs ag1
    where (ag1.id = new$analyticalgroupifs))) and
    (ifs1.BudgetRef = new$BudgetRef)
    ) AND (ROWNUM = 1)                   ;
    /*    0,        =0 */
    if (not (CNT$1<> 0))
    then  
      insert into InnerFinSource (KVSR, DescriptionCode, AnalyticalGroupIFS, Name, ShortName, CLSAspect, RemoteFlag, IFS_Level, BudgetRef, ExtID)
      values (0, new$DescriptionCode, new$AnalyticalGroupIFS, new$Name, new$ShortName, new$CLSAspect, new$RemoteFlag, new$IFS_Level, new$BudgetRef, new$ExtID);
      
    END IF;
  else
    /*   = 0,         ,     */      
    vName1$ := new$Name;
    vShortName1$ := new$ShortName;
    vIFSLevel1$ := new$IFS_Level;
    vDeleteDate1$ := new$DeleteDate;
    vDirection1$ := new$Direction;
    /* ,      .  ,        .    ,   . */
    if ((new$DeleteDate is not null) and (new$DeleteDate < current_date)) then
      SELECT COUNT(*) INTO CNT$2
      from InnerFinSource ifs1
      where ((ifs1.kvsr = 0) and
      ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
      (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
      (ifs1.BudgetRef = new$BudgetRef) and ((ifs1.DeleteDate is null) or (ifs1.DeleteDate > current_date))
      ) AND (ROWNUM = 1)                    ;
      if ((CNT$2<> 0))
      then
        BEGIN
          select ifs2.Name, ifs2.ShortName, ifs2.IFS_Level, ifs2.Direction, ifs2.DeleteDate                 into
          vName1$, vShortName1$, vIFSLevel1$, vDirection1$, vDeleteDate1$ from InnerFinSource ifs2
          where ifs2.id = (select max(id) from InnerFinSource ifs1
          where (ifs1.kvsr = 0) and
          ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
          (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
          (ifs1.BudgetRef = new$BudgetRef) and ((ifs1.DeleteDate is null) or (ifs1.DeleteDate > current_date)))
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;    
      END IF;
    END IF;
    update InnerFinSource ifs1 set
    name = vName1$,
    ShortName = vShortName1$,
    IFS_level = vIFSLevel1$,
    Direction = vDirection1$,
    deletedate = vDeleteDate1$

    where
    (ifs1.kvsr <> 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
    (ifs1.BudgetRef = new$BudgetRef);
      
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INNERFINSOURCE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (145, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=145) and (RecordId=new$ID);
  end if;

END;
/
ALTER TRIGGER TR_INNERFINSOURCE_BU_500 DISABLE
/
-- ALTER TRIGGER TR_INNERFINSOURCE_AU_100
CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_IU
  INSTEAD OF UPDATE
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  new$ID INNERFINSOURCE.ID%TYPE := :NEW.ID;
  new$CREATEDATE INNERFINSOURCE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INNERFINSOURCE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$DIRECTION INNERFINSOURCE.DIRECTION%TYPE := :NEW.DIRECTION;
  new$KVSR INNERFINSOURCE.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE INNERFINSOURCE.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE INNERFINSOURCE.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE INNERFINSOURCE.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE INNERFINSOURCE.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR INNERFINSOURCE.KESR%TYPE := :NEW.KESR;
  new$FINSOURCEVALUE INNERFINSOURCE.FINSOURCEVALUE%TYPE := :NEW.FINSOURCEVALUE;
  new$UNIONFLAG INNERFINSOURCE.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$REMOTEFLAG INNERFINSOURCE.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$BUDGETREF INNERFINSOURCE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE INNERFINSOURCE.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME INNERFINSOURCE.NAME%TYPE := :NEW.NAME;
  new$STARTDATE INNERFINSOURCE.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME INNERFINSOURCE.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CLSASPECT INNERFINSOURCE.CLSASPECT%TYPE := :NEW.CLSASPECT;
  new$CREATERUSER INNERFINSOURCE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER INNERFINSOURCE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$IFS_LEVEL INNERFINSOURCE.IFS_LEVEL%TYPE := :NEW.IFS_LEVEL;
  new$EXTID INNERFINSOURCE.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER INNERFINSOURCE.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE INNERFINSOURCE.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID INNERFINSOURCE.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION INNERFINSOURCE.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE INNERFINSOURCE.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPIFS INNERFINSOURCE.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
--
  tmp$ NUMBER(15,0);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  vName1$ VARCHAR2(1024);
  vShortName1$ VARCHAR2(1024);
  vIFSLevel1$ NUMBER(10);
  vDirection1$ NUMBER(10);
  vDeleteDate1$ DATE;
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(7);
  sDescrCode2$ VARCHAR2(7);
  sAnalyticalGroupIFS$ VARCHAR2(3);
  sIFSLevel$ NUMBER(10);
  sDirection$ NUMBER(10);
  AGIFS$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INNERFINSOURCE_BU_0)
-- Version 13.10.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*  Id,     */
--   if (new$id is null) then 
--     select g_shared.nextval into new$id from dual;
--   END IF;
--   if (new$KVSR is null) then 
--     new$KVSR := 0;
--   END IF;
--   if (new$AnalyticalGroupIFS is null) then 
--     new$AnalyticalGroupIFS := 0;
--   END IF;
--   if (new$ClsAspect is null) then 
--     new$ClsAspect := 0;
--   END IF;
--   if (new$UnionFlag is null) then 
--     new$UnionFlag := 0;
--   END IF;
--   if (new$RemoteFlag is null) then 
--     new$RemoteFlag := 0;
--   END IF;
--   if (new$BudgetRef is null) then 
--     new$BudgetRef := 0;
--   END IF;
--   /*     */
--   if (new$KVSR <> 0) then
--     select max(IFS_Level), max(Direction) 
--     into sIFSLevel$, sDirection$     from innerfinsource 
--     where ((AnalyticalGroupIFS = new$AnalyticalGroupIFS) and (BudgetRef=new$BudgetRef) and 
--     (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0)) 
--     ;
--   END IF;
--   if (sIFSLevel$ is not null) then
--     new$IFS_Level := sIFSLevel$;
--   END IF;
--   if (sDirection$ is not null) then
--     new$Direction := sDirection$;
--   END IF;
--   /*         
--             =3,5,8 */
--   if (new$Direction is null) then
--     if ((new$AnalyticalGroupIFS between 300 and 399) or 
--     (new$AnalyticalGroupIFS between 500 and 599) or 
--     (new$AnalyticalGroupIFS between 800 and 899)) then
--       new$Direction := -1;
--           
--     else
--       new$Direction := 1;
--     END IF;
--     GetIntConst(60, 9,AGIFS$);
--     if (new$AnalyticalGroupIFS = AGIFS$) then
--       new$Direction := 1;
--     END IF;
--     GetIntConst(60, 10,AGIFS$);
--     if (new$AnalyticalGroupIFS = AGIFS$) then
--       new$Direction := -1;  
--       
--     END IF;
--   END IF;
--   BEGIN
--       
-- 
--     /*      */ 
--     select Code into KVSRCode$ from KVSR where (ID = new$KVSR) ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   /*  20-    */
--   /*      */
--   if (KVSRCode$ = 0) then
--     sKVSR$ := '000';
--         
--   else
--     if (KVSRCode$ < 10) then
--       sKVSR$ := '00' || KVSRCode$;
--           
--     else
--       if (KVSRCode$ < 100) then
--         sKVSR$ := '0' || KVSRCode$;
--             
--       else
--         sKVSR$ := KVSRCode$;
--       END IF;
--     END IF;
--   END IF;
--   /*    , ,  */
--       
--   tmp$ := new$DescriptionCode;
--   tmp_Double$ := tmp$ / 1000000;
--   DescrCode1$ := tmp_Double$;
--   /*      ,
--           ,    1 */
--   if (DescrCode1$  > tmp_Double$) then 
--     DescrCode1$ := DescrCode1$ - 1;
--   END IF;
--   new$MainDescriptionCode := DescrCode1$; /*    */
--   /*       */    
--   tmp_Double$ := DescrCode1$;
--   tmp_Double$ := tmp$ - tmp_Double$ * 1000000;
--   DescrCode2$ := tmp_Double$;
--   tmp_Double$ := DescrCode2$ / 10000;
--   DescrCode1$ := tmp_Double$;
--   /*      */
--   if (DescrCode1$ > tmp_Double$) then 
--     DescrCode1$ := DescrCode1$ - 1;
--   END IF;
--   new$ItemCode := DescrCode1$; /* */
--   tmp_Double$ := DescrCode2$ - DescrCode1$ * 10000;
--   new$ProgramCode := tmp_Double$; /* */
--   /*       */
--       
--   tmp_Double$ := tmp$ / 10000000;
--   DescrCode1$ := tmp_Double$;
--   if (DescrCode1$ > tmp_Double$) then 
--     DescrCode1$ := DescrCode1$ - 1;
--   END IF;
--   tmp_Double$ := DescrCode1$;
--   tmp_Double$ := tmp$ - tmp_Double$ * 10000000;
--   DescrCode2$ := tmp_Double$;
--   if (DescrCode1$ = 0) then
--     sDescrCode1$ := '0000000';
--         
--   else
--     if (DescrCode1$ < 10) then
--       sDescrCode1$ := '000000' || DescrCode1$;
--           
--     else
--       if (DescrCode1$ < 100) then
--         sDescrCode1$ := '00000' || DescrCode1$;
--             
--       else
--         if (DescrCode1$ < 1000) then
--           sDescrCode1$ := '0000' || DescrCode1$;
--               
--         else
--           if (DescrCode1$ < 10000) then
--             sDescrCode1$ := '000' || DescrCode1$;
--                 
--           else
--             if (DescrCode1$ < 100000) then
--               sDescrCode1$ := '00' || DescrCode1$;
--                   
--             else
--               if (DescrCode1$ < 1000000) then
--                 sDescrCode1$ := '0' || DescrCode1$;
--                     
--               else
--                 sDescrCode1$ := DescrCode1$;
--               END IF;
--             END IF;
--           END IF;
--         END IF;
--       END IF;
--     END IF;
--   END IF;
--   if (DescrCode2$ = 0) then
--     sDescrCode2$ := '0000000';
--         
--   else
--     if (DescrCode2$ < 10) then
--       sDescrCode2$ := '000000' || DescrCode2$;
--           
--     else
--       if (DescrCode2$ < 100) then
--         sDescrCode2$ := '00000' || DescrCode2$;
--             
--       else
--         if (DescrCode2$ < 1000) then
--           sDescrCode2$ := '0000' || DescrCode2$;
--               
--         else
--           if (DescrCode2$ < 10000) then
--             sDescrCode2$ := '000' || DescrCode2$;
--                 
--           else
--             if (DescrCode2$ < 100000) then
--               sDescrCode2$ := '00' || DescrCode2$;
--                   
--             else
--               if (DescrCode2$ < 1000000) then
--                 sDescrCode2$ := '0' || DescrCode2$;
--                     
--               else
--                 sDescrCode2$ := DescrCode2$;
--               END IF;
--             END IF;
--           END IF;
--         END IF;
--       END IF;
--     END IF;
--   END IF;
--   BEGIN
-- 
--     /*        */ 
--     select Code into sAnalyticalGroupIFS$ from AnalyticalGroupIFS where (ID = new$AnalyticalGroupIFS) ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   if (new$KESR is null) then
--     getkesr(sAnalyticalGroupIFS$, new$BudgetRef,new$KESR);
--   END IF;
--   /*      */
--       
--   new$FinSourceValue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sAnalyticalGroupIFS$;
--       
--   if ((new$ID = 0) and (new$FinSourceValue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
--     RaiseException('ex_CantModify_ZeroIFS');
--   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INNERFINSOURCE SET
    ID = new$ID,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    DIRECTION = new$DIRECTION,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    FINSOURCEVALUE = new$FINSOURCEVALUE,
    UNIONFLAG = new$UNIONFLAG,
    REMOTEFLAG = new$REMOTEFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CLSASPECT = new$CLSASPECT,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    IFS_LEVEL = new$IFS_LEVEL,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPIFS = new$ANALYTICALGROUPIFS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_INNERFINSOURCE_AU_100)
-- Version 13.10.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$kvsr <> 0) then
--     SELECT COUNT(*) INTO CNT$1
--     from InnerFinSource ifs1
--     inner join analyticalgroupifs ag on (ag.id = ifs1.analyticalgroupifs)
--     where ((ifs1.kvsr = 0) and
--     ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
--     (ag.code = (select ag1.code
--     from analyticalgroupifs ag1
--     where (ag1.id = new$analyticalgroupifs))) and
--     (ifs1.BudgetRef = new$BudgetRef)
--     ) AND (ROWNUM = 1)                   ;
--     /*    0,        =0 */
--     if (not (CNT$1<> 0))
--     then  
--       insert into InnerFinSource (KVSR, DescriptionCode, AnalyticalGroupIFS, Name, ShortName, CLSAspect, RemoteFlag, IFS_Level, BudgetRef, ExtID)
--       values (0, new$DescriptionCode, new$AnalyticalGroupIFS, new$Name, new$ShortName, new$CLSAspect, new$RemoteFlag, new$IFS_Level, new$BudgetRef, new$ExtID);
--       
--     END IF;
--   else
--     /*   = 0,         ,     */      
--     vName1$ := new$Name;
--     vShortName1$ := new$ShortName;
--     vIFSLevel1$ := new$IFS_Level;
--     vDeleteDate1$ := new$DeleteDate;
--     vDirection1$ := new$Direction;
--     /* ,      .  ,        .    ,   . */
--     if ((new$DeleteDate is not null) and (new$DeleteDate < current_date)) then
--       SELECT COUNT(*) INTO CNT$2
--       from InnerFinSource ifs1
--       where ((ifs1.kvsr = 0) and
--       ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
--       (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
--       (ifs1.BudgetRef = new$BudgetRef) and ((ifs1.DeleteDate is null) or (ifs1.DeleteDate > current_date))
--       ) AND (ROWNUM = 1)                    ;
--       if ((CNT$2<> 0))
--       then
--         BEGIN
--           select ifs2.Name, ifs2.ShortName, ifs2.IFS_Level, ifs2.Direction, ifs2.DeleteDate                 into
--           vName1$, vShortName1$, vIFSLevel1$, vDirection1$, vDeleteDate1$ from InnerFinSource ifs2
--           where ifs2.id = (select max(id) from InnerFinSource ifs1
--           where (ifs1.kvsr = 0) and
--           ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
--           (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
--           (ifs1.BudgetRef = new$BudgetRef) and ((ifs1.DeleteDate is null) or (ifs1.DeleteDate > current_date)))
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;    
--       END IF;
--     END IF;
--     update InnerFinSource ifs1 set
--     name = vName1$,
--     ShortName = vShortName1$,
--     IFS_level = vIFSLevel1$,
--     Direction = vDirection1$,
--     deletedate = vDeleteDate1$
-- 
--     where
--     (ifs1.kvsr <> 0) and
--     ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
--     (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
--     (ifs1.BudgetRef = new$BudgetRef);
--       
--   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INNERFINSOURCE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (145, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=145) and (RecordId=new$ID);
  end if;

END;
/
commit work
/
update INNERFINSOURCE set
  KESR = (
    select max(k.id)
    from KESR k
    where
      k.CODE = (select CODE from AnalyticalGroupIFS a where a.id = INNERFINSOURCE.AnalyticalGroupIFS) and
      (k.BudgetRef = INNERFINSOURCE.BudgetRef) and ((k.deletedate is null) or (k.deletedate > current_date))
  )
where
  (not exists (select * from KESR where KESR.id = INNERFINSOURCE.KESR)) and
  exists (
    select *
    from KESR k
    where
      k.CODE = (select CODE from AnalyticalGroupIFS a where a.id = INNERFINSOURCE.AnalyticalGroupIFS) and
      (k.BudgetRef = INNERFINSOURCE.BudgetRef) and ((k.deletedate is null) or (k.deletedate > current_date))
  )
/
update INNERFINSOURCE set
  KESR = (
    select max(k.id)
    from KESR k
    where
      k.CODE = (select CODE from AnalyticalGroupIFS a where a.id = INNERFINSOURCE.AnalyticalGroupIFS) and
      (k.BudgetRef = 0) and ((k.deletedate is null) or (k.deletedate > current_date))
  )
where
  (not exists (select * from KESR where KESR.id = INNERFINSOURCE.KESR)) and
  exists (
    select *
    from KESR k
    where
      k.CODE = (select CODE from AnalyticalGroupIFS a where a.id = INNERFINSOURCE.AnalyticalGroupIFS) and
      (k.BudgetRef = 0) and ((k.deletedate is null) or (k.deletedate > current_date))
  )
/
update INNERFINSOURCE set
  KESR = 0
where
  not exists (select * from KESR where KESR.id = INNERFINSOURCE.KESR)
/
commit work
/
-- ALTER TRIGGER TR_INNERFINSOURCE_BU_0
CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_IU
  INSTEAD OF UPDATE
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  new$ID INNERFINSOURCE.ID%TYPE := :NEW.ID;
  new$CREATEDATE INNERFINSOURCE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INNERFINSOURCE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$DIRECTION INNERFINSOURCE.DIRECTION%TYPE := :NEW.DIRECTION;
  new$KVSR INNERFINSOURCE.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE INNERFINSOURCE.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE INNERFINSOURCE.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE INNERFINSOURCE.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE INNERFINSOURCE.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR INNERFINSOURCE.KESR%TYPE := :NEW.KESR;
  new$FINSOURCEVALUE INNERFINSOURCE.FINSOURCEVALUE%TYPE := :NEW.FINSOURCEVALUE;
  new$UNIONFLAG INNERFINSOURCE.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$REMOTEFLAG INNERFINSOURCE.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$BUDGETREF INNERFINSOURCE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE INNERFINSOURCE.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME INNERFINSOURCE.NAME%TYPE := :NEW.NAME;
  new$STARTDATE INNERFINSOURCE.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME INNERFINSOURCE.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CLSASPECT INNERFINSOURCE.CLSASPECT%TYPE := :NEW.CLSASPECT;
  new$CREATERUSER INNERFINSOURCE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER INNERFINSOURCE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$IFS_LEVEL INNERFINSOURCE.IFS_LEVEL%TYPE := :NEW.IFS_LEVEL;
  new$EXTID INNERFINSOURCE.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER INNERFINSOURCE.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE INNERFINSOURCE.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID INNERFINSOURCE.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION INNERFINSOURCE.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE INNERFINSOURCE.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPIFS INNERFINSOURCE.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
--
  tmp$ NUMBER(15,0);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  vName1$ VARCHAR2(1024);
  vShortName1$ VARCHAR2(1024);
  vIFSLevel1$ NUMBER(10);
  vDirection1$ NUMBER(10);
  vDeleteDate1$ DATE;
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(7);
  sDescrCode2$ VARCHAR2(7);
  sAnalyticalGroupIFS$ VARCHAR2(3);
  sIFSLevel$ NUMBER(10);
  sDirection$ NUMBER(10);
  AGIFS$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INNERFINSOURCE_BU_0)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupIFS is null) then 
    new$AnalyticalGroupIFS := 0;
  END IF;
  if (new$ClsAspect is null) then 
    new$ClsAspect := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  /*     */
  if (new$KVSR <> 0) then
    select max(IFS_Level), max(Direction) 
    into sIFSLevel$, sDirection$     from innerfinsource 
    where ((AnalyticalGroupIFS = new$AnalyticalGroupIFS) and (BudgetRef=new$BudgetRef) and 
    (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0)) 
    ;
  END IF;
  if (sIFSLevel$ is not null) then
    new$IFS_Level := sIFSLevel$;
  END IF;
  if (sDirection$ is not null) then
    new$Direction := sDirection$;
  END IF;
  /*         
            =3,5,8 */
  if (new$Direction is null) then
    if ((new$AnalyticalGroupIFS between 300 and 399) or 
    (new$AnalyticalGroupIFS between 500 and 599) or 
    (new$AnalyticalGroupIFS between 800 and 899)) then
      new$Direction := -1;
          
    else
      new$Direction := 1;
    END IF;
    GetIntConst(60, 9,AGIFS$);
    if (new$AnalyticalGroupIFS = AGIFS$) then
      new$Direction := 1;
    END IF;
    GetIntConst(60, 10,AGIFS$);
    if (new$AnalyticalGroupIFS = AGIFS$) then
      new$Direction := -1;  
      
    END IF;
  END IF;
  BEGIN
      

    /*      */ 
    select Code into KVSRCode$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-    */
  /*      */
  if (KVSRCode$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode$ < 10) then
      sKVSR$ := '00' || KVSRCode$;
          
    else
      if (KVSRCode$ < 100) then
        sKVSR$ := '0' || KVSRCode$;
            
      else
        sKVSR$ := KVSRCode$;
      END IF;
    END IF;
  END IF;
  /*    , ,  */
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 1000000;
  DescrCode1$ := tmp_Double$;
  /*      ,
          ,    1 */
  if (DescrCode1$  > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$MainDescriptionCode := DescrCode1$; /*    */
  /*       */    
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 1000000;
  DescrCode2$ := tmp_Double$;
  tmp_Double$ := DescrCode2$ / 10000;
  DescrCode1$ := tmp_Double$;
  /*      */
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$ItemCode := DescrCode1$; /* */
  tmp_Double$ := DescrCode2$ - DescrCode1$ * 10000;
  new$ProgramCode := tmp_Double$; /* */
  /*       */
      
  tmp_Double$ := tmp$ / 10000000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 10000000;
  DescrCode2$ := tmp_Double$;
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '0000000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '000000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '00000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '0000' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '000' || DescrCode1$;
                
          else
            if (DescrCode1$ < 100000) then
              sDescrCode1$ := '00' || DescrCode1$;
                  
            else
              if (DescrCode1$ < 1000000) then
                sDescrCode1$ := '0' || DescrCode1$;
                    
              else
                sDescrCode1$ := DescrCode1$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '0000000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '000000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '00000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '0000' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '000' || DescrCode2$;
                
          else
            if (DescrCode2$ < 100000) then
              sDescrCode2$ := '00' || DescrCode2$;
                  
            else
              if (DescrCode2$ < 1000000) then
                sDescrCode2$ := '0' || DescrCode2$;
                    
              else
                sDescrCode2$ := DescrCode2$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupIFS$ from AnalyticalGroupIFS where (ID = new$AnalyticalGroupIFS) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    getkesr(sAnalyticalGroupIFS$, new$BudgetRef,new$KESR);
  END IF;
  /*      */
      
  new$FinSourceValue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sAnalyticalGroupIFS$;
      
  if ((new$ID = 0) and (new$FinSourceValue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroIFS');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INNERFINSOURCE SET
    ID = new$ID,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    DIRECTION = new$DIRECTION,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    FINSOURCEVALUE = new$FINSOURCEVALUE,
    UNIONFLAG = new$UNIONFLAG,
    REMOTEFLAG = new$REMOTEFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CLSASPECT = new$CLSASPECT,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    IFS_LEVEL = new$IFS_LEVEL,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPIFS = new$ANALYTICALGROUPIFS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_INNERFINSOURCE_AU_100)
-- Version 13.10.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$kvsr <> 0) then
--     SELECT COUNT(*) INTO CNT$1
--     from InnerFinSource ifs1
--     inner join analyticalgroupifs ag on (ag.id = ifs1.analyticalgroupifs)
--     where ((ifs1.kvsr = 0) and
--     ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
--     (ag.code = (select ag1.code
--     from analyticalgroupifs ag1
--     where (ag1.id = new$analyticalgroupifs))) and
--     (ifs1.BudgetRef = new$BudgetRef)
--     ) AND (ROWNUM = 1)                   ;
--     /*    0,        =0 */
--     if (not (CNT$1<> 0))
--     then  
--       insert into InnerFinSource (KVSR, DescriptionCode, AnalyticalGroupIFS, Name, ShortName, CLSAspect, RemoteFlag, IFS_Level, BudgetRef, ExtID)
--       values (0, new$DescriptionCode, new$AnalyticalGroupIFS, new$Name, new$ShortName, new$CLSAspect, new$RemoteFlag, new$IFS_Level, new$BudgetRef, new$ExtID);
--       
--     END IF;
--   else
--     /*   = 0,         ,     */      
--     vName1$ := new$Name;
--     vShortName1$ := new$ShortName;
--     vIFSLevel1$ := new$IFS_Level;
--     vDeleteDate1$ := new$DeleteDate;
--     vDirection1$ := new$Direction;
--     /* ,      .  ,        .    ,   . */
--     if ((new$DeleteDate is not null) and (new$DeleteDate < current_date)) then
--       SELECT COUNT(*) INTO CNT$2
--       from InnerFinSource ifs1
--       where ((ifs1.kvsr = 0) and
--       ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
--       (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
--       (ifs1.BudgetRef = new$BudgetRef) and ((ifs1.DeleteDate is null) or (ifs1.DeleteDate > current_date))
--       ) AND (ROWNUM = 1)                    ;
--       if ((CNT$2<> 0))
--       then
--         BEGIN
--           select ifs2.Name, ifs2.ShortName, ifs2.IFS_Level, ifs2.Direction, ifs2.DeleteDate                 into
--           vName1$, vShortName1$, vIFSLevel1$, vDirection1$, vDeleteDate1$ from InnerFinSource ifs2
--           where ifs2.id = (select max(id) from InnerFinSource ifs1
--           where (ifs1.kvsr = 0) and
--           ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
--           (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
--           (ifs1.BudgetRef = new$BudgetRef) and ((ifs1.DeleteDate is null) or (ifs1.DeleteDate > current_date)))
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;    
--       END IF;
--     END IF;
--     update InnerFinSource ifs1 set
--     name = vName1$,
--     ShortName = vShortName1$,
--     IFS_level = vIFSLevel1$,
--     Direction = vDirection1$,
--     deletedate = vDeleteDate1$
-- 
--     where
--     (ifs1.kvsr <> 0) and
--     ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
--     (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
--     (ifs1.BudgetRef = new$BudgetRef);
--       
--   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INNERFINSOURCE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (145, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=145) and (RecordId=new$ID);
  end if;

END;
/
ALTER TRIGGER TR_INNERFINSOURCE_BU_500 ENABLE
/
-- ALTER TRIGGER TR_INNERFINSOURCE_AU_100
CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_IU
  INSTEAD OF UPDATE
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  new$ID INNERFINSOURCE.ID%TYPE := :NEW.ID;
  new$CREATEDATE INNERFINSOURCE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INNERFINSOURCE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$DIRECTION INNERFINSOURCE.DIRECTION%TYPE := :NEW.DIRECTION;
  new$KVSR INNERFINSOURCE.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE INNERFINSOURCE.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE INNERFINSOURCE.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE INNERFINSOURCE.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE INNERFINSOURCE.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR INNERFINSOURCE.KESR%TYPE := :NEW.KESR;
  new$FINSOURCEVALUE INNERFINSOURCE.FINSOURCEVALUE%TYPE := :NEW.FINSOURCEVALUE;
  new$UNIONFLAG INNERFINSOURCE.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$REMOTEFLAG INNERFINSOURCE.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$BUDGETREF INNERFINSOURCE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE INNERFINSOURCE.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME INNERFINSOURCE.NAME%TYPE := :NEW.NAME;
  new$STARTDATE INNERFINSOURCE.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME INNERFINSOURCE.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CLSASPECT INNERFINSOURCE.CLSASPECT%TYPE := :NEW.CLSASPECT;
  new$CREATERUSER INNERFINSOURCE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER INNERFINSOURCE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$IFS_LEVEL INNERFINSOURCE.IFS_LEVEL%TYPE := :NEW.IFS_LEVEL;
  new$EXTID INNERFINSOURCE.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER INNERFINSOURCE.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE INNERFINSOURCE.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID INNERFINSOURCE.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION INNERFINSOURCE.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE INNERFINSOURCE.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPIFS INNERFINSOURCE.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
--
  tmp$ NUMBER(15,0);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  vName1$ VARCHAR2(1024);
  vShortName1$ VARCHAR2(1024);
  vIFSLevel1$ NUMBER(10);
  vDirection1$ NUMBER(10);
  vDeleteDate1$ DATE;
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(7);
  sDescrCode2$ VARCHAR2(7);
  sAnalyticalGroupIFS$ VARCHAR2(3);
  sIFSLevel$ NUMBER(10);
  sDirection$ NUMBER(10);
  AGIFS$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INNERFINSOURCE_BU_0)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupIFS is null) then 
    new$AnalyticalGroupIFS := 0;
  END IF;
  if (new$ClsAspect is null) then 
    new$ClsAspect := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  /*     */
  if (new$KVSR <> 0) then
    select max(IFS_Level), max(Direction) 
    into sIFSLevel$, sDirection$     from innerfinsource 
    where ((AnalyticalGroupIFS = new$AnalyticalGroupIFS) and (BudgetRef=new$BudgetRef) and 
    (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0)) 
    ;
  END IF;
  if (sIFSLevel$ is not null) then
    new$IFS_Level := sIFSLevel$;
  END IF;
  if (sDirection$ is not null) then
    new$Direction := sDirection$;
  END IF;
  /*         
            =3,5,8 */
  if (new$Direction is null) then
    if ((new$AnalyticalGroupIFS between 300 and 399) or 
    (new$AnalyticalGroupIFS between 500 and 599) or 
    (new$AnalyticalGroupIFS between 800 and 899)) then
      new$Direction := -1;
          
    else
      new$Direction := 1;
    END IF;
    GetIntConst(60, 9,AGIFS$);
    if (new$AnalyticalGroupIFS = AGIFS$) then
      new$Direction := 1;
    END IF;
    GetIntConst(60, 10,AGIFS$);
    if (new$AnalyticalGroupIFS = AGIFS$) then
      new$Direction := -1;  
      
    END IF;
  END IF;
  BEGIN
      

    /*      */ 
    select Code into KVSRCode$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-    */
  /*      */
  if (KVSRCode$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode$ < 10) then
      sKVSR$ := '00' || KVSRCode$;
          
    else
      if (KVSRCode$ < 100) then
        sKVSR$ := '0' || KVSRCode$;
            
      else
        sKVSR$ := KVSRCode$;
      END IF;
    END IF;
  END IF;
  /*    , ,  */
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 1000000;
  DescrCode1$ := tmp_Double$;
  /*      ,
          ,    1 */
  if (DescrCode1$  > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$MainDescriptionCode := DescrCode1$; /*    */
  /*       */    
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 1000000;
  DescrCode2$ := tmp_Double$;
  tmp_Double$ := DescrCode2$ / 10000;
  DescrCode1$ := tmp_Double$;
  /*      */
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$ItemCode := DescrCode1$; /* */
  tmp_Double$ := DescrCode2$ - DescrCode1$ * 10000;
  new$ProgramCode := tmp_Double$; /* */
  /*       */
      
  tmp_Double$ := tmp$ / 10000000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 10000000;
  DescrCode2$ := tmp_Double$;
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '0000000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '000000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '00000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '0000' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '000' || DescrCode1$;
                
          else
            if (DescrCode1$ < 100000) then
              sDescrCode1$ := '00' || DescrCode1$;
                  
            else
              if (DescrCode1$ < 1000000) then
                sDescrCode1$ := '0' || DescrCode1$;
                    
              else
                sDescrCode1$ := DescrCode1$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '0000000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '000000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '00000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '0000' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '000' || DescrCode2$;
                
          else
            if (DescrCode2$ < 100000) then
              sDescrCode2$ := '00' || DescrCode2$;
                  
            else
              if (DescrCode2$ < 1000000) then
                sDescrCode2$ := '0' || DescrCode2$;
                    
              else
                sDescrCode2$ := DescrCode2$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupIFS$ from AnalyticalGroupIFS where (ID = new$AnalyticalGroupIFS) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    getkesr(sAnalyticalGroupIFS$, new$BudgetRef,new$KESR);
  END IF;
  /*      */
      
  new$FinSourceValue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sAnalyticalGroupIFS$;
      
  if ((new$ID = 0) and (new$FinSourceValue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroIFS');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INNERFINSOURCE SET
    ID = new$ID,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    DIRECTION = new$DIRECTION,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    FINSOURCEVALUE = new$FINSOURCEVALUE,
    UNIONFLAG = new$UNIONFLAG,
    REMOTEFLAG = new$REMOTEFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CLSASPECT = new$CLSASPECT,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    IFS_LEVEL = new$IFS_LEVEL,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPIFS = new$ANALYTICALGROUPIFS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_INNERFINSOURCE_AU_100)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from InnerFinSource ifs1
    inner join analyticalgroupifs ag on (ag.id = ifs1.analyticalgroupifs)
    where ((ifs1.kvsr = 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ag.code = (select ag1.code
    from analyticalgroupifs ag1
    where (ag1.id = new$analyticalgroupifs))) and
    (ifs1.BudgetRef = new$BudgetRef)
    ) AND (ROWNUM = 1)                   ;
    /*    0,        =0 */
    if (not (CNT$1<> 0))
    then  
      insert into InnerFinSource (KVSR, DescriptionCode, AnalyticalGroupIFS, Name, ShortName, CLSAspect, RemoteFlag, IFS_Level, BudgetRef, ExtID)
      values (0, new$DescriptionCode, new$AnalyticalGroupIFS, new$Name, new$ShortName, new$CLSAspect, new$RemoteFlag, new$IFS_Level, new$BudgetRef, new$ExtID);
      
    END IF;
  else
    /*   = 0,         ,     */      
    vName1$ := new$Name;
    vShortName1$ := new$ShortName;
    vIFSLevel1$ := new$IFS_Level;
    vDeleteDate1$ := new$DeleteDate;
    vDirection1$ := new$Direction;
    /* ,      .  ,        .    ,   . */
    if ((new$DeleteDate is not null) and (new$DeleteDate < current_date)) then
      SELECT COUNT(*) INTO CNT$2
      from InnerFinSource ifs1
      where ((ifs1.kvsr = 0) and
      ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
      (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
      (ifs1.BudgetRef = new$BudgetRef) and ((ifs1.DeleteDate is null) or (ifs1.DeleteDate > current_date))
      ) AND (ROWNUM = 1)                    ;
      if ((CNT$2<> 0))
      then
        BEGIN
          select ifs2.Name, ifs2.ShortName, ifs2.IFS_Level, ifs2.Direction, ifs2.DeleteDate                 into
          vName1$, vShortName1$, vIFSLevel1$, vDirection1$, vDeleteDate1$ from InnerFinSource ifs2
          where ifs2.id = (select max(id) from InnerFinSource ifs1
          where (ifs1.kvsr = 0) and
          ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
          (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
          (ifs1.BudgetRef = new$BudgetRef) and ((ifs1.DeleteDate is null) or (ifs1.DeleteDate > current_date)))
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;    
      END IF;
    END IF;
    update InnerFinSource ifs1 set
    name = vName1$,
    ShortName = vShortName1$,
    IFS_level = vIFSLevel1$,
    Direction = vDirection1$,
    deletedate = vDeleteDate1$

    where
    (ifs1.kvsr <> 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
    (ifs1.BudgetRef = new$BudgetRef);
      
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INNERFINSOURCE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (145, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=145) and (RecordId=new$ID);
  end if;

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- AddIndexes.sql
-- #########################################################
-- #########################################################

/*     .     */
CREATE INDEX IDX_UpdateDate_SIGNLOG ON SIGNLOG(UpdateDate)
/
create index IDX_SenderRecID_LinkRecords on LinkRecords(SenderRecordID)
/
commit work
/

-- #########################################################
-- #########################################################
-- ALTER_TR_BUDGETDATA_BI_BU_200.sql
-- #########################################################
-- #########################################################

/*   Kesr*/
-- ALTER TRIGGER TR_BUDGETDATA_BU_200
CREATE OR REPLACE TRIGGER TR_BUDGETDATA_BU
  BEFORE UPDATE
  ON BUDGETDATA
  FOR EACH ROW
DECLARE
  OrgRefByAcc1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
  doubleUse1$ NUMBER(10);
  BALBOFlag1$ NUMBER(10);
  AllowDivideBA1$ NUMBER(10);
  StimateKind1$ NUMBER(10);
  AutoKvrCorr1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDGETDATA_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (:new.KFSR IS NULL) THEN
    :new.KFSR := 0;
  END IF;
  IF (:new.KVSR IS NULL) THEN
    :new.KVSR := 0;
  END IF;
  IF (:new.KVR IS NULL) THEN
    :new.KVR := 0;
  END IF;
  IF (:new.KCSR IS NULL) THEN
    :new.KCSR := 0;
  END IF;
  IF (:new.KESR IS NULL) THEN
    :new.KESR := 0;
  END IF;
  IF (:new.SubKESR IS NULL) THEN
    :new.SubKESR := 0;
  END IF;
  IF (:new.RegionCLS IS NULL) THEN
    :new.RegionCLS := 0;
  END IF;
  IF (:new.DirectionCls IS NULL) THEN
    :new.DirectionCls := 0;
  END IF;
  IF (:new.FundsSource IS NULL) THEN
    :new.FundsSource := 0;
  END IF;
  IF (:new.KD IS NULL) THEN
    :new.KD := 0;
  END IF;
  IF (:new.subkd IS NULL) THEN
    :new.subkd := 0;
  END IF;
  IF (:new.Fact IS NULL) THEN
    :new.Fact := 0;
  END IF;
  IF (:new.FacialAcc_Cls IS NULL) THEN
    :new.FacialAcc_Cls := 0;
  END IF;
  IF (:new.KVRCorr IS NULL) THEN
    :new.KVRCorr := 0;
  END IF;
  IF (:new.KesrCorr IS NULL) THEN
    :new.KesrCorr := 0;
  END IF;
  IF (:new.AssignmentKind IS NULL) THEN
    :new.AssignmentKind := 0;
  END IF;
  IF (:new.Quarter1 IS NULL) THEN
    :new.Quarter1 := 0;
  END IF;
  IF (:new.Quarter2 IS NULL) THEN
    :new.Quarter2 := 0;
  END IF;
  IF (:new.Quarter3 IS NULL) THEN
    :new.Quarter3 := 0;
  END IF;
  IF (:new.Quarter4 IS NULL) THEN
    :new.Quarter4 := 0;
  END IF;
  IF (:new.FinType IS NULL) THEN
    :new.FinType := 0;
  END IF;
  IF (:new.MeansType IS NULL) THEN
    :new.MeansType := 0;
  END IF;
  IF (:new.DepartmentCls IS NULL) THEN
    :new.DepartmentCls := 0;
  END IF;
  /*   .        */
  IF (:new.IFS IS NULL) THEN
    :new.IFS := 0;
  END IF;
  IF (:new.BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,:new.BuhOperationCLS);
  END IF;
  IF (:new.Month01 IS NULL) THEN
    :new.Month01 := 0;
  END IF;
  IF (:new.Month02 IS NULL) THEN
    :new.Month02 := 0;
  END IF;
  IF (:new.Month03 IS NULL) THEN
    :new.Month03 := 0;
  END IF;
  IF (:new.Month04 IS NULL) THEN
    :new.Month04 := 0;
  END IF;
  IF (:new.Month05 IS NULL) THEN
    :new.Month05 := 0;
  END IF;
  IF (:new.Month06 IS NULL) THEN
    :new.Month06 := 0;
  END IF;
  IF (:new.Month07 IS NULL) THEN
    :new.Month07 := 0;
  END IF;
  IF (:new.Month08 IS NULL) THEN
    :new.Month08 := 0;
  END IF;
  IF (:new.Month09 IS NULL) THEN
    :new.Month09 := 0;
  END IF;
  IF (:new.Month10 IS NULL) THEN
    :new.Month10 := 0;
  END IF;
  IF (:new.Month11 IS NULL) THEN
    :new.Month11 := 0;
  END IF;
  IF (:new.Month12 IS NULL) THEN
    :new.Month12 := 0;
  END IF;
  IF (:new.SummaYear1 IS NULL) THEN
    :new.SummaYear1 := 0;
  END IF;
  IF (:new.SummaYear2 IS NULL) THEN
    :new.SummaYear2 := 0;
  END IF;
  IF (:new.SummaYear3 IS NULL) THEN
    :new.SummaYear3 := 0;
  END IF;
  IF (:new.SummaYear4 IS NULL) THEN
    :new.SummaYear4 := 0;
  END IF;
  IF (:new.SummaOtherYears IS NULL) THEN
    :new.SummaOtherYears := 0;
  END IF;
  IF (:new.DayPlanSumma IS NULL) THEN
    :new.DayPlanSumma := 0;
  END IF;
  /*     */
  IF (:new.BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((:new.BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN
      RaiseException('Ex_CantModufyBudget');
    END IF;
  END IF;
  BEGIN

    SELECT
    c.BA_LBO_FLAG
    INTO
    BALBOFlag1$  FROM
    BudNotify c
    WHERE
    c.id = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*   */
  IF (:new.ProgIndex = 262) THEN
    GetIntConst(32, 43,StimateKind1$);
    IF ((StimateKind1$  = 0) OR (StimateKind1$  IS NULL)) THEN
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;

    ELSE
      IF (StimateKind1$  = 1) THEN
        :new.Quarter1 := :new.SummaYear1;

      ELSE
        :new.Quarter1 := :new.Month01 + :new.Month02 +:new.Month03;
        :new.Quarter2 := :new.Month04 + :new.Month05 +:new.Month06;
        :new.Quarter3 := :new.Month07 + :new.Month08 +:new.Month09;
        :new.Quarter4 := :new.Month10 + :new.Month11 +:new.Month12;
        :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;

      END IF;
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 260) THEN
    GetIntConst(32, 30,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;

    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 264) THEN
    GetIntConst(32, 34,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;

    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 32) THEN
    GetIntConst(32, 31,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*          ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;

    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 215) THEN
    GetIntConst(32, 35,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*         ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;

    END IF;
  END IF;
  /*
   IF ((NEW.TransfertOrg_Ref IS NULL) AND (NEW.REGIONCLS <> 0)) THEN
       SELECT Organizations FROM REGIONCLS
         WHERE NEW.REGIONCLS = ID
       INTO NEW.TransfertOrg_Ref;
  *//*    */
  GETTARGETCLS(:old.transfertcls, :new.transfertcls, :old.meanstype, :new.meanstype,
  :new.targetcls,:new.targetcls);

-- - - - - - - - - - - - -
-- BU_100 (TR_BUDGETDATA_BU_100)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if (:new.ClsType is NULL) then
    BEGIN
      select
      bn.ClsType
      into
      CapClsType1$     from
      BudNotify bn
      where
      bn.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (CapClsType1$  = 3) then
      if (:new.IFS <> 0) then
        :new.ClsType := 1; /*       ClsType */

      else
        if (:new.KD <> 0) then
          :new.ClsType := 2; /* */

        else
          :new.ClsType := 0; /* */
        END IF;
      END IF;
    else
      :new.ClsType := CapClsType1$;

    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND ((:new.IFS <> 0)or(:new.KD <> 0))) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0)
  )) THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  if (((:new.ClsType = 1)and(:new.KD <> 0))or((:new.ClsType = 2)and(:new.IFS <> 0))) then
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 1) AND (:new.ClsType <> 2)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;
  IF (:new.ACC_REF IS NOT NULL) THEN /*    / */
    BEGIN
      SELECT oa.ORG_REF
      INTO OrgRefByAcc1$     FROM ORG_ACCOUNTS oa
      WHERE (oa.ID = :new.ACC_REF)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (:new.FacialAcc_CLS = 0) then
      :new.Org_Ref := OrgRefByAcc1$;

    END IF;
  END IF;
  /*  \ ,       \    \,  \ */
  if (:new.FacialAcc_CLS <> 0) then
    BEGIN
      SELECT
      fac.ORG_REF
      INTO :new.Org_Ref     FROM
      FacialACC_CLS fac
      WHERE
      (fac.ID = :new.FacialAcc_CLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (OrgRefByAcc1$<>:new.Org_Ref) then
      :new.ACC_REF := null;

    END IF;
  END IF;
  if ((:new.ProgIndex in (252, 253))and(:new.FacialAcc_CLS = 0)) then
    BEGIN
      SELECT
      bn.FacialAccCLS
      INTO :new.FacialAcc_CLS     FROM
      BudNotify bn
      WHERE
      (bn.ID = :new.RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_BUDGETDATA_BU_200)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*       32-, 260-, 261-, 262-  , 263-, 268-  , 252-. */
  if (:new.ProgIndex in (32, 252, 260, 261, 262, 263, 268)) then
    /*     (32  ()) 
             :
           =0     ,
           =1  ,
           =2   0  .*//*     260 ()
             :
           =2   0  .*/
    GetIntConst(32, 25,AutoKvrCorr1$);
    if (:new.ProgIndex = 32) then /*  ()*/
      if (AutoKvrCorr1$  = 0) then
        :new.KvrCorr := :new.Kvr;
              
      else
        if (AutoKvrCorr1$  = 2) then
          :new.KvrCorr := 0;
        END IF;
      END IF;
      /* KESR   */
      if (AutoKvrCorr1$  = 0) then
        :new.KesrCorr := :new.Kesr;
              
      else
        if (AutoKvrCorr1$  = 2) then
          :new.KesrCorr := 0;
        END IF;    
      END IF;
    else 
      if ((:new.ProgIndex = 260)and (AutoKvrCorr1$  = 2)) then  /* ()*/
        :new.KvrCorr := 0;
        --   ,    new.Kvr = 0;
        /* KESR   */        
                
        :new.KesrCorr := 0;
              
      else
        :new.KvrCorr := :new.Kvr; /*         */
        /* KESR   */        
        :new.KesrCorr := :new.Kesr;
              
      END IF;  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_BUDGETDATA_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

  IF (:NEW.RVersion IS NULL) THEN
     :NEW.RVersion := 1;
  ELSIF ((:NEW.RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
     :NEW.RVersion := :OLD.RVersion;
  ELSE
     :NEW.RVersion := :OLD.RVersion + 1;
  END IF;

END;
/
-- ALTER TRIGGER TR_BUDGETDATA_BI_200
CREATE OR REPLACE TRIGGER TR_BUDGETDATA_BI
  BEFORE INSERT
  ON BUDGETDATA
  FOR EACH ROW
DECLARE
  OrgRefByAcc1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
  doubleUse1$ NUMBER(10);
  BALBOFlag1$ NUMBER(10);
  AllowDivideBA1$ NUMBER(10);
  StimateKind1$ NUMBER(10);
  AutoKvrCorr1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_BUDGETDATA_BI)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (:new.id IS NULL) THEN
    select g_shared.nextval into :new.id from dual;
  END IF;
  IF (:new.KFSR IS NULL) THEN
    :new.KFSR := 0;
  END IF;
  IF (:new.KVSR IS NULL) THEN
    :new.KVSR := 0;
  END IF;
  IF (:new.KVR IS NULL) THEN
    :new.KVR := 0;
  END IF;
  IF (:new.KCSR IS NULL) THEN
    :new.KCSR := 0;
  END IF;
  IF (:new.KESR IS NULL) THEN
    :new.KESR := 0;
  END IF;
  IF (:new.SubKESR IS NULL) THEN
    :new.SubKESR := 0;
  END IF;
  IF (:new.RegionCLS IS NULL) THEN
    :new.RegionCLS := 0;
  END IF;
  IF (:new.DirectionCls IS NULL) THEN
    :new.DirectionCls := 0;
  END IF;
  IF (:new.FundsSource IS NULL) THEN
    :new.FundsSource := 0;
  END IF;
  IF (:new.KD IS NULL) THEN
    :new.KD := 0;
  END IF;
  IF (:new.subkd IS NULL) THEN
    :new.subkd := 0;
  END IF;
  IF (:new.Fact IS NULL) THEN
    :new.Fact := 0;
  END IF;
  IF (:new.FacialAcc_Cls IS NULL) THEN
    :new.FacialAcc_Cls := 0;
  END IF;
  IF (:new.KVRCorr IS NULL) THEN
    :new.KVRCorr := 0;
  END IF;
  IF (:new.KESRCorr IS NULL) THEN
    :new.KESRCorr := 0;
  END IF;
  IF (:new.AssignmentKind IS NULL) THEN
    :new.AssignmentKind := 0;
  END IF;
  IF (:new.Quarter1 IS NULL) THEN
    :new.Quarter1 := 0;
  END IF;
  IF (:new.Quarter2 IS NULL) THEN
    :new.Quarter2 := 0;
  END IF;
  IF (:new.Quarter3 IS NULL) THEN
    :new.Quarter3 := 0;
  END IF;
  IF (:new.Quarter4 IS NULL) THEN
    :new.Quarter4 := 0;
  END IF;
  IF (:new.DayPlanSumma IS NULL) THEN
    :new.DayPlanSumma := 0;
  END IF;
  IF (:new.FinType IS NULL) THEN
    :new.FinType := 0;
  END IF;
  IF (:new.MeansType IS NULL) THEN
    :new.MeansType := 0;
  END IF;
  IF (:new.DepartmentCls IS NULL) THEN
    :new.DepartmentCls := 0;
  END IF;
  /*   .      */
  IF (:new.IFS IS NULL) THEN
    :new.IFS := 0;
  END IF;
  IF (:new.BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,:new.BuhOperationCLS);
  END IF;
  BEGIN

    /*  .   */
    SELECT bn.BudgetRef      INTO :new.BudgetRef FROM BudNotify bn
    WHERE bn.id = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  IF (:new.Month01 IS NULL) THEN
    :new.Month01 := 0;
  END IF;
  IF (:new.Month02 IS NULL) THEN
    :new.Month02 := 0;
  END IF;
  IF (:new.Month03 IS NULL) THEN
    :new.Month03 := 0;
  END IF;
  IF (:new.Month04 IS NULL) THEN
    :new.Month04 := 0;
  END IF;
  IF (:new.Month05 IS NULL) THEN
    :new.Month05 := 0;
  END IF;
  IF (:new.Month06 IS NULL) THEN
    :new.Month06 := 0;
  END IF;
  IF (:new.Month07 IS NULL) THEN
    :new.Month07 := 0;
  END IF;
  IF (:new.Month08 IS NULL) THEN
    :new.Month08 := 0;
  END IF;
  IF (:new.Month09 IS NULL) THEN
    :new.Month09 := 0;
  END IF;
  IF (:new.Month10 IS NULL) THEN
    :new.Month10 := 0;
  END IF;
  IF (:new.Month11 IS NULL) THEN
    :new.Month11 := 0;
  END IF;
  IF (:new.Month12 IS NULL) THEN
    :new.Month12 := 0;
  END IF;
  IF (:new.SummaYear1 IS NULL) THEN
    :new.SummaYear1 := 0;
  END IF;
  IF (:new.SummaYear2 IS NULL) THEN
    :new.SummaYear2 := 0;
  END IF;
  IF (:new.SummaYear3 IS NULL) THEN
    :new.SummaYear3 := 0;
  END IF;
  IF (:new.SummaYear4 IS NULL) THEN
    :new.SummaYear4 := 0;
  END IF;
  IF (:new.SummaOtherYears IS NULL) THEN
    :new.SummaOtherYears := 0;
  END IF;
  BEGIN

    SELECT
    c.BA_LBO_FLAG
    INTO
    BALBOFlag1$  FROM
    BudNotify c
    WHERE
    c.id = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*   */
  IF (:new.ProgIndex = 262) THEN
    GetIntConst(32, 43,StimateKind1$);
    IF ((StimateKind1$  = 0) OR (StimateKind1$  IS NULL)) THEN
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;

    ELSE
      IF (StimateKind1$  = 1) THEN
        :new.Quarter1 := :new.SummaYear1;

      ELSE
        :new.Quarter1 := :new.Month01 + :new.Month02 +:new.Month03;
        :new.Quarter2 := :new.Month04 + :new.Month05 +:new.Month06;
        :new.Quarter3 := :new.Month07 + :new.Month08 +:new.Month09;
        :new.Quarter4 := :new.Month10 + :new.Month11 +:new.Month12;
        :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;

      END IF;
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 260) THEN
    GetIntConst(32, 30,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;

    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 264) THEN
    GetIntConst(32, 34,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;

    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 32) THEN
    GetIntConst(32, 31,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*          ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;

    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 215) THEN
    GetIntConst(32, 35,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*         ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;

    END IF;
  END IF;
  /*
   IF ((NEW.TransfertOrg_Ref IS NULL) AND (NEW.REGIONCLS <> 0)) THEN
      SELECT Organizations FROM REGIONCLS
        WHERE NEW.REGIONCLS = ID
      INTO NEW.TransfertOrg_Ref;
  *//*    */
  GETTARGETCLS(null, :new.transfertcls, null, :new.meanstype,
  :new.targetcls,:new.targetcls);

-- - - - - - - - - - - - -
-- BI_10 (tr_BudgetData_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.SenderID is null) then
    :new.SenderIDKey := -1;

  else
    :new.SenderIDKey := :new.SenderID;
  END IF;

  if (:new.SenderRecordID is null) then
    :new.SenderRecordIDKey := :new.ID;

  else
    :new.SenderRecordIDKey := :new.SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_BUDGETDATA_BI_100)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if (:new.ClsType is NULL) then
    BEGIN
      select
      bn.ClsType
      into
      CapClsType1$     from
      BudNotify bn
      where
      bn.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (CapClsType1$  = 3) then
      if (:new.IFS <> 0) then
        :new.ClsType := 1; /*       ClsType */

      else
        if (:new.KD <> 0) then
          :new.ClsType := 2; /* */

        else
          :new.ClsType := 0; /* */
        END IF;
      END IF;
    else
      :new.ClsType := CapClsType1$;

    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND ((:new.IFS <> 0)or(:new.KD <> 0))) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0)
  )) THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  if (((:new.ClsType = 1)and(:new.KD <> 0))or((:new.ClsType = 2)and(:new.IFS <> 0))) then
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 1) AND (:new.ClsType <> 2)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;
  IF (:new.ACC_REF IS NOT NULL) THEN /*    / */
    BEGIN
      SELECT oa.ORG_REF
      INTO OrgRefByAcc1$     FROM ORG_ACCOUNTS oa
      WHERE (oa.ID = :new.ACC_REF)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (:new.FacialAcc_CLS = 0) then
      :new.Org_Ref := OrgRefByAcc1$;

    END IF;
  END IF;
  /*  \ ,       \    \,  \ */
  if (:new.FacialAcc_CLS <> 0) then
    BEGIN
      SELECT
      fac.ORG_REF
      INTO :new.Org_Ref     FROM
      FacialACC_CLS fac
      WHERE
      (fac.ID = :new.FacialAcc_CLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (OrgRefByAcc1$<>:new.Org_Ref) then
      :new.ACC_REF := null;

    END IF;
  END IF;
  if ((:new.ProgIndex in (252, 253))and(:new.FacialAcc_CLS = 0)) then
    BEGIN
      SELECT
      bn.FacialAccCLS
      INTO :new.FacialAcc_CLS     FROM
      BudNotify bn
      WHERE
      (bn.ID = :new.RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_BUDGETDATA_BI_200)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*       32-, 260-, 261-, 262-  , 263-, 268-  , 252-. */
  if (:new.ProgIndex in (32, 252, 260, 261, 262, 263, 268)) then
    /*     (32  ()) 
             :
           =0     ,
           =1  ,
           =2   0  .*//*     260 ()
             :
           =2   0  .*/
    GetIntConst(32, 25,AutoKvrCorr1$);
    if (:new.ProgIndex = 32) then /*  ()*/
      if (AutoKvrCorr1$  = 0) then
        :new.KvrCorr := :new.Kvr;
              
      else
        if (AutoKvrCorr1$  = 2) then
          :new.KvrCorr := 0;
        END IF;
      END IF;
      /* KESR   */
      if (AutoKvrCorr1$  = 0) then
        :new.KesrCorr := :new.Kesr;
              
      else
        if (AutoKvrCorr1$  = 2) then
          :new.KesrCorr := 0;
        END IF;    
      END IF;
    else 
      if ((:new.ProgIndex = 260)and (AutoKvrCorr1$  = 2)) then  /* ()*/
        :new.KvrCorr := 0;
        --   ,    new.Kvr = 0;
        /* KESR   */        
                
        :new.KesrCorr := 0;
              
      else 
        :new.KvrCorr := :new.Kvr; /*         */
        /* KESR   */        
        :new.KesrCorr := :new.Kesr;
              
      END IF;  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_BUDGETDATA_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

  Update BudNotify set
  DocChangeDate = :new.UpdateDate,
  RVersion = -1
  where id = :new.recordindex;

END;
/
commit work 
/




-- #########################################################
-- #########################################################
-- AddProtReas113.sql
-- #########################################################
-- #########################################################

/* ***************************************
  ''
****************************************/
CREATE OR REPLACE procedure AddProtocolReason(ID$ NUMBER,Name$ VARCHAR2)
AS
  CNT$1 NUMBER(10);
BEGIN
  SELECT COUNT(id ) INTO CNT$1
  from ProtocolReason where (id = ID$) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    update ProtocolReason set Name = Name$  where id = ID$;
      
  else
    insert into ProtocolReason(ID, Name) values (ID$, Name$);
  END IF;
END;
/
-- ALTER TRIGGER TR_ProtocolReason_BI
CREATE OR REPLACE TRIGGER TR_PROTOCOLREASON_BI
  BEFORE INSERT
  ON PROTOCOLREASON
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ProtocolReason_BI)
-- Create 27.10.2009
-- - - - - - - - - - - - -
  NULL;
--   RaiseException('EX_PR_BanInsert');

-- - - - - - - - - - - - -
-- BI_500 (TR_PROTOCOLREASON_BI_500)
-- Create 20.05.2009
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;    

END;
/
-- ALTER TRIGGER TR_ProtocolReason_BU
CREATE OR REPLACE TRIGGER TR_PROTOCOLREASON_BU
  BEFORE UPDATE
  ON PROTOCOLREASON
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ProtocolReason_BU)
-- Create 27.10.2009
-- - - - - - - - - - - - -
  NULL;
--   RaiseException('EX_PR_BanUpdate');

END;
/
-- ALTER TRIGGER TR_ProtocolReason_BD
CREATE OR REPLACE TRIGGER TR_PROTOCOLREASON_BD
  BEFORE DELETE
  ON PROTOCOLREASON
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_ProtocolReason_BD)
-- Create 27.10.2009
-- - - - - - - - - - - - -
  NULL;
--   RaiseException('EX_PR_BanDelete');

END;
/
CALL AddProtocolReason(113, '. 83.1 . 2 . 7 44-  05.04.2013.')
/
CALL AddProtocolReason(114, '. 93 . 1 . 55 44-  05.04.2013.')
/
-- ALTER TRIGGER TR_ProtocolReason_BI
CREATE OR REPLACE TRIGGER TR_PROTOCOLREASON_BI
  BEFORE INSERT
  ON PROTOCOLREASON
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ProtocolReason_BI)
-- Create 27.10.2009
-- - - - - - - - - - - - -

  RaiseException('EX_PR_BanInsert');

-- - - - - - - - - - - - -
-- BI_500 (TR_PROTOCOLREASON_BI_500)
-- Create 20.05.2009
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;    

END;
/
-- ALTER TRIGGER TR_ProtocolReason_BU
CREATE OR REPLACE TRIGGER TR_PROTOCOLREASON_BU
  BEFORE UPDATE
  ON PROTOCOLREASON
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ProtocolReason_BU)
-- Create 27.10.2009
-- - - - - - - - - - - - -

  RaiseException('EX_PR_BanUpdate');

END;
/
-- ALTER TRIGGER TR_ProtocolReason_BD
CREATE OR REPLACE TRIGGER TR_PROTOCOLREASON_BD
  BEFORE DELETE
  ON PROTOCOLREASON
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_ProtocolReason_BD)
-- Create 27.10.2009
-- - - - - - - - - - - - -

  RaiseException('EX_PR_BanDelete');

END;
/
drop procedure AddProtocolReason
/
commit work
/

-- #########################################################
-- #########################################################
-- Add_BUDGETS_S_OKTMO.sql
-- #########################################################
-- #########################################################

/*   OKTMO */
ALTER TABLE TB_BUDGETS_S ADD (
  OKTMO NUMBER(10),
    CHECK((OKTMO<=2147483647)AND(OKTMO>-2147483648)),
  CONSTRAINT FK_BUDGETS_S_OKTMO FOREIGN KEY (OKTMO) REFERENCES OKTMO (ID)     
)
/
CREATE INDEX FK_BUDGETS_S_OKTMO ON TB_BUDGETS_S(OKTMO)
/

CREATE OR REPLACE VIEW BUDGETS_S (
  ID,
  NAME,
  LASTMODIFDATE_B,
  CURRENTBUDGET,
  NOTE,
  OKATO,
  ADDOKATO,
  CREATEDATE,
  UPDATEDATE,
  AYEAR,
  CREATERUSER,
  UPDATERUSER,
  BUDGETLEVEL,
  CHIEFNAME,
  CHIEFROLE,
  STARTDATE,
  DELETEDATE,
  EXTID,
  ISCONSOLIDATED,
  HIGHERBUDGETREF,
  OKTMO)
AS
  SELECT
    ID,
    NAME,
    LASTMODIFDATE_B,
    CURRENTBUDGET,
    NOTE,
    OKATO,
    ADDOKATO,
    CREATEDATE,
    UPDATEDATE,
    AYEAR,
    CREATERUSER,
    UPDATERUSER,
    BUDGETLEVEL,
    CHIEFNAME,
    CHIEFROLE,
    STARTDATE,
    DELETEDATE,
    EXTID,
    ISCONSOLIDATED,
    HIGHERBUDGETREF,
    OKTMO
  FROM TB_BUDGETS_S
/

CREATE OR REPLACE TRIGGER TR_BUDGETS_S_ID
  INSTEAD OF DELETE
  ON BUDGETS_S
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_BUDGETS_S
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_0 (TR_BUDGETS_S_AD)
-- Version 12.20.00.1
-- - - - - - - - - - - - -

  update Budgets_s set
  HigherBudgetRef = id
  where
  HigherBudgetRef = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_BUDGETS_S_AD_500)
-- Create 15.02.2006
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordID, DeleteDate) values (178, :old.ID, SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_BUDGETS_S_II
  INSTEAD OF INSERT
  ON BUDGETS_S
  FOR EACH ROW
DECLARE
  new$ID BUDGETS_S.ID%TYPE := :NEW.ID;
  new$NAME BUDGETS_S.NAME%TYPE := :NEW.NAME;
  new$LASTMODIFDATE_B BUDGETS_S.LASTMODIFDATE_B%TYPE := :NEW.LASTMODIFDATE_B;
  new$CURRENTBUDGET BUDGETS_S.CURRENTBUDGET%TYPE := :NEW.CURRENTBUDGET;
  new$NOTE BUDGETS_S.NOTE%TYPE := :NEW.NOTE;
  new$OKATO BUDGETS_S.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO BUDGETS_S.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$CREATEDATE BUDGETS_S.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE BUDGETS_S.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$AYEAR BUDGETS_S.AYEAR%TYPE := :NEW.AYEAR;
  new$CREATERUSER BUDGETS_S.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER BUDGETS_S.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETLEVEL BUDGETS_S.BUDGETLEVEL%TYPE := :NEW.BUDGETLEVEL;
  new$CHIEFNAME BUDGETS_S.CHIEFNAME%TYPE := :NEW.CHIEFNAME;
  new$CHIEFROLE BUDGETS_S.CHIEFROLE%TYPE := :NEW.CHIEFROLE;
  new$STARTDATE BUDGETS_S.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE BUDGETS_S.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$EXTID BUDGETS_S.EXTID%TYPE := :NEW.EXTID;
  new$ISCONSOLIDATED BUDGETS_S.ISCONSOLIDATED%TYPE := :NEW.ISCONSOLIDATED;
  new$HIGHERBUDGETREF BUDGETS_S.HIGHERBUDGETREF%TYPE := :NEW.HIGHERBUDGETREF;
  new$OKTMO BUDGETS_S.OKTMO%TYPE := :NEW.OKTMO;
--
  CNT$ NUMBER(10);
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_BUDGETS_S_BI)
-- Version 12.20.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$OKATO is null) then
    new$OKATO := 0;
  END IF;
  if (new$BudgetLevel is null) then
    new$BudgetLevel := 0;
  END IF;
  if (new$IsConsolidated is null) then
    new$IsConsolidated := 0;
  END IF;
  if (new$HigherBudgetRef is null) then
    new$HigherBudgetRef := new$id;

  else
    SELECT COUNT(*) INTO CNT$1
    from Budgets_s where (id = new$HigherBudgetRef) AND (ROWNUM = 1);
    if (not (CNT$1<> 0)) then
      RaiseException('EX_WRONG_HIGHERBUDGETREF');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_1 (TR_BUDGETS_S_BI_1)
-- Last update 06.12.2005
-- - - - - - - - - - - - -

   SELECT COUNT (*)
     INTO CNT$
     FROM Budgets_s
    WHERE (Note = new$note) AND (ROWNUM = 1);

   IF CNT$ > 0 THEN
      raiseException ('ex_Dublicate_FullName');
   END IF;

   SELECT COUNT (*)
     INTO CNT$
     FROM Budgets_s
    WHERE (NAME = new$Name) AND (ROWNUM = 1);

   IF CNT$ > 0 THEN
      raiseException ('ex_Dublicate_ShortName');
   END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_BUDGETS_S_BI_10)
-- Last update 12.04.2010
-- - - - - - - - - - - - -

  --      =1  
  --     =0     " "
  --  " "
  IF (new$currentbudget = 1) THEN
     UPDATE budgets_s
         SET currentbudget = 0
     WHERE ID <> new$ID;
     update intconst set
       constvalue = new$ID
     where (ProgIndex = -1) and (ConstIndex = 3);
     --     
     update intconst set
       constvalue = new$BudgetLevel
     where (ProgIndex = -1) and (ConstIndex = 5);
  ELSE
      new$currentbudget := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_BUDGETS_S_BI_500)
-- Create 15.02.2006
-- Last update 02.10.2009
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_BUDGETS_S (
    ID,
    NAME,
    LASTMODIFDATE_B,
    CURRENTBUDGET,
    NOTE,
    OKATO,
    ADDOKATO,
    CREATEDATE,
    UPDATEDATE,
    AYEAR,
    CREATERUSER,
    UPDATERUSER,
    BUDGETLEVEL,
    CHIEFNAME,
    CHIEFROLE,
    STARTDATE,
    DELETEDATE,
    EXTID,
    ISCONSOLIDATED,
    HIGHERBUDGETREF,
    OKTMO
  ) VALUES (
    new$ID,
    new$NAME,
    new$LASTMODIFDATE_B,
    new$CURRENTBUDGET,
    new$NOTE,
    new$OKATO,
    new$ADDOKATO,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$AYEAR,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$BUDGETLEVEL,
    new$CHIEFNAME,
    new$CHIEFROLE,
    new$STARTDATE,
    new$DELETEDATE,
    new$EXTID,
    new$ISCONSOLIDATED,
    new$HIGHERBUDGETREF,
    new$OKTMO);

-- - - - - - - - - - - - -
-- AI_500 (TR_BUDGETS_S_AI_500)
-- Create 15.02.2006
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 178) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_BUDGETS_S_IU
  INSTEAD OF UPDATE
  ON BUDGETS_S
  FOR EACH ROW
DECLARE
  new$ID BUDGETS_S.ID%TYPE := :NEW.ID;
  new$NAME BUDGETS_S.NAME%TYPE := :NEW.NAME;
  new$LASTMODIFDATE_B BUDGETS_S.LASTMODIFDATE_B%TYPE := :NEW.LASTMODIFDATE_B;
  new$CURRENTBUDGET BUDGETS_S.CURRENTBUDGET%TYPE := :NEW.CURRENTBUDGET;
  new$NOTE BUDGETS_S.NOTE%TYPE := :NEW.NOTE;
  new$OKATO BUDGETS_S.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO BUDGETS_S.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$CREATEDATE BUDGETS_S.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE BUDGETS_S.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$AYEAR BUDGETS_S.AYEAR%TYPE := :NEW.AYEAR;
  new$CREATERUSER BUDGETS_S.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER BUDGETS_S.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETLEVEL BUDGETS_S.BUDGETLEVEL%TYPE := :NEW.BUDGETLEVEL;
  new$CHIEFNAME BUDGETS_S.CHIEFNAME%TYPE := :NEW.CHIEFNAME;
  new$CHIEFROLE BUDGETS_S.CHIEFROLE%TYPE := :NEW.CHIEFROLE;
  new$STARTDATE BUDGETS_S.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE BUDGETS_S.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$EXTID BUDGETS_S.EXTID%TYPE := :NEW.EXTID;
  new$ISCONSOLIDATED BUDGETS_S.ISCONSOLIDATED%TYPE := :NEW.ISCONSOLIDATED;
  new$HIGHERBUDGETREF BUDGETS_S.HIGHERBUDGETREF%TYPE := :NEW.HIGHERBUDGETREF;
  new$OKTMO BUDGETS_S.OKTMO%TYPE := :NEW.OKTMO;
--
  CNT$ NUMBER(10);
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDGETS_S_BU)
-- Version 12.20.00.1
-- - - - - - - - - - - - -

  if (new$OKATO is null) then
    new$OKATO := 0;
  END IF;
  if (new$BudgetLevel is null) then
    new$BudgetLevel := 0;
  END IF;
  if (new$IsConsolidated is null) then
    new$IsConsolidated := 0;
  END IF;
  if (new$HigherBudgetRef is null) then
    new$HigherBudgetRef := new$id;

  else
    if (new$HigherBudgetRef <> :old.HigherBudgetRef) then
      SELECT COUNT(*) INTO CNT$1
      from Budgets_s where (id = new$HigherBudgetRef) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('EX_WRONG_HIGHERBUDGETREF');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_BUDGETS_S_BU_1)
-- Last update 14.02.2006
-- - - - - - - - - - - - -

   SELECT COUNT (*) INTO CNT$ FROM Budgets_s
   WHERE (ID <> :old.ID) AND (Note = new$note) AND (ROWNUM = 1);

   IF CNT$ > 0 THEN
     raiseException ('ex_Dublicate_FullName');
   END IF;

   SELECT COUNT (*) INTO CNT$ FROM Budgets_s
   WHERE (ID <> :old.id) AND (NAME = new$Name) AND (ROWNUM = 1);

   IF CNT$ > 0 THEN
     raiseException ('ex_Dublicate_ShortName');
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_BUDGETS_S_BU_10)
-- Version 12.20.00.1
-- - - - - - - - - - - - -

  if (new$CurrentBudget <> :old.CurrentBudget) then
    if (new$Currentbudget = 1)  then
      update BUDGETS_S set
      CurrentBudget = 0
      where id <> new$Id;
      update intconst set
      constvalue = new$ID
      where (ProgIndex = -1) and (ConstIndex = 3);
      /*         */
      update intconst set
      constvalue = new$BudgetLevel
      where (Progindex = -1) and (ConstIndex = 5);

    else
      new$CurrentBudget := 0;

    END IF;
  else
    /*        ,      */
    if ((new$BudgetLevel <> :old.BudgetLevel) and (new$Currentbudget = 1)) then
      update intconst set
      constvalue = new$BudgetLevel
      where (ProgIndex = -1) and (ConstIndex = 5);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_BUDGETS_S SET
    ID = new$ID,
    NAME = new$NAME,
    LASTMODIFDATE_B = new$LASTMODIFDATE_B,
    CURRENTBUDGET = new$CURRENTBUDGET,
    NOTE = new$NOTE,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    AYEAR = new$AYEAR,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETLEVEL = new$BUDGETLEVEL,
    CHIEFNAME = new$CHIEFNAME,
    CHIEFROLE = new$CHIEFROLE,
    STARTDATE = new$STARTDATE,
    DELETEDATE = new$DELETEDATE,
    EXTID = new$EXTID,
    ISCONSOLIDATED = new$ISCONSOLIDATED,
    HIGHERBUDGETREF = new$HIGHERBUDGETREF,
    OKTMO = new$OKTMO
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_500 (TR_BUDGETS_S_AU_500)
-- Create 15.02.2006
-- - - - - - - - - - - - -

  if (new$ID <> :old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (178, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID = 178) and (RecordId = new$ID);
  end if;

END;
/
COMMIT WORK
/

-- #########################################################
-- #########################################################
-- update_Banks_Uer.sql
-- #########################################################
-- #########################################################

/*   Uer, UerReal   */
ALTER TRIGGER TR_BANKS_BU_500 DISABLE
/
update banks set
  Uer = null,
  UerReal = null
/
ALTER TRIGGER TR_BANKS_BU_500 ENABLE
/
commit work
/

-- #########################################################
-- #########################################################
-- alter_InvestObject_add_fields.sql
-- #########################################################
-- #########################################################

/*     "": 
   ,  , ,  , 
    ,   ,   , 
    ,  ,     
*/
ALTER TRIGGER TR_INVESTOBJECT_BU DISABLE
/
ALTER TRIGGER TR_INVESTOBJECT_BU_500 DISABLE
/
ALTER TRIGGER TR_INVESTOBJECT_AU DISABLE
/
ALTER TABLE INVESTOBJECT ADD (
  InvestDirection NUMBER(10),/*   */
    CHECK((InvestDirection<=2147483647)AND(InvestDirection>-2147483648)),
  ProvidingPurpose BLOB,/*   */
  APower VARCHAR2(255),/*  */
  DeveloperName VARCHAR2(2000),/*   */
  DevelopStartDate NUMBER,/*    */
  DevelopEndDate NUMBER,/*    */
  DevelopCost NUMBER(15,2) default 0,/*    */
  TotalCost NUMBER(15,2) default 0,/*    */
  Coordinates VARCHAR2(255),/*   */
  RegistryAgreementNumber VARCHAR2(20)/*     */
)
/
ALTER TRIGGER TR_INVESTOBJECT_BU ENABLE
/
ALTER TRIGGER TR_INVESTOBJECT_BU_500 ENABLE
/
ALTER TRIGGER TR_INVESTOBJECT_AU ENABLE
/
commit work
/
-- ALTER TRIGGER TR_INVESTOBJECT_BU_0
CREATE OR REPLACE TRIGGER TR_INVESTOBJECT_BU
  BEFORE UPDATE
  ON INVESTOBJECT
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (tr_InvestObject_bu_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*  Id,     */
--   if (:new.id is null) then 
--     select g_shared.nextval into :new.id from dual;
--   END IF;
--   if (:new.Code is null) then  
--     RaiseException('ex_WrongClsEmpty');
--   END IF;
--   if (:new.OwnerLevel is null) then 
--     :new.OwnerLevel := 0;
--   END IF;
--   if (:new.RegionCls is null) then 
--     :new.RegionCls := 0;
--   END IF;
--   if (:new.BudgetFinSourceLevel is null) then 
--     :new.BudgetFinSourceLevel := 0;
--   END IF;
--   if (:new.KVSR is null) then 
--     :new.KVSR := 0;
--   END IF;
--   if (:new.KCSR is null) then 
--     :new.KCSR := 0;
--   END IF;
--   if (:new.MeansType is null) then 
--     :new.MeansType := 0;
--   END IF;
--   if (:new.Fact is null) then 
--     :new.Fact := 0;
--   END IF;
--   if (:new.BudgetRef is null) then 
--     :new.BudgetRef := 0;
--   END IF;
--   if ((not ((:new.MeansType) is null)) and (:new.TargetCls is null)) then 
--     GetTargetClsOnMeansType(:new.MeansType,:new.TargetCls);
--   END IF;

END;
/
update INVESTOBJECT set
  InvestDirection = 0,
  APower = '0',
  DevelopCost = 0,
  TotalCost = 0,
  Coordinates = '0, 0'
/
-- ALTER TRIGGER TR_INVESTOBJECT_BU_0
CREATE OR REPLACE TRIGGER TR_INVESTOBJECT_BU
  BEFORE UPDATE
  ON INVESTOBJECT
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (tr_InvestObject_bu_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.Code is null) then  
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.OwnerLevel is null) then 
    :new.OwnerLevel := 0;
  END IF;
  if (:new.RegionCls is null) then 
    :new.RegionCls := 0;
  END IF;
  if (:new.BudgetFinSourceLevel is null) then 
    :new.BudgetFinSourceLevel := 0;
  END IF;
  if (:new.KVSR is null) then 
    :new.KVSR := 0;
  END IF;
  if (:new.KCSR is null) then 
    :new.KCSR := 0;
  END IF;
  if (:new.MeansType is null) then 
    :new.MeansType := 0;
  END IF;
  if (:new.Fact is null) then 
    :new.Fact := 0;
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if ((not ((:new.MeansType) is null)) and (:new.TargetCls is null)) then 
    GetTargetClsOnMeansType(:new.MeansType,:new.TargetCls);
  END IF;

END;
/
commit work
/
-- ALTER TRIGGER tr_investobject_bi_0
CREATE OR REPLACE TRIGGER TR_INVESTOBJECT_BI
  BEFORE INSERT
  ON INVESTOBJECT
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (tr_InvestObject_bi_0)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.Code is null) then  
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.OwnerLevel is null) then 
    :new.OwnerLevel := 0;
  END IF;
  if (:new.RegionCls is null) then 
    :new.RegionCls := 0;
  END IF;
  if (:new.BudgetFinSourceLevel is null) then 
    :new.BudgetFinSourceLevel := 0;
  END IF;
  if (:new.KVSR is null) then 
    :new.KVSR := 0;
  END IF;
  if (:new.KCSR is null) then 
    :new.KCSR := 0;
  END IF;
  if (:new.MeansType is null) then 
    :new.MeansType := 0;
  END IF;
  if (:new.Fact is null) then 
    :new.Fact := 0;
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.InvestDirection is null) then 
    :new.InvestDirection := 0;
  END IF;
  if (:new.DevelopCost is null) then 
    :new.DevelopCost := 0;
  END IF;
  if (:new.TotalCost is null) then 
    :new.TotalCost := 0;
  END IF;
  if ((not ((:new.MeansType) is null)) and (:new.TargetCls is null)) then 
    GetTargetClsOnMeansType(:new.MeansType,:new.TargetCls);
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (tr_InvestObject_bi_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER tr_investobject_bu_0
CREATE OR REPLACE TRIGGER TR_INVESTOBJECT_BU
  BEFORE UPDATE
  ON INVESTOBJECT
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (tr_InvestObject_bu_0)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*     */
  if (:new.Code is null) then  
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.OwnerLevel is null) then 
    :new.OwnerLevel := 0;
  END IF;
  if (:new.RegionCls is null) then 
    :new.RegionCls := 0;
  END IF;
  if (:new.BudgetFinSourceLevel is null) then 
    :new.BudgetFinSourceLevel := 0;
  END IF;
  if (:new.KVSR is null) then 
    :new.KVSR := 0;
  END IF;
  if (:new.KCSR is null) then 
    :new.KCSR := 0;
  END IF;
  if (:new.MeansType is null) then 
    :new.MeansType := 0;
  END IF;
  if (:new.Fact is null) then 
    :new.Fact := 0;
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.InvestDirection is null) then 
    :new.InvestDirection := 0;
  END IF;
  if (:new.DevelopCost is null) then 
    :new.DevelopCost := 0;
  END IF;
  if (:new.TotalCost is null) then 
    :new.TotalCost := 0;
  END IF;
  if ((not ((:new.MeansType) is null)) and (:new.TargetCls is null)) then 
    GetTargetClsOnMeansType(:new.MeansType,:new.TargetCls);
  END IF;

END;
/
commit work
/
ALTER TABLE INVESTOBJECT MODIFY(InvestDirection NOT NULL)
/
ALTER TABLE INVESTOBJECT MODIFY(DevelopCost NOT NULL)
/
ALTER TABLE INVESTOBJECT MODIFY(TotalCost NOT NULL)
/

-- #########################################################
-- #########################################################
-- Alter_AutoSanctionData_AddFields.sql
-- #########################################################
-- #########################################################

/*   FinType, Fact, SubKesr, RegionCls, DirectionCls, TargetCls, TransfertCls,
 SubsidyCls, InvestObject, DocTypeCls, ContractCostsCls, STOREDCONTENT   AUTOSANCTIONDATA. */
ALTER TABLE AUTOSANCTIONDATA ADD (
  FINTYPE NUMBER(10),
    CHECK((FINTYPE<=2147483647)AND(FINTYPE>-2147483648)),
  FACT NUMBER(10),
    CHECK((FACT<=2147483647)AND(FACT>-2147483648)),
  SubKesr NUMBER(10),
    CHECK((SubKesr<=2147483647)AND(SubKesr>-2147483648)),
  RegionCls NUMBER(10),
    CHECK((RegionCls<=2147483647)AND(RegionCls>-2147483648)),
  DirectionCls NUMBER(10),
    CHECK((DirectionCls<=2147483647)AND(DirectionCls>-2147483648)),
  TargetCls NUMBER(10),
    CHECK((TargetCls<=2147483647)AND(TargetCls>-2147483648)),
  TransfertCls NUMBER(10),
    CHECK((TransfertCls<=2147483647)AND(TransfertCls>-2147483648)),
  SubsidyCls NUMBER(10),
    CHECK((SubsidyCls<=2147483647)AND(SubsidyCls>-2147483648)),
  DocTypeCls NUMBER(10),
    CHECK((DocTypeCls<=2147483647)AND(DocTypeCls>-2147483648)),
  InvestObject NUMBER(10),
    CHECK((InvestObject<=2147483647)AND(InvestObject>-2147483648)),
  ContractCostsCls NUMBER(10),
    CHECK((ContractCostsCls<=2147483647)AND(ContractCostsCls>-2147483648)),
  STOREDCONTENT VARCHAR2(4000),
  CONSTRAINT AUTOSANCTIONDATA_FK_FINTYPE FOREIGN KEY (FINTYPE) REFERENCES FINTYPE (ID),
  CONSTRAINT AUTOSANCTIONDATA_FK_FACT FOREIGN KEY (FACT) REFERENCES FACT (ID),
  CONSTRAINT AUTOSANCTIONDATA_FK_SUBKESR FOREIGN KEY (SubKesr) REFERENCES KESRSUBCODE (ID),
  CONSTRAINT AUTOSANCTIONDATA_FK_RegionCls FOREIGN KEY (RegionCls) REFERENCES RegionCls (ID),
  CONSTRAINT FK_ASDATA_ContractCostsCls FOREIGN KEY (ContractCostsCls) REFERENCES ContractCostsCls (ID),
  CONSTRAINT FK_ASDATA_DirectionCls FOREIGN KEY (DirectionCls) REFERENCES DirectionCls (ID),
  CONSTRAINT FK_ASDATA_TargetCls FOREIGN KEY (TargetCls) REFERENCES TargetCls (ID),
  CONSTRAINT FK_ASDATA_TRNSFTCLS FOREIGN KEY (TransfertCls) REFERENCES TB_TransfertCls (ID),
  CONSTRAINT FK_ASDATA_SubsidyCls FOREIGN KEY (SubsidyCls) REFERENCES SubsidyCls (ID),
  CONSTRAINT FK_ASDATA_DocTypeCls FOREIGN KEY (DocTypeCls) REFERENCES DocTypes (ID),
  CONSTRAINT FK_ASDATA_InvestObject FOREIGN KEY (InvestObject) REFERENCES InvestObject (ID)         
)
/
CREATE INDEX AUTOSANCTIONDATA_FK_FINTYPE ON AUTOSANCTIONDATA(FINTYPE)
/
CREATE INDEX AUTOSANCTIONDATA_FK_FACT ON AUTOSANCTIONDATA(FACT)
/
CREATE INDEX AUTOSANCTIONDATA_FK_SUBKESR ON AUTOSANCTIONDATA(SubKesr)
/
CREATE INDEX AUTOSANCTIONDATA_FK_RegionCls ON AUTOSANCTIONDATA(RegionCls)
/
CREATE INDEX FK_ASDATA_ContractCostsCls ON AUTOSANCTIONDATA(ContractCostsCls)
/
CREATE INDEX FK_ASDATA_DirectionCls ON AUTOSANCTIONDATA(DirectionCls)
/
CREATE INDEX FK_ASDATA_TargetCls ON AUTOSANCTIONDATA(TargetCls)
/
CREATE INDEX FK_ASDATA_TRNSFTCLS ON AUTOSANCTIONDATA(TransfertCls)
/
CREATE INDEX FK_ASDATA_SubsidyCls ON AUTOSANCTIONDATA(SubsidyCls)
/
CREATE INDEX FK_ASDATA_DocTypeCls ON AUTOSANCTIONDATA(DocTypeCls)
/
CREATE INDEX FK_ASDATA_InvestObject ON AUTOSANCTIONDATA(InvestObject)
/
COMMIT WORK
/

-- #########################################################
-- #########################################################
-- Alter_TR_AGREEMENTS_BU_400.sql
-- #########################################################
-- #########################################################

/*    "  /",
     " "  ""  ""  , 
       
*/
-- CREATE TRIGGER TR_AGREEMENTS_BU_400
CREATE OR REPLACE TRIGGER TR_AGREEMENTS_IU
  INSTEAD OF UPDATE
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
  new$EXECUTERSTOREDPROPS AGREEMENTS.EXECUTERSTOREDPROPS%TYPE := :NEW.EXECUTERSTOREDPROPS;
  new$AUTOSANCTION AGREEMENTS.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$PURCHASECODE AGREEMENTS.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$DOCUMENTNUMBER AGREEMENTS.DOCUMENTNUMBER%TYPE := :NEW.DOCUMENTNUMBER;
  new$REJECTCAUSE AGREEMENTS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$TENDERREF AGREEMENTS.TENDERREF%TYPE := :NEW.TENDERREF;
  new$TENDERINNERNUMBER AGREEMENTS.TENDERINNERNUMBER%TYPE := :NEW.TENDERINNERNUMBER;
  new$STOREDCONTENT AGREEMENTS.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
--
  CNT$1 NUMBER(10);
  CountAcc$ NUMBER(10);
  DetCount$ NUMBER(10);
  countLastAdj1$ NUMBER(10);
  rnClientID11$ VARCHAR2(15);
  rnYear11$ VARCHAR2(15);
  rnNumber11$ VARCHAR2(15);
  ReestrVersion11$ VARCHAR2(15);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_AGREEMENTS_BU)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*   13.0*/
  /*    -*/
  if (new$CardAdvancePercent is null) then
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then
    new$FinCardAdvance := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$client_ref is null) then
    new$client_ref := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from AgreementSteps where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      select count(ID)       into DetCount$ from Estimate where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*     ,        */
  if (new$InnerNumber is null) then
    new$InnerNumber := :old.InnerNumber;
  END IF;
  /*   */
  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  /*    .  */

  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*     30.  id */

  new$TenderInnerNumber := null;
  if (new$TenderRef is not null) then
    BEGIN
      select InnerNumber
      into new$TenderInnerNumber     from TenderCaption
      where id = new$TenderRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_AGREEMENTS_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_AGREEMENTS_BU_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  /* ,      ,   */
  if ((new$InnerNumber <> :old.InnerNumber) or
  (new$AdjustmentRef <> :old.AdjustmentRef) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber) or
  (new$AgreementType <> :old.AgreementType)) then
    RaiseException('EX_AGR_ChangeInnerNums');
  END IF;
      
  /*    !!!*/
  if (:old.AcceptDate is not null and :old.Accepted = 0 and (new$Accepted = 1 or new$AcceptDate is null)) then
    /* :  */
    if (new$AdjustmentRef is not null) then
      RaiseException('EX_RollbackCancel');
    END IF;
    /*      ,
             , ,          */
    select count(ID)
    into countLastAdj1$       from Agreements
    where InnerNumber=new$InnerNumber and LastAdjustment = 1
    ;
    if (countLastAdj1$ = 0) then
      new$LastAdjustment := 1;
      
    END IF;
  END IF;
  /*  ,     LastAccepted*/
  if (:old.AcceptDate is null and new$AcceptDate is not null and new$Accepted = 1) then 
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;
          
    else
      RaiseException('EX_AGR_ChangeStateAdjust');
    END IF;
  END IF;
  /*   ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;
          
    else
      RaiseException('EX_AGR_ChangeStateAdjust');  
    END IF;
  END IF;
  /*   ,     LastAdjustment  LastAccepted */
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment <> 1) then
      RaiseException('EX_AGR_ChangeStateAdjust');
    else
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_20 (TR_AGREEMENTS_BU_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,      */
  if ((new$Client_Ref <> :old.Client_Ref) and
      (((new$Client_INN is null) and
        (:old.Client_INN is null)) or
       (new$Client_INN = :old.Client_INN)) and
      (((new$Client_INN20 is null) and
        (:old.Client_INN20 is null)) or
       (new$Client_INN20 = :old.Client_INN20)) and
      (new$Client_Name = :old.Client_Name)) then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;

  /*    -,      */
  if ((new$Executer_Ref <> :old.Executer_Ref) and
      (((new$Executer_INN is null) and
        (:old.Executer_INN is null)) or
       (new$Executer_INN = :old.Executer_INN)) and
      (((new$Executer_INN20 is null) and
        (:old.Executer_INN20 is null)) or
       (new$Executer_INN20 = :old.Executer_INN20)) and
      (new$Executer_Name = :old.Executer_Name) and
      (((new$Executer_Status is null) and
        (:old.Executer_Status is null)) or
       (new$Executer_Status = :old.Executer_Status)) and
      (((new$Executer_Country is null) and
        (:old.Executer_Country is null)) or
       (new$Executer_Country = :old.Executer_Country)) and
      (((new$Executer_Address is null) and
        (:old.Executer_Address is null)) or
       (new$Executer_Address = :old.Executer_Address)) and
      (((new$Executer_Phone is null) and
        (:old.Executer_Phone is null)) or
       (new$Executer_Phone = :old.Executer_Phone))) then
     BEGIN
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_60 (tr_agreements_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*        ,     */
  if (:old.accepted = 1 and new$accepted = 0 and new$acceptdate is not null and new$adjustmentnumber = 0) then
    SELECT COUNT(*) INTO CNT$1
    from executiondocumentscaption
    where
    (            agreementinnernumber = new$innernumber
    and (accepted <> 0 or acceptdate is null)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_Agr_CannotReject');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_AGREEMENTS_BU_200)
-- Create 04.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$id, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (tr_agreements_bu_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$ExecuterAccRef is not null) then
    select count(ID)
    into CountAcc$     from org_accounts oa
    where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
    ;
    if (CountAcc$ = 0) then
      RaiseException('EX_AGR_ACCORGCHECK');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (TR_AGREEMENTS_BU_400)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  if (((new$rnClientID <> :old.rnClientID) or (new$rnYear <> :old.rnYear) or
  (new$rnNumber <> :old.rnNumber) or (new$ReestrVersion <> :old.ReestrVersion) or
  (:old.rnClientID is null) or (:old.rnYear is null) or (:old.ReestrVersion is null)
  ) and
  (new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID11$ := new$rnClientID;
    rnYear11$ := new$rnYear;
    rnNumber11$ := new$rnNumber;
    ReestrVersion11$ := new$ReestrVersion;
    while (LENGTH(rnClientID11$) < 11) LOOP
      rnClientID11$ := '0' || rnClientID11$;
    END LOOP;
    while (LENGTH(rnNumber11$) < 6) LOOP
      rnNumber11$ := '0' || rnNumber11$;
    END LOOP;
    if (LENGTH(ReestrVersion11$) < 2) then
      ReestrVersion11$ := '0' || ReestrVersion11$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID11$ || rnYear11$ || rnNumber11$;
          
    else
      new$ReestrRecordNumber := rnClientID11$ || rnYear11$ || rnNumber11$ || ReestrVersion11$;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_600 (agreements_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_AGREEMENTS_BU_700)
-- Create 14.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_AGREEMENTS SET
    ID = new$ID,
    SUMMA = new$SUMMA,
    AGREEMENTDATE = new$AGREEMENTDATE,
    AGREEMENTENDDATE = new$AGREEMENTENDDATE,
    EXECUTER_REF = new$EXECUTER_REF,
    CLIENT_REF = new$CLIENT_REF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    AGREEMENTTYPE = new$AGREEMENTTYPE,
    ACCEPTED = new$ACCEPTED,
    ACCEPTDATE = new$ACCEPTDATE,
    CARDADVANCEPERCENT = new$CARDADVANCEPERCENT,
    CARDADVANCE = new$CARDADVANCE,
    CLOSEDOC = new$CLOSEDOC,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    FACT = new$FACT,
    REGION = new$REGION,
    CLOSEDATE = new$CLOSEDATE,
    DELIVERYRULES = new$DELIVERYRULES,
    AGREEMENTSUMMA = new$AGREEMENTSUMMA,
    AGREEMENTFINSUMMA = new$AGREEMENTFINSUMMA,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    REESTRNUMBER = new$REESTRNUMBER,
    PAYMENTDATE = new$PAYMENTDATE,
    AGREEMENTCARDADVANCE = new$AGREEMENTCARDADVANCE,
    FINCARDADVANCE = new$FINCARDADVANCE,
    STATEORDERREF = new$STATEORDERREF,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    AGREEMENTBEGINDATE = new$AGREEMENTBEGINDATE,
    PROTOCOLNUMBER = new$PROTOCOLNUMBER,
    PROTOCOLDATE = new$PROTOCOLDATE,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXPORTDATE = new$EXPORTDATE,
    FSORGAN = new$FSORGAN,
    FSBUDGETNAME = new$FSBUDGETNAME,
    FSOFFBUDGET = new$FSOFFBUDGET,
    RNYEAR = new$RNYEAR,
    RNNUMBER = new$RNNUMBER,
    RNDATE = new$RNDATE,
    PROTOCOLNOTICE = new$PROTOCOLNOTICE,
    PROTOCOLRESULTDATE = new$PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE = new$PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE = new$PROTOCOLSALETYPE,
    NOTIFYDATE = new$NOTIFYDATE,
    EXECUTERACCREF = new$EXECUTERACCREF,
    DOCBASEDATE = new$DOCBASEDATE,
    DOCBASENOTIFYDATE = new$DOCBASENOTIFYDATE,
    DOCBASETEXT = new$DOCBASETEXT,
    DOCBASETYPE = new$DOCBASETYPE,
    DOCBASESUMMA = new$DOCBASESUMMA,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PROTOCOLREASON = new$PROTOCOLREASON,
    DOCNUMBER = new$DOCNUMBER,
    ADJUSTMENTDOCNUMBER = new$ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER = new$OLDDOCNUMBER,
    LOTMAXSUM = new$LOTMAXSUM,
    CLIENT_INN = new$CLIENT_INN,
    CLIENT_INN20 = new$CLIENT_INN20,
    CLIENT_NAME = new$CLIENT_NAME,
    EXECUTER_INN = new$EXECUTER_INN,
    EXECUTER_INN20 = new$EXECUTER_INN20,
    EXECUTER_NAME = new$EXECUTER_NAME,
    EXECUTER_STATUS = new$EXECUTER_STATUS,
    EXECUTER_COUNTRY = new$EXECUTER_COUNTRY,
    EXECUTER_ADDRESS = new$EXECUTER_ADDRESS,
    EXECUTER_PHONE = new$EXECUTER_PHONE,
    REALID = new$REALID,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    INNERNUMBER = new$INNERNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REESTRVERSION = new$REESTRVERSION,
    DOCTYPE = new$DOCTYPE,
    RNCLIENTID = new$RNCLIENTID,
    INFONUMBER = new$INFONUMBER,
    STATEORDERINNERNUMBER = new$STATEORDERINNERNUMBER,
    PROGINDEX = new$PROGINDEX,
    NOTE = new$NOTE,
    PURPORTDOC = new$PURPORTDOC,
    REESTRRECORDNUMBER = new$REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS = new$EXECUTERSTOREDPROPS,
    AUTOSANCTION = new$AUTOSANCTION,
    PURCHASECODE = new$PURCHASECODE,
    DOCUMENTNUMBER = new$DOCUMENTNUMBER,
    REJECTCAUSE = new$REJECTCAUSE,
    TENDERREF = new$TENDERREF,
    TENDERINNERNUMBER = new$TENDERINNERNUMBER,
    STOREDCONTENT = new$STOREDCONTENT
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_AGREEMENTS_AU_10)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*   13.0*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update Agreements set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update Agreements set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*          */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 304)or(new$ProgIndex = 314)))then
    update Estimate
    set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    (RecordIndex = new$Id);
  END IF;
  /*         */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 305) or (new$ProgIndex = 314))) then
    update paymentschedule set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    AgreementRef = new$ID and
    ProgIndex in (317, 318);
  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_AGREEMENTS_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*      */
  if ((new$ProgIndex = 305) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null
    where
    StateOrder = :old.ID;
  END IF;
  /*      */
  if ((new$ProgIndex = 314) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null,
    Agreement = null
    where
    StateOrder = :old.ID;
  END IF;
  /*     */
  if ((:old.ProgIndex = 304) and (new$AdjustmentNumber = 0) and (new$Accepted = 0) and
  (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    Agreement = null
    where
    Agreement = :old.ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_AGREEMENTS_AU_30)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$ProgIndex = 304) or (new$ProgIndex = 314)) and
  ((new$Accepted <> :old.Accepted) or
  (new$AcceptDate is not null and :old.AcceptDate is null) or
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where AgreementRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_AGREEMENTS_AU_500)
-- Create 28.04.2005
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes
                  (TableID, RecordId, DeleteDate
                  )
           VALUES (110, :OLD.ID, SYSDATE
                  );

      DELETE FROM DelRecIndexes
            WHERE (TableID = 110) AND (RecordId = new$ID);
   END IF;

END;
/
COMMIT WORK
/

-- #########################################################
-- #########################################################
-- Add_PartAggregateID.sql
-- #########################################################
-- #########################################################

/*    PartAggregateID (   )   bankexch_ls_kb  bankexch_merdoc*/
ALTER TABLE bankexch_ls_kb ADD (
  PartAggregateID VARCHAR2(50)
)
/
ALTER TABLE bankexch_merdoc ADD (
  PartAggregateID VARCHAR2(50)
)
/
commit work 
/


-- #########################################################
-- #########################################################
-- delete_old_document_fields.sql
-- #########################################################
-- #########################################################


--     DFU     30.01, 30.03  25.
-- 
CREATE OR REPLACE PROCEDURE DELOLDFLD_2501 IS
BEGIN
  FOR tab_rec IN (
      SELECT ID
      FROM DocumentFields
      WHERE (DOCTYPEREF=2501)
      AND (ID NOT IN (250110072, 250110073, 250111022, 250112013, 250110001, 250110002, 250110003, 250110004, 250110005, 250110006, 250110007, 250110008, 250110009, 250110010, 250110011, 250110012, 250110013, 250110014, 250110015, 250110016, 250110017, 250110018, 250110019, 250110020, 250110021, 250110022, 250110023, 250110024, 250110025, 250110026, 250110027, 250110028, 250110029, 250110030, 250110031, 250110032, 250110033, 250110034, 250110035, 250110036, 250110037, 250110038, 250110039, 250110040, 250110041, 250110042, 250110043, 250110044, 250110045, 250110046))
      AND (ID NOT IN (250110047, 250110048, 250110049, 250110050, 250110051, 250110052, 250110053, 250110054, 250110055, 250110056, 250110057, 250110058, 250110059, 250110060, 250110061, 250110062, 250110063, 250110064, 250110065, 250110066, 250110067, 250110068, 250110069, 250110070, 250110071, 250110074, 250110075, 250110076, 250110079, 250110080, 250110081, 250110082, 250110087, 250111001, 250111002, 250111003, 250111004, 250111005, 250111006, 250111007, 250111008, 250111009, 250111010, 250111011, 250111012, 250111013, 250111014, 250111015, 250111016, 250111017))
      AND (ID NOT IN (250111018, 250111019, 250111020, 250111021, 250111089, 250111090, 250111091, 250111092, 250111093, 250112001, 250112002, 250112003, 250112004, 250112005, 250112006, 250112007, 250112008, 250112009, 250112010, 250112011, 250112012, 250112077, 250112078, 250112083, 250112084, 250112085, 250112086, 250112088, 250112094))
       and (IsBudget in(0, 1, 2))
  )
  LOOP
    DELETE FROM State_OpenFields
    WHERE (docfieldref = tab_rec.ID);

    DELETE FROM DOCLOCKFIELDS
    WHERE (fieldref = tab_rec.ID);

    DELETE FROM DocumentFields
    WHERE (id = tab_rec.ID);
  END LOOP;
END;
/

CALL DELOLDFLD_2501();

DROP PROCEDURE DELOLDFLD_2501
/

-- 
CREATE OR REPLACE PROCEDURE DELOLDFLD_2502 IS
BEGIN
  FOR tab_rec IN (
      SELECT ID
      FROM DocumentFields
      WHERE (DOCTYPEREF=2502)
      AND (ID NOT IN (250210001, 250210002, 250210003, 250210004, 250210005, 250210006, 250210007, 250210008, 250210009, 250210010, 250210011, 250210012, 250210013, 250210014, 250210015, 250210016, 250210017, 250210018, 250210019, 250210020, 250210021, 250210022, 250210023, 250210024, 250210025, 250210026, 250210027, 250210028, 250210029, 250210030, 250210031, 250210032, 250210033, 250210034, 250210035, 250210036, 250210037, 250210038, 250210039, 250210041, 250210042, 250210043, 250210044, 250210045, 250210046, 250210047, 250210048, 250210049, 250210050, 250210051))
      AND (ID NOT IN (250210052, 250210053, 250210054, 250210055, 250210056, 250210057, 250210058, 250210059, 250210060, 250210061, 250210062, 250210063, 250210064, 250210065, 250210066, 250210067, 250210068, 250210073, 250210074, 250211001, 250211002, 250211003, 250211004, 250211005, 250211006, 250211007, 250211008, 250211009, 250211010, 250211075, 250211076, 250211077, 250211078, 250211079, 250212001, 250212002, 250212003, 250212004, 250212005, 250212006, 250212007, 250212008, 250212009, 250212010, 250212011, 250212012, 250212013, 250212014, 250212015, 250212016))
      AND (ID NOT IN (250212017, 250212018, 250212019, 250212020, 250212021, 250212022, 250212023, 250212024, 250212025, 250212026, 250212027, 250212028, 250212029, 250212030, 250212031, 250212032, 250212033, 250212034, 250212035, 250212036, 250212037, 250212038, 250212040, 250212041, 250212042, 250212043, 250212044, 250212045, 250212046, 250212047, 250212048, 250212049, 250212050, 250212051, 250212052, 250212053, 250212054, 250212055, 250212056, 250212057, 250212058, 250212059, 250212060, 250212061, 250212062, 250212063, 250212069, 250212070, 250212071, 250212072))
      AND (ID NOT IN (250212074, 250212075, 250212076, 250212077, 250212090, 250212091, 250212092, 250213001, 250213002, 250213003, 250213004, 250213005, 250213006, 250213007, 250213008, 250213009, 250213080, 250213081, 250213082, 250213083, 250213084, 250214085, 250214086, 250214087, 250214088, 250214089))
       and (IsBudget in(0, 1, 2))
  )
  LOOP
    DELETE FROM State_OpenFields
    WHERE (docfieldref = tab_rec.ID);

    DELETE FROM DOCLOCKFIELDS
    WHERE (fieldref = tab_rec.ID);

    DELETE FROM DocumentFields
    WHERE (id = tab_rec.ID);
  END LOOP;
END;
/

CALL DELOLDFLD_2502();

DROP PROCEDURE DELOLDFLD_2502
/

--  
CREATE OR REPLACE PROCEDURE DELOLDFLD_2503 IS
BEGIN
  FOR tab_rec IN (
      SELECT ID
      FROM DocumentFields
      WHERE (DOCTYPEREF=2503)
      AND (ID NOT IN (250310040, 250311014, 250311015, 250310001, 250310002, 250310003, 250310004, 250310005, 250310006, 250310007, 250310008, 250310009, 250310010, 250310011, 250310012, 250310013, 250310014, 250310015, 250310016, 250310017, 250310018, 250310019, 250310020, 250310021, 250310022, 250310023, 250310024, 250310025, 250310026, 250310027, 250310028, 250310029, 250310030, 250310031, 250310032, 250310033, 250310034, 250310035, 250310036, 250310037, 250310038, 250310039, 250310041, 250310042, 250310043, 250310044, 250310045, 250310046, 250310047, 250310048))
      AND (ID NOT IN (250310049, 250310059, 250310060, 250310061, 250310062, 250310067, 250310068, 250310069, 250310076, 250310077, 250311001, 250311002, 250311004, 250311005, 250311006, 250311007, 250311008, 250311009, 250311010, 250311012, 250311013, 250311069, 250311070, 250311071, 250311072, 250311073, 250312002, 250312003, 250312004, 250312005, 250312006, 250312007, 250312008, 250312009, 250312010, 250312011, 250312012, 250312013, 250312014, 250312015, 250312016, 250312017, 250312018, 250312019, 250312020, 250312021, 250312022, 250312023, 250312024, 250312025))
      AND (ID NOT IN (250312026, 250312027, 250312028, 250312029, 250312030, 250312031, 250312032, 250312033, 250312034, 250312035, 250312036, 250312037, 250312038, 250312039, 250312040, 250312041, 250312042, 250312043, 250312044, 250312045, 250312046, 250312047, 250312048, 250312049, 250312050, 250312051, 250312052, 250312053, 250312054, 250312055, 250312056, 250312057, 250312058, 250312063, 250312064, 250312065, 250312066, 250312068, 250312069, 250312070, 250312071, 250312072, 250312073, 250312074, 250312075, 250312078, 250312079, 250312080))
       and (IsBudget in(0, 1, 2))
  )
  LOOP
    DELETE FROM State_OpenFields
    WHERE (docfieldref = tab_rec.ID);

    DELETE FROM DOCLOCKFIELDS
    WHERE (fieldref = tab_rec.ID);

    DELETE FROM DocumentFields
    WHERE (id = tab_rec.ID);
  END LOOP;
END;
/

CALL DELOLDFLD_2503();

DROP PROCEDURE DELOLDFLD_2503
/

-- 
CREATE OR REPLACE PROCEDURE DELOLDFLD_2504 IS
BEGIN
  FOR tab_rec IN (
      SELECT ID
      FROM DocumentFields
      WHERE (DOCTYPEREF=2504)
      AND (ID NOT IN (250400117, 250410001, 250410002, 250410003, 250410004, 250410005, 250410006, 250410007, 250410009, 250410010, 250410011, 250410012, 250410013, 250410014, 250410015, 250410016, 250410017, 250410018, 250410019, 250410020, 250410021, 250410022, 250410024, 250410025, 250410026, 250410027, 250410029, 250410030, 250410031, 250410032, 250410033, 250410034, 250410035, 250410036, 250410039, 250410042, 250410043, 250410044, 250410045, 250410046, 250410047, 250410048, 250410049, 250410053, 250410056, 250410057, 250410058, 250410059, 250410060, 250410061))
      AND (ID NOT IN (250410062, 250410063, 250410064, 250410065, 250410066, 250410067, 250410068, 250410069, 250410070, 250410078, 250410079, 250410080, 250410081, 250410082, 250410083, 250410084, 250410085, 250410086, 250410087, 250410088, 250410089, 250410090, 250410091, 250410092, 250410093, 250410094, 250410095, 250410096, 250410055, 250410097, 250410098, 250410099, 250410100, 250410101, 250410102, 250410103, 250410104, 250410105, 250410106, 250410111, 250410112, 250410113, 250410114, 250410115, 250410116, 250410141, 250410142, 250410143, 250410144, 250411001))
      AND (ID NOT IN (250411002, 250411003, 250411004, 250411005, 250411006, 250411007, 250411008, 250411009, 250411010, 250411126, 250411127, 250411128, 250411129, 250411130, 250412001, 250412002, 250412003, 250412004, 250412005, 250412006, 250412007, 250412008, 250412009, 250412010, 250412011, 250412012, 250412013, 250412014, 250412015, 250412016, 250412017, 250412018, 250412019, 250412020, 250412021, 250412022, 250412023, 250412024, 250412025, 250412026, 250412027, 250412028, 250412029, 250412030, 250412031, 250412032, 250412033, 250412034, 250412035, 250412036))
      AND (ID NOT IN (250412037, 250412038, 250412039, 250412040, 250412041, 250412042, 250412043, 250412044, 250412045, 250412046, 250412047, 250412049, 250412050, 250412051, 250412052, 250412053, 250412054, 250412055, 250412056, 250412057, 250412058, 250412059, 250412060, 250412061, 250412107, 250412108, 250412109, 250412110, 250412116, 250412117, 250412118, 250412119, 250412120, 250412121, 250412158, 250412159, 250413001, 250413002, 250413003, 250413004, 250413005, 250413006, 250413007, 250413008, 250413009, 250413010, 250413011, 250413012, 250413013, 250413014))
      AND (ID NOT IN (250413131, 250413132, 250413133, 250413134, 250413135, 250414121, 250414122, 250414123, 250414124, 250414125, 250414126, 250414127, 250414128, 250414129, 250414130, 250414131, 250414132, 250414133, 250414134, 250414135, 250414136, 250414137, 250414138, 250414139, 250414140, 250414141, 250415010, 250415136, 250415137, 250415138, 250415139, 250415140, 250416145, 250416146, 250416147, 250416148, 250416149, 250416150, 250416151, 250416152, 250416153, 250416154, 250416155, 250416156))
       and (IsBudget in(0, 1, 2))
  )
  LOOP
    DELETE FROM State_OpenFields
    WHERE (docfieldref = tab_rec.ID);

    DELETE FROM DOCLOCKFIELDS
    WHERE (fieldref = tab_rec.ID);

    DELETE FROM DocumentFields
    WHERE (id = tab_rec.ID);
  END LOOP;
END;
/

CALL DELOLDFLD_2504();

DROP PROCEDURE DELOLDFLD_2504
/

--   
CREATE OR REPLACE PROCEDURE DELOLDFLD_3001 IS
BEGIN
  FOR tab_rec IN (
      SELECT ID
      FROM DocumentFields
      WHERE (DOCTYPEREF=3001)
      AND (ID NOT IN (300110001, 300110002, 300110003, 300110004, 300110005, 300110006, 300110008, 300110009, 300110010, 300110011, 300110012, 300110013, 300110014, 300110015, 300110016, 300110017, 300110018, 300110019, 300110021, 300110022, 300110023, 300110024, 300110025, 300110026, 300110028, 300110029, 300110030, 300110031, 300110032, 300110033, 300110034, 300110035, 300110106, 300110107, 300110108, 300110109, 300110110, 300111001, 300111002, 300111003, 300111005, 300111006, 300111007, 300111008, 300111010, 300111011, 300111012, 300111013, 300111014, 300111015))
      AND (ID NOT IN (300111016, 300111017, 300111018, 300111019, 300111020, 300111021, 300111022, 300111023, 300111024, 300111025, 300111026, 300111027, 300111028, 300111029, 300111030, 300111031, 300111032, 300111033, 300111034, 300111035, 300111036, 300111037, 300111038, 300111039, 300111040, 300111041, 300111042, 300111043, 300111044, 300111045, 300111046, 300111047, 300111048, 300111049, 300111050, 300111051, 300111052, 300111053, 300111054, 300111055, 300111057, 300111058, 300111059, 300111060, 300111061, 300111062, 300111063, 300111064, 300111065, 300111066))
      AND (ID NOT IN (300111067, 300111068, 300111069, 300111070, 300111071, 300111072, 300111073, 300111074, 300111075, 300111076, 300111077, 300111078, 300111079, 300111080, 300111081, 300111082, 300111083, 300111084, 300111085, 300111086, 300111087, 300111088, 300111089, 300111090, 300111091, 300111092, 300111093, 300111094, 300111095, 300111096, 300111097, 300111098, 300111099, 300111100, 300111101, 300111102, 300111103, 300111104, 300111105, 300111111, 300111112, 300111113, 300111114, 300111115, 300111116, 300111117, 300111118, 300111119, 300111151, 300111152))
      AND (ID NOT IN (300111153, 300112001, 300112002, 300112003, 300112116, 300112117, 300112118, 300112119, 300112120, 300113001, 300113002, 300113003, 300113004, 300113005, 300113006, 300113007, 300113008, 300113009, 300113010, 300113011, 300113012, 300113013, 300113014, 300113015, 300113016, 300113017, 300113018, 300113019, 300113020, 300113021, 300113022, 300113023, 300113024, 300113121, 300113122, 300113123, 300113124, 300113125, 300114001, 300114002, 300114003, 300114004, 300114006, 300114007, 300114008, 300114009, 300114010, 300114011, 300114012, 300114013))
      AND (ID NOT IN (300114126, 300114127, 300114128, 300114129, 300114130, 300115001, 300115002, 300115003, 300115131, 300115132, 300115133, 300115134, 300115135, 300116001, 300116002, 300116136, 300116137, 300116138, 300116139, 300116140, 300117001, 300117002, 300117003, 300117004, 300117005, 300117006, 300117007, 300117008, 300117009, 300117010, 300117141, 300117142, 300117143, 300117144, 300117145, 300118001, 300118002, 300118003, 300118004, 300118005, 300118006, 300118007, 300118146, 300118147, 300118148, 300118149, 300118150))
       and (IsBudget in(0, 1, 2))
  )
  LOOP
    DELETE FROM State_OpenFields
    WHERE (docfieldref = tab_rec.ID);

    DELETE FROM DOCLOCKFIELDS
    WHERE (fieldref = tab_rec.ID);

    DELETE FROM DocumentFields
    WHERE (id = tab_rec.ID);
  END LOOP;
END;
/

CALL DELOLDFLD_3001();

DROP PROCEDURE DELOLDFLD_3001
/

-- 
CREATE OR REPLACE PROCEDURE DELOLDFLD_3003 IS
BEGIN
  FOR tab_rec IN (
      SELECT ID
      FROM DocumentFields
      WHERE (DOCTYPEREF=3003)
      AND (ID NOT IN (300310047, 300310048, 300310049, 300310001, 300310002, 300310003, 300310004, 300310005, 300310006, 300310007, 300310008, 300310009, 300310010, 300310011, 300310012, 300310013, 300310014, 300310015, 300310016, 300310017, 300310018, 300310019, 300310020, 300310021, 300310022, 300310023, 300310024, 300310025, 300310026, 300310027, 300310028, 300310029, 300310030, 300310031, 300310032, 300310033, 300310034, 300310035, 300310036, 300310037, 300310038, 300310039, 300310040, 300310041, 300310042, 300310043, 300310044, 300310045, 300310046, 300310050))
      AND (ID NOT IN (300310051, 300310052, 300310053, 300310054))
       and (IsBudget in(0, 1, 2))
  )
  LOOP
    DELETE FROM State_OpenFields
    WHERE (docfieldref = tab_rec.ID);

    DELETE FROM DOCLOCKFIELDS
    WHERE (fieldref = tab_rec.ID);

    DELETE FROM DocumentFields
    WHERE (id = tab_rec.ID);
  END LOOP;
END;
/

CALL DELOLDFLD_3003();

DROP PROCEDURE DELOLDFLD_3003
/

COMMIT WORK
/


-- #########################################################
-- #########################################################
-- Alter_ExecutionDocumentsCaption_Add_Autosanction.sql
-- #########################################################
-- #########################################################

ALTER TABLE TB_ExecutionDocumentsCaption ADD (
  AUTOSANCTION NUMBER(10),
    CHECK((AUTOSANCTION<=2147483647)AND(AUTOSANCTION>-2147483648))
)
/

CREATE OR REPLACE VIEW ExecutionDocumentsCaption (
  ID,
  DOCTYPE,
  DOCUMENTDATE,
  ACCEPTDATE,
  SUMMA,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  STEPNUMBER,
  FACIALACC_CLS,
  RECIPIENT_REF,
  REGISTRATIONTYPE,
  REESTRNUMBER,
  AGREEMENTINNERNUMBER,
  REJECTCLS,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  REVIEWNOTE,
  DOCSTATEREF,
  RVERSION,
  EXECDOCFINSUMMA,
  FACT,
  DOCNUMBER,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  REALID,
  INNERNUMBER,
  ADJUSTMENTREF,
  ADJUSTMENTNUMBER,
  ACCEPTED,
  LASTACCEPTED,
  LASTADJUSTMENT,
  AGREEMENTREF,
  NOTE,
  SUPPLIERSTOREDPROPS,
  SUPPLIER_REF,
  SUPPLIERACC_REF,
  REJECTCAUSE,
  INFONUMBER,
  NOTIFYDATE,
  MONEYPROMISENUMBER,
  PURPORTDOC,
  STOREDCONTENT,
  PAYDATE,
  AUTOSANCTION)
AS
  SELECT
    ID,
    DOCTYPE,
    DOCUMENTDATE,
    ACCEPTDATE,
    SUMMA,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    STEPNUMBER,
    FACIALACC_CLS,
    RECIPIENT_REF,
    REGISTRATIONTYPE,
    REESTRNUMBER,
    AGREEMENTINNERNUMBER,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXECDOCFINSUMMA,
    FACT,
    DOCNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REALID,
    INNERNUMBER,
    ADJUSTMENTREF,
    ADJUSTMENTNUMBER,
    ACCEPTED,
    LASTACCEPTED,
    LASTADJUSTMENT,
    AGREEMENTREF,
    NOTE,
    SUPPLIERSTOREDPROPS,
    SUPPLIER_REF,
    SUPPLIERACC_REF,
    REJECTCAUSE,
    INFONUMBER,
    NOTIFYDATE,
    MONEYPROMISENUMBER,
    PURPORTDOC,
    STOREDCONTENT,
    PAYDATE,
    AUTOSANCTION
  FROM TB_ExecutionDocumentsCaption
/

CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_ID
  INSTEAD OF DELETE
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  quant$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_DOCEXECCAPTION_BD)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  select count(ID)   into quant$ from executiondocumentscaption
  where AdjustmentRef = :old.ID
  ;
  if (quant$  = 0) then
    delete from ExecutionDocumentsDetail where (RecordIndex = :old.ID);
    delete from paymentschedule where (ExecutionRef = :old.ID)and(ProgIndex=308);

  else
    RaiseException('ex_agr_cantdeladjustmented');
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_EXECUTIONDOCUMENTSCAPTION
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_10 (TR_ExecDocCaption_AD_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*   LastAdjustment     */
  if ((:old.AdjustmentRef is not null) and (:old.LastAdjustment = 1)) then
    update ExecutionDocumentsCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;
  /*   LastAccepted     */
  if ((:old.AdjustmentRef is not null) and (:old.LastAccepted = 1)) then
    update ExecutionDocumentsCaption set
    LastAccepted = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AD_200 (TR_EXECDOCCAPTION_AD_200)
-- Create 04.10.2004
-- - - - - - - - - - - - -

  /*        */
  delete from StateJumpHistory where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_EXECDOCCAPTION_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordId, DeleteDate, SUMMA) values (114, :old.ID, SYSDATE, :old.SUMMA);

END;
/

CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_II
  INSTEAD OF INSERT
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  new$ID EXECUTIONDOCUMENTSCAPTION.ID%TYPE := :NEW.ID;
  new$DOCTYPE EXECUTIONDOCUMENTSCAPTION.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$DOCUMENTDATE EXECUTIONDOCUMENTSCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE EXECUTIONDOCUMENTSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SUMMA EXECUTIONDOCUMENTSCAPTION.SUMMA%TYPE := :NEW.SUMMA;
  new$CREATERUSER EXECUTIONDOCUMENTSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE EXECUTIONDOCUMENTSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE EXECUTIONDOCUMENTSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER EXECUTIONDOCUMENTSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF EXECUTIONDOCUMENTSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$STEPNUMBER EXECUTIONDOCUMENTSCAPTION.STEPNUMBER%TYPE := :NEW.STEPNUMBER;
  new$FACIALACC_CLS EXECUTIONDOCUMENTSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$RECIPIENT_REF EXECUTIONDOCUMENTSCAPTION.RECIPIENT_REF%TYPE := :NEW.RECIPIENT_REF;
  new$REGISTRATIONTYPE EXECUTIONDOCUMENTSCAPTION.REGISTRATIONTYPE%TYPE := :NEW.REGISTRATIONTYPE;
  new$REESTRNUMBER EXECUTIONDOCUMENTSCAPTION.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$AGREEMENTINNERNUMBER EXECUTIONDOCUMENTSCAPTION.AGREEMENTINNERNUMBER%TYPE := :NEW.AGREEMENTINNERNUMBER;
  new$REJECTCLS EXECUTIONDOCUMENTSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS EXECUTIONDOCUMENTSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID EXECUTIONDOCUMENTSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID EXECUTIONDOCUMENTSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REVIEWNOTE EXECUTIONDOCUMENTSCAPTION.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF EXECUTIONDOCUMENTSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION EXECUTIONDOCUMENTSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$EXECDOCFINSUMMA EXECUTIONDOCUMENTSCAPTION.EXECDOCFINSUMMA%TYPE := :NEW.EXECDOCFINSUMMA;
  new$FACT EXECUTIONDOCUMENTSCAPTION.FACT%TYPE := :NEW.FACT;
  new$DOCNUMBER EXECUTIONDOCUMENTSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SENDERIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REALID EXECUTIONDOCUMENTSCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER EXECUTIONDOCUMENTSCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTREF EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ADJUSTMENTNUMBER EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$ACCEPTED EXECUTIONDOCUMENTSCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED EXECUTIONDOCUMENTSCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$LASTADJUSTMENT EXECUTIONDOCUMENTSCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$AGREEMENTREF EXECUTIONDOCUMENTSCAPTION.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$NOTE EXECUTIONDOCUMENTSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$SUPPLIERSTOREDPROPS EXECUTIONDOCUMENTSCAPTION.SUPPLIERSTOREDPROPS%TYPE := :NEW.SUPPLIERSTOREDPROPS;
  new$SUPPLIER_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$SUPPLIERACC_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIERACC_REF%TYPE := :NEW.SUPPLIERACC_REF;
  new$REJECTCAUSE EXECUTIONDOCUMENTSCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$INFONUMBER EXECUTIONDOCUMENTSCAPTION.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$NOTIFYDATE EXECUTIONDOCUMENTSCAPTION.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$MONEYPROMISENUMBER EXECUTIONDOCUMENTSCAPTION.MONEYPROMISENUMBER%TYPE := :NEW.MONEYPROMISENUMBER;
  new$PURPORTDOC EXECUTIONDOCUMENTSCAPTION.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$STOREDCONTENT EXECUTIONDOCUMENTSCAPTION.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
  new$PAYDATE EXECUTIONDOCUMENTSCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$AUTOSANCTION EXECUTIONDOCUMENTSCAPTION.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
--
  Tmp$ NUMBER(10);
  AdjID$ NUMBER(10);
  AdjDocNum$ VARCHAR2(50);
  agr_accepted$ NUMBER(10);
  agr_acceptdate$ NUMBER(10);
  PreviousInner1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ExecDoccaption_BI)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$ExecDocFinSumma is null) then
    new$ExecDocFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$RegistrationType is null) then
    new$RegistrationType := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    BEGIN
      select fa.BudgetRef
      into new$BudgetRef     from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    GetIntConst(-1,3,new$BudgetRef);
  END IF;
  if (new$Supplier_Ref is null and new$SupplierAcc_Ref is not null) then
    BEGIN
      select oa.Org_Ref
      into new$Supplier_Ref   from Org_Accounts oa
      where oa.id = new$SupplierAcc_Ref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,     ,      */
  if (new$AdjustmentRef is null) then
    new$InnerNumber := GEN_ID('g_ExecDocNumber',1);

  else
    BEGIN
      /*          */
      select
      InnerNumber
      into PreviousInner1$     from ExecutionDocumentsCaption
      where ID = new$AdjustmentRef and LastAccepted = 1 and LastAdjustment = 1
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (PreviousInner1$ is null) then
      RaiseException('EX_NotFindInnerNumber');
    END IF;
    new$InnerNumber := PreviousInner1$;

  END IF;
  /*      id */
  new$agreementinnernumber := null;
  if (new$agreementref is not null) then
    BEGIN
      select
      innernumber
      into new$agreementinnernumber     from agreements
      where
      id = new$agreementref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_EXECDOCCAPTION_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_EXECDOCCAPTION_BI_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*    .*/
  if (new$InnerNumber is null) then
    RaiseException('EX_AGR_InnerNumsIsNull');
  END IF;

  /*    */
  select max(AdjustmentNumber)
  into Tmp$     from ExecutionDocumentsCaption
  where (InnerNumber = new$InnerNumber)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;

  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;
  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;

  else
    new$LastAdjustment := 1;
  END IF;
  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then
    new$LastAccepted := 1;

  else
    new$LastAccepted := 0;
  END IF;
  /*    */
  if (new$AdjustmentRef is not null) then
    /*      -    */
    select count(ID), max(ID), max(DocNumber)
    into Tmp$, AdjID$, AdjDocNum$       from ExecutionDocumentsCaption
    where (InnerNumber = new$InnerNumber) and (LastAccepted = 1)
    ;
    /*   ,  */
    if (Tmp$ <> 1) then
      RaiseException('EX_ExecDoc_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID)
    into Tmp$       from ExecutionDocumentsCaption
    where (InnerNumber = new$InnerNumber) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then
      RaiseException('EX_ExecDoc_AdjustDuplicate');
    END IF;
    /* ,    ,    */
    new$AdjustmentRef := AdjID$;

  else /*     */
    /*       (    )*/
    new$AdjustmentRef := null;
  END IF;

-- - - - - - - - - - - - -
-- BI_40 (tr_execdoccaption_bi_40)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*       */
  if (new$senderId is null) then
    new$senderIdKey := -1;

  else
    new$senderIdKey := new$senderId;
  END IF;
  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;

  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_60 (tr_execdoccaption_bi_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$agreementinnernumber is not null) then
    BEGIN
      /*        , .. 
             ,    ,   
            ,     */
      select accepted, acceptdate     into
      agr_accepted$, agr_acceptdate$ from agreements
      where
      innernumber = new$agreementinnernumber and adjustmentnumber = 0
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*        */
    if (new$acceptdate is null and agr_accepted$ = 0 and agr_acceptdate$ is not null) then
      RaiseException('EX_Agr_Rejected');
    END IF;
    /*        */
    if (new$accepted = 1 and new$acceptdate is not null and
    (agr_accepted$ = 0 or agr_acceptdate$ is null)) then
      RaiseException('EX_Agr_NotAccepted');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_EXECDOCCAPTION_BI_500)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_EXECUTIONDOCUMENTSCAPTION (
    ID,
    DOCTYPE,
    DOCUMENTDATE,
    ACCEPTDATE,
    SUMMA,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    STEPNUMBER,
    FACIALACC_CLS,
    RECIPIENT_REF,
    REGISTRATIONTYPE,
    REESTRNUMBER,
    AGREEMENTINNERNUMBER,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXECDOCFINSUMMA,
    FACT,
    DOCNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REALID,
    INNERNUMBER,
    ADJUSTMENTREF,
    ADJUSTMENTNUMBER,
    ACCEPTED,
    LASTACCEPTED,
    LASTADJUSTMENT,
    AGREEMENTREF,
    NOTE,
    SUPPLIERSTOREDPROPS,
    SUPPLIER_REF,
    SUPPLIERACC_REF,
    REJECTCAUSE,
    INFONUMBER,
    NOTIFYDATE,
    MONEYPROMISENUMBER,
    PURPORTDOC,
    STOREDCONTENT,
    PAYDATE,
    AUTOSANCTION
  ) VALUES (
    new$ID,
    new$DOCTYPE,
    new$DOCUMENTDATE,
    new$ACCEPTDATE,
    new$SUMMA,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$STEPNUMBER,
    new$FACIALACC_CLS,
    new$RECIPIENT_REF,
    new$REGISTRATIONTYPE,
    new$REESTRNUMBER,
    new$AGREEMENTINNERNUMBER,
    new$REJECTCLS,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$REVIEWNOTE,
    new$DOCSTATEREF,
    new$RVERSION,
    new$EXECDOCFINSUMMA,
    new$FACT,
    new$DOCNUMBER,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$REALID,
    new$INNERNUMBER,
    new$ADJUSTMENTREF,
    new$ADJUSTMENTNUMBER,
    new$ACCEPTED,
    new$LASTACCEPTED,
    new$LASTADJUSTMENT,
    new$AGREEMENTREF,
    new$NOTE,
    new$SUPPLIERSTOREDPROPS,
    new$SUPPLIER_REF,
    new$SUPPLIERACC_REF,
    new$REJECTCAUSE,
    new$INFONUMBER,
    new$NOTIFYDATE,
    new$MONEYPROMISENUMBER,
    new$PURPORTDOC,
    new$STOREDCONTENT,
    new$PAYDATE,
    new$AUTOSANCTION);

-- - - - - - - - - - - - -
-- AI_0 (TR_ExecDocCaption_AI)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*       */
  /*     ,       */
  if ((new$AdjustmentRef is not null) and (new$LastAdjustment = 1)) then
    update ExecutionDocuMENTSCaption set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);
    if (new$LastAccepted = 1) then
      update ExecutionDocuMENTSCaption set
      LastAccepted = 0,
      RVersion = -1
      where (ID = new$AdjustmentRef);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_EXECDOCCAPTION_AI_500)
-- - - - - - - - - - - - -

-- 25.08.2004
  delete from DelRecIndexes where (TableID = 114) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_IU
  INSTEAD OF UPDATE
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  new$ID EXECUTIONDOCUMENTSCAPTION.ID%TYPE := :NEW.ID;
  new$DOCTYPE EXECUTIONDOCUMENTSCAPTION.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$DOCUMENTDATE EXECUTIONDOCUMENTSCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE EXECUTIONDOCUMENTSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SUMMA EXECUTIONDOCUMENTSCAPTION.SUMMA%TYPE := :NEW.SUMMA;
  new$CREATERUSER EXECUTIONDOCUMENTSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE EXECUTIONDOCUMENTSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE EXECUTIONDOCUMENTSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER EXECUTIONDOCUMENTSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF EXECUTIONDOCUMENTSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$STEPNUMBER EXECUTIONDOCUMENTSCAPTION.STEPNUMBER%TYPE := :NEW.STEPNUMBER;
  new$FACIALACC_CLS EXECUTIONDOCUMENTSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$RECIPIENT_REF EXECUTIONDOCUMENTSCAPTION.RECIPIENT_REF%TYPE := :NEW.RECIPIENT_REF;
  new$REGISTRATIONTYPE EXECUTIONDOCUMENTSCAPTION.REGISTRATIONTYPE%TYPE := :NEW.REGISTRATIONTYPE;
  new$REESTRNUMBER EXECUTIONDOCUMENTSCAPTION.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$AGREEMENTINNERNUMBER EXECUTIONDOCUMENTSCAPTION.AGREEMENTINNERNUMBER%TYPE := :NEW.AGREEMENTINNERNUMBER;
  new$REJECTCLS EXECUTIONDOCUMENTSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS EXECUTIONDOCUMENTSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID EXECUTIONDOCUMENTSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID EXECUTIONDOCUMENTSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REVIEWNOTE EXECUTIONDOCUMENTSCAPTION.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF EXECUTIONDOCUMENTSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION EXECUTIONDOCUMENTSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$EXECDOCFINSUMMA EXECUTIONDOCUMENTSCAPTION.EXECDOCFINSUMMA%TYPE := :NEW.EXECDOCFINSUMMA;
  new$FACT EXECUTIONDOCUMENTSCAPTION.FACT%TYPE := :NEW.FACT;
  new$DOCNUMBER EXECUTIONDOCUMENTSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SENDERIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REALID EXECUTIONDOCUMENTSCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER EXECUTIONDOCUMENTSCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTREF EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ADJUSTMENTNUMBER EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$ACCEPTED EXECUTIONDOCUMENTSCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED EXECUTIONDOCUMENTSCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$LASTADJUSTMENT EXECUTIONDOCUMENTSCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$AGREEMENTREF EXECUTIONDOCUMENTSCAPTION.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$NOTE EXECUTIONDOCUMENTSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$SUPPLIERSTOREDPROPS EXECUTIONDOCUMENTSCAPTION.SUPPLIERSTOREDPROPS%TYPE := :NEW.SUPPLIERSTOREDPROPS;
  new$SUPPLIER_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$SUPPLIERACC_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIERACC_REF%TYPE := :NEW.SUPPLIERACC_REF;
  new$REJECTCAUSE EXECUTIONDOCUMENTSCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$INFONUMBER EXECUTIONDOCUMENTSCAPTION.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$NOTIFYDATE EXECUTIONDOCUMENTSCAPTION.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$MONEYPROMISENUMBER EXECUTIONDOCUMENTSCAPTION.MONEYPROMISENUMBER%TYPE := :NEW.MONEYPROMISENUMBER;
  new$PURPORTDOC EXECUTIONDOCUMENTSCAPTION.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$STOREDCONTENT EXECUTIONDOCUMENTSCAPTION.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
  new$PAYDATE EXECUTIONDOCUMENTSCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$AUTOSANCTION EXECUTIONDOCUMENTSCAPTION.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  CntAgr$ NUMBER(10);
  CntStep$ NUMBER(10);
  agr_accepted$ NUMBER(10);
  agr_acceptdate$ NUMBER(10);
  CountExecDoc$ NUMBER(10);
  countLastAdj1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_EXECDOCCAPTION_BU)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$ExecDocFinSumma is null) then
    new$ExecDocFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$RegistrationType is null) then
    new$RegistrationType := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      SELECT COUNT(                   Id
      ) INTO CNT$1
      from ExecutionDocumentsDetail
      where
      (                   RecordIndex = :old.Id
      ) AND (ROWNUM = 1)                ;
      if ((CNT$1<> 0)         ) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      SELECT COUNT(                   Id
      ) INTO CNT$2
      from PaymentSchedule
      where
      (                   ExecutionRef = :old.Id
      ) AND (ROWNUM = 1)                ;
      if ((CNT$2<> 0)         ) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*     ,        */
  if (new$InnerNumber is null) then
    new$InnerNumber := :old.InnerNumber;
  END IF;
  /* c,           */
  /* ,    */
  if (new$InnerNumber <> :old.InnerNumber or
  new$AdjustmentRef <> :old.AdjustmentRef or
  new$AdjustmentNumber <> :old.AdjustmentNumber) then
    RaiseException('EX_Agr_ChangeInnerNums');
  END IF;
  /*      id */
  new$agreementinnernumber := null;
  if (new$agreementref is not null) then
    BEGIN
      select
      innernumber
      into new$agreementinnernumber     from agreements
      where
      id = new$agreementref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_EXECDOCCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_EXECDOCCAPTION_BU_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*     */
  if (:old.AcceptDate is not null and :old.Accepted = 0 and (new$Accepted = 1 or new$AcceptDate is null)) then
    /* :  */
    if (new$AdjustmentRef is not null) then
      RaiseException('EX_RollbackCancel');
    END IF;
    /*      ,
           , ,          */
    select count(ID)
    into countLastAdj1$     from ExecutionDocumentsCaption
    where InnerNumber=new$InnerNumber and LastAdjustment = 1
    ;
    if (countLastAdj1$ = 0) then
      new$LastAdjustment := 1;
      
    END IF;
  END IF;
  /*   ,     LastAccepted*/
  if (:old.AcceptDate is null and new$AcceptDate is not null and new$Accepted = 1) then 
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
  END IF;
      
  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');   
    END IF;
  END IF;
  /*   ,     LastAdjustment  LastAccepted */
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment <> 1) then
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    else
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_40 (tr_execdoccaption_bu_40)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  if ((:old.AcceptDate is not null) and (new$AcceptDate is null)) then
    select count(ID) into CntAgr$ from Agreements where (CloseDoc = :old.ID) ;
    select count(ID) into CntStep$ from AgreementSteps where (CloseDoc = :old.ID) ;
    if ((CntAgr$ > 0) or (CntStep$ > 0)) then
      RaiseException('ex_CannotUpdateCloseDoc');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_60 (tr_execdoccaption_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$agreementinnernumber is not null) then
    BEGIN
      /*        , .. 
             ,    ,   
            ,     */
      select accepted, acceptdate     into
      agr_accepted$, agr_acceptdate$ from agreements
      where
      innernumber = new$agreementinnernumber and adjustmentnumber = 0
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*        */
    if (new$acceptdate is null and agr_accepted$ = 0 and agr_acceptdate$ is not null) then
      RaiseException('EX_Agr_Rejected');
    END IF;
    /*        */
    if (new$accepted = 1 and new$acceptdate is not null and
    (agr_accepted$ = 0 or agr_acceptdate$ is null)) then
      RaiseException('EX_Agr_NotAccepted');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_EXECDOCCAPTION_BU_200)
-- Create 04.10.2004
-- - - - - - - - - - - - -

  /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_EXECDOCCAPTION_BU_210)
-- Version 11.20.00.1
-- - - - - - - - - - - - -

  /*   */
  if (new$rejectcls is not null and new$accepted = 0) then
    /*         */
    select
    count(ffd.id)
    into CountExecDoc$     from
    facialfindetail ffd
    left join facialfincaption ffc on ffc.id = ffd.recordindex
    where
    (ffc.acceptdate is not null and (ffd.sourceexecdoc = new$id or ffd.destexecdoc = new$id))
    ;
    /*       */
    if (CountExecDoc$ <> 0) then
      RaiseException('ex_exedoc_useinfacialfindetail');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_EDCAPTION_BU_700)
-- Create 14.10.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_EXECUTIONDOCUMENTSCAPTION SET
    ID = new$ID,
    DOCTYPE = new$DOCTYPE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    SUMMA = new$SUMMA,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    STEPNUMBER = new$STEPNUMBER,
    FACIALACC_CLS = new$FACIALACC_CLS,
    RECIPIENT_REF = new$RECIPIENT_REF,
    REGISTRATIONTYPE = new$REGISTRATIONTYPE,
    REESTRNUMBER = new$REESTRNUMBER,
    AGREEMENTINNERNUMBER = new$AGREEMENTINNERNUMBER,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXECDOCFINSUMMA = new$EXECDOCFINSUMMA,
    FACT = new$FACT,
    DOCNUMBER = new$DOCNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REALID = new$REALID,
    INNERNUMBER = new$INNERNUMBER,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    ACCEPTED = new$ACCEPTED,
    LASTACCEPTED = new$LASTACCEPTED,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    AGREEMENTREF = new$AGREEMENTREF,
    NOTE = new$NOTE,
    SUPPLIERSTOREDPROPS = new$SUPPLIERSTOREDPROPS,
    SUPPLIER_REF = new$SUPPLIER_REF,
    SUPPLIERACC_REF = new$SUPPLIERACC_REF,
    REJECTCAUSE = new$REJECTCAUSE,
    INFONUMBER = new$INFONUMBER,
    NOTIFYDATE = new$NOTIFYDATE,
    MONEYPROMISENUMBER = new$MONEYPROMISENUMBER,
    PURPORTDOC = new$PURPORTDOC,
    STOREDCONTENT = new$STOREDCONTENT,
    PAYDATE = new$PAYDATE,
    AUTOSANCTION = new$AUTOSANCTION
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_0 (TR_ExecDocCaption_AU)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*       */
  /*     ,       */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update ExecutionDocuMENTSCaption set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update ExecutionDocuMENTSCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_EXECDOCCAPTION_AU_30)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$Accepted <> :old.Accepted) or
  (new$AcceptDate is not null and :old.AcceptDate is null) or
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where ExecutionRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_EXECDOCCAPTION_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (114, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=114) and (RecordId=new$ID);
  end if;

END;
/
ALTER TABLE TB_ExecutionDocumentsCaption ADD (
  CONSTRAINT FK_EXECUTIONCAPTION_AUTOSANC FOREIGN KEY (AUTOSANCTION) REFERENCES autosanctiondata (ID)
)
/
CREATE INDEX FK_EXECUTIONCAPTION_AUTOSANC ON TB_ExecutionDocumentsCaption(AUTOSANCTION)
/
COMMIT WORK
/


-- #########################################################
-- #########################################################
-- Add_UIS_to_BankExch_LsKb.sql
-- #########################################################
-- #########################################################

/*    UIS (    - )   bankexch_ls_kb*/
ALTER TABLE bankexch_ls_kb ADD (
  UIS VARCHAR2(10)
)
/
commit work 
/


-- #########################################################
-- #########################################################
-- ProtocolDocType24to29.sql
-- #########################################################
-- #########################################################

CREATE OR REPLACE procedure AddProtocolDocType(ID$ NUMBER,Name$ VARCHAR2,AType$ NUMBER)
AS
  CNT$1 NUMBER(10);
BEGIN
  SELECT COUNT(id ) INTO CNT$1
  from ProtocolDoctype where (id = ID$) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    update ProtocolDocType set Name = Name$, AType = AType$  where id = ID$;
      
  else
    insert into ProtocolDoctype(ID, Name, AType) values (ID$, Name$, AType$);
  END IF;
END;
/
-- ALTER TRIGGER TR_ProtocolDocType_BI
CREATE OR REPLACE TRIGGER TR_PROTOCOLDOCTYPE_BI
  BEFORE INSERT
  ON PROTOCOLDOCTYPE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ProtocolDocType_BI)
-- Create 27.10.2009
-- - - - - - - - - - - - -
  NULL;
--   RaiseException('EX_PDT_BanInsert');

-- - - - - - - - - - - - -
-- BI_500 (TR_PROTOCOLDOCTYPE_BI_500)
-- Create 20.05.2009
-- - - - - - - - - - - - -

    :new.CreateDate := SYSDATE;
    :new.UpdateDate := :new.CreateDate;    

END;
/
-- ALTER TRIGGER TR_ProtocolDocType_BU
CREATE OR REPLACE TRIGGER TR_PROTOCOLDOCTYPE_BU
  BEFORE UPDATE
  ON PROTOCOLDOCTYPE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ProtocolDocType_BU)
-- Version 8.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (not ((:new.id in (7,12)) and (:old.id in (7,12)) and (:new.AType = :old.AType))) then
--     RaiseException('EX_PDT_BanUpdate');
--   END IF;

END;
/
CALL AddProtocolDocType(24, '      ', 124)
/
CALL AddProtocolDocType(25, '            ', 124)
/
CALL AddProtocolDocType(26, '       ', 124)
/
CALL AddProtocolDocType(27, '           ', 124)
/
CALL AddProtocolDocType(28, '         ', 124)
/
CALL AddProtocolDocType(29, '       ', 124)
/
-- ALTER TRIGGER TR_ProtocolDocType_BI
CREATE OR REPLACE TRIGGER TR_PROTOCOLDOCTYPE_BI
  BEFORE INSERT
  ON PROTOCOLDOCTYPE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ProtocolDocType_BI)
-- Create 27.10.2009
-- - - - - - - - - - - - -

  RaiseException('EX_PDT_BanInsert');

-- - - - - - - - - - - - -
-- BI_500 (TR_PROTOCOLDOCTYPE_BI_500)
-- Create 20.05.2009
-- - - - - - - - - - - - -

    :new.CreateDate := SYSDATE;
    :new.UpdateDate := :new.CreateDate;    

END;
/
-- ALTER TRIGGER TR_ProtocolDocType_BU
CREATE OR REPLACE TRIGGER TR_PROTOCOLDOCTYPE_BU
  BEFORE UPDATE
  ON PROTOCOLDOCTYPE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ProtocolDocType_BU)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (not ((:new.id in (7,12)) and (:old.id in (7,12)) and (:new.AType = :old.AType))) then
    RaiseException('EX_PDT_BanUpdate');
  END IF;

END;
/
drop procedure AddProtocolDocType
/
commit work
/

-- #########################################################
-- #########################################################
-- Add_TargetClsDetail.sql
-- #########################################################
-- #########################################################

/*              */
create table TargetClsDetail (
  ID NUMBER(10) NOT NULL,/*  */
    CHECK((ID<=2147483647)AND(ID>-2147483648)),
  TargetCls NUMBER(10) NOT NULL,/*     */
    CHECK((TargetCls<=2147483647)AND(TargetCls>-2147483648)),
  TransferKVSR NUMBER(10) NOT NULL,/*   */
    CHECK((TransferKVSR<=2147483647)AND(TransferKVSR>-2147483648)),
  TransferKFSR NUMBER(10) NOT NULL,/*  */
    CHECK((TransferKFSR<=2147483647)AND(TransferKFSR>-2147483648)),
  TransferKCSR NUMBER(10) NOT NULL,/*  */
    CHECK((TransferKCSR<=2147483647)AND(TransferKCSR>-2147483648)),
  TransferKVR NUMBER(10) NOT NULL,/*  */
    CHECK((TransferKVR<=2147483647)AND(TransferKVR>-2147483648)),
  KESR NUMBER(10) NOT NULL,/*  */
    CHECK((KESR<=2147483647)AND(KESR>-2147483648)),
  MEANSTYPE NUMBER(10) NOT NULL,/*   */
    CHECK((MEANSTYPE<=2147483647)AND(MEANSTYPE>-2147483648)),
  INVESTOBJECT NUMBER(10),/*  */
    CHECK((INVESTOBJECT<=2147483647)AND(INVESTOBJECT>-2147483648)),
  FACT NUMBER(10) NOT NULL,/*  */
    CHECK((FACT<=2147483647)AND(FACT>-2147483648)),
  OKTMO NUMBER(10),/*  */
    CHECK((OKTMO<=2147483647)AND(OKTMO>-2147483648)),
  SUBKESR NUMBER(10) NOT NULL,/* */
    CHECK((SUBKESR<=2147483647)AND(SUBKESR>-2147483648)),
  REGIONCLS NUMBER(10) NOT NULL,/*   */
    CHECK((REGIONCLS<=2147483647)AND(REGIONCLS>-2147483648)),
  FINTYPE NUMBER(10) NOT NULL,/*  .  */
    CHECK((FINTYPE<=2147483647)AND(FINTYPE>-2147483648)),
  DIRECTIONCLS NUMBER(10) NOT NULL,/*  */
    CHECK((DIRECTIONCLS<=2147483647)AND(DIRECTIONCLS>-2147483648)),
  SUBSIDYCLS NUMBER(10),/*   */
    CHECK((SUBSIDYCLS<=2147483647)AND(SUBSIDYCLS>-2147483648)),
  ASSIGNMENTKIND NUMBER(10) NOT NULL,/*   */
    CHECK((ASSIGNMENTKIND<=2147483647)AND(ASSIGNMENTKIND>-2147483648)),
  BUDALLOCATIONCLS NUMBER(10),/*   */
    CHECK((BUDALLOCATIONCLS<=2147483647)AND(BUDALLOCATIONCLS>-2147483648)),
  PAYPROMISECLS NUMBER(10),/*   */
    CHECK((PAYPROMISECLS<=2147483647)AND(PAYPROMISECLS>-2147483648)),
  CONTRACTCOSTSCLS NUMBER(10),/*  */
    CHECK((CONTRACTCOSTSCLS<=2147483647)AND(CONTRACTCOSTSCLS>-2147483648)),
  FundsSource NUMBER(10) NOT NULL,/*   */
    CHECK((FundsSource<=2147483647)AND(FundsSource>-2147483648)),
  LowerBudgetKD VARCHAR2(20),/*     */
  CREATERUSER VARCHAR2(30) NOT NULL,
  CREATEDATE DATE NOT NULL,
  UPDATEDATE DATE NOT NULL,
  UPDATERUSER VARCHAR2(30) NOT NULL,
  DeleteDate DATE,/*  */
  StartDate DATE,/*     */
  ExtID VARCHAR2(50),/* UID     ,  GUID */
  ExtOwner VARCHAR2(50),/*    */
  ExtSyncDate DATE,/* ,  ,   */
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion NUMBER(10),/*     */
    CHECK((ExtVersion<=2147483647)AND(ExtVersion>-2147483648)),
  ExtVersionDate DATE,/*     */
  CONSTRAINT PK_TargetClsDetail PRIMARY KEY (ID),
  CONSTRAINT FK_TargetClsDet_TargetCls FOREIGN KEY (TargetCls) REFERENCES TargetCls (ID),
  CONSTRAINT FK_TargetClsDet_TransKVSR FOREIGN KEY (TransferKVSR) REFERENCES KVSR (ID),
  CONSTRAINT FK_TargetClsDet_TransKFSR FOREIGN KEY (TransferKFSR) REFERENCES KFSR (ID),
  CONSTRAINT FK_TargetClsDet_TransKCSR FOREIGN KEY (TransferKCSR) REFERENCES KCSR (ID),
  CONSTRAINT FK_TargetClsDet_TransKVR FOREIGN KEY (TransferKVR) REFERENCES KVR (ID),
  CONSTRAINT FK_TargetClsDet_TransKESR FOREIGN KEY (KESR) REFERENCES KESR (ID),
  CONSTRAINT FK_TargetClsDet_MEANSTYPE FOREIGN KEY (MEANSTYPE) REFERENCES MEANSTYPE (ID),
  CONSTRAINT FK_TargetClsDet_IO FOREIGN KEY (INVESTOBJECT) REFERENCES INVESTOBJECT (ID),
  CONSTRAINT FK_TargetClsDet_FACT FOREIGN KEY (FACT) REFERENCES FACT (ID),
  CONSTRAINT FK_TargetClsDet_OKTMO FOREIGN KEY (OKTMO) REFERENCES OKTMO (ID),
  CONSTRAINT FK_TargetClsDet_SUBKESR FOREIGN KEY (SUBKESR) REFERENCES KESRSUBCODE (ID),
  CONSTRAINT FK_TargetClsDet_REGIONCLS FOREIGN KEY (REGIONCLS) REFERENCES REGIONCLS (ID),
  CONSTRAINT FK_TargetClsDet_FINTYPE FOREIGN KEY (FINTYPE) REFERENCES FINTYPE (ID),
  CONSTRAINT FK_TargetClsDet_DIRECTIONCLS FOREIGN KEY (DIRECTIONCLS) REFERENCES DIRECTIONCLS (ID),
  CONSTRAINT FK_TargetClsDet_SUBSIDYCLS FOREIGN KEY (SUBSIDYCLS) REFERENCES SUBSIDYCLS (ID),
  CONSTRAINT FK_TargetClsDet_ASSIGNKIND FOREIGN KEY (ASSIGNMENTKIND) REFERENCES ASSIGNMENTKIND (ID),
  CONSTRAINT FK_TargetClsDet_BUDALLOCCLS FOREIGN KEY (BUDALLOCATIONCLS) REFERENCES BUDALLOCATIONCLS (ID),
  CONSTRAINT FK_TargetClsDet_PAYPROMISECLS FOREIGN KEY (PAYPROMISECLS) REFERENCES PAYPROMISECLS (ID),
  CONSTRAINT FK_TargetClsDet_CCS FOREIGN KEY (CONTRACTCOSTSCLS) REFERENCES CONTRACTCOSTSCLS (ID),
  CONSTRAINT FK_TargetClsDet_FUNDSSOURCE FOREIGN KEY (FUNDSSOURCE) REFERENCES FUNDSSOURCE (ID)
)
/
CREATE INDEX FK_TargetClsDet_TargetCls ON TargetClsDetail(TargetCls)
/
CREATE INDEX FK_TargetClsDet_TransKVSR ON TargetClsDetail(TransferKVSR)
/
CREATE INDEX FK_TargetClsDet_TransKFSR ON TargetClsDetail(TransferKFSR)
/
CREATE INDEX FK_TargetClsDet_TransKCSR ON TargetClsDetail(TransferKCSR)
/
CREATE INDEX FK_TargetClsDet_TransKVR ON TargetClsDetail(TransferKVR)
/
CREATE INDEX FK_TargetClsDet_TransKESR ON TargetClsDetail(KESR)
/
CREATE INDEX FK_TargetClsDet_MEANSTYPE ON TargetClsDetail(MEANSTYPE)
/
CREATE INDEX FK_TargetClsDet_IO ON TargetClsDetail(INVESTOBJECT)
/
CREATE INDEX FK_TargetClsDet_FACT ON TargetClsDetail(FACT)
/
CREATE INDEX FK_TargetClsDet_OKTMO ON TargetClsDetail(OKTMO)
/
CREATE INDEX FK_TargetClsDet_SUBKESR ON TargetClsDetail(SUBKESR)
/
CREATE INDEX FK_TargetClsDet_REGIONCLS ON TargetClsDetail(REGIONCLS)
/
CREATE INDEX FK_TargetClsDet_FINTYPE ON TargetClsDetail(FINTYPE)
/
CREATE INDEX FK_TargetClsDet_DIRECTIONCLS ON TargetClsDetail(DIRECTIONCLS)
/
CREATE INDEX FK_TargetClsDet_SUBSIDYCLS ON TargetClsDetail(SUBSIDYCLS)
/
CREATE INDEX FK_TargetClsDet_ASSIGNKIND ON TargetClsDetail(ASSIGNMENTKIND)
/
CREATE INDEX FK_TargetClsDet_BUDALLOCCLS ON TargetClsDetail(BUDALLOCATIONCLS)
/
CREATE INDEX FK_TargetClsDet_PAYPROMISECLS ON TargetClsDetail(PAYPROMISECLS)
/
CREATE INDEX FK_TargetClsDet_CCS ON TargetClsDetail(CONTRACTCOSTSCLS)
/
CREATE INDEX FK_TargetClsDet_FUNDSSOURCE ON TargetClsDetail(FUNDSSOURCE)
/
create index idx_TargetClsDet_ExtID on TargetClsDetail(ExtID)
/
create index idx_TargetClsDet_ExtRootID on TargetClsDetail(ExtRootID)
/
grant SELECT, INSERT, UPDATE, DELETE on TargetClsDetail to BUDGET_USERS
/
INSERT INTO SqlExceptions(Name, Code, Text) VALUES ('EX_TARGETCLSDETAIL_ROWEMPTY', -20369, '     .     .')
/
-- CREATE TRIGGER TR_TargetClsDetail_BI
CREATE OR REPLACE TRIGGER TR_TargetClsDetail_BI
  BEFORE INSERT
  ON TargetClsDetail
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_TargetClsDetail_BI)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.Transferkvsr is null) then 
    :new.Transferkvsr := 0;
  END IF;
  if (:new.Transferkfsr is null) then 
    :new.Transferkfsr := 0;  
  END IF;
  if (:new.Transferkcsr is null) then 
    :new.Transferkcsr := 0;  
  END IF;
  if (:new.kesr is null) then 
    :new.kesr := 0;  
  END IF;
  if (:new.Transferkvr is null) then 
    :new.Transferkvr := 0;
  END IF;
  if (:new.MeansType is null) then 
    :new.MeansType := 0;
  END IF;
  if (:new.Fact is null) then 
    :new.Fact := 0;  
  END IF;
  if (:new.LowerBudgetKD is null) then 
    BEGIN
      select KDValue into :new.LowerBudgetKD from KD where id = 0 ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (:new.SubKESR is null) then 
    :new.SubKESR := 0;
  END IF;
  if (:new.RegionCLS is null) then 
    :new.RegionCLS := 0;
  END IF;
  if (:new.FinType is null) then 
    :new.FinType := 0;
  END IF;
  if (:new.DirectionCls is null) then 
    :new.DirectionCls := 0;
  END IF;
  if (:new.AssignmentKind is null) then 
    :new.AssignmentKind := 0;
  END IF;
  if (:new.FundsSource is null) then 
    :new.FundsSource := 0;
  END IF;
  if ((:new.Transferkvsr = 0) and (:new.Transferkfsr = 0) and (:new.Transferkcsr = 0) and (:new.kesr = 0) and (:new.Transferkvr = 0) and
  (:new.MeansType = 0) and (:new.Fact = 0) and (:new.SubKESR = 0) and (:new.RegionCLS = 0) and (:new.FinType = 0) and (:new.DirectionCls = 0) and
  (:new.AssignmentKind = 0) and (:new.FundsSource = 0) and (:new.OKTMO is null) and (:new.SUBSIDYCLS is null) and (:new.BUDALLOCATIONCLS is null) and 
  (:new.PAYPROMISECLS is null) and (:new.CONTRACTCOSTSCLS is null) and (:new.INVESTOBJECT is null)) then
    RaiseException('Ex_TargetClsDetail_RowEmpty');
  END IF;

END;
/
-- CREATE TRIGGER TR_TargetClsDetail_BU
CREATE OR REPLACE TRIGGER TR_TargetClsDetail_BU
  BEFORE UPDATE
  ON TargetClsDetail
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TargetClsDetail_BU)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  if (:new.Transferkvsr is null) then 
    :new.Transferkvsr := 0;
  END IF;
  if (:new.Transferkfsr is null) then 
    :new.Transferkfsr := 0;  
  END IF;
  if (:new.Transferkcsr is null) then 
    :new.Transferkcsr := 0;  
  END IF;
  if (:new.kesr is null) then 
    :new.kesr := 0;  
  END IF;
  if (:new.Transferkvr is null) then 
    :new.Transferkvr := 0;
  END IF;
  if (:new.MeansType is null) then 
    :new.MeansType := 0;
  END IF;
  if (:new.Fact is null) then 
    :new.Fact := 0; 
  END IF;
  if (:new.LowerBudgetKD is null) then 
    BEGIN
      select KDValue into :new.LowerBudgetKD from KD where id = 0 ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (:new.SubKESR is null) then  
    :new.SubKESR := 0;
  END IF;
  if (:new.RegionCLS is null) then  
    :new.RegionCLS := 0;
  END IF;
  if (:new.FinType is null) then  
    :new.FinType := 0;
  END IF;
  if (:new.DirectionCls is null) then 
    :new.DirectionCls := 0;
  END IF;
  if (:new.AssignmentKind is null) then 
    :new.AssignmentKind := 0;
  END IF;
  if (:new.FundsSource is null) then 
    :new.FundsSource := 0;
  END IF;
  if ((:new.Transferkvsr = 0) and (:new.Transferkfsr = 0) and (:new.Transferkcsr = 0) and (:new.kesr = 0) and (:new.Transferkvr = 0) and
  (:new.MeansType = 0) and (:new.Fact = 0) and (:new.SubKESR = 0) and (:new.RegionCLS = 0) and (:new.FinType = 0) and (:new.DirectionCls = 0) and
  (:new.AssignmentKind = 0) and (:new.FundsSource = 0) and (:new.OKTMO is null) and (:new.SUBSIDYCLS is null) and (:new.BUDALLOCATIONCLS is null) and 
  (:new.PAYPROMISECLS is null) and (:new.CONTRACTCOSTSCLS is null) and (:new.INVESTOBJECT is null)) then
    RaiseException('Ex_TargetClsDetail_RowEmpty');
  END IF;

END;
/
-- CREATE TRIGGER TR_TargetClsDetail_BI_500
CREATE OR REPLACE TRIGGER TR_TargetClsDetail_BI
  BEFORE INSERT
  ON TargetClsDetail
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_TargetClsDetail_BI)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.Transferkvsr is null) then 
    :new.Transferkvsr := 0;
  END IF;
  if (:new.Transferkfsr is null) then 
    :new.Transferkfsr := 0;  
  END IF;
  if (:new.Transferkcsr is null) then 
    :new.Transferkcsr := 0;  
  END IF;
  if (:new.kesr is null) then 
    :new.kesr := 0;  
  END IF;
  if (:new.Transferkvr is null) then 
    :new.Transferkvr := 0;
  END IF;
  if (:new.MeansType is null) then 
    :new.MeansType := 0;
  END IF;
  if (:new.Fact is null) then 
    :new.Fact := 0;  
  END IF;
  if (:new.LowerBudgetKD is null) then 
    BEGIN
      select KDValue into :new.LowerBudgetKD from KD where id = 0 ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (:new.SubKESR is null) then 
    :new.SubKESR := 0;
  END IF;
  if (:new.RegionCLS is null) then 
    :new.RegionCLS := 0;
  END IF;
  if (:new.FinType is null) then 
    :new.FinType := 0;
  END IF;
  if (:new.DirectionCls is null) then 
    :new.DirectionCls := 0;
  END IF;
  if (:new.AssignmentKind is null) then 
    :new.AssignmentKind := 0;
  END IF;
  if (:new.FundsSource is null) then 
    :new.FundsSource := 0;
  END IF;
  if ((:new.Transferkvsr = 0) and (:new.Transferkfsr = 0) and (:new.Transferkcsr = 0) and (:new.kesr = 0) and (:new.Transferkvr = 0) and
  (:new.MeansType = 0) and (:new.Fact = 0) and (:new.SubKESR = 0) and (:new.RegionCLS = 0) and (:new.FinType = 0) and (:new.DirectionCls = 0) and
  (:new.AssignmentKind = 0) and (:new.FundsSource = 0) and (:new.OKTMO is null) and (:new.SUBSIDYCLS is null) and (:new.BUDALLOCATIONCLS is null) and 
  (:new.PAYPROMISECLS is null) and (:new.CONTRACTCOSTSCLS is null) and (:new.INVESTOBJECT is null)) then
    RaiseException('Ex_TargetClsDetail_RowEmpty');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_TargetClsDetail_BI_500)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- CREATE TRIGGER TR_TargetClsDetail_BU_500
CREATE OR REPLACE TRIGGER TR_TargetClsDetail_BU_500
  BEFORE UPDATE
  ON TARGETCLSDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_TargetClsDetail_BU_500)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  :new.Updatedate := SYSDATE;
  :new.UpdaterUser := user;

END;
/
-- CREATE TRIGGER tr_TargetClsDetail_ad_500
CREATE OR REPLACE TRIGGER TR_TargetClsDetail_AD
  AFTER DELETE
  ON TargetClsDetail
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AD_500 (tr_TargetClsDetail_ad_500)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (33, :old.Id, SYSDATE);

END;
/
-- CREATE TRIGGER tr_TargetClsDetail_ai_500
CREATE OR REPLACE TRIGGER TR_TargetClsDetail_AI
  AFTER INSERT
  ON TargetClsDetail
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AI_500 (tr_TargetClsDetail_ai_500)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 33) and (RecordId = :new.ID);

END;
/
-- CREATE TRIGGER tr_TargetClsDetail_au_500
CREATE OR REPLACE TRIGGER TR_TargetClsDetail_AU
  AFTER UPDATE
  ON TargetClsDetail
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AU_500 (tr_TargetClsDetail_au_500)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  if (:new.Id <> :old.Id) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (33, :old.Id, SYSDATE);
    delete from DelRecIndexes where (TableID = 33) and (RecordId = :new.ID);
      
  END IF;

END;
/
-- drop trigger tr_targetcls_bi
CREATE OR REPLACE TRIGGER TR_TARGETCLS_BI
  BEFORE INSERT
  ON TARGETCLS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_500 (TR_TARGETCLS_BI_500)
-- Version 12.20.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- drop trigger tr_targetcls_bu
DROP TRIGGER TR_TARGETCLS_BU
/
ALTER TRIGGER TR_TARGETCLS_BU_500 DISABLE
/
ALTER TABLE TargetCls ADD (
  LowerBudgetKD VARCHAR2(20),
  ParentTargetCls NUMBER(10),
    CHECK((ParentTargetCls<=2147483647)AND(ParentTargetCls>-2147483648)),
  ExportInFK NUMBER(10),
    CHECK((ExportInFK<=2147483647)AND(ExportInFK>-2147483648)),
  OverCofinancing NUMBER(10),
    CHECK((OverCofinancing<=2147483647)AND(OverCofinancing>-2147483648)),
  BudgetLevel NUMBER(10),
    CHECK((BudgetLevel<=2147483647)AND(BudgetLevel>-2147483648)),
  IsTransfert NUMBER(10),
    CHECK((IsTransfert<=2147483647)AND(IsTransfert>-2147483648)),
  IsCofinancing NUMBER(10),
    CHECK((IsCofinancing<=2147483647)AND(IsCofinancing>-2147483648)),
  TempTRANSFERKVSR VARCHAR2(20),
  TempTRANSFERKFSR VARCHAR2(20),
  constraint FK_TargetCls_OverCofinancing foreign key (OverCofinancing) references TARGETCLS(ID),
  constraint FK_TargetCls_ParentTargetCls foreign key (ParentTargetCls) references TARGETCLS(ID)
)
/
CREATE INDEX FK_TargetCls_OverCofinancing ON TargetCls(OverCofinancing)
/
CREATE INDEX FK_TargetCls_ParentTargetCls ON TargetCls(ParentTargetCls)
/
commit work
/
update TARGETCLS set
  LowerBudgetKD = '00000000000000000000',
  BudgetLevel = 0,
  IsTransfert = 1,
  IsCofinancing = 0,
  ExportInFK = 0,
  TempTRANSFERKVSR = TRANSFERKVSR,
  TempTRANSFERKFSR = TRANSFERKFSR
/
commit work
/
ALTER TABLE TARGETCLS DROP (TRANSFERKVSR)
/
ALTER TABLE TARGETCLS DROP (TRANSFERKFSR)
/
commit work
/
ALTER TABLE TARGETCLS ADD (
  TRANSFERKVSR VARCHAR2(20),
  TRANSFERKFSR VARCHAR2(20)
)
/
-- CREATE TRIGGER tr_targetcls_bi
CREATE OR REPLACE TRIGGER TR_TARGETCLS_BI
  BEFORE INSERT
  ON TARGETCLS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (tr_targetcls_bi)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.TransferKVSR is null) then 
    :new.TransferKVSR := '000';
  END IF;
  if (:new.TransferKFSR is null) then 
    :new.TransferKFSR := '0000';
  END IF;
  if (:new.TransferKCSR is null) then 
    BEGIN
      select CODE into :new.TransferKCSR from KCSR where id = 0 ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (:new.TransferKVR is null) then 
    BEGIN
      select CODE into :new.TransferKVR from KVR where id = 0 ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (:new.ReceiveKDValue is null) then 
    BEGIN
      select KDValue into :new.ReceiveKDValue from KD where id = 0 ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (:new.TransfertKind is null) then 
    :new.TransfertKind := 0;
  END IF;
  if (:new.TransferBudgetRef is null) then 
    :new.TransferBudgetRef := 0;
  END IF;
  if (:new.ControlFK is null) then 
    :new.ControlFK := 1; 
  END IF;
  if (:new.LowerBudgetKD is null) then 
    BEGIN
      select KDValue into :new.LowerBudgetKD from KD where id = 0 ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (:new.BudgetLevel is null) then 
    :new.BudgetLevel := 0;
  END IF;
  if (:new.IsTransfert is null) then 
    :new.IsTransfert := 1;
  END IF;
  if (:new.IsCofinancing is null) then 
    :new.IsCofinancing := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_TARGETCLS_BI_500)
-- Version 12.20.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- CREATE TRIGGER tr_targetcls_bu
CREATE OR REPLACE TRIGGER TR_targetcls_BU
  BEFORE UPDATE
  ON targetcls
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (tr_targetcls_bu)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.TransferKVSR is null) then 
    :new.TransferKVSR := '000';
  END IF;
  if (:new.TransferKFSR is null) then 
    :new.TransferKFSR := '0000';
  END IF;
  if (:new.TransferKCSR is null) then 
    BEGIN
      select CODE into :new.TransferKCSR from KCSR where id = 0 ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (:new.TransferKVR is null) then 
    BEGIN
      select CODE into :new.TransferKVR from KVR where id = 0 ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (:new.ReceiveKDValue is null) then 
    BEGIN
      select KDValue into :new.ReceiveKDValue from KD where id = 0 ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (:new.TransfertKind is null) then 
    :new.TransfertKind := 0;
  END IF;
  if (:new.TransferBudgetRef is null) then 
    :new.TransferBudgetRef := 0;
  END IF;
  if (:new.ControlFK is null) then 
    :new.ControlFK := 1;
  END IF;
  if (:new.LowerBudgetKD is null) then 
    BEGIN
      select KDValue into :new.LowerBudgetKD from KD where id = 0 ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (:new.BudgetLevel is null) then 
    :new.BudgetLevel := 0;
  END IF;
  if (:new.IsTransfert is null) then 
    :new.IsTransfert := 1;
  END IF;
  if (:new.IsCofinancing is null) then 
    :new.IsCofinancing := 0;
  END IF;

END;
/
-- CREATE TRIGGER tr_targetcls_bd
CREATE OR REPLACE TRIGGER TR_targetcls_BD
  BEFORE DELETE
  ON targetcls
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (tr_targetcls_bd)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*      */
  delete
  from TargetClsDetail
  where
  (TargetCls = :old.id);

END;
/
commit work
/
update TARGETCLS set
  TRANSFERKVSR = TempTRANSFERKVSR,
  TRANSFERKFSR = TempTRANSFERKFSR
/
ALTER TABLE TARGETCLS DROP (TempTRANSFERKVSR)
/
ALTER TABLE TARGETCLS DROP (TempTRANSFERKFSR)
/
update TARGETCLS set
  TRANSFERKVSR='00' || TRANSFERKVSR
where
  TRANSFERKVSR like '_'
/
update TARGETCLS set
  TRANSFERKVSR='0' || TRANSFERKVSR
where
  TRANSFERKVSR like '__'
/
update TARGETCLS set
  TRANSFERKFSR='000' || TRANSFERKFSR
where
  TRANSFERKFSR like '_'
/
update TARGETCLS set
  TRANSFERKFSR='00' || TRANSFERKFSR
where
  TRANSFERKFSR like '__'
/
update TARGETCLS set
  TRANSFERKFSR='0' || TRANSFERKFSR
where
  TRANSFERKFSR like '___'
/
update TARGETCLS set
  TRANSFERKCSR='000000000' || TRANSFERKCSR
where
  TRANSFERKCSR like '_'
/
update TARGETCLS set
  TRANSFERKCSR='00000000' || TRANSFERKCSR
where
  TRANSFERKCSR like '__'
/
update TARGETCLS set
  TRANSFERKCSR='0000000' || TRANSFERKCSR
where
  TRANSFERKCSR like '___'
/
update TARGETCLS set
  TRANSFERKCSR='000000' || TRANSFERKCSR
where
  TRANSFERKCSR like '____'
/
update TARGETCLS set
  TRANSFERKCSR='00000' || TRANSFERKCSR
where
  TRANSFERKCSR like '_____'
/
update TARGETCLS set
  TRANSFERKCSR='0000' || TRANSFERKCSR
where
  TRANSFERKCSR like '______'
/
update TARGETCLS set
  TRANSFERKCSR='000' || TRANSFERKCSR
where
  TRANSFERKCSR like '_______'
/
update TARGETCLS set
  TRANSFERKCSR='00' || TRANSFERKCSR
where
  TRANSFERKCSR like '________'
/
update TARGETCLS set
  TRANSFERKCSR='0' || TRANSFERKCSR
where
  TRANSFERKCSR like '_________'
/
update TARGETCLS set
  TRANSFERKVR='00' || TRANSFERKVR
where
  TRANSFERKVR like '_'
/
update TARGETCLS set
  TRANSFERKVR='0' || TRANSFERKVR
where
  TRANSFERKVR like '__'
/
ALTER TRIGGER TR_TARGETCLS_BU_500 ENABLE
/
commit work 
/
ALTER TABLE TargetCls MODIFY(BudgetLevel NOT NULL)
/
ALTER TABLE TargetCls MODIFY(IsTransfert NOT NULL)
/
ALTER TABLE TargetCls MODIFY(IsCofinancing NOT NULL)
/
ALTER TABLE TARGETCLS MODIFY(TRANSFERKVSR NOT NULL)
/
ALTER TABLE TARGETCLS MODIFY(TRANSFERKFSR NOT NULL)
/

-- #########################################################
-- #########################################################
-- UpdateOrg_TypeName11100.sql
-- #########################################################
-- #########################################################

update org_type set
name = '   ,   '
where id=11100
/
commit work 
/

-- #########################################################
-- #########################################################
-- Add_TOFK_to_EDCorCap.sql
-- #########################################################
-- #########################################################

/*    KodTOFK  NameTOFK ( )   ed_correctioncaption*/
ALTER TABLE ed_correctioncaption ADD (
  KodTOFK VARCHAR2(50),
  NameTOFK VARCHAR2(2000)
)
/
commit work 
/


-- #########################################################
-- #########################################################
-- Add_MessageId_to_PayDocExchange.sql
-- #########################################################
-- #########################################################

/*    MessageId (   ,  )   PayDocExchange*/
ALTER TABLE PayDocExchange ADD (
  MessageId VARCHAR2(36)
)
/
commit work 
/


-- #########################################################
-- #########################################################
-- Alter_MeansType_add_MeansSource.sql
-- #########################################################
-- #########################################################

ALTER TABLE MEANSTYPE ADD (
  MEANSSOURCE NUMBER(10),
    CHECK((MEANSSOURCE<=2147483647)AND(MEANSSOURCE>-2147483648))
)
/
COMMIT WORK
/

-- #########################################################
-- #########################################################
-- Alter_PayShAdjustmentRefCheck.sql
-- #########################################################
-- #########################################################

/*  / AdjustmentRef,   ,  AdjustmentRef,      */
-- CREATE TRIGGER TR_AGREEMENTS_BI_10
CREATE OR REPLACE TRIGGER TR_AGREEMENTS_II
  INSTEAD OF INSERT
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
  new$EXECUTERSTOREDPROPS AGREEMENTS.EXECUTERSTOREDPROPS%TYPE := :NEW.EXECUTERSTOREDPROPS;
  new$AUTOSANCTION AGREEMENTS.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$PURCHASECODE AGREEMENTS.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$DOCUMENTNUMBER AGREEMENTS.DOCUMENTNUMBER%TYPE := :NEW.DOCUMENTNUMBER;
  new$REJECTCAUSE AGREEMENTS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$TENDERREF AGREEMENTS.TENDERREF%TYPE := :NEW.TENDERREF;
  new$TENDERINNERNUMBER AGREEMENTS.TENDERINNERNUMBER%TYPE := :NEW.TENDERINNERNUMBER;
  new$STOREDCONTENT AGREEMENTS.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
--
  CountAcc$ NUMBER(10);
  rnClientID1$ VARCHAR2(15);
  rnYear1$ VARCHAR2(15);
  rnNumber1$ VARCHAR2(15);
  ReestrVersion1$ VARCHAR2(15);
  PreviousInner$ NUMBER(10);
  Tmp$ NUMBER(10);
  AdjDocNum$ VARCHAR2(150);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_AGREEMENTS_BI)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*   13.0*/
  /*    -*/
  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$CardAdvancePercent is null) then
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then
    new$FinCardAdvance := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  if (new$client_ref is null) then
    new$client_ref := 0;
  END IF;

  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    BEGIN
      select fa.BudgetRef     into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;

  /*    ,     ,      */
  if (new$AdjustmentRef is null) then
    new$InnerNumber := GEN_ID('G_AgreementNumber',1);

  else
    BEGIN
      /*          */
      select
      InnerNumber
      into PreviousInner$     from Agreements
      where ID = new$AdjustmentRef and LastAccepted = 1 and LastAdjustment = 1
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (PreviousInner$ is null) then
      RaiseException('EX_NotFindInnerNumber');
    END IF;
    new$InnerNumber := PreviousInner$;

  END IF;
  /*   */
  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  /*    .  */

  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*     30.  id */

  new$TenderInnerNumber := null;
  if (new$TenderRef is not null) then
    BEGIN
      select InnerNumber
      into new$TenderInnerNumber     from TenderCaption
      where id = new$TenderRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_AGREEMENTS_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_AGREEMENTS_BI_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  /*    .*/
  if (new$InnerNumber is null) then
    RaiseException('EX_AGR_InnerNumsIsNull');
  END IF;

  /*    */
  select max(AdjustmentNumber)
  into Tmp$         from Agreements
  where (InnerNumber = new$InnerNumber)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;
        
  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;
  /*        */
  if (((new$AgreementType = 0) and (new$AdjustmentNumber > 0)) or
  ((new$AgreementType = 1) and (new$AdjustmentNumber = 0))) then
    RaiseException('EX_AGR_AgrTypeViolation');
  END IF;
  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;
        
  else
    new$LastAdjustment := 1;
  END IF;
  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then
    new$LastAccepted := 1;
        
  else
    new$LastAccepted := 0;
  END IF;
  /*     */
  if (new$AdjustmentRef is null) then
    new$AdjustmentDocNumber := null;
        
  else
    /*    */
    /*       */
    select count(ID), max(DocNumber)
    into Tmp$, AdjDocNum$             from Agreements
    where (InnerNumber = new$InnerNumber) and (AcceptDate is not null)
    ;
    /*     ,  */    
    if (Tmp$ = 0) then
      RaiseException('EX_AGR_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID)
    into Tmp$             from Agreements
    where (InnerNumber = new$InnerNumber) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then
      RaiseException('EX_AGR_AdjustDuplicate');
    END IF;
    new$AdjustmentDocNumber := AdjDocNum$;
        
  END IF;

-- - - - - - - - - - - - -
-- BI_20 (TR_AGREEMENTS_BI_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,     */
  if ((new$Client_INN   is null) and
      (new$Client_INN20 is null) and
      (new$Client_Name  is null))then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;

  /*    -,     */
  if ((new$Executer_INN     is null) and
      (new$Executer_INN20   is null) and
      (new$Executer_Name    is null) and
      (new$Executer_Status  is null) and
      (new$Executer_Country is null) and
      (new$Executer_Address is null) and
      (new$Executer_Phone   is null))then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_40 (TR_AGREEMENTS_BI_40)
-- Create 06.08.2010
-- - - - - - - - - - - - -

  /*       */
  if (new$senderId is null) then
    new$senderIdKey := -1;
  else
    new$senderIdKey := new$senderId;
  end if;

  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  end if;

-- - - - - - - - - - - - -
-- BI_300 (tr_agreements_bi_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$ExecuterAccRef is not null) then
    select count(ID)
    into CountAcc$     from org_accounts oa
    where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
    ;
    if (CountAcc$ = 0) then
      RaiseException('EX_AGR_ACCORGCHECK');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_400 (TR_AGREEMENTS_BI_400)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if ((new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID1$ := new$rnClientID;
    rnYear1$ := new$rnYear;
    rnNumber1$ := new$rnNumber;
    ReestrVersion1$ := new$ReestrVersion;
    while (LENGTH(rnClientID1$) < 11) LOOP
      rnClientID1$ := '0' || rnClientID1$;
    END LOOP;
    while (LENGTH(rnNumber1$) < 6) LOOP
      rnNumber1$ := '0' || rnNumber1$;
    END LOOP;
    if (LENGTH(ReestrVersion1$) < 2) then
      ReestrVersion1$ := '0' || ReestrVersion1$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$;

    else
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$ || ReestrVersion1$;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_AGREEMENTS_BI_500)
-- Last update 19.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- BI_600 (agreements_realid_bi_600)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_AGREEMENTS (
    ID,
    SUMMA,
    AGREEMENTDATE,
    AGREEMENTENDDATE,
    EXECUTER_REF,
    CLIENT_REF,
    FACIALACC_CLS,
    AGREEMENTTYPE,
    ACCEPTED,
    ACCEPTDATE,
    CARDADVANCEPERCENT,
    CARDADVANCE,
    CLOSEDOC,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    LASTADJUSTMENT,
    LASTACCEPTED,
    FACT,
    REGION,
    CLOSEDATE,
    DELIVERYRULES,
    AGREEMENTSUMMA,
    AGREEMENTFINSUMMA,
    ADJUSTMENTREF,
    REESTRNUMBER,
    PAYMENTDATE,
    AGREEMENTCARDADVANCE,
    FINCARDADVANCE,
    STATEORDERREF,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    AGREEMENTBEGINDATE,
    PROTOCOLNUMBER,
    PROTOCOLDATE,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXPORTDATE,
    FSORGAN,
    FSBUDGETNAME,
    FSOFFBUDGET,
    RNYEAR,
    RNNUMBER,
    RNDATE,
    PROTOCOLNOTICE,
    PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE,
    NOTIFYDATE,
    EXECUTERACCREF,
    DOCBASEDATE,
    DOCBASENOTIFYDATE,
    DOCBASETEXT,
    DOCBASETYPE,
    DOCBASESUMMA,
    UNKNOWNAMOUNT,
    PROTOCOLREASON,
    DOCNUMBER,
    ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER,
    LOTMAXSUM,
    CLIENT_INN,
    CLIENT_INN20,
    CLIENT_NAME,
    EXECUTER_INN,
    EXECUTER_INN20,
    EXECUTER_NAME,
    EXECUTER_STATUS,
    EXECUTER_COUNTRY,
    EXECUTER_ADDRESS,
    EXECUTER_PHONE,
    REALID,
    ADJUSTMENTNUMBER,
    INNERNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REESTRVERSION,
    DOCTYPE,
    RNCLIENTID,
    INFONUMBER,
    STATEORDERINNERNUMBER,
    PROGINDEX,
    NOTE,
    PURPORTDOC,
    REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS,
    AUTOSANCTION,
    PURCHASECODE,
    DOCUMENTNUMBER,
    REJECTCAUSE,
    TENDERREF,
    TENDERINNERNUMBER,
    STOREDCONTENT
  ) VALUES (
    new$ID,
    new$SUMMA,
    new$AGREEMENTDATE,
    new$AGREEMENTENDDATE,
    new$EXECUTER_REF,
    new$CLIENT_REF,
    new$FACIALACC_CLS,
    new$AGREEMENTTYPE,
    new$ACCEPTED,
    new$ACCEPTDATE,
    new$CARDADVANCEPERCENT,
    new$CARDADVANCE,
    new$CLOSEDOC,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$LASTADJUSTMENT,
    new$LASTACCEPTED,
    new$FACT,
    new$REGION,
    new$CLOSEDATE,
    new$DELIVERYRULES,
    new$AGREEMENTSUMMA,
    new$AGREEMENTFINSUMMA,
    new$ADJUSTMENTREF,
    new$REESTRNUMBER,
    new$PAYMENTDATE,
    new$AGREEMENTCARDADVANCE,
    new$FINCARDADVANCE,
    new$STATEORDERREF,
    new$REJECTCLS,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$AGREEMENTBEGINDATE,
    new$PROTOCOLNUMBER,
    new$PROTOCOLDATE,
    new$REVIEWNOTE,
    new$DOCSTATEREF,
    new$RVERSION,
    new$EXPORTDATE,
    new$FSORGAN,
    new$FSBUDGETNAME,
    new$FSOFFBUDGET,
    new$RNYEAR,
    new$RNNUMBER,
    new$RNDATE,
    new$PROTOCOLNOTICE,
    new$PROTOCOLRESULTDATE,
    new$PROTOCOLDOCTYPE,
    new$PROTOCOLSALETYPE,
    new$NOTIFYDATE,
    new$EXECUTERACCREF,
    new$DOCBASEDATE,
    new$DOCBASENOTIFYDATE,
    new$DOCBASETEXT,
    new$DOCBASETYPE,
    new$DOCBASESUMMA,
    new$UNKNOWNAMOUNT,
    new$PROTOCOLREASON,
    new$DOCNUMBER,
    new$ADJUSTMENTDOCNUMBER,
    new$OLDDOCNUMBER,
    new$LOTMAXSUM,
    new$CLIENT_INN,
    new$CLIENT_INN20,
    new$CLIENT_NAME,
    new$EXECUTER_INN,
    new$EXECUTER_INN20,
    new$EXECUTER_NAME,
    new$EXECUTER_STATUS,
    new$EXECUTER_COUNTRY,
    new$EXECUTER_ADDRESS,
    new$EXECUTER_PHONE,
    new$REALID,
    new$ADJUSTMENTNUMBER,
    new$INNERNUMBER,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$REESTRVERSION,
    new$DOCTYPE,
    new$RNCLIENTID,
    new$INFONUMBER,
    new$STATEORDERINNERNUMBER,
    new$PROGINDEX,
    new$NOTE,
    new$PURPORTDOC,
    new$REESTRRECORDNUMBER,
    new$EXECUTERSTOREDPROPS,
    new$AUTOSANCTION,
    new$PURCHASECODE,
    new$DOCUMENTNUMBER,
    new$REJECTCAUSE,
    new$TENDERREF,
    new$TENDERINNERNUMBER,
    new$STOREDCONTENT);

-- - - - - - - - - - - - -
-- AI_10 (TR_AGREEMENTS_AI_10)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*   13.0*/
  if ((new$AdjustmentRef is not null) and (new$LastAdjustment = 1)) then
    update Agreements set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);
    if (new$LastAccepted = 1) then
      update Agreements set
      LastAccepted = 0,
      RVersion = -1
      where (ID = new$AdjustmentRef);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_AGREEMENTS_AI_500)
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 110) AND (RecordID = new$ID);

END;
/
-- CREATE TRIGGER TR_AGREEMENTS_BU_10
CREATE OR REPLACE TRIGGER TR_AGREEMENTS_IU
  INSTEAD OF UPDATE
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
  new$EXECUTERSTOREDPROPS AGREEMENTS.EXECUTERSTOREDPROPS%TYPE := :NEW.EXECUTERSTOREDPROPS;
  new$AUTOSANCTION AGREEMENTS.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$PURCHASECODE AGREEMENTS.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$DOCUMENTNUMBER AGREEMENTS.DOCUMENTNUMBER%TYPE := :NEW.DOCUMENTNUMBER;
  new$REJECTCAUSE AGREEMENTS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$TENDERREF AGREEMENTS.TENDERREF%TYPE := :NEW.TENDERREF;
  new$TENDERINNERNUMBER AGREEMENTS.TENDERINNERNUMBER%TYPE := :NEW.TENDERINNERNUMBER;
  new$STOREDCONTENT AGREEMENTS.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
--
  CNT$1 NUMBER(10);
  CountAcc$ NUMBER(10);
  DetCount$ NUMBER(10);
  rnClientID11$ VARCHAR2(15);
  rnYear11$ VARCHAR2(15);
  rnNumber11$ VARCHAR2(15);
  ReestrVersion11$ VARCHAR2(15);
  previousAccept$ NUMBER(10);
  previousAcceptDate$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_AGREEMENTS_BU)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*   13.0*/
  /*    -*/
  if (new$CardAdvancePercent is null) then
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then
    new$FinCardAdvance := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$client_ref is null) then
    new$client_ref := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from AgreementSteps where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      select count(ID)       into DetCount$ from Estimate where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*     ,        */
  if (new$InnerNumber is null) then
    new$InnerNumber := :old.InnerNumber;
  END IF;
  /*   */
  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  /*    .  */

  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*     30.  id */

  new$TenderInnerNumber := null;
  if (new$TenderRef is not null) then
    BEGIN
      select InnerNumber
      into new$TenderInnerNumber     from TenderCaption
      where id = new$TenderRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_AGREEMENTS_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_AGREEMENTS_BU_10)
-- Version 13.10.00.2
-- - - - - - - - - - - - -

  /*   13.10*/
  /* ,      ,   */
  if ((new$InnerNumber <> :old.InnerNumber) or
  (new$AdjustmentRef <> :old.AdjustmentRef) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber) or
  (new$AgreementType <> :old.AgreementType)) then
    RaiseException('EX_AGR_ChangeInnerNums');
  END IF;
      
  /*   */
  if (:old.AcceptDate is not null and :old.Accepted = 0 and new$Accepted = 1) then
    BEGIN
      /*             */
      select Accepted, AcceptDate
      into previousAccept$, previousAcceptDate$       from Agreements
      where id=new$Adjustmentref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$Adjustmentref is not null and (previousAccept$ = 0 or previousAcceptDate$ is null)) then
      RaiseException('EX_RollbackCancel');
    END IF;
    new$LastAdjustment := 1;
      
  END IF;
  /*  ,     LastAccepted*/
  if ((:old.AcceptDate is null and new$AcceptDate is not null and new$Accepted = 1)) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;
          
    else
      RaiseException('EX_AGR_ChangeStateAdjust');
    END IF;
  END IF;
  /*   ,     LastAccepted*/
  if ((:old.AcceptDate is not null and :old.Accepted = 0 and new$AcceptDate is not null and new$Accepted = 1)) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;
          
    else
      RaiseException('EX_AGR_ChangeStateAdjust');
    END IF;
  END IF;
  /*   ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;
          
    else
      RaiseException('EX_AGR_ChangeStateAdjust');
    END IF;
  END IF;
  /*   ,     LastAdjustment  LastAccepted */
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment <> 1) then
      RaiseException('EX_AGR_ChangeStateAdjust');
    else
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
          
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_20 (TR_AGREEMENTS_BU_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,      */
  if ((new$Client_Ref <> :old.Client_Ref) and
      (((new$Client_INN is null) and
        (:old.Client_INN is null)) or
       (new$Client_INN = :old.Client_INN)) and
      (((new$Client_INN20 is null) and
        (:old.Client_INN20 is null)) or
       (new$Client_INN20 = :old.Client_INN20)) and
      (new$Client_Name = :old.Client_Name)) then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;

  /*    -,      */
  if ((new$Executer_Ref <> :old.Executer_Ref) and
      (((new$Executer_INN is null) and
        (:old.Executer_INN is null)) or
       (new$Executer_INN = :old.Executer_INN)) and
      (((new$Executer_INN20 is null) and
        (:old.Executer_INN20 is null)) or
       (new$Executer_INN20 = :old.Executer_INN20)) and
      (new$Executer_Name = :old.Executer_Name) and
      (((new$Executer_Status is null) and
        (:old.Executer_Status is null)) or
       (new$Executer_Status = :old.Executer_Status)) and
      (((new$Executer_Country is null) and
        (:old.Executer_Country is null)) or
       (new$Executer_Country = :old.Executer_Country)) and
      (((new$Executer_Address is null) and
        (:old.Executer_Address is null)) or
       (new$Executer_Address = :old.Executer_Address)) and
      (((new$Executer_Phone is null) and
        (:old.Executer_Phone is null)) or
       (new$Executer_Phone = :old.Executer_Phone))) then
     BEGIN
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_60 (tr_agreements_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*        ,     */
  if (:old.accepted = 1 and new$accepted = 0 and new$acceptdate is not null and new$adjustmentnumber = 0) then
    SELECT COUNT(*) INTO CNT$1
    from executiondocumentscaption
    where
    (            agreementinnernumber = new$innernumber
    and (accepted <> 0 or acceptdate is null)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_Agr_CannotReject');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_AGREEMENTS_BU_200)
-- Create 04.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$id, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (tr_agreements_bu_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$ExecuterAccRef is not null) then
    select count(ID)
    into CountAcc$     from org_accounts oa
    where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
    ;
    if (CountAcc$ = 0) then
      RaiseException('EX_AGR_ACCORGCHECK');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (TR_AGREEMENTS_BU_400)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  if (((new$rnClientID <> :old.rnClientID) or (new$rnYear <> :old.rnYear) or
  (new$rnNumber <> :old.rnNumber) or (new$ReestrVersion <> :old.ReestrVersion) or
  (:old.rnClientID is null) or (:old.rnYear is null) or (:old.ReestrVersion is null)
  ) and
  (new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID11$ := new$rnClientID;
    rnYear11$ := new$rnYear;
    rnNumber11$ := new$rnNumber;
    ReestrVersion11$ := new$ReestrVersion;
    while (LENGTH(rnClientID11$) < 11) LOOP
      rnClientID11$ := '0' || rnClientID11$;
    END LOOP;
    while (LENGTH(rnNumber11$) < 6) LOOP
      rnNumber11$ := '0' || rnNumber11$;
    END LOOP;
    if (LENGTH(ReestrVersion11$) < 2) then
      ReestrVersion11$ := '0' || ReestrVersion11$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID11$ || rnYear11$ || rnNumber11$;
          
    else
      new$ReestrRecordNumber := rnClientID11$ || rnYear11$ || rnNumber11$ || ReestrVersion11$;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_600 (agreements_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_AGREEMENTS_BU_700)
-- Create 14.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_AGREEMENTS SET
    ID = new$ID,
    SUMMA = new$SUMMA,
    AGREEMENTDATE = new$AGREEMENTDATE,
    AGREEMENTENDDATE = new$AGREEMENTENDDATE,
    EXECUTER_REF = new$EXECUTER_REF,
    CLIENT_REF = new$CLIENT_REF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    AGREEMENTTYPE = new$AGREEMENTTYPE,
    ACCEPTED = new$ACCEPTED,
    ACCEPTDATE = new$ACCEPTDATE,
    CARDADVANCEPERCENT = new$CARDADVANCEPERCENT,
    CARDADVANCE = new$CARDADVANCE,
    CLOSEDOC = new$CLOSEDOC,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    FACT = new$FACT,
    REGION = new$REGION,
    CLOSEDATE = new$CLOSEDATE,
    DELIVERYRULES = new$DELIVERYRULES,
    AGREEMENTSUMMA = new$AGREEMENTSUMMA,
    AGREEMENTFINSUMMA = new$AGREEMENTFINSUMMA,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    REESTRNUMBER = new$REESTRNUMBER,
    PAYMENTDATE = new$PAYMENTDATE,
    AGREEMENTCARDADVANCE = new$AGREEMENTCARDADVANCE,
    FINCARDADVANCE = new$FINCARDADVANCE,
    STATEORDERREF = new$STATEORDERREF,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    AGREEMENTBEGINDATE = new$AGREEMENTBEGINDATE,
    PROTOCOLNUMBER = new$PROTOCOLNUMBER,
    PROTOCOLDATE = new$PROTOCOLDATE,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXPORTDATE = new$EXPORTDATE,
    FSORGAN = new$FSORGAN,
    FSBUDGETNAME = new$FSBUDGETNAME,
    FSOFFBUDGET = new$FSOFFBUDGET,
    RNYEAR = new$RNYEAR,
    RNNUMBER = new$RNNUMBER,
    RNDATE = new$RNDATE,
    PROTOCOLNOTICE = new$PROTOCOLNOTICE,
    PROTOCOLRESULTDATE = new$PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE = new$PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE = new$PROTOCOLSALETYPE,
    NOTIFYDATE = new$NOTIFYDATE,
    EXECUTERACCREF = new$EXECUTERACCREF,
    DOCBASEDATE = new$DOCBASEDATE,
    DOCBASENOTIFYDATE = new$DOCBASENOTIFYDATE,
    DOCBASETEXT = new$DOCBASETEXT,
    DOCBASETYPE = new$DOCBASETYPE,
    DOCBASESUMMA = new$DOCBASESUMMA,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PROTOCOLREASON = new$PROTOCOLREASON,
    DOCNUMBER = new$DOCNUMBER,
    ADJUSTMENTDOCNUMBER = new$ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER = new$OLDDOCNUMBER,
    LOTMAXSUM = new$LOTMAXSUM,
    CLIENT_INN = new$CLIENT_INN,
    CLIENT_INN20 = new$CLIENT_INN20,
    CLIENT_NAME = new$CLIENT_NAME,
    EXECUTER_INN = new$EXECUTER_INN,
    EXECUTER_INN20 = new$EXECUTER_INN20,
    EXECUTER_NAME = new$EXECUTER_NAME,
    EXECUTER_STATUS = new$EXECUTER_STATUS,
    EXECUTER_COUNTRY = new$EXECUTER_COUNTRY,
    EXECUTER_ADDRESS = new$EXECUTER_ADDRESS,
    EXECUTER_PHONE = new$EXECUTER_PHONE,
    REALID = new$REALID,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    INNERNUMBER = new$INNERNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REESTRVERSION = new$REESTRVERSION,
    DOCTYPE = new$DOCTYPE,
    RNCLIENTID = new$RNCLIENTID,
    INFONUMBER = new$INFONUMBER,
    STATEORDERINNERNUMBER = new$STATEORDERINNERNUMBER,
    PROGINDEX = new$PROGINDEX,
    NOTE = new$NOTE,
    PURPORTDOC = new$PURPORTDOC,
    REESTRRECORDNUMBER = new$REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS = new$EXECUTERSTOREDPROPS,
    AUTOSANCTION = new$AUTOSANCTION,
    PURCHASECODE = new$PURCHASECODE,
    DOCUMENTNUMBER = new$DOCUMENTNUMBER,
    REJECTCAUSE = new$REJECTCAUSE,
    TENDERREF = new$TENDERREF,
    TENDERINNERNUMBER = new$TENDERINNERNUMBER,
    STOREDCONTENT = new$STOREDCONTENT
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_AGREEMENTS_AU_10)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*   13.0*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update Agreements set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update Agreements set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*          */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 304)or(new$ProgIndex = 314)))then
    update Estimate
    set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    (RecordIndex = new$Id);
  END IF;
  /*         */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 305) or (new$ProgIndex = 314))) then
    update paymentschedule set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    AgreementRef = new$ID and
    ProgIndex in (317, 318);
  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_AGREEMENTS_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*      */
  if ((new$ProgIndex = 305) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null
    where
    StateOrder = :old.ID;
  END IF;
  /*      */
  if ((new$ProgIndex = 314) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null,
    Agreement = null
    where
    StateOrder = :old.ID;
  END IF;
  /*     */
  if ((:old.ProgIndex = 304) and (new$AdjustmentNumber = 0) and (new$Accepted = 0) and
  (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    Agreement = null
    where
    Agreement = :old.ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_AGREEMENTS_AU_30)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$ProgIndex = 304) or (new$ProgIndex = 314)) and
  ((new$Accepted <> :old.Accepted) or
  (new$AcceptDate is not null and :old.AcceptDate is null) or
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where AgreementRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_AGREEMENTS_AU_500)
-- Create 28.04.2005
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes
                  (TableID, RecordId, DeleteDate
                  )
           VALUES (110, :OLD.ID, SYSDATE
                  );

      DELETE FROM DelRecIndexes
            WHERE (TableID = 110) AND (RecordId = new$ID);
   END IF;

END;
/
-- CREATE TRIGGER TR_AGREEMENTS_AU_10
CREATE OR REPLACE TRIGGER TR_AGREEMENTS_IU
  INSTEAD OF UPDATE
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
  new$EXECUTERSTOREDPROPS AGREEMENTS.EXECUTERSTOREDPROPS%TYPE := :NEW.EXECUTERSTOREDPROPS;
  new$AUTOSANCTION AGREEMENTS.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$PURCHASECODE AGREEMENTS.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$DOCUMENTNUMBER AGREEMENTS.DOCUMENTNUMBER%TYPE := :NEW.DOCUMENTNUMBER;
  new$REJECTCAUSE AGREEMENTS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$TENDERREF AGREEMENTS.TENDERREF%TYPE := :NEW.TENDERREF;
  new$TENDERINNERNUMBER AGREEMENTS.TENDERINNERNUMBER%TYPE := :NEW.TENDERINNERNUMBER;
  new$STOREDCONTENT AGREEMENTS.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
--
  CNT$1 NUMBER(10);
  CountAcc$ NUMBER(10);
  DetCount$ NUMBER(10);
  rnClientID11$ VARCHAR2(15);
  rnYear11$ VARCHAR2(15);
  rnNumber11$ VARCHAR2(15);
  ReestrVersion11$ VARCHAR2(15);
  previousAccept$ NUMBER(10);
  previousAcceptDate$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_AGREEMENTS_BU)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*   13.0*/
  /*    -*/
  if (new$CardAdvancePercent is null) then
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then
    new$FinCardAdvance := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$client_ref is null) then
    new$client_ref := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from AgreementSteps where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      select count(ID)       into DetCount$ from Estimate where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*     ,        */
  if (new$InnerNumber is null) then
    new$InnerNumber := :old.InnerNumber;
  END IF;
  /*   */
  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  /*    .  */

  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*     30.  id */

  new$TenderInnerNumber := null;
  if (new$TenderRef is not null) then
    BEGIN
      select InnerNumber
      into new$TenderInnerNumber     from TenderCaption
      where id = new$TenderRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_AGREEMENTS_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_AGREEMENTS_BU_10)
-- Version 13.10.00.2
-- - - - - - - - - - - - -

  /*   13.10*/
  /* ,      ,   */
  if ((new$InnerNumber <> :old.InnerNumber) or
  (new$AdjustmentRef <> :old.AdjustmentRef) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber) or
  (new$AgreementType <> :old.AgreementType)) then
    RaiseException('EX_AGR_ChangeInnerNums');
  END IF;
      
  /*   */
  if (:old.AcceptDate is not null and :old.Accepted = 0 and new$Accepted = 1) then
    BEGIN
      /*             */
      select Accepted, AcceptDate
      into previousAccept$, previousAcceptDate$       from Agreements
      where id=new$Adjustmentref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$Adjustmentref is not null and (previousAccept$ = 0 or previousAcceptDate$ is null)) then
      RaiseException('EX_RollbackCancel');
    END IF;
    new$LastAdjustment := 1;
      
  END IF;
  /*  ,     LastAccepted*/
  if ((:old.AcceptDate is null and new$AcceptDate is not null and new$Accepted = 1)) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;
          
    else
      RaiseException('EX_AGR_ChangeStateAdjust');
    END IF;
  END IF;
  /*   ,     LastAccepted*/
  if ((:old.AcceptDate is not null and :old.Accepted = 0 and new$AcceptDate is not null and new$Accepted = 1)) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;
          
    else
      RaiseException('EX_AGR_ChangeStateAdjust');
    END IF;
  END IF;
  /*   ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;
          
    else
      RaiseException('EX_AGR_ChangeStateAdjust');
    END IF;
  END IF;
  /*   ,     LastAdjustment  LastAccepted */
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment <> 1) then
      RaiseException('EX_AGR_ChangeStateAdjust');
    else
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
          
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_20 (TR_AGREEMENTS_BU_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,      */
  if ((new$Client_Ref <> :old.Client_Ref) and
      (((new$Client_INN is null) and
        (:old.Client_INN is null)) or
       (new$Client_INN = :old.Client_INN)) and
      (((new$Client_INN20 is null) and
        (:old.Client_INN20 is null)) or
       (new$Client_INN20 = :old.Client_INN20)) and
      (new$Client_Name = :old.Client_Name)) then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;

  /*    -,      */
  if ((new$Executer_Ref <> :old.Executer_Ref) and
      (((new$Executer_INN is null) and
        (:old.Executer_INN is null)) or
       (new$Executer_INN = :old.Executer_INN)) and
      (((new$Executer_INN20 is null) and
        (:old.Executer_INN20 is null)) or
       (new$Executer_INN20 = :old.Executer_INN20)) and
      (new$Executer_Name = :old.Executer_Name) and
      (((new$Executer_Status is null) and
        (:old.Executer_Status is null)) or
       (new$Executer_Status = :old.Executer_Status)) and
      (((new$Executer_Country is null) and
        (:old.Executer_Country is null)) or
       (new$Executer_Country = :old.Executer_Country)) and
      (((new$Executer_Address is null) and
        (:old.Executer_Address is null)) or
       (new$Executer_Address = :old.Executer_Address)) and
      (((new$Executer_Phone is null) and
        (:old.Executer_Phone is null)) or
       (new$Executer_Phone = :old.Executer_Phone))) then
     BEGIN
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_60 (tr_agreements_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*        ,     */
  if (:old.accepted = 1 and new$accepted = 0 and new$acceptdate is not null and new$adjustmentnumber = 0) then
    SELECT COUNT(*) INTO CNT$1
    from executiondocumentscaption
    where
    (            agreementinnernumber = new$innernumber
    and (accepted <> 0 or acceptdate is null)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_Agr_CannotReject');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_AGREEMENTS_BU_200)
-- Create 04.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$id, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (tr_agreements_bu_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$ExecuterAccRef is not null) then
    select count(ID)
    into CountAcc$     from org_accounts oa
    where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
    ;
    if (CountAcc$ = 0) then
      RaiseException('EX_AGR_ACCORGCHECK');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (TR_AGREEMENTS_BU_400)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  if (((new$rnClientID <> :old.rnClientID) or (new$rnYear <> :old.rnYear) or
  (new$rnNumber <> :old.rnNumber) or (new$ReestrVersion <> :old.ReestrVersion) or
  (:old.rnClientID is null) or (:old.rnYear is null) or (:old.ReestrVersion is null)
  ) and
  (new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID11$ := new$rnClientID;
    rnYear11$ := new$rnYear;
    rnNumber11$ := new$rnNumber;
    ReestrVersion11$ := new$ReestrVersion;
    while (LENGTH(rnClientID11$) < 11) LOOP
      rnClientID11$ := '0' || rnClientID11$;
    END LOOP;
    while (LENGTH(rnNumber11$) < 6) LOOP
      rnNumber11$ := '0' || rnNumber11$;
    END LOOP;
    if (LENGTH(ReestrVersion11$) < 2) then
      ReestrVersion11$ := '0' || ReestrVersion11$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID11$ || rnYear11$ || rnNumber11$;
          
    else
      new$ReestrRecordNumber := rnClientID11$ || rnYear11$ || rnNumber11$ || ReestrVersion11$;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_600 (agreements_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_AGREEMENTS_BU_700)
-- Create 14.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_AGREEMENTS SET
    ID = new$ID,
    SUMMA = new$SUMMA,
    AGREEMENTDATE = new$AGREEMENTDATE,
    AGREEMENTENDDATE = new$AGREEMENTENDDATE,
    EXECUTER_REF = new$EXECUTER_REF,
    CLIENT_REF = new$CLIENT_REF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    AGREEMENTTYPE = new$AGREEMENTTYPE,
    ACCEPTED = new$ACCEPTED,
    ACCEPTDATE = new$ACCEPTDATE,
    CARDADVANCEPERCENT = new$CARDADVANCEPERCENT,
    CARDADVANCE = new$CARDADVANCE,
    CLOSEDOC = new$CLOSEDOC,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    FACT = new$FACT,
    REGION = new$REGION,
    CLOSEDATE = new$CLOSEDATE,
    DELIVERYRULES = new$DELIVERYRULES,
    AGREEMENTSUMMA = new$AGREEMENTSUMMA,
    AGREEMENTFINSUMMA = new$AGREEMENTFINSUMMA,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    REESTRNUMBER = new$REESTRNUMBER,
    PAYMENTDATE = new$PAYMENTDATE,
    AGREEMENTCARDADVANCE = new$AGREEMENTCARDADVANCE,
    FINCARDADVANCE = new$FINCARDADVANCE,
    STATEORDERREF = new$STATEORDERREF,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    AGREEMENTBEGINDATE = new$AGREEMENTBEGINDATE,
    PROTOCOLNUMBER = new$PROTOCOLNUMBER,
    PROTOCOLDATE = new$PROTOCOLDATE,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXPORTDATE = new$EXPORTDATE,
    FSORGAN = new$FSORGAN,
    FSBUDGETNAME = new$FSBUDGETNAME,
    FSOFFBUDGET = new$FSOFFBUDGET,
    RNYEAR = new$RNYEAR,
    RNNUMBER = new$RNNUMBER,
    RNDATE = new$RNDATE,
    PROTOCOLNOTICE = new$PROTOCOLNOTICE,
    PROTOCOLRESULTDATE = new$PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE = new$PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE = new$PROTOCOLSALETYPE,
    NOTIFYDATE = new$NOTIFYDATE,
    EXECUTERACCREF = new$EXECUTERACCREF,
    DOCBASEDATE = new$DOCBASEDATE,
    DOCBASENOTIFYDATE = new$DOCBASENOTIFYDATE,
    DOCBASETEXT = new$DOCBASETEXT,
    DOCBASETYPE = new$DOCBASETYPE,
    DOCBASESUMMA = new$DOCBASESUMMA,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PROTOCOLREASON = new$PROTOCOLREASON,
    DOCNUMBER = new$DOCNUMBER,
    ADJUSTMENTDOCNUMBER = new$ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER = new$OLDDOCNUMBER,
    LOTMAXSUM = new$LOTMAXSUM,
    CLIENT_INN = new$CLIENT_INN,
    CLIENT_INN20 = new$CLIENT_INN20,
    CLIENT_NAME = new$CLIENT_NAME,
    EXECUTER_INN = new$EXECUTER_INN,
    EXECUTER_INN20 = new$EXECUTER_INN20,
    EXECUTER_NAME = new$EXECUTER_NAME,
    EXECUTER_STATUS = new$EXECUTER_STATUS,
    EXECUTER_COUNTRY = new$EXECUTER_COUNTRY,
    EXECUTER_ADDRESS = new$EXECUTER_ADDRESS,
    EXECUTER_PHONE = new$EXECUTER_PHONE,
    REALID = new$REALID,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    INNERNUMBER = new$INNERNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REESTRVERSION = new$REESTRVERSION,
    DOCTYPE = new$DOCTYPE,
    RNCLIENTID = new$RNCLIENTID,
    INFONUMBER = new$INFONUMBER,
    STATEORDERINNERNUMBER = new$STATEORDERINNERNUMBER,
    PROGINDEX = new$PROGINDEX,
    NOTE = new$NOTE,
    PURPORTDOC = new$PURPORTDOC,
    REESTRRECORDNUMBER = new$REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS = new$EXECUTERSTOREDPROPS,
    AUTOSANCTION = new$AUTOSANCTION,
    PURCHASECODE = new$PURCHASECODE,
    DOCUMENTNUMBER = new$DOCUMENTNUMBER,
    REJECTCAUSE = new$REJECTCAUSE,
    TENDERREF = new$TENDERREF,
    TENDERINNERNUMBER = new$TENDERINNERNUMBER,
    STOREDCONTENT = new$STOREDCONTENT
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_AGREEMENTS_AU_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  /*      */
  /*     ,       */
  /*        */
  if ((new$AdjustmentRef is not null) and (new$LastAdjustment = 1)) then
    update Agreements set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);        
  END IF;
      
  /*              */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and ((:old.LastAdjustment = 1) or (new$LastAdjustment = 1))) then
    update Agreements set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update Agreements set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*          */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 304)or(new$ProgIndex = 314)))then
    update Estimate
    set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    (RecordIndex = new$Id);
  END IF;
  /*         */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 305) or (new$ProgIndex = 314))) then
    update paymentschedule set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    AgreementRef = new$ID and
    ProgIndex in (317, 318);
  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_AGREEMENTS_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*      */
  if ((new$ProgIndex = 305) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null
    where
    StateOrder = :old.ID;
  END IF;
  /*      */
  if ((new$ProgIndex = 314) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null,
    Agreement = null
    where
    StateOrder = :old.ID;
  END IF;
  /*     */
  if ((:old.ProgIndex = 304) and (new$AdjustmentNumber = 0) and (new$Accepted = 0) and
  (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    Agreement = null
    where
    Agreement = :old.ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_AGREEMENTS_AU_30)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$ProgIndex = 304) or (new$ProgIndex = 314)) and
  ((new$Accepted <> :old.Accepted) or
  (new$AcceptDate is not null and :old.AcceptDate is null) or
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where AgreementRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_AGREEMENTS_AU_500)
-- Create 28.04.2005
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes
                  (TableID, RecordId, DeleteDate
                  )
           VALUES (110, :OLD.ID, SYSDATE
                  );

      DELETE FROM DelRecIndexes
            WHERE (TableID = 110) AND (RecordId = new$ID);
   END IF;

END;
/
-- CREATE TRIGGER TR_EXECDOCCAPTION_BU_10
CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_IU
  INSTEAD OF UPDATE
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  new$ID EXECUTIONDOCUMENTSCAPTION.ID%TYPE := :NEW.ID;
  new$DOCTYPE EXECUTIONDOCUMENTSCAPTION.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$DOCUMENTDATE EXECUTIONDOCUMENTSCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE EXECUTIONDOCUMENTSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SUMMA EXECUTIONDOCUMENTSCAPTION.SUMMA%TYPE := :NEW.SUMMA;
  new$CREATERUSER EXECUTIONDOCUMENTSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE EXECUTIONDOCUMENTSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE EXECUTIONDOCUMENTSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER EXECUTIONDOCUMENTSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF EXECUTIONDOCUMENTSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$STEPNUMBER EXECUTIONDOCUMENTSCAPTION.STEPNUMBER%TYPE := :NEW.STEPNUMBER;
  new$FACIALACC_CLS EXECUTIONDOCUMENTSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$RECIPIENT_REF EXECUTIONDOCUMENTSCAPTION.RECIPIENT_REF%TYPE := :NEW.RECIPIENT_REF;
  new$REGISTRATIONTYPE EXECUTIONDOCUMENTSCAPTION.REGISTRATIONTYPE%TYPE := :NEW.REGISTRATIONTYPE;
  new$REESTRNUMBER EXECUTIONDOCUMENTSCAPTION.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$AGREEMENTINNERNUMBER EXECUTIONDOCUMENTSCAPTION.AGREEMENTINNERNUMBER%TYPE := :NEW.AGREEMENTINNERNUMBER;
  new$REJECTCLS EXECUTIONDOCUMENTSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS EXECUTIONDOCUMENTSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID EXECUTIONDOCUMENTSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID EXECUTIONDOCUMENTSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REVIEWNOTE EXECUTIONDOCUMENTSCAPTION.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF EXECUTIONDOCUMENTSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION EXECUTIONDOCUMENTSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$EXECDOCFINSUMMA EXECUTIONDOCUMENTSCAPTION.EXECDOCFINSUMMA%TYPE := :NEW.EXECDOCFINSUMMA;
  new$FACT EXECUTIONDOCUMENTSCAPTION.FACT%TYPE := :NEW.FACT;
  new$DOCNUMBER EXECUTIONDOCUMENTSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SENDERIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REALID EXECUTIONDOCUMENTSCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER EXECUTIONDOCUMENTSCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTREF EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ADJUSTMENTNUMBER EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$ACCEPTED EXECUTIONDOCUMENTSCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED EXECUTIONDOCUMENTSCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$LASTADJUSTMENT EXECUTIONDOCUMENTSCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$AGREEMENTREF EXECUTIONDOCUMENTSCAPTION.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$NOTE EXECUTIONDOCUMENTSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$SUPPLIERSTOREDPROPS EXECUTIONDOCUMENTSCAPTION.SUPPLIERSTOREDPROPS%TYPE := :NEW.SUPPLIERSTOREDPROPS;
  new$SUPPLIER_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$SUPPLIERACC_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIERACC_REF%TYPE := :NEW.SUPPLIERACC_REF;
  new$REJECTCAUSE EXECUTIONDOCUMENTSCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$INFONUMBER EXECUTIONDOCUMENTSCAPTION.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$NOTIFYDATE EXECUTIONDOCUMENTSCAPTION.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$MONEYPROMISENUMBER EXECUTIONDOCUMENTSCAPTION.MONEYPROMISENUMBER%TYPE := :NEW.MONEYPROMISENUMBER;
  new$PURPORTDOC EXECUTIONDOCUMENTSCAPTION.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$STOREDCONTENT EXECUTIONDOCUMENTSCAPTION.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
  new$PAYDATE EXECUTIONDOCUMENTSCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$AUTOSANCTION EXECUTIONDOCUMENTSCAPTION.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  CntAgr$ NUMBER(10);
  CntStep$ NUMBER(10);
  agr_accepted$ NUMBER(10);
  agr_acceptdate$ NUMBER(10);
  CountExecDoc$ NUMBER(10);
  previousAccept$ NUMBER(10);
  previousAcceptDate$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_EXECDOCCAPTION_BU)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$ExecDocFinSumma is null) then
    new$ExecDocFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$RegistrationType is null) then
    new$RegistrationType := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      SELECT COUNT(                   Id
      ) INTO CNT$1
      from ExecutionDocumentsDetail
      where
      (                   RecordIndex = :old.Id
      ) AND (ROWNUM = 1)                ;
      if ((CNT$1<> 0)         ) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      SELECT COUNT(                   Id
      ) INTO CNT$2
      from PaymentSchedule
      where
      (                   ExecutionRef = :old.Id
      ) AND (ROWNUM = 1)                ;
      if ((CNT$2<> 0)         ) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*     ,        */
  if (new$InnerNumber is null) then
    new$InnerNumber := :old.InnerNumber;
  END IF;
  /* c,           */
  /* ,    */
  if (new$InnerNumber <> :old.InnerNumber or
  new$AdjustmentRef <> :old.AdjustmentRef or
  new$AdjustmentNumber <> :old.AdjustmentNumber) then
    RaiseException('EX_Agr_ChangeInnerNums');
  END IF;
  /*      id */
  new$agreementinnernumber := null;
  if (new$agreementref is not null) then
    BEGIN
      select
      innernumber
      into new$agreementinnernumber     from agreements
      where
      id = new$agreementref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_EXECDOCCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_EXECDOCCAPTION_BU_10)
-- Version 13.10.00.2
-- - - - - - - - - - - - -

  /*   13.10*/
  /*   */
  if (:old.AcceptDate is not null and :old.Accepted = 0 and new$Accepted = 1) then
    BEGIN
      /*             */
      select Accepted, AcceptDate
      into previousAccept$, previousAcceptDate$       from ExecutionDocumentsCaption
      where id=new$Adjustmentref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$Adjustmentref is not null and (previousAccept$ = 0 or previousAcceptDate$ is null)) then
      RaiseException('EX_RollbackCancel');
    END IF;
    new$LastAdjustment := 1;
      
  END IF;
  /*   ,     LastAccepted*/
  if (:old.AcceptDate is null and new$AcceptDate is not null and new$Accepted = 1) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
  END IF;
  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 0 and new$AcceptDate is not null and new$Accepted = 1) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
  END IF;
      
  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
  END IF;
      
  /*   ,     LastAdjustment  LastAccepted */
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment <> 1) then
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    else
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
          
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_40 (tr_execdoccaption_bu_40)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  if ((:old.AcceptDate is not null) and (new$AcceptDate is null)) then
    select count(ID) into CntAgr$ from Agreements where (CloseDoc = :old.ID) ;
    select count(ID) into CntStep$ from AgreementSteps where (CloseDoc = :old.ID) ;
    if ((CntAgr$ > 0) or (CntStep$ > 0)) then
      RaiseException('ex_CannotUpdateCloseDoc');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_60 (tr_execdoccaption_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$agreementinnernumber is not null) then
    BEGIN
      /*        , .. 
             ,    ,   
            ,     */
      select accepted, acceptdate     into
      agr_accepted$, agr_acceptdate$ from agreements
      where
      innernumber = new$agreementinnernumber and adjustmentnumber = 0
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*        */
    if (new$acceptdate is null and agr_accepted$ = 0 and agr_acceptdate$ is not null) then
      RaiseException('EX_Agr_Rejected');
    END IF;
    /*        */
    if (new$accepted = 1 and new$acceptdate is not null and
    (agr_accepted$ = 0 or agr_acceptdate$ is null)) then
      RaiseException('EX_Agr_NotAccepted');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_EXECDOCCAPTION_BU_200)
-- Create 04.10.2004
-- - - - - - - - - - - - -

  /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_EXECDOCCAPTION_BU_210)
-- Version 11.20.00.1
-- - - - - - - - - - - - -

  /*   */
  if (new$rejectcls is not null and new$accepted = 0) then
    /*         */
    select
    count(ffd.id)
    into CountExecDoc$     from
    facialfindetail ffd
    left join facialfincaption ffc on ffc.id = ffd.recordindex
    where
    (ffc.acceptdate is not null and (ffd.sourceexecdoc = new$id or ffd.destexecdoc = new$id))
    ;
    /*       */
    if (CountExecDoc$ <> 0) then
      RaiseException('ex_exedoc_useinfacialfindetail');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_EDCAPTION_BU_700)
-- Create 14.10.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_EXECUTIONDOCUMENTSCAPTION SET
    ID = new$ID,
    DOCTYPE = new$DOCTYPE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    SUMMA = new$SUMMA,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    STEPNUMBER = new$STEPNUMBER,
    FACIALACC_CLS = new$FACIALACC_CLS,
    RECIPIENT_REF = new$RECIPIENT_REF,
    REGISTRATIONTYPE = new$REGISTRATIONTYPE,
    REESTRNUMBER = new$REESTRNUMBER,
    AGREEMENTINNERNUMBER = new$AGREEMENTINNERNUMBER,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXECDOCFINSUMMA = new$EXECDOCFINSUMMA,
    FACT = new$FACT,
    DOCNUMBER = new$DOCNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REALID = new$REALID,
    INNERNUMBER = new$INNERNUMBER,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    ACCEPTED = new$ACCEPTED,
    LASTACCEPTED = new$LASTACCEPTED,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    AGREEMENTREF = new$AGREEMENTREF,
    NOTE = new$NOTE,
    SUPPLIERSTOREDPROPS = new$SUPPLIERSTOREDPROPS,
    SUPPLIER_REF = new$SUPPLIER_REF,
    SUPPLIERACC_REF = new$SUPPLIERACC_REF,
    REJECTCAUSE = new$REJECTCAUSE,
    INFONUMBER = new$INFONUMBER,
    NOTIFYDATE = new$NOTIFYDATE,
    MONEYPROMISENUMBER = new$MONEYPROMISENUMBER,
    PURPORTDOC = new$PURPORTDOC,
    STOREDCONTENT = new$STOREDCONTENT,
    PAYDATE = new$PAYDATE,
    AUTOSANCTION = new$AUTOSANCTION
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_0 (TR_ExecDocCaption_AU)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*       */
  /*     ,       */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update ExecutionDocuMENTSCaption set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update ExecutionDocuMENTSCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_EXECDOCCAPTION_AU_30)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$Accepted <> :old.Accepted) or
  (new$AcceptDate is not null and :old.AcceptDate is null) or
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where ExecutionRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_EXECDOCCAPTION_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (114, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=114) and (RecordId=new$ID);
  end if;

END;
/
-- CREATE TRIGGER TR_EXECDOCCAPTION_AU
CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_IU
  INSTEAD OF UPDATE
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  new$ID EXECUTIONDOCUMENTSCAPTION.ID%TYPE := :NEW.ID;
  new$DOCTYPE EXECUTIONDOCUMENTSCAPTION.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$DOCUMENTDATE EXECUTIONDOCUMENTSCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE EXECUTIONDOCUMENTSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SUMMA EXECUTIONDOCUMENTSCAPTION.SUMMA%TYPE := :NEW.SUMMA;
  new$CREATERUSER EXECUTIONDOCUMENTSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE EXECUTIONDOCUMENTSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE EXECUTIONDOCUMENTSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER EXECUTIONDOCUMENTSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF EXECUTIONDOCUMENTSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$STEPNUMBER EXECUTIONDOCUMENTSCAPTION.STEPNUMBER%TYPE := :NEW.STEPNUMBER;
  new$FACIALACC_CLS EXECUTIONDOCUMENTSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$RECIPIENT_REF EXECUTIONDOCUMENTSCAPTION.RECIPIENT_REF%TYPE := :NEW.RECIPIENT_REF;
  new$REGISTRATIONTYPE EXECUTIONDOCUMENTSCAPTION.REGISTRATIONTYPE%TYPE := :NEW.REGISTRATIONTYPE;
  new$REESTRNUMBER EXECUTIONDOCUMENTSCAPTION.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$AGREEMENTINNERNUMBER EXECUTIONDOCUMENTSCAPTION.AGREEMENTINNERNUMBER%TYPE := :NEW.AGREEMENTINNERNUMBER;
  new$REJECTCLS EXECUTIONDOCUMENTSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS EXECUTIONDOCUMENTSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID EXECUTIONDOCUMENTSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID EXECUTIONDOCUMENTSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REVIEWNOTE EXECUTIONDOCUMENTSCAPTION.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF EXECUTIONDOCUMENTSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION EXECUTIONDOCUMENTSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$EXECDOCFINSUMMA EXECUTIONDOCUMENTSCAPTION.EXECDOCFINSUMMA%TYPE := :NEW.EXECDOCFINSUMMA;
  new$FACT EXECUTIONDOCUMENTSCAPTION.FACT%TYPE := :NEW.FACT;
  new$DOCNUMBER EXECUTIONDOCUMENTSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SENDERIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REALID EXECUTIONDOCUMENTSCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER EXECUTIONDOCUMENTSCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTREF EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ADJUSTMENTNUMBER EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$ACCEPTED EXECUTIONDOCUMENTSCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED EXECUTIONDOCUMENTSCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$LASTADJUSTMENT EXECUTIONDOCUMENTSCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$AGREEMENTREF EXECUTIONDOCUMENTSCAPTION.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$NOTE EXECUTIONDOCUMENTSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$SUPPLIERSTOREDPROPS EXECUTIONDOCUMENTSCAPTION.SUPPLIERSTOREDPROPS%TYPE := :NEW.SUPPLIERSTOREDPROPS;
  new$SUPPLIER_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$SUPPLIERACC_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIERACC_REF%TYPE := :NEW.SUPPLIERACC_REF;
  new$REJECTCAUSE EXECUTIONDOCUMENTSCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$INFONUMBER EXECUTIONDOCUMENTSCAPTION.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$NOTIFYDATE EXECUTIONDOCUMENTSCAPTION.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$MONEYPROMISENUMBER EXECUTIONDOCUMENTSCAPTION.MONEYPROMISENUMBER%TYPE := :NEW.MONEYPROMISENUMBER;
  new$PURPORTDOC EXECUTIONDOCUMENTSCAPTION.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$STOREDCONTENT EXECUTIONDOCUMENTSCAPTION.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
  new$PAYDATE EXECUTIONDOCUMENTSCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$AUTOSANCTION EXECUTIONDOCUMENTSCAPTION.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  CntAgr$ NUMBER(10);
  CntStep$ NUMBER(10);
  agr_accepted$ NUMBER(10);
  agr_acceptdate$ NUMBER(10);
  CountExecDoc$ NUMBER(10);
  previousAccept$ NUMBER(10);
  previousAcceptDate$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_EXECDOCCAPTION_BU)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$ExecDocFinSumma is null) then
    new$ExecDocFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$RegistrationType is null) then
    new$RegistrationType := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      SELECT COUNT(                   Id
      ) INTO CNT$1
      from ExecutionDocumentsDetail
      where
      (                   RecordIndex = :old.Id
      ) AND (ROWNUM = 1)                ;
      if ((CNT$1<> 0)         ) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      SELECT COUNT(                   Id
      ) INTO CNT$2
      from PaymentSchedule
      where
      (                   ExecutionRef = :old.Id
      ) AND (ROWNUM = 1)                ;
      if ((CNT$2<> 0)         ) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*     ,        */
  if (new$InnerNumber is null) then
    new$InnerNumber := :old.InnerNumber;
  END IF;
  /* c,           */
  /* ,    */
  if (new$InnerNumber <> :old.InnerNumber or
  new$AdjustmentRef <> :old.AdjustmentRef or
  new$AdjustmentNumber <> :old.AdjustmentNumber) then
    RaiseException('EX_Agr_ChangeInnerNums');
  END IF;
  /*      id */
  new$agreementinnernumber := null;
  if (new$agreementref is not null) then
    BEGIN
      select
      innernumber
      into new$agreementinnernumber     from agreements
      where
      id = new$agreementref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_EXECDOCCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_EXECDOCCAPTION_BU_10)
-- Version 13.10.00.2
-- - - - - - - - - - - - -

  /*   13.10*/
  /*   */
  if (:old.AcceptDate is not null and :old.Accepted = 0 and new$Accepted = 1) then
    BEGIN
      /*             */
      select Accepted, AcceptDate
      into previousAccept$, previousAcceptDate$       from ExecutionDocumentsCaption
      where id=new$Adjustmentref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$Adjustmentref is not null and (previousAccept$ = 0 or previousAcceptDate$ is null)) then
      RaiseException('EX_RollbackCancel');
    END IF;
    new$LastAdjustment := 1;
      
  END IF;
  /*   ,     LastAccepted*/
  if (:old.AcceptDate is null and new$AcceptDate is not null and new$Accepted = 1) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
  END IF;
  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 0 and new$AcceptDate is not null and new$Accepted = 1) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
  END IF;
      
  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
  END IF;
      
  /*   ,     LastAdjustment  LastAccepted */
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment <> 1) then
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    else
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
          
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_40 (tr_execdoccaption_bu_40)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  if ((:old.AcceptDate is not null) and (new$AcceptDate is null)) then
    select count(ID) into CntAgr$ from Agreements where (CloseDoc = :old.ID) ;
    select count(ID) into CntStep$ from AgreementSteps where (CloseDoc = :old.ID) ;
    if ((CntAgr$ > 0) or (CntStep$ > 0)) then
      RaiseException('ex_CannotUpdateCloseDoc');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_60 (tr_execdoccaption_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$agreementinnernumber is not null) then
    BEGIN
      /*        , .. 
             ,    ,   
            ,     */
      select accepted, acceptdate     into
      agr_accepted$, agr_acceptdate$ from agreements
      where
      innernumber = new$agreementinnernumber and adjustmentnumber = 0
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*        */
    if (new$acceptdate is null and agr_accepted$ = 0 and agr_acceptdate$ is not null) then
      RaiseException('EX_Agr_Rejected');
    END IF;
    /*        */
    if (new$accepted = 1 and new$acceptdate is not null and
    (agr_accepted$ = 0 or agr_acceptdate$ is null)) then
      RaiseException('EX_Agr_NotAccepted');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_EXECDOCCAPTION_BU_200)
-- Create 04.10.2004
-- - - - - - - - - - - - -

  /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_EXECDOCCAPTION_BU_210)
-- Version 11.20.00.1
-- - - - - - - - - - - - -

  /*   */
  if (new$rejectcls is not null and new$accepted = 0) then
    /*         */
    select
    count(ffd.id)
    into CountExecDoc$     from
    facialfindetail ffd
    left join facialfincaption ffc on ffc.id = ffd.recordindex
    where
    (ffc.acceptdate is not null and (ffd.sourceexecdoc = new$id or ffd.destexecdoc = new$id))
    ;
    /*       */
    if (CountExecDoc$ <> 0) then
      RaiseException('ex_exedoc_useinfacialfindetail');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_EDCAPTION_BU_700)
-- Create 14.10.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_EXECUTIONDOCUMENTSCAPTION SET
    ID = new$ID,
    DOCTYPE = new$DOCTYPE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    SUMMA = new$SUMMA,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    STEPNUMBER = new$STEPNUMBER,
    FACIALACC_CLS = new$FACIALACC_CLS,
    RECIPIENT_REF = new$RECIPIENT_REF,
    REGISTRATIONTYPE = new$REGISTRATIONTYPE,
    REESTRNUMBER = new$REESTRNUMBER,
    AGREEMENTINNERNUMBER = new$AGREEMENTINNERNUMBER,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXECDOCFINSUMMA = new$EXECDOCFINSUMMA,
    FACT = new$FACT,
    DOCNUMBER = new$DOCNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REALID = new$REALID,
    INNERNUMBER = new$INNERNUMBER,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    ACCEPTED = new$ACCEPTED,
    LASTACCEPTED = new$LASTACCEPTED,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    AGREEMENTREF = new$AGREEMENTREF,
    NOTE = new$NOTE,
    SUPPLIERSTOREDPROPS = new$SUPPLIERSTOREDPROPS,
    SUPPLIER_REF = new$SUPPLIER_REF,
    SUPPLIERACC_REF = new$SUPPLIERACC_REF,
    REJECTCAUSE = new$REJECTCAUSE,
    INFONUMBER = new$INFONUMBER,
    NOTIFYDATE = new$NOTIFYDATE,
    MONEYPROMISENUMBER = new$MONEYPROMISENUMBER,
    PURPORTDOC = new$PURPORTDOC,
    STOREDCONTENT = new$STOREDCONTENT,
    PAYDATE = new$PAYDATE,
    AUTOSANCTION = new$AUTOSANCTION
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_0 (TR_ExecDocCaption_AU)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  /*       */
  /*     ,       */
  /*        */
  if ((new$AdjustmentRef is not null) and (new$LastAdjustment = 1)) then
    update ExecutionDocumentsCaption set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*              */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and ((:old.LastAdjustment = 1) or (new$LastAdjustment = 1))) then
    update ExecutionDocuMENTSCaption set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update ExecutionDocuMENTSCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_EXECDOCCAPTION_AU_30)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$Accepted <> :old.Accepted) or
  (new$AcceptDate is not null and :old.AcceptDate is null) or
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where ExecutionRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_EXECDOCCAPTION_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (114, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=114) and (RecordId=new$ID);
  end if;

END;
/
-- CREATE TRIGGER TR_TENDERCAPTION_BU_10
CREATE OR REPLACE TRIGGER TR_TENDERCAPTION_IU
  INSTEAD OF UPDATE
  ON TENDERCAPTION
  FOR EACH ROW
DECLARE
  new$ID TENDERCAPTION.ID%TYPE := :NEW.ID;
  new$BUDGETREF TENDERCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FACIALACCCLS TENDERCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$MULTIPURPOSE TENDERCAPTION.MULTIPURPOSE%TYPE := :NEW.MULTIPURPOSE;
  new$DOCUMENTDATE TENDERCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE TENDERCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PERIOD TENDERCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$ACCEPTSUMMA TENDERCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$SALETYPE TENDERCAPTION.SALETYPE%TYPE := :NEW.SALETYPE;
  new$REJECTCLS TENDERCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS TENDERCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID TENDERCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID TENDERCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCSTATEREF TENDERCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CREATERUSER TENDERCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TENDERCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE TENDERCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER TENDERCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$LASTADJUSTMENT TENDERCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED TENDERCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$ADJUSTMENTREF TENDERCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ACCEPTED TENDERCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$EXPORTDATE TENDERCAPTION.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$YEARACCEPTSUMMA TENDERCAPTION.YEARACCEPTSUMMA%TYPE := :NEW.YEARACCEPTSUMMA;
  new$TENDEROPTION TENDERCAPTION.TENDEROPTION%TYPE := :NEW.TENDEROPTION;
  new$TENDERTARGET TENDERCAPTION.TENDERTARGET%TYPE := :NEW.TENDERTARGET;
  new$RVERSION TENDERCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$ALLOWANCE TENDERCAPTION.ALLOWANCE%TYPE := :NEW.ALLOWANCE;
  new$REFINEMENTCAUSE TENDERCAPTION.REFINEMENTCAUSE%TYPE := :NEW.REFINEMENTCAUSE;
  new$PREFERENCE TENDERCAPTION.PREFERENCE%TYPE := :NEW.PREFERENCE;
  new$PREFERENCESIZE TENDERCAPTION.PREFERENCESIZE%TYPE := :NEW.PREFERENCESIZE;
  new$SECURITY TENDERCAPTION.SECURITY%TYPE := :NEW.SECURITY;
  new$UNKNOWNAMOUNT TENDERCAPTION.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PERIODYEAR TENDERCAPTION.PERIODYEAR%TYPE := :NEW.PERIODYEAR;
  new$SUPPORTUNDERTAKER TENDERCAPTION.SUPPORTUNDERTAKER%TYPE := :NEW.SUPPORTUNDERTAKER;
  new$AYEAR TENDERCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$REWORKCAUSE TENDERCAPTION.REWORKCAUSE%TYPE := :NEW.REWORKCAUSE;
  new$NOTE TENDERCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$REALID TENDERCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER TENDERCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTNUMBER TENDERCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$SENDERIDKEY TENDERCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY TENDERCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$PROTOCOLREASON TENDERCAPTION.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$PROGINDEX TENDERCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER TENDERCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SECURITYTSIZE TENDERCAPTION.SECURITYTSIZE%TYPE := :NEW.SECURITYTSIZE;
  new$SECURITYASIZE TENDERCAPTION.SECURITYASIZE%TYPE := :NEW.SECURITYASIZE;
  new$AVANSSIZE TENDERCAPTION.AVANSSIZE%TYPE := :NEW.AVANSSIZE;
  new$PREFERENCECRIPPLE TENDERCAPTION.PREFERENCECRIPPLE%TYPE := :NEW.PREFERENCECRIPPLE;
  new$PREFERENCERUSPRODUCT TENDERCAPTION.PREFERENCERUSPRODUCT%TYPE := :NEW.PREFERENCERUSPRODUCT;
  new$PREFERENCEPRISON TENDERCAPTION.PREFERENCEPRISON%TYPE := :NEW.PREFERENCEPRISON;
  new$AGREEMENTEXECUTIONDATE TENDERCAPTION.AGREEMENTEXECUTIONDATE%TYPE := :NEW.AGREEMENTEXECUTIONDATE;
  new$PURCHASECODE TENDERCAPTION.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$PURCHASESOCIALNKO TENDERCAPTION.PURCHASESOCIALNKO%TYPE := :NEW.PURCHASESOCIALNKO;
  new$AVERSION TENDERCAPTION.AVERSION%TYPE := :NEW.AVERSION;
  new$PARENTREF TENDERCAPTION.PARENTREF%TYPE := :NEW.PARENTREF;
  new$REJECTCAUSE TENDERCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$PARENTINNERNUMBER TENDERCAPTION.PARENTINNERNUMBER%TYPE := :NEW.PARENTINNERNUMBER;
--
  DetCount1$ NUMBER(10);
  ParentProgIndex1$ NUMBER(10);
  AdjParentRef1$ NUMBER(10);
  AdjParentInnerNumber1$ NUMBER(10);
  previousAccept$ NUMBER(10);
  previousAcceptDate$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TENDERCAPTION_BU_0)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*   13.0*/
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  /*         ( ) */
  if (new$ProgIndex = 230 and new$Multipurpose is null) then
    new$Multipurpose := 0;
  END IF;
  if (new$AcceptSumma is null) then
    new$AcceptSumma := 0;
  END IF;
  if (new$YearAcceptSumma is null) then
    new$YearAcceptSumma := 0;
  END IF;
  if (new$Allowance is null) then
    new$Allowance := 0;
  END IF;
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if (not((new$BudgetRef is null) and (:old.BudgetRef is null))) then
      select count(ID)         into DetCount1$ from TENDERSOURCEORG where RecordIndex = :old.ID
      ;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount1$ from TENDERCONTACTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount1$ from TENDERSUPDOCUMENT where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount1$ from TENDERSUPPLEMENTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount1$ from TENDERYARDSTICKS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount1$ from TenderLot where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  if (new$SaleType is null) then
    new$SaleType := 0;
  END IF;
  if (new$TenderOption is null) then
    new$TenderOption := 0;
  END IF;
  if (new$RefinementCause is Null) then
    new$RefinementCause := 0;
  END IF;
  if (new$Preference is Null) then
    new$Preference := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$SupportUndertaker is null) then
    new$SupportUndertaker := 0;
  END IF;
  /*     ,        */
  if (new$InnerNumber is null) then
    new$InnerNumber := :old.InnerNumber;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_TENDERCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_TENDERCAPTION_BU_10)
-- Version 13.10.00.2
-- - - - - - - - - - - - -

  /*   13.10*/
  if ((new$InnerNumber <> :old.InnerNumber) or
  (new$AdjustmentRef <> :old.AdjustmentRef) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber)) then
    RaiseException('EX_AGR_ChangeInnerNums');
  END IF;
      
  /*  */
  if (:old.AcceptDate is not null and :old.Accepted = 0 and new$Accepted = 1) then
    BEGIN
      /*             */
      select Accepted, AcceptDate
      into previousAccept$, previousAcceptDate$       from TenderCaption
      where id=new$Adjustmentref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$Adjustmentref is not null and (previousAccept$ = 0 or previousAcceptDate$ is null)) then
      RaiseException('EX_RollbackCancel');
    END IF;
    new$LastAdjustment := 1;
      
  END IF;
  /*  ,     LastAccepted*/
  if (:old.AcceptDate is null and new$AcceptDate is not null and new$Accepted = 1) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;
            
    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;
  /*   ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 0 and new$AcceptDate is not null and new$Accepted = 1) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;
            
    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;
  /*   ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;
            
    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;
  /*   ,     LastAdjustment*/
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment <> 1) then
      RaiseException('EX_Ten_ChangeStateAdjust');
    else
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
            
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_TENDERCAPTION_BU_30)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  new$ParentInnerNumber := null;
  if (new$ParentRef is not null) then
    BEGIN
      select InnerNumber
      into new$ParentInnerNumber     from TenderCaption
      where ID=new$ParentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /* :  /    / */
  if (new$ParentRef is not null
  /*  ,   */
  and  (:old.ParentRef is null
  or (:old.ParentRef is not null and :old.ParentRef <> new$ParentRef)))
  then
    /* :     ParentRef  */
    if (new$LastAdjustment = 0) then
      RaiseException('EX_ChangeAdjTenderParentRef');
    END IF;
    BEGIN
      select ProgIndex
      into ParentProgIndex1$     from TenderCaption
      where ID=new$ParentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /* :  /    / */
    if  ((new$ProgIndex=243 and ParentProgIndex1$ <> 242)
    or (new$ProgIndex=241 and ParentProgIndex1$ <> 240))
    then
      RaiseException('EX_IncorrectTenderParentRef');
    END IF;
    /* :       /     ( ,    ) */
    if (new$AdjustmentRef is not null) then
      BEGIN
        select ParentRef
        into AdjParentRef1$       from TenderCaption
        where ID=new$AdjustmentRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (AdjParentRef1$ is not null) then
        BEGIN
          select InnerNumber
          into AdjParentInnerNumber1$         from TenderCaption
          where ID=AdjParentRef1$

          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        if (AdjParentInnerNumber1$ <> new$ParentInnerNumber) then
          RaiseException('EX_IncorrectAdjTenderParentRef');
        END IF;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_TENDERCAPTION_BU_200)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*        */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
        VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef);
   END IF;

-- - - - - - - - - - - - -
-- BU_600 (tendercaption_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_TENDERCAPTION_BU_700)
-- Create 14.10.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TENDERCAPTION SET
    ID = new$ID,
    BUDGETREF = new$BUDGETREF,
    FACIALACCCLS = new$FACIALACCCLS,
    MULTIPURPOSE = new$MULTIPURPOSE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    PERIOD = new$PERIOD,
    ACCEPTSUMMA = new$ACCEPTSUMMA,
    SALETYPE = new$SALETYPE,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DOCSTATEREF = new$DOCSTATEREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    ACCEPTED = new$ACCEPTED,
    EXPORTDATE = new$EXPORTDATE,
    YEARACCEPTSUMMA = new$YEARACCEPTSUMMA,
    TENDEROPTION = new$TENDEROPTION,
    TENDERTARGET = new$TENDERTARGET,
    RVERSION = new$RVERSION,
    ALLOWANCE = new$ALLOWANCE,
    REFINEMENTCAUSE = new$REFINEMENTCAUSE,
    PREFERENCE = new$PREFERENCE,
    PREFERENCESIZE = new$PREFERENCESIZE,
    SECURITY = new$SECURITY,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PERIODYEAR = new$PERIODYEAR,
    SUPPORTUNDERTAKER = new$SUPPORTUNDERTAKER,
    AYEAR = new$AYEAR,
    REWORKCAUSE = new$REWORKCAUSE,
    NOTE = new$NOTE,
    REALID = new$REALID,
    INNERNUMBER = new$INNERNUMBER,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    PROTOCOLREASON = new$PROTOCOLREASON,
    PROGINDEX = new$PROGINDEX,
    DOCNUMBER = new$DOCNUMBER,
    SECURITYTSIZE = new$SECURITYTSIZE,
    SECURITYASIZE = new$SECURITYASIZE,
    AVANSSIZE = new$AVANSSIZE,
    PREFERENCECRIPPLE = new$PREFERENCECRIPPLE,
    PREFERENCERUSPRODUCT = new$PREFERENCERUSPRODUCT,
    PREFERENCEPRISON = new$PREFERENCEPRISON,
    AGREEMENTEXECUTIONDATE = new$AGREEMENTEXECUTIONDATE,
    PURCHASECODE = new$PURCHASECODE,
    PURCHASESOCIALNKO = new$PURCHASESOCIALNKO,
    AVERSION = new$AVERSION,
    PARENTREF = new$PARENTREF,
    REJECTCAUSE = new$REJECTCAUSE,
    PARENTINNERNUMBER = new$PARENTINNERNUMBER
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_TENDERCAPTION_AU_10)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*   13.0*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update TenderCaption set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

  /*       LastAdjustment    */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update TenderCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_TENDERCAPTION_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   2.0*/
  /*       ,      */
  if (:old.FacialAccCls <> new$FacialAccCls) then
    update TenderProduct set
    RVersion = -1,
    FacialAccCls = new$FacialAccCls
    where
    (RecordIndex = new$ID) and (ProgIndex = 230);
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (tr_TenderCaption_au_30)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) /*      */
  and ((new$ProgIndex = 240) /* */ or (new$ProgIndex = 242) /* */))
  then
    if ((new$Accepted <> :old.Accepted)
    or (new$AcceptDate is not null and :old.AcceptDate is null)
    or (new$AcceptDate is null and :old.AcceptDate is not null)
    or (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))
    then
      update TenderCaption set
      RejectCls = new$RejectCls,
      AcceptDate = new$AcceptDate
      where ParentRef=new$ID;
      /*          */
      if (:old.Accepted=1 and new$Accepted=0) then
        update TenderCaption set
        RejectCause = '   : ' || new$RejectCause
        where ParentRef=new$ID;
      END IF;
      /*             */
      if (:old.Accepted=0 and new$Accepted=1) then
        update TenderCaption set
        RejectCls = null,
        RejectCause = null
        where ParentRef=new$ID;

      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_TENDERCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
           VALUES (139, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
            WHERE (TableID = 139) AND (RecordId = new$ID);
   END IF;

END;
/
-- CREATE TRIGGER TR_TENDERCAPTION_AU_10
CREATE OR REPLACE TRIGGER TR_TENDERCAPTION_IU
  INSTEAD OF UPDATE
  ON TENDERCAPTION
  FOR EACH ROW
DECLARE
  new$ID TENDERCAPTION.ID%TYPE := :NEW.ID;
  new$BUDGETREF TENDERCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FACIALACCCLS TENDERCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$MULTIPURPOSE TENDERCAPTION.MULTIPURPOSE%TYPE := :NEW.MULTIPURPOSE;
  new$DOCUMENTDATE TENDERCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE TENDERCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PERIOD TENDERCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$ACCEPTSUMMA TENDERCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$SALETYPE TENDERCAPTION.SALETYPE%TYPE := :NEW.SALETYPE;
  new$REJECTCLS TENDERCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS TENDERCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID TENDERCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID TENDERCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCSTATEREF TENDERCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CREATERUSER TENDERCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TENDERCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE TENDERCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER TENDERCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$LASTADJUSTMENT TENDERCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED TENDERCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$ADJUSTMENTREF TENDERCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ACCEPTED TENDERCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$EXPORTDATE TENDERCAPTION.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$YEARACCEPTSUMMA TENDERCAPTION.YEARACCEPTSUMMA%TYPE := :NEW.YEARACCEPTSUMMA;
  new$TENDEROPTION TENDERCAPTION.TENDEROPTION%TYPE := :NEW.TENDEROPTION;
  new$TENDERTARGET TENDERCAPTION.TENDERTARGET%TYPE := :NEW.TENDERTARGET;
  new$RVERSION TENDERCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$ALLOWANCE TENDERCAPTION.ALLOWANCE%TYPE := :NEW.ALLOWANCE;
  new$REFINEMENTCAUSE TENDERCAPTION.REFINEMENTCAUSE%TYPE := :NEW.REFINEMENTCAUSE;
  new$PREFERENCE TENDERCAPTION.PREFERENCE%TYPE := :NEW.PREFERENCE;
  new$PREFERENCESIZE TENDERCAPTION.PREFERENCESIZE%TYPE := :NEW.PREFERENCESIZE;
  new$SECURITY TENDERCAPTION.SECURITY%TYPE := :NEW.SECURITY;
  new$UNKNOWNAMOUNT TENDERCAPTION.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PERIODYEAR TENDERCAPTION.PERIODYEAR%TYPE := :NEW.PERIODYEAR;
  new$SUPPORTUNDERTAKER TENDERCAPTION.SUPPORTUNDERTAKER%TYPE := :NEW.SUPPORTUNDERTAKER;
  new$AYEAR TENDERCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$REWORKCAUSE TENDERCAPTION.REWORKCAUSE%TYPE := :NEW.REWORKCAUSE;
  new$NOTE TENDERCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$REALID TENDERCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER TENDERCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTNUMBER TENDERCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$SENDERIDKEY TENDERCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY TENDERCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$PROTOCOLREASON TENDERCAPTION.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$PROGINDEX TENDERCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER TENDERCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SECURITYTSIZE TENDERCAPTION.SECURITYTSIZE%TYPE := :NEW.SECURITYTSIZE;
  new$SECURITYASIZE TENDERCAPTION.SECURITYASIZE%TYPE := :NEW.SECURITYASIZE;
  new$AVANSSIZE TENDERCAPTION.AVANSSIZE%TYPE := :NEW.AVANSSIZE;
  new$PREFERENCECRIPPLE TENDERCAPTION.PREFERENCECRIPPLE%TYPE := :NEW.PREFERENCECRIPPLE;
  new$PREFERENCERUSPRODUCT TENDERCAPTION.PREFERENCERUSPRODUCT%TYPE := :NEW.PREFERENCERUSPRODUCT;
  new$PREFERENCEPRISON TENDERCAPTION.PREFERENCEPRISON%TYPE := :NEW.PREFERENCEPRISON;
  new$AGREEMENTEXECUTIONDATE TENDERCAPTION.AGREEMENTEXECUTIONDATE%TYPE := :NEW.AGREEMENTEXECUTIONDATE;
  new$PURCHASECODE TENDERCAPTION.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$PURCHASESOCIALNKO TENDERCAPTION.PURCHASESOCIALNKO%TYPE := :NEW.PURCHASESOCIALNKO;
  new$AVERSION TENDERCAPTION.AVERSION%TYPE := :NEW.AVERSION;
  new$PARENTREF TENDERCAPTION.PARENTREF%TYPE := :NEW.PARENTREF;
  new$REJECTCAUSE TENDERCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$PARENTINNERNUMBER TENDERCAPTION.PARENTINNERNUMBER%TYPE := :NEW.PARENTINNERNUMBER;
--
  DetCount1$ NUMBER(10);
  ParentProgIndex1$ NUMBER(10);
  AdjParentRef1$ NUMBER(10);
  AdjParentInnerNumber1$ NUMBER(10);
  previousAccept$ NUMBER(10);
  previousAcceptDate$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TENDERCAPTION_BU_0)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*   13.0*/
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  /*         ( ) */
  if (new$ProgIndex = 230 and new$Multipurpose is null) then
    new$Multipurpose := 0;
  END IF;
  if (new$AcceptSumma is null) then
    new$AcceptSumma := 0;
  END IF;
  if (new$YearAcceptSumma is null) then
    new$YearAcceptSumma := 0;
  END IF;
  if (new$Allowance is null) then
    new$Allowance := 0;
  END IF;
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if (not((new$BudgetRef is null) and (:old.BudgetRef is null))) then
      select count(ID)         into DetCount1$ from TENDERSOURCEORG where RecordIndex = :old.ID
      ;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount1$ from TENDERCONTACTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount1$ from TENDERSUPDOCUMENT where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount1$ from TENDERSUPPLEMENTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount1$ from TENDERYARDSTICKS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount1$ from TenderLot where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  if (new$SaleType is null) then
    new$SaleType := 0;
  END IF;
  if (new$TenderOption is null) then
    new$TenderOption := 0;
  END IF;
  if (new$RefinementCause is Null) then
    new$RefinementCause := 0;
  END IF;
  if (new$Preference is Null) then
    new$Preference := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$SupportUndertaker is null) then
    new$SupportUndertaker := 0;
  END IF;
  /*     ,        */
  if (new$InnerNumber is null) then
    new$InnerNumber := :old.InnerNumber;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_TENDERCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_TENDERCAPTION_BU_10)
-- Version 13.10.00.2
-- - - - - - - - - - - - -

  /*   13.10*/
  if ((new$InnerNumber <> :old.InnerNumber) or
  (new$AdjustmentRef <> :old.AdjustmentRef) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber)) then
    RaiseException('EX_AGR_ChangeInnerNums');
  END IF;
      
  /*  */
  if (:old.AcceptDate is not null and :old.Accepted = 0 and new$Accepted = 1) then
    BEGIN
      /*             */
      select Accepted, AcceptDate
      into previousAccept$, previousAcceptDate$       from TenderCaption
      where id=new$Adjustmentref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$Adjustmentref is not null and (previousAccept$ = 0 or previousAcceptDate$ is null)) then
      RaiseException('EX_RollbackCancel');
    END IF;
    new$LastAdjustment := 1;
      
  END IF;
  /*  ,     LastAccepted*/
  if (:old.AcceptDate is null and new$AcceptDate is not null and new$Accepted = 1) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;
            
    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;
  /*   ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 0 and new$AcceptDate is not null and new$Accepted = 1) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;
            
    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;
  /*   ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;
            
    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;
  /*   ,     LastAdjustment*/
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment <> 1) then
      RaiseException('EX_Ten_ChangeStateAdjust');
    else
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
            
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_TENDERCAPTION_BU_30)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  new$ParentInnerNumber := null;
  if (new$ParentRef is not null) then
    BEGIN
      select InnerNumber
      into new$ParentInnerNumber     from TenderCaption
      where ID=new$ParentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /* :  /    / */
  if (new$ParentRef is not null
  /*  ,   */
  and  (:old.ParentRef is null
  or (:old.ParentRef is not null and :old.ParentRef <> new$ParentRef)))
  then
    /* :     ParentRef  */
    if (new$LastAdjustment = 0) then
      RaiseException('EX_ChangeAdjTenderParentRef');
    END IF;
    BEGIN
      select ProgIndex
      into ParentProgIndex1$     from TenderCaption
      where ID=new$ParentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /* :  /    / */
    if  ((new$ProgIndex=243 and ParentProgIndex1$ <> 242)
    or (new$ProgIndex=241 and ParentProgIndex1$ <> 240))
    then
      RaiseException('EX_IncorrectTenderParentRef');
    END IF;
    /* :       /     ( ,    ) */
    if (new$AdjustmentRef is not null) then
      BEGIN
        select ParentRef
        into AdjParentRef1$       from TenderCaption
        where ID=new$AdjustmentRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (AdjParentRef1$ is not null) then
        BEGIN
          select InnerNumber
          into AdjParentInnerNumber1$         from TenderCaption
          where ID=AdjParentRef1$

          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        if (AdjParentInnerNumber1$ <> new$ParentInnerNumber) then
          RaiseException('EX_IncorrectAdjTenderParentRef');
        END IF;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_TENDERCAPTION_BU_200)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*        */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
        VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef);
   END IF;

-- - - - - - - - - - - - -
-- BU_600 (tendercaption_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_TENDERCAPTION_BU_700)
-- Create 14.10.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TENDERCAPTION SET
    ID = new$ID,
    BUDGETREF = new$BUDGETREF,
    FACIALACCCLS = new$FACIALACCCLS,
    MULTIPURPOSE = new$MULTIPURPOSE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    PERIOD = new$PERIOD,
    ACCEPTSUMMA = new$ACCEPTSUMMA,
    SALETYPE = new$SALETYPE,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DOCSTATEREF = new$DOCSTATEREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    ACCEPTED = new$ACCEPTED,
    EXPORTDATE = new$EXPORTDATE,
    YEARACCEPTSUMMA = new$YEARACCEPTSUMMA,
    TENDEROPTION = new$TENDEROPTION,
    TENDERTARGET = new$TENDERTARGET,
    RVERSION = new$RVERSION,
    ALLOWANCE = new$ALLOWANCE,
    REFINEMENTCAUSE = new$REFINEMENTCAUSE,
    PREFERENCE = new$PREFERENCE,
    PREFERENCESIZE = new$PREFERENCESIZE,
    SECURITY = new$SECURITY,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PERIODYEAR = new$PERIODYEAR,
    SUPPORTUNDERTAKER = new$SUPPORTUNDERTAKER,
    AYEAR = new$AYEAR,
    REWORKCAUSE = new$REWORKCAUSE,
    NOTE = new$NOTE,
    REALID = new$REALID,
    INNERNUMBER = new$INNERNUMBER,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    PROTOCOLREASON = new$PROTOCOLREASON,
    PROGINDEX = new$PROGINDEX,
    DOCNUMBER = new$DOCNUMBER,
    SECURITYTSIZE = new$SECURITYTSIZE,
    SECURITYASIZE = new$SECURITYASIZE,
    AVANSSIZE = new$AVANSSIZE,
    PREFERENCECRIPPLE = new$PREFERENCECRIPPLE,
    PREFERENCERUSPRODUCT = new$PREFERENCERUSPRODUCT,
    PREFERENCEPRISON = new$PREFERENCEPRISON,
    AGREEMENTEXECUTIONDATE = new$AGREEMENTEXECUTIONDATE,
    PURCHASECODE = new$PURCHASECODE,
    PURCHASESOCIALNKO = new$PURCHASESOCIALNKO,
    AVERSION = new$AVERSION,
    PARENTREF = new$PARENTREF,
    REJECTCAUSE = new$REJECTCAUSE,
    PARENTINNERNUMBER = new$PARENTINNERNUMBER
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_TENDERCAPTION_AU_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  /*      */
  /*     ,       */
  /*        */
  if ((new$AdjustmentRef is not null) and (new$LastAdjustment = 1)) then
    update TenderCaption set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);  
  END IF;
      
  /*              */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and ((:old.LastAdjustment = 1) or (new$LastAdjustment = 1))) then
    update TenderCaption set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
          
  /*       LastAdjustment    */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update TenderCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_TENDERCAPTION_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   2.0*/
  /*       ,      */
  if (:old.FacialAccCls <> new$FacialAccCls) then
    update TenderProduct set
    RVersion = -1,
    FacialAccCls = new$FacialAccCls
    where
    (RecordIndex = new$ID) and (ProgIndex = 230);
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (tr_TenderCaption_au_30)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) /*      */
  and ((new$ProgIndex = 240) /* */ or (new$ProgIndex = 242) /* */))
  then
    if ((new$Accepted <> :old.Accepted)
    or (new$AcceptDate is not null and :old.AcceptDate is null)
    or (new$AcceptDate is null and :old.AcceptDate is not null)
    or (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))
    then
      update TenderCaption set
      RejectCls = new$RejectCls,
      AcceptDate = new$AcceptDate
      where ParentRef=new$ID;
      /*          */
      if (:old.Accepted=1 and new$Accepted=0) then
        update TenderCaption set
        RejectCause = '   : ' || new$RejectCause
        where ParentRef=new$ID;
      END IF;
      /*             */
      if (:old.Accepted=0 and new$Accepted=1) then
        update TenderCaption set
        RejectCls = null,
        RejectCause = null
        where ParentRef=new$ID;

      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_TENDERCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
           VALUES (139, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
            WHERE (TableID = 139) AND (RecordId = new$ID);
   END IF;

END;
/
-- CREATE TRIGGER TR_PAYMENTSCHEDULE_BI
CREATE OR REPLACE TRIGGER TR_PAYMENTSCHEDULE_II
  INSTEAD OF INSERT
  ON PAYMENTSCHEDULE
  FOR EACH ROW
DECLARE
  new$ID PAYMENTSCHEDULE.ID%TYPE := :NEW.ID;
  new$ANUMBER PAYMENTSCHEDULE.ANUMBER%TYPE := :NEW.ANUMBER;
  new$PARENTNUMBER PAYMENTSCHEDULE.PARENTNUMBER%TYPE := :NEW.PARENTNUMBER;
  new$KFSR PAYMENTSCHEDULE.KFSR%TYPE := :NEW.KFSR;
  new$KESR PAYMENTSCHEDULE.KESR%TYPE := :NEW.KESR;
  new$KVSR PAYMENTSCHEDULE.KVSR%TYPE := :NEW.KVSR;
  new$KCSR PAYMENTSCHEDULE.KCSR%TYPE := :NEW.KCSR;
  new$KVR PAYMENTSCHEDULE.KVR%TYPE := :NEW.KVR;
  new$MONTH01 PAYMENTSCHEDULE.MONTH01%TYPE := :NEW.MONTH01;
  new$MONTH02 PAYMENTSCHEDULE.MONTH02%TYPE := :NEW.MONTH02;
  new$MONTH03 PAYMENTSCHEDULE.MONTH03%TYPE := :NEW.MONTH03;
  new$MONTH04 PAYMENTSCHEDULE.MONTH04%TYPE := :NEW.MONTH04;
  new$MONTH05 PAYMENTSCHEDULE.MONTH05%TYPE := :NEW.MONTH05;
  new$MONTH06 PAYMENTSCHEDULE.MONTH06%TYPE := :NEW.MONTH06;
  new$MONTH07 PAYMENTSCHEDULE.MONTH07%TYPE := :NEW.MONTH07;
  new$MONTH08 PAYMENTSCHEDULE.MONTH08%TYPE := :NEW.MONTH08;
  new$MONTH09 PAYMENTSCHEDULE.MONTH09%TYPE := :NEW.MONTH09;
  new$MONTH10 PAYMENTSCHEDULE.MONTH10%TYPE := :NEW.MONTH10;
  new$MONTH11 PAYMENTSCHEDULE.MONTH11%TYPE := :NEW.MONTH11;
  new$MONTH12 PAYMENTSCHEDULE.MONTH12%TYPE := :NEW.MONTH12;
  new$SUMMA PAYMENTSCHEDULE.SUMMA%TYPE := :NEW.SUMMA;
  new$REGION PAYMENTSCHEDULE.REGION%TYPE := :NEW.REGION;
  new$SUBKESR PAYMENTSCHEDULE.SUBKESR%TYPE := :NEW.SUBKESR;
  new$MEANSTYPE PAYMENTSCHEDULE.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FINSOURCE PAYMENTSCHEDULE.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE PAYMENTSCHEDULE.FINTYPE%TYPE := :NEW.FINTYPE;
  new$FACT PAYMENTSCHEDULE.FACT%TYPE := :NEW.FACT;
  new$FACIALACC_CLS PAYMENTSCHEDULE.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$CREATERUSER PAYMENTSCHEDULE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYMENTSCHEDULE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PAYMENTSCHEDULE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PAYMENTSCHEDULE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF PAYMENTSCHEDULE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ACCEPTDATE PAYMENTSCHEDULE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$LASTADJUSTMENT PAYMENTSCHEDULE.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$ACCEPTED PAYMENTSCHEDULE.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED PAYMENTSCHEDULE.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$PROMISETYPE PAYMENTSCHEDULE.PROMISETYPE%TYPE := :NEW.PROMISETYPE;
  new$ADJUSTMENTREF PAYMENTSCHEDULE.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$OLDNUMBER PAYMENTSCHEDULE.OLDNUMBER%TYPE := :NEW.OLDNUMBER;
  new$SUMMAPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAPREVIOUSYEAR%TYPE := :NEW.SUMMAPREVIOUSYEAR;
  new$SUMMAFINPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAFINPREVIOUSYEAR%TYPE := :NEW.SUMMAFINPREVIOUSYEAR;
  new$QUARTER1 PAYMENTSCHEDULE.QUARTER1%TYPE := :NEW.QUARTER1;
  new$QUARTER2 PAYMENTSCHEDULE.QUARTER2%TYPE := :NEW.QUARTER2;
  new$QUARTER3 PAYMENTSCHEDULE.QUARTER3%TYPE := :NEW.QUARTER3;
  new$QUARTER4 PAYMENTSCHEDULE.QUARTER4%TYPE := :NEW.QUARTER4;
  new$RECORDINDEX PAYMENTSCHEDULE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CRYPTOSTATUS PAYMENTSCHEDULE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PAYMENTSCHEDULE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PAYMENTSCHEDULE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DIRECTIONCLS PAYMENTSCHEDULE.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$RVERSION PAYMENTSCHEDULE.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYMENTSCHEDULE.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MONTH01DELTA PAYMENTSCHEDULE.MONTH01DELTA%TYPE := :NEW.MONTH01DELTA;
  new$MONTH02DELTA PAYMENTSCHEDULE.MONTH02DELTA%TYPE := :NEW.MONTH02DELTA;
  new$MONTH03DELTA PAYMENTSCHEDULE.MONTH03DELTA%TYPE := :NEW.MONTH03DELTA;
  new$MONTH04DELTA PAYMENTSCHEDULE.MONTH04DELTA%TYPE := :NEW.MONTH04DELTA;
  new$MONTH05DELTA PAYMENTSCHEDULE.MONTH05DELTA%TYPE := :NEW.MONTH05DELTA;
  new$MONTH06DELTA PAYMENTSCHEDULE.MONTH06DELTA%TYPE := :NEW.MONTH06DELTA;
  new$MONTH07DELTA PAYMENTSCHEDULE.MONTH07DELTA%TYPE := :NEW.MONTH07DELTA;
  new$MONTH08DELTA PAYMENTSCHEDULE.MONTH08DELTA%TYPE := :NEW.MONTH08DELTA;
  new$MONTH09DELTA PAYMENTSCHEDULE.MONTH09DELTA%TYPE := :NEW.MONTH09DELTA;
  new$MONTH10DELTA PAYMENTSCHEDULE.MONTH10DELTA%TYPE := :NEW.MONTH10DELTA;
  new$MONTH11DELTA PAYMENTSCHEDULE.MONTH11DELTA%TYPE := :NEW.MONTH11DELTA;
  new$MONTH12DELTA PAYMENTSCHEDULE.MONTH12DELTA%TYPE := :NEW.MONTH12DELTA;
  new$QUARTER1DELTA PAYMENTSCHEDULE.QUARTER1DELTA%TYPE := :NEW.QUARTER1DELTA;
  new$QUARTER2DELTA PAYMENTSCHEDULE.QUARTER2DELTA%TYPE := :NEW.QUARTER2DELTA;
  new$QUARTER3DELTA PAYMENTSCHEDULE.QUARTER3DELTA%TYPE := :NEW.QUARTER3DELTA;
  new$QUARTER4DELTA PAYMENTSCHEDULE.QUARTER4DELTA%TYPE := :NEW.QUARTER4DELTA;
  new$SUMMADELTA PAYMENTSCHEDULE.SUMMADELTA%TYPE := :NEW.SUMMADELTA;
  new$NOTE PAYMENTSCHEDULE.NOTE%TYPE := :NEW.NOTE;
  new$FINYEAR PAYMENTSCHEDULE.FINYEAR%TYPE := :NEW.FINYEAR;
  new$SUMMAYEAR1 PAYMENTSCHEDULE.SUMMAYEAR1%TYPE := :NEW.SUMMAYEAR1;
  new$SUMMAYEAR2 PAYMENTSCHEDULE.SUMMAYEAR2%TYPE := :NEW.SUMMAYEAR2;
  new$SUMMAYEAR3 PAYMENTSCHEDULE.SUMMAYEAR3%TYPE := :NEW.SUMMAYEAR3;
  new$SUMMAYEAR1DELTA PAYMENTSCHEDULE.SUMMAYEAR1DELTA%TYPE := :NEW.SUMMAYEAR1DELTA;
  new$SUMMAYEAR2DELTA PAYMENTSCHEDULE.SUMMAYEAR2DELTA%TYPE := :NEW.SUMMAYEAR2DELTA;
  new$SUMMAYEAR3DELTA PAYMENTSCHEDULE.SUMMAYEAR3DELTA%TYPE := :NEW.SUMMAYEAR3DELTA;
  new$ASSIGNMENTKIND PAYMENTSCHEDULE.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$TRANSFERTCLS PAYMENTSCHEDULE.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SENDERIDKEY PAYMENTSCHEDULE.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY PAYMENTSCHEDULE.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXECUTIONREF PAYMENTSCHEDULE.EXECUTIONREF%TYPE := :NEW.EXECUTIONREF;
  new$INNERPROMISENUM PAYMENTSCHEDULE.INNERPROMISENUM%TYPE := :NEW.INNERPROMISENUM;
  new$ADJUSTMENTNUMBER PAYMENTSCHEDULE.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$PROMISENUMBER PAYMENTSCHEDULE.PROMISENUMBER%TYPE := :NEW.PROMISENUMBER;
  new$SUBSIDYCLS PAYMENTSCHEDULE.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$AGREEMENTREF PAYMENTSCHEDULE.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$BUDALLOCATIONCLS PAYMENTSCHEDULE.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS PAYMENTSCHEDULE.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$PROGINDEX PAYMENTSCHEDULE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$INVESTOBJECT PAYMENTSCHEDULE.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$SUMMAYEAR4 PAYMENTSCHEDULE.SUMMAYEAR4%TYPE := :NEW.SUMMAYEAR4;
  new$SUMMAOTHERYEARS PAYMENTSCHEDULE.SUMMAOTHERYEARS%TYPE := :NEW.SUMMAOTHERYEARS;
  new$SUMMAYEAR4DELTA PAYMENTSCHEDULE.SUMMAYEAR4DELTA%TYPE := :NEW.SUMMAYEAR4DELTA;
  new$SUMMAOTHERYEARSDELTA PAYMENTSCHEDULE.SUMMAOTHERYEARSDELTA%TYPE := :NEW.SUMMAOTHERYEARSDELTA;
  new$CONTRACTCOSTSCLS PAYMENTSCHEDULE.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS PAYMENTSCHEDULE.TARGETCLS%TYPE := :NEW.TARGETCLS;
--
  M01$ NUMBER;
  M02$ NUMBER;
  M03$ NUMBER;
  M04$ NUMBER;
  M05$ NUMBER;
  M06$ NUMBER;
  M07$ NUMBER;
  M08$ NUMBER;
  M09$ NUMBER;
  M10$ NUMBER;
  M11$ NUMBER;
  M12$ NUMBER;
  Q1$ NUMBER;
  Q2$ NUMBER;
  Q3$ NUMBER;
  Q4$ NUMBER;
  S$ NUMBER;
  S1$ NUMBER;
  S2$ NUMBER;
  S3$ NUMBER;
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  Tmp$ NUMBER(10);
  AdjID$ NUMBER(10);
  AdjDocNum$ NUMBER(10);
  InnerNumber_parent$ NUMBER(10);
  InnerNumber_child$ NUMBER(10);
  S4$ NUMBER;
  SOther$ NUMBER;
  PreviousInner$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_PAYMENTSCHEDULE_BI)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$Accepted is null) then 
    new$Accepted := 1;
  END IF;
  if (new$PromiseType is null) then 
    new$PromiseType := 0;
  END IF;
  if (new$KFSR is null) then 
    new$KFSR := 0;
  END IF;
  if (new$KESR is null) then 
    new$KESR := 0;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$KCSR is null) then 
    new$KCSR := 0;
  END IF;
  if (new$KVR is null) then 
    new$KVR := 0;
  END IF;
  if (new$SubKESR is null) then 
    new$SubKESR := 0;
  END IF;
  if (new$AssignmentKind is null) then 
    new$AssignmentKind := 0;
  END IF;
  if (new$DirectionCls is null) then 
    new$DirectionCls := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Region is null) then 
    new$Region := 0;
  END IF;
  if (new$MeansType is null) then 
    new$MeansType := 0;
  END IF;
  if (new$FinSource is null) then 
    new$FinSource := 0;
  END IF;
  if (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$Month01 is null) then 
    new$Month01 := 0;
  END IF;
  if (new$Month02 is null) then 
    new$Month02 := 0;
  END IF;
  if (new$Month03 is null) then 
    new$Month03 := 0;
  END IF;
  if (new$Month04 is null) then 
    new$Month04 := 0;
  END IF;
  if (new$Month05 is null) then 
    new$Month05 := 0;
  END IF;
  if (new$Month06 is null) then 
    new$Month06 := 0;
  END IF;
  if (new$Month07 is null) then 
    new$Month07 := 0;
  END IF;
  if (new$Month08 is null) then 
    new$Month08 := 0;
  END IF;
  if (new$Month09 is null) then 
    new$Month09 := 0;
  END IF;
  if (new$Month10 is null) then 
    new$Month10 := 0;
  END IF;
  if (new$Month11 is null) then 
    new$Month11 := 0;
  END IF;
  if (new$Month12 is null) then 
    new$Month12 := 0;
  END IF;
  if (new$Quarter1 is null) then 
    new$Quarter1 := 0;
  END IF;
  if (new$Quarter2 is null) then 
    new$Quarter2 := 0;
  END IF;
  if (new$Quarter3 is null) then 
    new$Quarter3 := 0;
  END IF;
  if (new$Quarter4 is null) then 
    new$Quarter4 := 0;
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$Month01Delta is null) then 
    new$Month01Delta := 0;
  END IF;
  if (new$Month02Delta is null) then 
    new$Month02Delta := 0;
  END IF;
  if (new$Month03Delta is null) then 
    new$Month03Delta := 0;
  END IF;
  if (new$Month04Delta is null) then 
    new$Month04Delta := 0;
  END IF;
  if (new$Month05Delta is null) then 
    new$Month05Delta := 0;
  END IF;
  if (new$Month06Delta is null) then 
    new$Month06Delta := 0;
  END IF;
  if (new$Month07Delta is null) then 
    new$Month07Delta := 0;
  END IF;
  if (new$Month08Delta is null) then 
    new$Month08Delta := 0;
  END IF;
  if (new$Month09Delta is null) then 
    new$Month09Delta := 0;
  END IF;
  if (new$Month10Delta is null) then 
    new$Month10Delta := 0;
  END IF;
  if (new$Month11Delta is null) then 
    new$Month11Delta := 0;
  END IF;
  if (new$Month12Delta is null) then 
    new$Month12Delta := 0;
  END IF;
  if (new$Quarter1Delta is null) then 
    new$Quarter1Delta := 0;
  END IF;
  if (new$Quarter2Delta is null) then 
    new$Quarter2Delta := 0;
  END IF;
  if (new$Quarter3Delta is null) then 
    new$Quarter3Delta := 0;
  END IF;
  if (new$Quarter4Delta is null) then 
    new$Quarter4Delta := 0;
  END IF;
  if (new$SummaDelta is null) then 
    new$SummaDelta := 0;
  END IF;
  if (new$SummaPreviousYear is null) then 
    new$SummaPreviousYear := 0;
  END IF;
  if (new$SummaFinPreviousYear is null) then 
    new$SummaFinPreviousYear := 0;
  END IF;
  if (new$SummaYear1 is null) then 
    new$SummaYear1 := 0;
  END IF;
  if (new$SummaYear2 is null) then 
    new$SummaYear2 := 0;
  END IF;
  if (new$SummaYear3 is null) then 
    new$SummaYear3 := 0;
  END IF;
  if (new$SummaYear4 is null) then 
    new$SummaYear4 := 0;
  END IF;
  if (new$SummaOtherYears is null) then 
    new$SummaOtherYears := 0;
  END IF;
  if (new$SummaYear1Delta is null) then 
    new$SummaYear1Delta := 0;
  END IF;
  if (new$SummaYear2Delta is null) then 
    new$SummaYear2Delta := 0;
  END IF;
  if (new$SummaYear3Delta is null) then 
    new$SummaYear3Delta := 0;
  END IF;
  if (new$SummaYear4Delta is null) then 
    new$SummaYear4Delta := 0;
  END IF;
  if (new$SummaOtherYearsDelta is null) then 
    new$SummaOtherYearsDelta := 0;
  END IF;
  /*   ,        */
  if (new$ProgIndex = 304 and new$RecordIndex is not null) then
    SELECT COUNT(*) INTO CNT$1
    from AgreementSteps s where (s.Id = new$RecordIndex and s.RecordIndex = new$AgreementRef) AND (ROWNUM = 1);
    if (not (CNT$1<> 0)) then
      RaiseException('Ex_WrongStep');
    END IF;
  END IF;
  /*       */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    if (new$ProgIndex in (304,314,317,318)) then
      BEGIN
        select a.BudgetRef       into new$BudgetRef from Agreements a
        where a.ID = new$AgreementRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    else 
      if (new$ProgIndex = 308) then
        BEGIN
          select e.BudgetRef
          into new$BudgetRef       from ExecutionDocumentsCaption e
          where e.ID = new$ExecutionRef
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
      END IF;
    END IF;
  END IF;
        
  /*    ,     ,      */
  if (new$AdjustmentRef is null) then
    select g_shared.nextval into new$InnerPromiseNum from dual;
  else
    /*      , ..     */
    if (new$Accepted = 0) then
      BEGIN
        select
        InnerPromiseNum 
        into PreviousInner$       from Paymentschedule
        where ID = new$AdjustmentRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    else
      BEGIN
        /*          */
        select
        InnerPromiseNum 
        into PreviousInner$       from Paymentschedule
        where ID = new$AdjustmentRef and LastAccepted = 1 and LastAdjustment = 1
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (PreviousInner$ is null) then
        RaiseException('EX_NotFindInnerNumber');    
      END IF;
    END IF;
    new$InnerPromiseNum := PreviousInner$;
      
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$ANumber is not null) then
    SELECT COUNT(                    id
    ) INTO CNT$2
    from
    PaymentSchedule ps
    where
    (                    (ps.ANumber = new$ANumber)
    and
    (ps.BudgetRef = new$BudgetRef)) AND (ROWNUM = 1);
    if ((CNT$2<> 0)) then
      RaiseException('ex_Promise_NumUQ');
    END IF;
  END IF;
  /*    */
  GETTARGETCLS(null, new$transfertcls, null, new$meanstype,
  new$targetcls,new$targetcls);     

-- - - - - - - - - - - - -
-- BI_1 (TR_PAYMENTSCHEDULE_BI_1)
-- Create 05.03.2004
-- Last update 29.12.2007
-- - - - - - - - - - - - -

/*   1.0*/
    if (new$Quarter1 = 0) then new$Quarter1 := new$Month01 + new$Month02 + new$Month03; end if;
    if (new$Quarter2 = 0) then new$Quarter2 := new$Month04 + new$Month05 + new$Month06; end if;
    if (new$Quarter3 = 0) then new$Quarter3 := new$Month07 + new$Month08 + new$Month09; end if;
    if (new$Quarter4 = 0) then new$Quarter4 := new$Month10 + new$Month11 + new$Month12; end if;
    new$SummaYear1 := new$Quarter1 + new$Quarter2 + new$Quarter3 + new$Quarter4;

-- - - - - - - - - - - - -
-- BI_10 (TR_PAYMENTSCHEDULE_BI_10)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   5.0*/

  /*    .*/
  if (new$InnerPromiseNum is null) then
    RaiseException('EX_BP_InnerNumsIsNull');
  END IF;

  /*    */
  select max(AdjustmentNumber)
  into Tmp$         from PaymentSchedule
  where (InnerPromiseNum = new$InnerPromiseNum)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;

  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;

  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;

  else
    new$LastAdjustment := 1;
  END IF;

  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then
    new$LastAccepted := 1;

  else
    new$LastAccepted := 0;
  END IF;
  /*    */
  if (new$AdjustmentNumber > 0) then
    /*      -    */
    select count(ID), max(ID), max(ANumber)
    into Tmp$, AdjID$, AdjDocNum$             from PaymentSchedule
    where (InnerPromiseNum = new$InnerPromiseNum) and (LastAccepted = 1)
    ;
    /*   ,  */
    if (Tmp$ <> 1) then
      RaiseException('EX_BP_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID)
    into Tmp$             from PaymentSchedule
    where (InnerPromiseNum = new$InnerPromiseNum) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then
      RaiseException('EX_BP_AdjustDuplicate');
    END IF;
    /* ,    ,    */
    new$AdjustmentRef := AdjID$;
    new$ParentNumber := AdjDocNum$;
    /*   - ,  ,       */
    if (new$ProgIndex in (304, 314)) then
      BEGIN
        /*     */
        select a.InnerNumber
        into InnerNumber_child$             from Agreements a
        where a.ID = new$AgreementRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN
        /*       */
        select a.InnerNumber
        into InnerNumber_parent$             from PaymentSchedule ps
        left join Agreements a on (a.Id = ps.AgreementRef)
        where (ps.Id = new$AdjustmentRef)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*      */
      if (InnerNumber_parent$ <> InnerNumber_child$) then
        RaiseException('EX_PROMISE_ADJ_INCORRECT');
      END IF;
    else
      if (new$ProgIndex = 308) then
        BEGIN
          /*     */
          select edc.InnerNumber
          into InnerNumber_child$             from ExecutionDocumentsCaption edc
          where edc.ID = new$ExecutionRef
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        BEGIN
          /*       */
          select edc.InnerNumber
          into InnerNumber_parent$             from PaymentSchedule ps
          left join ExecutionDocumentsCaption edc on (edc.id=ps.ExecutionRef)
          where (ps.Id = new$AdjustmentRef)
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        /*      */
        if (InnerNumber_parent$ <> InnerNumber_child$) then
          RaiseException('EX_PROMISE_ADJ_INCORRECT');
        END IF;
      END IF;
    END IF;
  else /*     */
    /*       (    )*/
    new$AdjustmentRef := null;
    new$ParentNumber := null;

  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_PAYMENTSCHEDULE_BI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*           */
  if (new$AdjustmentNumber > 0) then
    BEGIN
      select
      Month01, Month02, Month03, Month04, Month05, Month06,
      Month07, Month08, Month09, Month10, Month11, Month12,
      Quarter1, Quarter2, Quarter3, Quarter4, Summa,
      SummaYear1, SummaYear2, SummaYear3, SummaYear4, SummaOtherYears
      into
      M01$, M02$, M03$, M04$, M05$, M06$, M07$, M08$, M09$, M10$, M11$, M12$,
      Q1$, Q2$, Q3$, Q4$, S$, S1$, S2$, S3$, S4$, SOther$         from
      PaymentSchedule
      where
      ID = new$AdjustmentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    new$Month01Delta := new$Month01 - M01$;
    new$Month02Delta := new$Month02 - M02$;
    new$Month03Delta := new$Month03 - M03$;
    new$Month04Delta := new$Month04 - M04$;
    new$Month05Delta := new$Month05 - M05$;
    new$Month06Delta := new$Month06 - M06$;
    new$Month07Delta := new$Month07 - M07$;
    new$Month08Delta := new$Month08 - M08$;
    new$Month09Delta := new$Month09 - M09$;
    new$Month10Delta := new$Month10 - M10$;
    new$Month11Delta := new$Month11 - M11$;
    new$Month12Delta := new$Month12 - M12$;
    new$Quarter1Delta := new$Quarter1 - Q1$;
    new$Quarter2Delta := new$Quarter2 - Q2$;
    new$Quarter3Delta := new$Quarter3 - Q3$;
    new$Quarter4Delta := new$Quarter4 - Q4$;
    new$SummaDelta := new$Summa - S$;
    new$SummaYear1Delta := new$SummaYear1 - S1$;
    new$SummaYear2Delta := new$SummaYear2 - S2$;
    new$SummaYear3Delta := new$SummaYear3 - S3$;
    new$SummaYear4Delta := new$SummaYear4 - S4$;
    new$SummaOtherYearsDelta := new$SummaOtherYears - SOther$;

  else    /*        */
    new$Month01Delta := new$Month01;
    new$Month02Delta := new$Month02;
    new$Month03Delta := new$Month03;
    new$Month04Delta := new$Month04;
    new$Month05Delta := new$Month05;
    new$Month06Delta := new$Month06;
    new$Month07Delta := new$Month07;
    new$Month08Delta := new$Month08;
    new$Month09Delta := new$Month09;
    new$Month10Delta := new$Month10;
    new$Month11Delta := new$Month11;
    new$Month12Delta := new$Month12;
    new$Quarter1Delta := new$Quarter1;
    new$Quarter2Delta := new$Quarter2;
    new$Quarter3Delta := new$Quarter3;
    new$Quarter4Delta := new$Quarter4;
    new$SummaDelta := new$Summa;
    new$SummaYear1Delta := new$SummaYear1;
    new$SummaYear2Delta := new$SummaYear2;
    new$SummaYear3Delta := new$SummaYear3;
    new$SummaYear4Delta := new$SummaYear4;
    new$SummaOtherYearsDelta := new$SummaOtherYears;

  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_PAYMENTSCHEDULE_BI_200)
-- Create 06.08.2010
-- - - - - - - - - - - - -

  /*      */
  if (new$senderId is null) then
    new$senderIdKey := -1;
  else
    new$senderIdKey := new$senderId;
  end if;

  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  end if;

-- - - - - - - - - - - - -
-- BI_500 (TR_PAYMENTSCHEDULE_BI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_PAYMENTSCHEDULE (
    ID,
    ANUMBER,
    PARENTNUMBER,
    KFSR,
    KESR,
    KVSR,
    KCSR,
    KVR,
    MONTH01,
    MONTH02,
    MONTH03,
    MONTH04,
    MONTH05,
    MONTH06,
    MONTH07,
    MONTH08,
    MONTH09,
    MONTH10,
    MONTH11,
    MONTH12,
    SUMMA,
    REGION,
    SUBKESR,
    MEANSTYPE,
    FINSOURCE,
    FINTYPE,
    FACT,
    FACIALACC_CLS,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    ACCEPTDATE,
    LASTADJUSTMENT,
    ACCEPTED,
    LASTACCEPTED,
    PROMISETYPE,
    ADJUSTMENTREF,
    OLDNUMBER,
    SUMMAPREVIOUSYEAR,
    SUMMAFINPREVIOUSYEAR,
    QUARTER1,
    QUARTER2,
    QUARTER3,
    QUARTER4,
    RECORDINDEX,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DIRECTIONCLS,
    RVERSION,
    BUHOPERATIONCLS,
    MONTH01DELTA,
    MONTH02DELTA,
    MONTH03DELTA,
    MONTH04DELTA,
    MONTH05DELTA,
    MONTH06DELTA,
    MONTH07DELTA,
    MONTH08DELTA,
    MONTH09DELTA,
    MONTH10DELTA,
    MONTH11DELTA,
    MONTH12DELTA,
    QUARTER1DELTA,
    QUARTER2DELTA,
    QUARTER3DELTA,
    QUARTER4DELTA,
    SUMMADELTA,
    NOTE,
    FINYEAR,
    SUMMAYEAR1,
    SUMMAYEAR2,
    SUMMAYEAR3,
    SUMMAYEAR1DELTA,
    SUMMAYEAR2DELTA,
    SUMMAYEAR3DELTA,
    ASSIGNMENTKIND,
    TRANSFERTCLS,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    EXECUTIONREF,
    INNERPROMISENUM,
    ADJUSTMENTNUMBER,
    PROMISENUMBER,
    SUBSIDYCLS,
    AGREEMENTREF,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    PROGINDEX,
    INVESTOBJECT,
    SUMMAYEAR4,
    SUMMAOTHERYEARS,
    SUMMAYEAR4DELTA,
    SUMMAOTHERYEARSDELTA,
    CONTRACTCOSTSCLS,
    TARGETCLS
  ) VALUES (
    new$ID,
    new$ANUMBER,
    new$PARENTNUMBER,
    new$KFSR,
    new$KESR,
    new$KVSR,
    new$KCSR,
    new$KVR,
    new$MONTH01,
    new$MONTH02,
    new$MONTH03,
    new$MONTH04,
    new$MONTH05,
    new$MONTH06,
    new$MONTH07,
    new$MONTH08,
    new$MONTH09,
    new$MONTH10,
    new$MONTH11,
    new$MONTH12,
    new$SUMMA,
    new$REGION,
    new$SUBKESR,
    new$MEANSTYPE,
    new$FINSOURCE,
    new$FINTYPE,
    new$FACT,
    new$FACIALACC_CLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$ACCEPTDATE,
    new$LASTADJUSTMENT,
    new$ACCEPTED,
    new$LASTACCEPTED,
    new$PROMISETYPE,
    new$ADJUSTMENTREF,
    new$OLDNUMBER,
    new$SUMMAPREVIOUSYEAR,
    new$SUMMAFINPREVIOUSYEAR,
    new$QUARTER1,
    new$QUARTER2,
    new$QUARTER3,
    new$QUARTER4,
    new$RECORDINDEX,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$DIRECTIONCLS,
    new$RVERSION,
    new$BUHOPERATIONCLS,
    new$MONTH01DELTA,
    new$MONTH02DELTA,
    new$MONTH03DELTA,
    new$MONTH04DELTA,
    new$MONTH05DELTA,
    new$MONTH06DELTA,
    new$MONTH07DELTA,
    new$MONTH08DELTA,
    new$MONTH09DELTA,
    new$MONTH10DELTA,
    new$MONTH11DELTA,
    new$MONTH12DELTA,
    new$QUARTER1DELTA,
    new$QUARTER2DELTA,
    new$QUARTER3DELTA,
    new$QUARTER4DELTA,
    new$SUMMADELTA,
    new$NOTE,
    new$FINYEAR,
    new$SUMMAYEAR1,
    new$SUMMAYEAR2,
    new$SUMMAYEAR3,
    new$SUMMAYEAR1DELTA,
    new$SUMMAYEAR2DELTA,
    new$SUMMAYEAR3DELTA,
    new$ASSIGNMENTKIND,
    new$TRANSFERTCLS,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$EXECUTIONREF,
    new$INNERPROMISENUM,
    new$ADJUSTMENTNUMBER,
    new$PROMISENUMBER,
    new$SUBSIDYCLS,
    new$AGREEMENTREF,
    new$BUDALLOCATIONCLS,
    new$PAYPROMISECLS,
    new$PROGINDEX,
    new$INVESTOBJECT,
    new$SUMMAYEAR4,
    new$SUMMAOTHERYEARS,
    new$SUMMAYEAR4DELTA,
    new$SUMMAOTHERYEARSDELTA,
    new$CONTRACTCOSTSCLS,
    new$TARGETCLS);

-- - - - - - - - - - - - -
-- AI_10 (TR_PAYMENTSCHEDULE_AI_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  /*      */
  if ((new$AdjustmentNumber > 0) and (new$LastAdjustment = 1)) then
    update PaymentSchedule set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);
    if (new$LastAccepted = 1) then
      update PaymentSchedule set
      LastAccepted = 0,
      RVersion = -1
      where (ID = new$AdjustmentRef);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_PAYMENTSCHEDULE_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 113) and (RecordID = new$ID);

END;
/
-- CREATE TRIGGER TR_PAYMENTSCHEDULE_BI_10
CREATE OR REPLACE TRIGGER TR_PAYMENTSCHEDULE_II
  INSTEAD OF INSERT
  ON PAYMENTSCHEDULE
  FOR EACH ROW
DECLARE
  new$ID PAYMENTSCHEDULE.ID%TYPE := :NEW.ID;
  new$ANUMBER PAYMENTSCHEDULE.ANUMBER%TYPE := :NEW.ANUMBER;
  new$PARENTNUMBER PAYMENTSCHEDULE.PARENTNUMBER%TYPE := :NEW.PARENTNUMBER;
  new$KFSR PAYMENTSCHEDULE.KFSR%TYPE := :NEW.KFSR;
  new$KESR PAYMENTSCHEDULE.KESR%TYPE := :NEW.KESR;
  new$KVSR PAYMENTSCHEDULE.KVSR%TYPE := :NEW.KVSR;
  new$KCSR PAYMENTSCHEDULE.KCSR%TYPE := :NEW.KCSR;
  new$KVR PAYMENTSCHEDULE.KVR%TYPE := :NEW.KVR;
  new$MONTH01 PAYMENTSCHEDULE.MONTH01%TYPE := :NEW.MONTH01;
  new$MONTH02 PAYMENTSCHEDULE.MONTH02%TYPE := :NEW.MONTH02;
  new$MONTH03 PAYMENTSCHEDULE.MONTH03%TYPE := :NEW.MONTH03;
  new$MONTH04 PAYMENTSCHEDULE.MONTH04%TYPE := :NEW.MONTH04;
  new$MONTH05 PAYMENTSCHEDULE.MONTH05%TYPE := :NEW.MONTH05;
  new$MONTH06 PAYMENTSCHEDULE.MONTH06%TYPE := :NEW.MONTH06;
  new$MONTH07 PAYMENTSCHEDULE.MONTH07%TYPE := :NEW.MONTH07;
  new$MONTH08 PAYMENTSCHEDULE.MONTH08%TYPE := :NEW.MONTH08;
  new$MONTH09 PAYMENTSCHEDULE.MONTH09%TYPE := :NEW.MONTH09;
  new$MONTH10 PAYMENTSCHEDULE.MONTH10%TYPE := :NEW.MONTH10;
  new$MONTH11 PAYMENTSCHEDULE.MONTH11%TYPE := :NEW.MONTH11;
  new$MONTH12 PAYMENTSCHEDULE.MONTH12%TYPE := :NEW.MONTH12;
  new$SUMMA PAYMENTSCHEDULE.SUMMA%TYPE := :NEW.SUMMA;
  new$REGION PAYMENTSCHEDULE.REGION%TYPE := :NEW.REGION;
  new$SUBKESR PAYMENTSCHEDULE.SUBKESR%TYPE := :NEW.SUBKESR;
  new$MEANSTYPE PAYMENTSCHEDULE.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FINSOURCE PAYMENTSCHEDULE.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE PAYMENTSCHEDULE.FINTYPE%TYPE := :NEW.FINTYPE;
  new$FACT PAYMENTSCHEDULE.FACT%TYPE := :NEW.FACT;
  new$FACIALACC_CLS PAYMENTSCHEDULE.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$CREATERUSER PAYMENTSCHEDULE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYMENTSCHEDULE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PAYMENTSCHEDULE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PAYMENTSCHEDULE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF PAYMENTSCHEDULE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ACCEPTDATE PAYMENTSCHEDULE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$LASTADJUSTMENT PAYMENTSCHEDULE.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$ACCEPTED PAYMENTSCHEDULE.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED PAYMENTSCHEDULE.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$PROMISETYPE PAYMENTSCHEDULE.PROMISETYPE%TYPE := :NEW.PROMISETYPE;
  new$ADJUSTMENTREF PAYMENTSCHEDULE.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$OLDNUMBER PAYMENTSCHEDULE.OLDNUMBER%TYPE := :NEW.OLDNUMBER;
  new$SUMMAPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAPREVIOUSYEAR%TYPE := :NEW.SUMMAPREVIOUSYEAR;
  new$SUMMAFINPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAFINPREVIOUSYEAR%TYPE := :NEW.SUMMAFINPREVIOUSYEAR;
  new$QUARTER1 PAYMENTSCHEDULE.QUARTER1%TYPE := :NEW.QUARTER1;
  new$QUARTER2 PAYMENTSCHEDULE.QUARTER2%TYPE := :NEW.QUARTER2;
  new$QUARTER3 PAYMENTSCHEDULE.QUARTER3%TYPE := :NEW.QUARTER3;
  new$QUARTER4 PAYMENTSCHEDULE.QUARTER4%TYPE := :NEW.QUARTER4;
  new$RECORDINDEX PAYMENTSCHEDULE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CRYPTOSTATUS PAYMENTSCHEDULE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PAYMENTSCHEDULE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PAYMENTSCHEDULE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DIRECTIONCLS PAYMENTSCHEDULE.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$RVERSION PAYMENTSCHEDULE.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYMENTSCHEDULE.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MONTH01DELTA PAYMENTSCHEDULE.MONTH01DELTA%TYPE := :NEW.MONTH01DELTA;
  new$MONTH02DELTA PAYMENTSCHEDULE.MONTH02DELTA%TYPE := :NEW.MONTH02DELTA;
  new$MONTH03DELTA PAYMENTSCHEDULE.MONTH03DELTA%TYPE := :NEW.MONTH03DELTA;
  new$MONTH04DELTA PAYMENTSCHEDULE.MONTH04DELTA%TYPE := :NEW.MONTH04DELTA;
  new$MONTH05DELTA PAYMENTSCHEDULE.MONTH05DELTA%TYPE := :NEW.MONTH05DELTA;
  new$MONTH06DELTA PAYMENTSCHEDULE.MONTH06DELTA%TYPE := :NEW.MONTH06DELTA;
  new$MONTH07DELTA PAYMENTSCHEDULE.MONTH07DELTA%TYPE := :NEW.MONTH07DELTA;
  new$MONTH08DELTA PAYMENTSCHEDULE.MONTH08DELTA%TYPE := :NEW.MONTH08DELTA;
  new$MONTH09DELTA PAYMENTSCHEDULE.MONTH09DELTA%TYPE := :NEW.MONTH09DELTA;
  new$MONTH10DELTA PAYMENTSCHEDULE.MONTH10DELTA%TYPE := :NEW.MONTH10DELTA;
  new$MONTH11DELTA PAYMENTSCHEDULE.MONTH11DELTA%TYPE := :NEW.MONTH11DELTA;
  new$MONTH12DELTA PAYMENTSCHEDULE.MONTH12DELTA%TYPE := :NEW.MONTH12DELTA;
  new$QUARTER1DELTA PAYMENTSCHEDULE.QUARTER1DELTA%TYPE := :NEW.QUARTER1DELTA;
  new$QUARTER2DELTA PAYMENTSCHEDULE.QUARTER2DELTA%TYPE := :NEW.QUARTER2DELTA;
  new$QUARTER3DELTA PAYMENTSCHEDULE.QUARTER3DELTA%TYPE := :NEW.QUARTER3DELTA;
  new$QUARTER4DELTA PAYMENTSCHEDULE.QUARTER4DELTA%TYPE := :NEW.QUARTER4DELTA;
  new$SUMMADELTA PAYMENTSCHEDULE.SUMMADELTA%TYPE := :NEW.SUMMADELTA;
  new$NOTE PAYMENTSCHEDULE.NOTE%TYPE := :NEW.NOTE;
  new$FINYEAR PAYMENTSCHEDULE.FINYEAR%TYPE := :NEW.FINYEAR;
  new$SUMMAYEAR1 PAYMENTSCHEDULE.SUMMAYEAR1%TYPE := :NEW.SUMMAYEAR1;
  new$SUMMAYEAR2 PAYMENTSCHEDULE.SUMMAYEAR2%TYPE := :NEW.SUMMAYEAR2;
  new$SUMMAYEAR3 PAYMENTSCHEDULE.SUMMAYEAR3%TYPE := :NEW.SUMMAYEAR3;
  new$SUMMAYEAR1DELTA PAYMENTSCHEDULE.SUMMAYEAR1DELTA%TYPE := :NEW.SUMMAYEAR1DELTA;
  new$SUMMAYEAR2DELTA PAYMENTSCHEDULE.SUMMAYEAR2DELTA%TYPE := :NEW.SUMMAYEAR2DELTA;
  new$SUMMAYEAR3DELTA PAYMENTSCHEDULE.SUMMAYEAR3DELTA%TYPE := :NEW.SUMMAYEAR3DELTA;
  new$ASSIGNMENTKIND PAYMENTSCHEDULE.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$TRANSFERTCLS PAYMENTSCHEDULE.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SENDERIDKEY PAYMENTSCHEDULE.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY PAYMENTSCHEDULE.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXECUTIONREF PAYMENTSCHEDULE.EXECUTIONREF%TYPE := :NEW.EXECUTIONREF;
  new$INNERPROMISENUM PAYMENTSCHEDULE.INNERPROMISENUM%TYPE := :NEW.INNERPROMISENUM;
  new$ADJUSTMENTNUMBER PAYMENTSCHEDULE.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$PROMISENUMBER PAYMENTSCHEDULE.PROMISENUMBER%TYPE := :NEW.PROMISENUMBER;
  new$SUBSIDYCLS PAYMENTSCHEDULE.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$AGREEMENTREF PAYMENTSCHEDULE.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$BUDALLOCATIONCLS PAYMENTSCHEDULE.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS PAYMENTSCHEDULE.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$PROGINDEX PAYMENTSCHEDULE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$INVESTOBJECT PAYMENTSCHEDULE.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$SUMMAYEAR4 PAYMENTSCHEDULE.SUMMAYEAR4%TYPE := :NEW.SUMMAYEAR4;
  new$SUMMAOTHERYEARS PAYMENTSCHEDULE.SUMMAOTHERYEARS%TYPE := :NEW.SUMMAOTHERYEARS;
  new$SUMMAYEAR4DELTA PAYMENTSCHEDULE.SUMMAYEAR4DELTA%TYPE := :NEW.SUMMAYEAR4DELTA;
  new$SUMMAOTHERYEARSDELTA PAYMENTSCHEDULE.SUMMAOTHERYEARSDELTA%TYPE := :NEW.SUMMAOTHERYEARSDELTA;
  new$CONTRACTCOSTSCLS PAYMENTSCHEDULE.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS PAYMENTSCHEDULE.TARGETCLS%TYPE := :NEW.TARGETCLS;
--
  M01$ NUMBER;
  M02$ NUMBER;
  M03$ NUMBER;
  M04$ NUMBER;
  M05$ NUMBER;
  M06$ NUMBER;
  M07$ NUMBER;
  M08$ NUMBER;
  M09$ NUMBER;
  M10$ NUMBER;
  M11$ NUMBER;
  M12$ NUMBER;
  Q1$ NUMBER;
  Q2$ NUMBER;
  Q3$ NUMBER;
  Q4$ NUMBER;
  S$ NUMBER;
  S1$ NUMBER;
  S2$ NUMBER;
  S3$ NUMBER;
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  S4$ NUMBER;
  SOther$ NUMBER;
  PreviousInner$ NUMBER(10);
  Tmp1$ NUMBER(10);
  AdjDocNum1$ NUMBER(10);
  InnerNumber_parent1$ NUMBER(10);
  InnerNumber_child1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_PAYMENTSCHEDULE_BI)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$Accepted is null) then 
    new$Accepted := 1;
  END IF;
  if (new$PromiseType is null) then 
    new$PromiseType := 0;
  END IF;
  if (new$KFSR is null) then 
    new$KFSR := 0;
  END IF;
  if (new$KESR is null) then 
    new$KESR := 0;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$KCSR is null) then 
    new$KCSR := 0;
  END IF;
  if (new$KVR is null) then 
    new$KVR := 0;
  END IF;
  if (new$SubKESR is null) then 
    new$SubKESR := 0;
  END IF;
  if (new$AssignmentKind is null) then 
    new$AssignmentKind := 0;
  END IF;
  if (new$DirectionCls is null) then 
    new$DirectionCls := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Region is null) then 
    new$Region := 0;
  END IF;
  if (new$MeansType is null) then 
    new$MeansType := 0;
  END IF;
  if (new$FinSource is null) then 
    new$FinSource := 0;
  END IF;
  if (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$Month01 is null) then 
    new$Month01 := 0;
  END IF;
  if (new$Month02 is null) then 
    new$Month02 := 0;
  END IF;
  if (new$Month03 is null) then 
    new$Month03 := 0;
  END IF;
  if (new$Month04 is null) then 
    new$Month04 := 0;
  END IF;
  if (new$Month05 is null) then 
    new$Month05 := 0;
  END IF;
  if (new$Month06 is null) then 
    new$Month06 := 0;
  END IF;
  if (new$Month07 is null) then 
    new$Month07 := 0;
  END IF;
  if (new$Month08 is null) then 
    new$Month08 := 0;
  END IF;
  if (new$Month09 is null) then 
    new$Month09 := 0;
  END IF;
  if (new$Month10 is null) then 
    new$Month10 := 0;
  END IF;
  if (new$Month11 is null) then 
    new$Month11 := 0;
  END IF;
  if (new$Month12 is null) then 
    new$Month12 := 0;
  END IF;
  if (new$Quarter1 is null) then 
    new$Quarter1 := 0;
  END IF;
  if (new$Quarter2 is null) then 
    new$Quarter2 := 0;
  END IF;
  if (new$Quarter3 is null) then 
    new$Quarter3 := 0;
  END IF;
  if (new$Quarter4 is null) then 
    new$Quarter4 := 0;
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$Month01Delta is null) then 
    new$Month01Delta := 0;
  END IF;
  if (new$Month02Delta is null) then 
    new$Month02Delta := 0;
  END IF;
  if (new$Month03Delta is null) then 
    new$Month03Delta := 0;
  END IF;
  if (new$Month04Delta is null) then 
    new$Month04Delta := 0;
  END IF;
  if (new$Month05Delta is null) then 
    new$Month05Delta := 0;
  END IF;
  if (new$Month06Delta is null) then 
    new$Month06Delta := 0;
  END IF;
  if (new$Month07Delta is null) then 
    new$Month07Delta := 0;
  END IF;
  if (new$Month08Delta is null) then 
    new$Month08Delta := 0;
  END IF;
  if (new$Month09Delta is null) then 
    new$Month09Delta := 0;
  END IF;
  if (new$Month10Delta is null) then 
    new$Month10Delta := 0;
  END IF;
  if (new$Month11Delta is null) then 
    new$Month11Delta := 0;
  END IF;
  if (new$Month12Delta is null) then 
    new$Month12Delta := 0;
  END IF;
  if (new$Quarter1Delta is null) then 
    new$Quarter1Delta := 0;
  END IF;
  if (new$Quarter2Delta is null) then 
    new$Quarter2Delta := 0;
  END IF;
  if (new$Quarter3Delta is null) then 
    new$Quarter3Delta := 0;
  END IF;
  if (new$Quarter4Delta is null) then 
    new$Quarter4Delta := 0;
  END IF;
  if (new$SummaDelta is null) then 
    new$SummaDelta := 0;
  END IF;
  if (new$SummaPreviousYear is null) then 
    new$SummaPreviousYear := 0;
  END IF;
  if (new$SummaFinPreviousYear is null) then 
    new$SummaFinPreviousYear := 0;
  END IF;
  if (new$SummaYear1 is null) then 
    new$SummaYear1 := 0;
  END IF;
  if (new$SummaYear2 is null) then 
    new$SummaYear2 := 0;
  END IF;
  if (new$SummaYear3 is null) then 
    new$SummaYear3 := 0;
  END IF;
  if (new$SummaYear4 is null) then 
    new$SummaYear4 := 0;
  END IF;
  if (new$SummaOtherYears is null) then 
    new$SummaOtherYears := 0;
  END IF;
  if (new$SummaYear1Delta is null) then 
    new$SummaYear1Delta := 0;
  END IF;
  if (new$SummaYear2Delta is null) then 
    new$SummaYear2Delta := 0;
  END IF;
  if (new$SummaYear3Delta is null) then 
    new$SummaYear3Delta := 0;
  END IF;
  if (new$SummaYear4Delta is null) then 
    new$SummaYear4Delta := 0;
  END IF;
  if (new$SummaOtherYearsDelta is null) then 
    new$SummaOtherYearsDelta := 0;
  END IF;
  /*   ,        */
  if (new$ProgIndex = 304 and new$RecordIndex is not null) then
    SELECT COUNT(*) INTO CNT$1
    from AgreementSteps s where (s.Id = new$RecordIndex and s.RecordIndex = new$AgreementRef) AND (ROWNUM = 1);
    if (not (CNT$1<> 0)) then
      RaiseException('Ex_WrongStep');
    END IF;
  END IF;
  /*       */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    if (new$ProgIndex in (304,314,317,318)) then
      BEGIN
        select a.BudgetRef       into new$BudgetRef from Agreements a
        where a.ID = new$AgreementRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    else 
      if (new$ProgIndex = 308) then
        BEGIN
          select e.BudgetRef
          into new$BudgetRef       from ExecutionDocumentsCaption e
          where e.ID = new$ExecutionRef
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
      END IF;
    END IF;
  END IF;
        
  /*    ,     ,      */
  if (new$AdjustmentRef is null) then
    select g_shared.nextval into new$InnerPromiseNum from dual;
  else
    /*      , ..     */
    if (new$Accepted = 0) then
      BEGIN
        select
        InnerPromiseNum 
        into PreviousInner$       from Paymentschedule
        where ID = new$AdjustmentRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    else
      BEGIN
        /*          */
        select
        InnerPromiseNum 
        into PreviousInner$       from Paymentschedule
        where ID = new$AdjustmentRef and LastAccepted = 1 and LastAdjustment = 1
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (PreviousInner$ is null) then
        RaiseException('EX_NotFindInnerNumber');    
      END IF;
    END IF;
    new$InnerPromiseNum := PreviousInner$;
      
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$ANumber is not null) then
    SELECT COUNT(                    id
    ) INTO CNT$2
    from
    PaymentSchedule ps
    where
    (                    (ps.ANumber = new$ANumber)
    and
    (ps.BudgetRef = new$BudgetRef)) AND (ROWNUM = 1);
    if ((CNT$2<> 0)) then
      RaiseException('ex_Promise_NumUQ');
    END IF;
  END IF;
  /*    */
  GETTARGETCLS(null, new$transfertcls, null, new$meanstype,
  new$targetcls,new$targetcls);     

-- - - - - - - - - - - - -
-- BI_1 (TR_PAYMENTSCHEDULE_BI_1)
-- Create 05.03.2004
-- Last update 29.12.2007
-- - - - - - - - - - - - -

/*   1.0*/
    if (new$Quarter1 = 0) then new$Quarter1 := new$Month01 + new$Month02 + new$Month03; end if;
    if (new$Quarter2 = 0) then new$Quarter2 := new$Month04 + new$Month05 + new$Month06; end if;
    if (new$Quarter3 = 0) then new$Quarter3 := new$Month07 + new$Month08 + new$Month09; end if;
    if (new$Quarter4 = 0) then new$Quarter4 := new$Month10 + new$Month11 + new$Month12; end if;
    new$SummaYear1 := new$Quarter1 + new$Quarter2 + new$Quarter3 + new$Quarter4;

-- - - - - - - - - - - - -
-- BI_10 (TR_PAYMENTSCHEDULE_BI_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
     
  /*    .*/
  if (new$InnerPromiseNum is null) then
    RaiseException('EX_BP_InnerNumsIsNull');
  END IF;
      
  /*    */
  select max(AdjustmentNumber)
  into Tmp1$         from PaymentSchedule 
  where (InnerPromiseNum = new$InnerPromiseNum)
  ;
  /*      ,   0*/
  if (Tmp1$ is null) then
    new$AdjustmentNumber := 0;
        
  else
    new$AdjustmentNumber := Tmp1$ + 1;
  END IF;
      
  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;
        
  else
    new$LastAdjustment := 1;
  END IF;
      
  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then 
    new$LastAccepted := 1;
        
  else
    new$LastAccepted := 0;
  END IF;
  /*     */
  if (new$AdjustmentRef is null) then
    /*       (    )*/        
    new$ParentNumber := null;
        
  else
    /*      -    */
    select count(ID), max(ANumber)
    into Tmp1$, AdjDocNum1$             from PaymentSchedule
    where (InnerPromiseNum = new$InnerPromiseNum) and (AcceptDate is not null)
    ;
    /*     ,  */    
    if (Tmp1$ = 0) then 
      RaiseException('EX_BP_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID) 
    into Tmp1$             from PaymentSchedule
    where (InnerPromiseNum = new$InnerPromiseNum) and (AcceptDate is null)
    ;
    if (Tmp1$ > 0) then 
      RaiseException('EX_BP_AdjustDuplicate');
    END IF;
    /* ,    ,    */        
    new$ParentNumber := AdjDocNum1$;
    /*   - ,  ,       */
    if (new$ProgIndex in (304, 314)) then
      BEGIN
        /*     */
        select a.InnerNumber
        into InnerNumber_child1$             from Agreements a
        where a.ID = new$AgreementRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN
        /*       */
        select a.InnerNumber
        into InnerNumber_parent1$             from PaymentSchedule ps
        left join Agreements a on (a.Id = ps.AgreementRef)
        where (ps.Id = new$AdjustmentRef)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*      */
      if (InnerNumber_parent1$ <> InnerNumber_child1$) then
        RaiseException('EX_PROMISE_ADJ_INCORRECT');        
      END IF;
    else 
      if (new$ProgIndex = 308) then
        BEGIN
          /*     */
          select edc.InnerNumber
          into InnerNumber_child1$             from ExecutionDocumentsCaption edc
          where edc.ID = new$ExecutionRef
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        BEGIN
          /*       */
          select edc.InnerNumber
          into InnerNumber_parent1$             from PaymentSchedule ps
          left join ExecutionDocumentsCaption edc on (edc.id=ps.ExecutionRef)
          where (ps.Id = new$AdjustmentRef)
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        /*      */
        if (InnerNumber_parent1$ <> InnerNumber_child1$) then
          RaiseException('EX_PROMISE_ADJ_INCORRECT');        
        END IF;
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_PAYMENTSCHEDULE_BI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*           */
  if (new$AdjustmentNumber > 0) then
    BEGIN
      select
      Month01, Month02, Month03, Month04, Month05, Month06,
      Month07, Month08, Month09, Month10, Month11, Month12,
      Quarter1, Quarter2, Quarter3, Quarter4, Summa,
      SummaYear1, SummaYear2, SummaYear3, SummaYear4, SummaOtherYears
      into
      M01$, M02$, M03$, M04$, M05$, M06$, M07$, M08$, M09$, M10$, M11$, M12$,
      Q1$, Q2$, Q3$, Q4$, S$, S1$, S2$, S3$, S4$, SOther$         from
      PaymentSchedule
      where
      ID = new$AdjustmentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    new$Month01Delta := new$Month01 - M01$;
    new$Month02Delta := new$Month02 - M02$;
    new$Month03Delta := new$Month03 - M03$;
    new$Month04Delta := new$Month04 - M04$;
    new$Month05Delta := new$Month05 - M05$;
    new$Month06Delta := new$Month06 - M06$;
    new$Month07Delta := new$Month07 - M07$;
    new$Month08Delta := new$Month08 - M08$;
    new$Month09Delta := new$Month09 - M09$;
    new$Month10Delta := new$Month10 - M10$;
    new$Month11Delta := new$Month11 - M11$;
    new$Month12Delta := new$Month12 - M12$;
    new$Quarter1Delta := new$Quarter1 - Q1$;
    new$Quarter2Delta := new$Quarter2 - Q2$;
    new$Quarter3Delta := new$Quarter3 - Q3$;
    new$Quarter4Delta := new$Quarter4 - Q4$;
    new$SummaDelta := new$Summa - S$;
    new$SummaYear1Delta := new$SummaYear1 - S1$;
    new$SummaYear2Delta := new$SummaYear2 - S2$;
    new$SummaYear3Delta := new$SummaYear3 - S3$;
    new$SummaYear4Delta := new$SummaYear4 - S4$;
    new$SummaOtherYearsDelta := new$SummaOtherYears - SOther$;

  else    /*        */
    new$Month01Delta := new$Month01;
    new$Month02Delta := new$Month02;
    new$Month03Delta := new$Month03;
    new$Month04Delta := new$Month04;
    new$Month05Delta := new$Month05;
    new$Month06Delta := new$Month06;
    new$Month07Delta := new$Month07;
    new$Month08Delta := new$Month08;
    new$Month09Delta := new$Month09;
    new$Month10Delta := new$Month10;
    new$Month11Delta := new$Month11;
    new$Month12Delta := new$Month12;
    new$Quarter1Delta := new$Quarter1;
    new$Quarter2Delta := new$Quarter2;
    new$Quarter3Delta := new$Quarter3;
    new$Quarter4Delta := new$Quarter4;
    new$SummaDelta := new$Summa;
    new$SummaYear1Delta := new$SummaYear1;
    new$SummaYear2Delta := new$SummaYear2;
    new$SummaYear3Delta := new$SummaYear3;
    new$SummaYear4Delta := new$SummaYear4;
    new$SummaOtherYearsDelta := new$SummaOtherYears;

  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_PAYMENTSCHEDULE_BI_200)
-- Create 06.08.2010
-- - - - - - - - - - - - -

  /*      */
  if (new$senderId is null) then
    new$senderIdKey := -1;
  else
    new$senderIdKey := new$senderId;
  end if;

  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  end if;

-- - - - - - - - - - - - -
-- BI_500 (TR_PAYMENTSCHEDULE_BI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_PAYMENTSCHEDULE (
    ID,
    ANUMBER,
    PARENTNUMBER,
    KFSR,
    KESR,
    KVSR,
    KCSR,
    KVR,
    MONTH01,
    MONTH02,
    MONTH03,
    MONTH04,
    MONTH05,
    MONTH06,
    MONTH07,
    MONTH08,
    MONTH09,
    MONTH10,
    MONTH11,
    MONTH12,
    SUMMA,
    REGION,
    SUBKESR,
    MEANSTYPE,
    FINSOURCE,
    FINTYPE,
    FACT,
    FACIALACC_CLS,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    ACCEPTDATE,
    LASTADJUSTMENT,
    ACCEPTED,
    LASTACCEPTED,
    PROMISETYPE,
    ADJUSTMENTREF,
    OLDNUMBER,
    SUMMAPREVIOUSYEAR,
    SUMMAFINPREVIOUSYEAR,
    QUARTER1,
    QUARTER2,
    QUARTER3,
    QUARTER4,
    RECORDINDEX,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DIRECTIONCLS,
    RVERSION,
    BUHOPERATIONCLS,
    MONTH01DELTA,
    MONTH02DELTA,
    MONTH03DELTA,
    MONTH04DELTA,
    MONTH05DELTA,
    MONTH06DELTA,
    MONTH07DELTA,
    MONTH08DELTA,
    MONTH09DELTA,
    MONTH10DELTA,
    MONTH11DELTA,
    MONTH12DELTA,
    QUARTER1DELTA,
    QUARTER2DELTA,
    QUARTER3DELTA,
    QUARTER4DELTA,
    SUMMADELTA,
    NOTE,
    FINYEAR,
    SUMMAYEAR1,
    SUMMAYEAR2,
    SUMMAYEAR3,
    SUMMAYEAR1DELTA,
    SUMMAYEAR2DELTA,
    SUMMAYEAR3DELTA,
    ASSIGNMENTKIND,
    TRANSFERTCLS,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    EXECUTIONREF,
    INNERPROMISENUM,
    ADJUSTMENTNUMBER,
    PROMISENUMBER,
    SUBSIDYCLS,
    AGREEMENTREF,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    PROGINDEX,
    INVESTOBJECT,
    SUMMAYEAR4,
    SUMMAOTHERYEARS,
    SUMMAYEAR4DELTA,
    SUMMAOTHERYEARSDELTA,
    CONTRACTCOSTSCLS,
    TARGETCLS
  ) VALUES (
    new$ID,
    new$ANUMBER,
    new$PARENTNUMBER,
    new$KFSR,
    new$KESR,
    new$KVSR,
    new$KCSR,
    new$KVR,
    new$MONTH01,
    new$MONTH02,
    new$MONTH03,
    new$MONTH04,
    new$MONTH05,
    new$MONTH06,
    new$MONTH07,
    new$MONTH08,
    new$MONTH09,
    new$MONTH10,
    new$MONTH11,
    new$MONTH12,
    new$SUMMA,
    new$REGION,
    new$SUBKESR,
    new$MEANSTYPE,
    new$FINSOURCE,
    new$FINTYPE,
    new$FACT,
    new$FACIALACC_CLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$ACCEPTDATE,
    new$LASTADJUSTMENT,
    new$ACCEPTED,
    new$LASTACCEPTED,
    new$PROMISETYPE,
    new$ADJUSTMENTREF,
    new$OLDNUMBER,
    new$SUMMAPREVIOUSYEAR,
    new$SUMMAFINPREVIOUSYEAR,
    new$QUARTER1,
    new$QUARTER2,
    new$QUARTER3,
    new$QUARTER4,
    new$RECORDINDEX,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$DIRECTIONCLS,
    new$RVERSION,
    new$BUHOPERATIONCLS,
    new$MONTH01DELTA,
    new$MONTH02DELTA,
    new$MONTH03DELTA,
    new$MONTH04DELTA,
    new$MONTH05DELTA,
    new$MONTH06DELTA,
    new$MONTH07DELTA,
    new$MONTH08DELTA,
    new$MONTH09DELTA,
    new$MONTH10DELTA,
    new$MONTH11DELTA,
    new$MONTH12DELTA,
    new$QUARTER1DELTA,
    new$QUARTER2DELTA,
    new$QUARTER3DELTA,
    new$QUARTER4DELTA,
    new$SUMMADELTA,
    new$NOTE,
    new$FINYEAR,
    new$SUMMAYEAR1,
    new$SUMMAYEAR2,
    new$SUMMAYEAR3,
    new$SUMMAYEAR1DELTA,
    new$SUMMAYEAR2DELTA,
    new$SUMMAYEAR3DELTA,
    new$ASSIGNMENTKIND,
    new$TRANSFERTCLS,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$EXECUTIONREF,
    new$INNERPROMISENUM,
    new$ADJUSTMENTNUMBER,
    new$PROMISENUMBER,
    new$SUBSIDYCLS,
    new$AGREEMENTREF,
    new$BUDALLOCATIONCLS,
    new$PAYPROMISECLS,
    new$PROGINDEX,
    new$INVESTOBJECT,
    new$SUMMAYEAR4,
    new$SUMMAOTHERYEARS,
    new$SUMMAYEAR4DELTA,
    new$SUMMAOTHERYEARSDELTA,
    new$CONTRACTCOSTSCLS,
    new$TARGETCLS);

-- - - - - - - - - - - - -
-- AI_10 (TR_PAYMENTSCHEDULE_AI_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  /*      */
  if ((new$AdjustmentNumber > 0) and (new$LastAdjustment = 1)) then
    update PaymentSchedule set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);
    if (new$LastAccepted = 1) then
      update PaymentSchedule set
      LastAccepted = 0,
      RVersion = -1
      where (ID = new$AdjustmentRef);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_PAYMENTSCHEDULE_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 113) and (RecordID = new$ID);

END;
/
-- CREATE TRIGGER TR_PAYMENTSCHEDULE_BU_10
CREATE OR REPLACE TRIGGER TR_PAYMENTSCHEDULE_IU
  INSTEAD OF UPDATE
  ON PAYMENTSCHEDULE
  FOR EACH ROW
DECLARE
  new$ID PAYMENTSCHEDULE.ID%TYPE := :NEW.ID;
  new$ANUMBER PAYMENTSCHEDULE.ANUMBER%TYPE := :NEW.ANUMBER;
  new$PARENTNUMBER PAYMENTSCHEDULE.PARENTNUMBER%TYPE := :NEW.PARENTNUMBER;
  new$KFSR PAYMENTSCHEDULE.KFSR%TYPE := :NEW.KFSR;
  new$KESR PAYMENTSCHEDULE.KESR%TYPE := :NEW.KESR;
  new$KVSR PAYMENTSCHEDULE.KVSR%TYPE := :NEW.KVSR;
  new$KCSR PAYMENTSCHEDULE.KCSR%TYPE := :NEW.KCSR;
  new$KVR PAYMENTSCHEDULE.KVR%TYPE := :NEW.KVR;
  new$MONTH01 PAYMENTSCHEDULE.MONTH01%TYPE := :NEW.MONTH01;
  new$MONTH02 PAYMENTSCHEDULE.MONTH02%TYPE := :NEW.MONTH02;
  new$MONTH03 PAYMENTSCHEDULE.MONTH03%TYPE := :NEW.MONTH03;
  new$MONTH04 PAYMENTSCHEDULE.MONTH04%TYPE := :NEW.MONTH04;
  new$MONTH05 PAYMENTSCHEDULE.MONTH05%TYPE := :NEW.MONTH05;
  new$MONTH06 PAYMENTSCHEDULE.MONTH06%TYPE := :NEW.MONTH06;
  new$MONTH07 PAYMENTSCHEDULE.MONTH07%TYPE := :NEW.MONTH07;
  new$MONTH08 PAYMENTSCHEDULE.MONTH08%TYPE := :NEW.MONTH08;
  new$MONTH09 PAYMENTSCHEDULE.MONTH09%TYPE := :NEW.MONTH09;
  new$MONTH10 PAYMENTSCHEDULE.MONTH10%TYPE := :NEW.MONTH10;
  new$MONTH11 PAYMENTSCHEDULE.MONTH11%TYPE := :NEW.MONTH11;
  new$MONTH12 PAYMENTSCHEDULE.MONTH12%TYPE := :NEW.MONTH12;
  new$SUMMA PAYMENTSCHEDULE.SUMMA%TYPE := :NEW.SUMMA;
  new$REGION PAYMENTSCHEDULE.REGION%TYPE := :NEW.REGION;
  new$SUBKESR PAYMENTSCHEDULE.SUBKESR%TYPE := :NEW.SUBKESR;
  new$MEANSTYPE PAYMENTSCHEDULE.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FINSOURCE PAYMENTSCHEDULE.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE PAYMENTSCHEDULE.FINTYPE%TYPE := :NEW.FINTYPE;
  new$FACT PAYMENTSCHEDULE.FACT%TYPE := :NEW.FACT;
  new$FACIALACC_CLS PAYMENTSCHEDULE.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$CREATERUSER PAYMENTSCHEDULE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYMENTSCHEDULE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PAYMENTSCHEDULE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PAYMENTSCHEDULE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF PAYMENTSCHEDULE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ACCEPTDATE PAYMENTSCHEDULE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$LASTADJUSTMENT PAYMENTSCHEDULE.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$ACCEPTED PAYMENTSCHEDULE.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED PAYMENTSCHEDULE.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$PROMISETYPE PAYMENTSCHEDULE.PROMISETYPE%TYPE := :NEW.PROMISETYPE;
  new$ADJUSTMENTREF PAYMENTSCHEDULE.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$OLDNUMBER PAYMENTSCHEDULE.OLDNUMBER%TYPE := :NEW.OLDNUMBER;
  new$SUMMAPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAPREVIOUSYEAR%TYPE := :NEW.SUMMAPREVIOUSYEAR;
  new$SUMMAFINPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAFINPREVIOUSYEAR%TYPE := :NEW.SUMMAFINPREVIOUSYEAR;
  new$QUARTER1 PAYMENTSCHEDULE.QUARTER1%TYPE := :NEW.QUARTER1;
  new$QUARTER2 PAYMENTSCHEDULE.QUARTER2%TYPE := :NEW.QUARTER2;
  new$QUARTER3 PAYMENTSCHEDULE.QUARTER3%TYPE := :NEW.QUARTER3;
  new$QUARTER4 PAYMENTSCHEDULE.QUARTER4%TYPE := :NEW.QUARTER4;
  new$RECORDINDEX PAYMENTSCHEDULE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CRYPTOSTATUS PAYMENTSCHEDULE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PAYMENTSCHEDULE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PAYMENTSCHEDULE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DIRECTIONCLS PAYMENTSCHEDULE.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$RVERSION PAYMENTSCHEDULE.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYMENTSCHEDULE.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MONTH01DELTA PAYMENTSCHEDULE.MONTH01DELTA%TYPE := :NEW.MONTH01DELTA;
  new$MONTH02DELTA PAYMENTSCHEDULE.MONTH02DELTA%TYPE := :NEW.MONTH02DELTA;
  new$MONTH03DELTA PAYMENTSCHEDULE.MONTH03DELTA%TYPE := :NEW.MONTH03DELTA;
  new$MONTH04DELTA PAYMENTSCHEDULE.MONTH04DELTA%TYPE := :NEW.MONTH04DELTA;
  new$MONTH05DELTA PAYMENTSCHEDULE.MONTH05DELTA%TYPE := :NEW.MONTH05DELTA;
  new$MONTH06DELTA PAYMENTSCHEDULE.MONTH06DELTA%TYPE := :NEW.MONTH06DELTA;
  new$MONTH07DELTA PAYMENTSCHEDULE.MONTH07DELTA%TYPE := :NEW.MONTH07DELTA;
  new$MONTH08DELTA PAYMENTSCHEDULE.MONTH08DELTA%TYPE := :NEW.MONTH08DELTA;
  new$MONTH09DELTA PAYMENTSCHEDULE.MONTH09DELTA%TYPE := :NEW.MONTH09DELTA;
  new$MONTH10DELTA PAYMENTSCHEDULE.MONTH10DELTA%TYPE := :NEW.MONTH10DELTA;
  new$MONTH11DELTA PAYMENTSCHEDULE.MONTH11DELTA%TYPE := :NEW.MONTH11DELTA;
  new$MONTH12DELTA PAYMENTSCHEDULE.MONTH12DELTA%TYPE := :NEW.MONTH12DELTA;
  new$QUARTER1DELTA PAYMENTSCHEDULE.QUARTER1DELTA%TYPE := :NEW.QUARTER1DELTA;
  new$QUARTER2DELTA PAYMENTSCHEDULE.QUARTER2DELTA%TYPE := :NEW.QUARTER2DELTA;
  new$QUARTER3DELTA PAYMENTSCHEDULE.QUARTER3DELTA%TYPE := :NEW.QUARTER3DELTA;
  new$QUARTER4DELTA PAYMENTSCHEDULE.QUARTER4DELTA%TYPE := :NEW.QUARTER4DELTA;
  new$SUMMADELTA PAYMENTSCHEDULE.SUMMADELTA%TYPE := :NEW.SUMMADELTA;
  new$NOTE PAYMENTSCHEDULE.NOTE%TYPE := :NEW.NOTE;
  new$FINYEAR PAYMENTSCHEDULE.FINYEAR%TYPE := :NEW.FINYEAR;
  new$SUMMAYEAR1 PAYMENTSCHEDULE.SUMMAYEAR1%TYPE := :NEW.SUMMAYEAR1;
  new$SUMMAYEAR2 PAYMENTSCHEDULE.SUMMAYEAR2%TYPE := :NEW.SUMMAYEAR2;
  new$SUMMAYEAR3 PAYMENTSCHEDULE.SUMMAYEAR3%TYPE := :NEW.SUMMAYEAR3;
  new$SUMMAYEAR1DELTA PAYMENTSCHEDULE.SUMMAYEAR1DELTA%TYPE := :NEW.SUMMAYEAR1DELTA;
  new$SUMMAYEAR2DELTA PAYMENTSCHEDULE.SUMMAYEAR2DELTA%TYPE := :NEW.SUMMAYEAR2DELTA;
  new$SUMMAYEAR3DELTA PAYMENTSCHEDULE.SUMMAYEAR3DELTA%TYPE := :NEW.SUMMAYEAR3DELTA;
  new$ASSIGNMENTKIND PAYMENTSCHEDULE.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$TRANSFERTCLS PAYMENTSCHEDULE.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SENDERIDKEY PAYMENTSCHEDULE.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY PAYMENTSCHEDULE.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXECUTIONREF PAYMENTSCHEDULE.EXECUTIONREF%TYPE := :NEW.EXECUTIONREF;
  new$INNERPROMISENUM PAYMENTSCHEDULE.INNERPROMISENUM%TYPE := :NEW.INNERPROMISENUM;
  new$ADJUSTMENTNUMBER PAYMENTSCHEDULE.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$PROMISENUMBER PAYMENTSCHEDULE.PROMISENUMBER%TYPE := :NEW.PROMISENUMBER;
  new$SUBSIDYCLS PAYMENTSCHEDULE.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$AGREEMENTREF PAYMENTSCHEDULE.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$BUDALLOCATIONCLS PAYMENTSCHEDULE.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS PAYMENTSCHEDULE.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$PROGINDEX PAYMENTSCHEDULE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$INVESTOBJECT PAYMENTSCHEDULE.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$SUMMAYEAR4 PAYMENTSCHEDULE.SUMMAYEAR4%TYPE := :NEW.SUMMAYEAR4;
  new$SUMMAOTHERYEARS PAYMENTSCHEDULE.SUMMAOTHERYEARS%TYPE := :NEW.SUMMAOTHERYEARS;
  new$SUMMAYEAR4DELTA PAYMENTSCHEDULE.SUMMAYEAR4DELTA%TYPE := :NEW.SUMMAYEAR4DELTA;
  new$SUMMAOTHERYEARSDELTA PAYMENTSCHEDULE.SUMMAOTHERYEARSDELTA%TYPE := :NEW.SUMMAOTHERYEARSDELTA;
  new$CONTRACTCOSTSCLS PAYMENTSCHEDULE.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS PAYMENTSCHEDULE.TARGETCLS%TYPE := :NEW.TARGETCLS;
--
  M01$ NUMBER;
  M02$ NUMBER;
  M03$ NUMBER;
  M04$ NUMBER;
  M05$ NUMBER;
  M06$ NUMBER;
  M07$ NUMBER;
  M08$ NUMBER;
  M09$ NUMBER;
  M10$ NUMBER;
  M11$ NUMBER;
  M12$ NUMBER;
  Q1$ NUMBER;
  Q2$ NUMBER;
  Q3$ NUMBER;
  Q4$ NUMBER;
  S$ NUMBER;
  S1$ NUMBER;
  S2$ NUMBER;
  S3$ NUMBER;
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  S4$ NUMBER;
  SOther$ NUMBER;
  previousAccept$ NUMBER(10);
  previousAcceptDate$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_PAYMENTSCHEDULE_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*   2.4*/
  /*    -*/
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  if (new$PromiseType is null) then
    new$PromiseType := 0;
  END IF;
  if (new$KFSR is null) then
    new$KFSR := 0;
  END IF;
  if (new$KESR is null) then
    new$KESR := 0;
  END IF;
  if (new$KVSR is null) then
    new$KVSR := 0;
  END IF;
  if (new$KCSR is null) then
    new$KCSR := 0;
  END IF;
  if (new$KVR is null) then
    new$KVR := 0;
  END IF;
  if (new$SubKESR is null) then
    new$SubKESR := 0;
  END IF;
  if (new$AssignmentKind is null) then
    new$AssignmentKind := 0;
  END IF;

  if (new$DirectionCls is null) then
    new$DirectionCls := 0;
  END IF;

  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$MeansType is null) then
    new$MeansType := 0;
  END IF;
  if (new$FinSource is null) then
    new$FinSource := 0;
  END IF;
  if (new$FinType is null) then
    new$FinType := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$Month01 is null) then
    new$Month01 := 0;
  END IF;
  if (new$Month02 is null) then
    new$Month02 := 0;
  END IF;
  if (new$Month03 is null) then
    new$Month03 := 0;
  END IF;
  if (new$Month04 is null) then
    new$Month04 := 0;
  END IF;
  if (new$Month05 is null) then
    new$Month05 := 0;
  END IF;
  if (new$Month06 is null) then
    new$Month06 := 0;
  END IF;
  if (new$Month07 is null) then
    new$Month07 := 0;
  END IF;
  if (new$Month08 is null) then
    new$Month08 := 0;
  END IF;
  if (new$Month09 is null) then
    new$Month09 := 0;
  END IF;
  if (new$Month10 is null) then
    new$Month10 := 0;
  END IF;
  if (new$Month11 is null) then
    new$Month11 := 0;
  END IF;
  if (new$Month12 is null) then
    new$Month12 := 0;
  END IF;
  if (new$Quarter1 is null) then
    new$Quarter1 := 0;
  END IF;
  if (new$Quarter2 is null) then
    new$Quarter2 := 0;
  END IF;
  if (new$Quarter3 is null) then
    new$Quarter3 := 0;
  END IF;
  if (new$Quarter4 is null) then
    new$Quarter4 := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$Month01Delta is null) then
    new$Month01Delta := 0;
  END IF;
  if (new$Month02Delta is null) then
    new$Month02Delta := 0;
  END IF;
  if (new$Month03Delta is null) then
    new$Month03Delta := 0;
  END IF;
  if (new$Month04Delta is null) then
    new$Month04Delta := 0;
  END IF;
  if (new$Month05Delta is null) then
    new$Month05Delta := 0;
  END IF;
  if (new$Month06Delta is null) then
    new$Month06Delta := 0;
  END IF;
  if (new$Month07Delta is null) then
    new$Month07Delta := 0;
  END IF;
  if (new$Month08Delta is null) then
    new$Month08Delta := 0;
  END IF;
  if (new$Month09Delta is null) then
    new$Month09Delta := 0;
  END IF;
  if (new$Month10Delta is null) then
    new$Month10Delta := 0;
  END IF;
  if (new$Month11Delta is null) then
    new$Month11Delta := 0;
  END IF;
  if (new$Month12Delta is null) then
    new$Month12Delta := 0;
  END IF;
  if (new$Quarter1Delta is null) then
    new$Quarter1Delta := 0;
  END IF;
  if (new$Quarter2Delta is null) then
    new$Quarter2Delta := 0;
  END IF;
  if (new$Quarter3Delta is null) then
    new$Quarter3Delta := 0;
  END IF;
  if (new$Quarter4Delta is null) then
    new$Quarter4Delta := 0;
  END IF;
  if (new$SummaDelta is null) then
    new$SummaDelta := 0;
  END IF;
  if (new$SummaPreviousYear is null) then
    new$SummaPreviousYear := 0;
  END IF;
  if (new$SummaFinPreviousYear is null) then
    new$SummaFinPreviousYear := 0;
  END IF;

  if (new$SummaYear1 is null) then
    new$SummaYear1 := 0;
  END IF;
  if (new$SummaYear2 is null) then
    new$SummaYear2 := 0;
  END IF;
  if (new$SummaYear3 is null) then
    new$SummaYear3 := 0;
  END IF;
  if (new$SummaYear4 is null) then
    new$SummaYear4 := 0;
  END IF;
  if (new$SummaOtherYears is null) then
    new$SummaOtherYears := 0;
  END IF;

  if (new$SummaYear1Delta is null) then
    new$SummaYear1Delta := 0;
  END IF;
  if (new$SummaYear2Delta is null) then
    new$SummaYear2Delta := 0;
  END IF;
  if (new$SummaYear3Delta is null) then
    new$SummaYear3Delta := 0;
  END IF;
  if (new$SummaYear4Delta is null) then
    new$SummaYear4Delta := 0;
  END IF;
  if (new$SummaOtherYearsDelta is null) then
    new$SummaOtherYearsDelta := 0;
  END IF;

  /*   ,        */
  if (new$ProgIndex = 304 and new$RecordIndex is not null and (:old.RecordIndex is null or :old.RecordIndex <> new$RecordIndex)) then
    SELECT COUNT(*) INTO CNT$1
    from AgreementSteps s where (s.Id = new$RecordIndex and s.RecordIndex = new$AgreementRef) AND (ROWNUM = 1);
    if (not (CNT$1<> 0)) then
      RaiseException('Ex_WrongStep');
    END IF;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      RaiseException('Ex_CantModufyBudget');
    END IF;
  END IF;
  if ((:old.ANumber is null) and (new$ANumber is not Null)) then
    SELECT COUNT(                    id
    ) INTO CNT$2
    from
    PaymentSchedule ps
    where
    (                    (ps.ANumber = new$ANumber)
    and
    (ps.BudgetRef = new$BudgetRef)) AND (ROWNUM = 1);
    if ((CNT$2<> 0)) then
      RaiseException('ex_Promise_NumUQ');
    END IF;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls);

-- - - - - - - - - - - - -
-- BU_1 (TR_PAYMENTSCHEDULE_BU_1)
-- Create 05.03.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  /*   1.0*/
    if (new$Quarter1 = 0) then new$Quarter1 := new$Month01 + new$Month02 + new$Month03; end if;
    if (new$Quarter2 = 0) then new$Quarter2 := new$Month04 + new$Month05 + new$Month06; end if;
    if (new$Quarter3 = 0) then new$Quarter3 := new$Month07 + new$Month08 + new$Month09; end if;
    if (new$Quarter4 = 0) then new$Quarter4 := new$Month10 + new$Month11 + new$Month12; end if;
    new$SummaYear1 := new$Quarter1 + new$Quarter2 + new$Quarter3 + new$Quarter4;

-- - - - - - - - - - - - -
-- BU_3 (TR_PAYMENTSCHEDULE_BU_3)
-- Create 03.12.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

    /*            */
    new$AdjustmentRef := :old.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_10 (TR_PAYMENTSCHEDULE_BU_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  /* ,      ,   */
  if ((new$ANumber <> :old.ANumber) or
  (new$AdjustmentRef <> :old.AdjustmentRef) or
  (new$InnerPromiseNum <> :old.InnerPromiseNum) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber)) then
    RaiseException('EX_AGR_ChangeInnerNums');
  END IF;
      
  /*   */
  if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and 
  ((new$Accepted = 1) or (new$AcceptDate is null))) then
    BEGIN
      /*             */
      select Accepted, AcceptDate
      into previousAccept$, previousAcceptDate$       from Paymentschedule
      where id=new$Adjustmentref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$Adjustmentref is not null and (previousAccept$ = 0 or previousAcceptDate$ is null)) then
      RaiseException('EX_RollbackCancel');
    END IF;
    new$LastAdjustment := 1;
        
  END IF;
  /*   ,     LastAccepted*/
  if ((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;
              
    else
      RaiseException('EX_BP_ChangeStateAdjust');
    END IF;
  END IF;
  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 0 and new$AcceptDate is not null and new$Accepted = 1) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;
              
    else
      RaiseException('EX_BP_ChangeStateAdjust');
    END IF;
  END IF;
      
  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;
              
    else
      RaiseException('EX_BP_ChangeStateAdjust');
    END IF;
  END IF;
      
  /*   ,     LastAdjustment*/
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment <> 1) then
      RaiseException('EX_BP_ChangeStateAdjust');
    else
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
              
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_PAYMENTSCHEDULE_BU_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*           */
  if (new$AdjustmentNumber > 0) then
    BEGIN
      select
      Month01, Month02, Month03, Month04, Month05, Month06,
      Month07, Month08, Month09, Month10, Month11, Month12,
      Quarter1, Quarter2, Quarter3, Quarter4, Summa,
      SummaYear1, SummaYear2, SummaYear3, SummaYear4, SummaOtherYears
      into
      M01$, M02$, M03$, M04$, M05$, M06$, M07$, M08$, M09$, M10$, M11$, M12$,
      Q1$, Q2$, Q3$, Q4$, S$, S1$, S2$, S3$, S4$, SOther$         from
      PaymentSchedule
      where
      ID = new$AdjustmentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    new$Month01Delta := new$Month01 - M01$;
    new$Month02Delta := new$Month02 - M02$;
    new$Month03Delta := new$Month03 - M03$;
    new$Month04Delta := new$Month04 - M04$;
    new$Month05Delta := new$Month05 - M05$;
    new$Month06Delta := new$Month06 - M06$;
    new$Month07Delta := new$Month07 - M07$;
    new$Month08Delta := new$Month08 - M08$;
    new$Month09Delta := new$Month09 - M09$;
    new$Month10Delta := new$Month10 - M10$;
    new$Month11Delta := new$Month11 - M11$;
    new$Month12Delta := new$Month12 - M12$;
    new$Quarter1Delta := new$Quarter1 - Q1$;
    new$Quarter2Delta := new$Quarter2 - Q2$;
    new$Quarter3Delta := new$Quarter3 - Q3$;
    new$Quarter4Delta := new$Quarter4 - Q4$;
    new$SummaDelta := new$Summa - S$;
    new$SummaYear1Delta := new$SummaYear1 - S1$;
    new$SummaYear2Delta := new$SummaYear2 - S2$;
    new$SummaYear3Delta := new$SummaYear3 - S3$;
    new$SummaYear4Delta := new$SummaYear4 - S4$;
    new$SummaOtherYearsDelta := new$SummaOtherYears - SOther$;

  else /*        */
    new$Month01Delta := new$Month01;
    new$Month02Delta := new$Month02;
    new$Month03Delta := new$Month03;
    new$Month04Delta := new$Month04;
    new$Month05Delta := new$Month05;
    new$Month06Delta := new$Month06;
    new$Month07Delta := new$Month07;
    new$Month08Delta := new$Month08;
    new$Month09Delta := new$Month09;
    new$Month10Delta := new$Month10;
    new$Month11Delta := new$Month11;
    new$Month12Delta := new$Month12;
    new$Quarter1Delta := new$Quarter1;
    new$Quarter2Delta := new$Quarter2;
    new$Quarter3Delta := new$Quarter3;
    new$Quarter4Delta := new$Quarter4;
    new$SummaDelta := new$Summa;
    new$SummaYear1Delta := new$SummaYear1;
    new$SummaYear2Delta := new$SummaYear2;
    new$SummaYear3Delta := new$SummaYear3;
    new$SummaYear4Delta := new$SummaYear4;
    new$SummaOtherYearsDelta := new$SummaOtherYears;

  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_PAYMENTSCHEDULE_BU_200)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*    */
  if (new$Accepted = 0 and new$AcceptDate is not null and :old.Accepted = 1) then
    /*   ,     
         *    ,      */
    FOR REC$1 IN (      select ffc.Reject_Cls  AS DocumentRejectCls from FacialFinDetail ffd
    left join FacialFinCaption ffc on (ffc.ID = ffd.RecordIndex)
    where SourcePromise = new$ANumber and SourceBudgetPromise = new$InnerPromiseNum
    or DestPromise = new$ANumber and DestBudgetPromise = new$InnerPromiseNum
    )
    LOOP
      if (REC$1.DocumentRejectCls is null) then
        RaiseException('Ex_BP_CannotReject');
      END IF;
    END LOOP;
    /* ,         */
    FOR REC$1 IN (      SELECT Count(ps_in.ID)  AS AdjCount FROM PaymentSchedule ps_in
    WHERE (ps_in.InnerPromiseNum = new$InnerPromiseNum)and(ps_in.AdjustmentNumber > new$AdjustmentNumber)
    and (ps_in.Accepted<>0)
    )
    LOOP
      if (REC$1.AdjCount > 0) then
        RaiseException('EX_BP_AdjustmentedCANNOTREJECT');
      END IF;
    END LOOP;
  END IF;
  /*   .       */
  if (new$Accepted = 1 and new$AcceptDate is null and :old.Accepted = 1 and :old.AcceptDate is not null) then
    SELECT COUNT(ffc.Reject_Cls ) INTO CNT$1
    from FacialFinDetail ffd
    left join FacialFinCaption ffc on (ffc.ID = ffd.RecordIndex)
    where ((SourcePromise = new$ANumber and SourceBudgetPromise = new$InnerPromiseNum
    or DestPromise = new$ANumber and DestBudgetPromise = new$InnerPromiseNum)
    and ffc.acceptdate is not null and ffc.Reject_cls is null) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_BP_NOTACCEPTED');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (tr_PaymentSchedule_BU_400)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$AgreementRef <> :old.AgreementRef or new$ExecutionRef <> :old.ExecutionRef) then
    RaiseException('EX_CANTCHANGECAPTIONREF');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_PAYMENTSCHEDULE_BU_700)
-- Create 14.10.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$RVersion is null) then
    new$RVersion := 1;
  elsif ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
    new$RVersion := :Old.RVersion;
  else
    new$RVersion := :Old.RVersion + 1;
  end if;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_PAYMENTSCHEDULE SET
    ID = new$ID,
    ANUMBER = new$ANUMBER,
    PARENTNUMBER = new$PARENTNUMBER,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVSR = new$KVSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    MONTH01 = new$MONTH01,
    MONTH02 = new$MONTH02,
    MONTH03 = new$MONTH03,
    MONTH04 = new$MONTH04,
    MONTH05 = new$MONTH05,
    MONTH06 = new$MONTH06,
    MONTH07 = new$MONTH07,
    MONTH08 = new$MONTH08,
    MONTH09 = new$MONTH09,
    MONTH10 = new$MONTH10,
    MONTH11 = new$MONTH11,
    MONTH12 = new$MONTH12,
    SUMMA = new$SUMMA,
    REGION = new$REGION,
    SUBKESR = new$SUBKESR,
    MEANSTYPE = new$MEANSTYPE,
    FINSOURCE = new$FINSOURCE,
    FINTYPE = new$FINTYPE,
    FACT = new$FACT,
    FACIALACC_CLS = new$FACIALACC_CLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    ACCEPTDATE = new$ACCEPTDATE,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    ACCEPTED = new$ACCEPTED,
    LASTACCEPTED = new$LASTACCEPTED,
    PROMISETYPE = new$PROMISETYPE,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    OLDNUMBER = new$OLDNUMBER,
    SUMMAPREVIOUSYEAR = new$SUMMAPREVIOUSYEAR,
    SUMMAFINPREVIOUSYEAR = new$SUMMAFINPREVIOUSYEAR,
    QUARTER1 = new$QUARTER1,
    QUARTER2 = new$QUARTER2,
    QUARTER3 = new$QUARTER3,
    QUARTER4 = new$QUARTER4,
    RECORDINDEX = new$RECORDINDEX,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DIRECTIONCLS = new$DIRECTIONCLS,
    RVERSION = new$RVERSION,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    MONTH01DELTA = new$MONTH01DELTA,
    MONTH02DELTA = new$MONTH02DELTA,
    MONTH03DELTA = new$MONTH03DELTA,
    MONTH04DELTA = new$MONTH04DELTA,
    MONTH05DELTA = new$MONTH05DELTA,
    MONTH06DELTA = new$MONTH06DELTA,
    MONTH07DELTA = new$MONTH07DELTA,
    MONTH08DELTA = new$MONTH08DELTA,
    MONTH09DELTA = new$MONTH09DELTA,
    MONTH10DELTA = new$MONTH10DELTA,
    MONTH11DELTA = new$MONTH11DELTA,
    MONTH12DELTA = new$MONTH12DELTA,
    QUARTER1DELTA = new$QUARTER1DELTA,
    QUARTER2DELTA = new$QUARTER2DELTA,
    QUARTER3DELTA = new$QUARTER3DELTA,
    QUARTER4DELTA = new$QUARTER4DELTA,
    SUMMADELTA = new$SUMMADELTA,
    NOTE = new$NOTE,
    FINYEAR = new$FINYEAR,
    SUMMAYEAR1 = new$SUMMAYEAR1,
    SUMMAYEAR2 = new$SUMMAYEAR2,
    SUMMAYEAR3 = new$SUMMAYEAR3,
    SUMMAYEAR1DELTA = new$SUMMAYEAR1DELTA,
    SUMMAYEAR2DELTA = new$SUMMAYEAR2DELTA,
    SUMMAYEAR3DELTA = new$SUMMAYEAR3DELTA,
    ASSIGNMENTKIND = new$ASSIGNMENTKIND,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    EXECUTIONREF = new$EXECUTIONREF,
    INNERPROMISENUM = new$INNERPROMISENUM,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    PROMISENUMBER = new$PROMISENUMBER,
    SUBSIDYCLS = new$SUBSIDYCLS,
    AGREEMENTREF = new$AGREEMENTREF,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    PAYPROMISECLS = new$PAYPROMISECLS,
    PROGINDEX = new$PROGINDEX,
    INVESTOBJECT = new$INVESTOBJECT,
    SUMMAYEAR4 = new$SUMMAYEAR4,
    SUMMAOTHERYEARS = new$SUMMAOTHERYEARS,
    SUMMAYEAR4DELTA = new$SUMMAYEAR4DELTA,
    SUMMAOTHERYEARSDELTA = new$SUMMAOTHERYEARSDELTA,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_10 (TR_PAYMENTSCHEDULE_AU_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/

  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update PaymentSchedule set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment    */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update PaymentSchedule set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_PAYMENTSCHEDULE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (113, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=113) and (RecordId=new$ID);
  end if;

END;
/
-- CREATE TRIGGER TR_PAYMENTSCHEDULE_AI_10
CREATE OR REPLACE TRIGGER TR_PAYMENTSCHEDULE_II
  INSTEAD OF INSERT
  ON PAYMENTSCHEDULE
  FOR EACH ROW
DECLARE
  new$ID PAYMENTSCHEDULE.ID%TYPE := :NEW.ID;
  new$ANUMBER PAYMENTSCHEDULE.ANUMBER%TYPE := :NEW.ANUMBER;
  new$PARENTNUMBER PAYMENTSCHEDULE.PARENTNUMBER%TYPE := :NEW.PARENTNUMBER;
  new$KFSR PAYMENTSCHEDULE.KFSR%TYPE := :NEW.KFSR;
  new$KESR PAYMENTSCHEDULE.KESR%TYPE := :NEW.KESR;
  new$KVSR PAYMENTSCHEDULE.KVSR%TYPE := :NEW.KVSR;
  new$KCSR PAYMENTSCHEDULE.KCSR%TYPE := :NEW.KCSR;
  new$KVR PAYMENTSCHEDULE.KVR%TYPE := :NEW.KVR;
  new$MONTH01 PAYMENTSCHEDULE.MONTH01%TYPE := :NEW.MONTH01;
  new$MONTH02 PAYMENTSCHEDULE.MONTH02%TYPE := :NEW.MONTH02;
  new$MONTH03 PAYMENTSCHEDULE.MONTH03%TYPE := :NEW.MONTH03;
  new$MONTH04 PAYMENTSCHEDULE.MONTH04%TYPE := :NEW.MONTH04;
  new$MONTH05 PAYMENTSCHEDULE.MONTH05%TYPE := :NEW.MONTH05;
  new$MONTH06 PAYMENTSCHEDULE.MONTH06%TYPE := :NEW.MONTH06;
  new$MONTH07 PAYMENTSCHEDULE.MONTH07%TYPE := :NEW.MONTH07;
  new$MONTH08 PAYMENTSCHEDULE.MONTH08%TYPE := :NEW.MONTH08;
  new$MONTH09 PAYMENTSCHEDULE.MONTH09%TYPE := :NEW.MONTH09;
  new$MONTH10 PAYMENTSCHEDULE.MONTH10%TYPE := :NEW.MONTH10;
  new$MONTH11 PAYMENTSCHEDULE.MONTH11%TYPE := :NEW.MONTH11;
  new$MONTH12 PAYMENTSCHEDULE.MONTH12%TYPE := :NEW.MONTH12;
  new$SUMMA PAYMENTSCHEDULE.SUMMA%TYPE := :NEW.SUMMA;
  new$REGION PAYMENTSCHEDULE.REGION%TYPE := :NEW.REGION;
  new$SUBKESR PAYMENTSCHEDULE.SUBKESR%TYPE := :NEW.SUBKESR;
  new$MEANSTYPE PAYMENTSCHEDULE.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FINSOURCE PAYMENTSCHEDULE.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE PAYMENTSCHEDULE.FINTYPE%TYPE := :NEW.FINTYPE;
  new$FACT PAYMENTSCHEDULE.FACT%TYPE := :NEW.FACT;
  new$FACIALACC_CLS PAYMENTSCHEDULE.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$CREATERUSER PAYMENTSCHEDULE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYMENTSCHEDULE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PAYMENTSCHEDULE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PAYMENTSCHEDULE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF PAYMENTSCHEDULE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ACCEPTDATE PAYMENTSCHEDULE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$LASTADJUSTMENT PAYMENTSCHEDULE.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$ACCEPTED PAYMENTSCHEDULE.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED PAYMENTSCHEDULE.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$PROMISETYPE PAYMENTSCHEDULE.PROMISETYPE%TYPE := :NEW.PROMISETYPE;
  new$ADJUSTMENTREF PAYMENTSCHEDULE.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$OLDNUMBER PAYMENTSCHEDULE.OLDNUMBER%TYPE := :NEW.OLDNUMBER;
  new$SUMMAPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAPREVIOUSYEAR%TYPE := :NEW.SUMMAPREVIOUSYEAR;
  new$SUMMAFINPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAFINPREVIOUSYEAR%TYPE := :NEW.SUMMAFINPREVIOUSYEAR;
  new$QUARTER1 PAYMENTSCHEDULE.QUARTER1%TYPE := :NEW.QUARTER1;
  new$QUARTER2 PAYMENTSCHEDULE.QUARTER2%TYPE := :NEW.QUARTER2;
  new$QUARTER3 PAYMENTSCHEDULE.QUARTER3%TYPE := :NEW.QUARTER3;
  new$QUARTER4 PAYMENTSCHEDULE.QUARTER4%TYPE := :NEW.QUARTER4;
  new$RECORDINDEX PAYMENTSCHEDULE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CRYPTOSTATUS PAYMENTSCHEDULE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PAYMENTSCHEDULE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PAYMENTSCHEDULE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DIRECTIONCLS PAYMENTSCHEDULE.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$RVERSION PAYMENTSCHEDULE.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYMENTSCHEDULE.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MONTH01DELTA PAYMENTSCHEDULE.MONTH01DELTA%TYPE := :NEW.MONTH01DELTA;
  new$MONTH02DELTA PAYMENTSCHEDULE.MONTH02DELTA%TYPE := :NEW.MONTH02DELTA;
  new$MONTH03DELTA PAYMENTSCHEDULE.MONTH03DELTA%TYPE := :NEW.MONTH03DELTA;
  new$MONTH04DELTA PAYMENTSCHEDULE.MONTH04DELTA%TYPE := :NEW.MONTH04DELTA;
  new$MONTH05DELTA PAYMENTSCHEDULE.MONTH05DELTA%TYPE := :NEW.MONTH05DELTA;
  new$MONTH06DELTA PAYMENTSCHEDULE.MONTH06DELTA%TYPE := :NEW.MONTH06DELTA;
  new$MONTH07DELTA PAYMENTSCHEDULE.MONTH07DELTA%TYPE := :NEW.MONTH07DELTA;
  new$MONTH08DELTA PAYMENTSCHEDULE.MONTH08DELTA%TYPE := :NEW.MONTH08DELTA;
  new$MONTH09DELTA PAYMENTSCHEDULE.MONTH09DELTA%TYPE := :NEW.MONTH09DELTA;
  new$MONTH10DELTA PAYMENTSCHEDULE.MONTH10DELTA%TYPE := :NEW.MONTH10DELTA;
  new$MONTH11DELTA PAYMENTSCHEDULE.MONTH11DELTA%TYPE := :NEW.MONTH11DELTA;
  new$MONTH12DELTA PAYMENTSCHEDULE.MONTH12DELTA%TYPE := :NEW.MONTH12DELTA;
  new$QUARTER1DELTA PAYMENTSCHEDULE.QUARTER1DELTA%TYPE := :NEW.QUARTER1DELTA;
  new$QUARTER2DELTA PAYMENTSCHEDULE.QUARTER2DELTA%TYPE := :NEW.QUARTER2DELTA;
  new$QUARTER3DELTA PAYMENTSCHEDULE.QUARTER3DELTA%TYPE := :NEW.QUARTER3DELTA;
  new$QUARTER4DELTA PAYMENTSCHEDULE.QUARTER4DELTA%TYPE := :NEW.QUARTER4DELTA;
  new$SUMMADELTA PAYMENTSCHEDULE.SUMMADELTA%TYPE := :NEW.SUMMADELTA;
  new$NOTE PAYMENTSCHEDULE.NOTE%TYPE := :NEW.NOTE;
  new$FINYEAR PAYMENTSCHEDULE.FINYEAR%TYPE := :NEW.FINYEAR;
  new$SUMMAYEAR1 PAYMENTSCHEDULE.SUMMAYEAR1%TYPE := :NEW.SUMMAYEAR1;
  new$SUMMAYEAR2 PAYMENTSCHEDULE.SUMMAYEAR2%TYPE := :NEW.SUMMAYEAR2;
  new$SUMMAYEAR3 PAYMENTSCHEDULE.SUMMAYEAR3%TYPE := :NEW.SUMMAYEAR3;
  new$SUMMAYEAR1DELTA PAYMENTSCHEDULE.SUMMAYEAR1DELTA%TYPE := :NEW.SUMMAYEAR1DELTA;
  new$SUMMAYEAR2DELTA PAYMENTSCHEDULE.SUMMAYEAR2DELTA%TYPE := :NEW.SUMMAYEAR2DELTA;
  new$SUMMAYEAR3DELTA PAYMENTSCHEDULE.SUMMAYEAR3DELTA%TYPE := :NEW.SUMMAYEAR3DELTA;
  new$ASSIGNMENTKIND PAYMENTSCHEDULE.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$TRANSFERTCLS PAYMENTSCHEDULE.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SENDERIDKEY PAYMENTSCHEDULE.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY PAYMENTSCHEDULE.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXECUTIONREF PAYMENTSCHEDULE.EXECUTIONREF%TYPE := :NEW.EXECUTIONREF;
  new$INNERPROMISENUM PAYMENTSCHEDULE.INNERPROMISENUM%TYPE := :NEW.INNERPROMISENUM;
  new$ADJUSTMENTNUMBER PAYMENTSCHEDULE.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$PROMISENUMBER PAYMENTSCHEDULE.PROMISENUMBER%TYPE := :NEW.PROMISENUMBER;
  new$SUBSIDYCLS PAYMENTSCHEDULE.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$AGREEMENTREF PAYMENTSCHEDULE.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$BUDALLOCATIONCLS PAYMENTSCHEDULE.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS PAYMENTSCHEDULE.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$PROGINDEX PAYMENTSCHEDULE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$INVESTOBJECT PAYMENTSCHEDULE.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$SUMMAYEAR4 PAYMENTSCHEDULE.SUMMAYEAR4%TYPE := :NEW.SUMMAYEAR4;
  new$SUMMAOTHERYEARS PAYMENTSCHEDULE.SUMMAOTHERYEARS%TYPE := :NEW.SUMMAOTHERYEARS;
  new$SUMMAYEAR4DELTA PAYMENTSCHEDULE.SUMMAYEAR4DELTA%TYPE := :NEW.SUMMAYEAR4DELTA;
  new$SUMMAOTHERYEARSDELTA PAYMENTSCHEDULE.SUMMAOTHERYEARSDELTA%TYPE := :NEW.SUMMAOTHERYEARSDELTA;
  new$CONTRACTCOSTSCLS PAYMENTSCHEDULE.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS PAYMENTSCHEDULE.TARGETCLS%TYPE := :NEW.TARGETCLS;
--
  M01$ NUMBER;
  M02$ NUMBER;
  M03$ NUMBER;
  M04$ NUMBER;
  M05$ NUMBER;
  M06$ NUMBER;
  M07$ NUMBER;
  M08$ NUMBER;
  M09$ NUMBER;
  M10$ NUMBER;
  M11$ NUMBER;
  M12$ NUMBER;
  Q1$ NUMBER;
  Q2$ NUMBER;
  Q3$ NUMBER;
  Q4$ NUMBER;
  S$ NUMBER;
  S1$ NUMBER;
  S2$ NUMBER;
  S3$ NUMBER;
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  S4$ NUMBER;
  SOther$ NUMBER;
  PreviousInner$ NUMBER(10);
  Tmp1$ NUMBER(10);
  AdjDocNum1$ NUMBER(10);
  InnerNumber_parent1$ NUMBER(10);
  InnerNumber_child1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_PAYMENTSCHEDULE_BI)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$Accepted is null) then 
    new$Accepted := 1;
  END IF;
  if (new$PromiseType is null) then 
    new$PromiseType := 0;
  END IF;
  if (new$KFSR is null) then 
    new$KFSR := 0;
  END IF;
  if (new$KESR is null) then 
    new$KESR := 0;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$KCSR is null) then 
    new$KCSR := 0;
  END IF;
  if (new$KVR is null) then 
    new$KVR := 0;
  END IF;
  if (new$SubKESR is null) then 
    new$SubKESR := 0;
  END IF;
  if (new$AssignmentKind is null) then 
    new$AssignmentKind := 0;
  END IF;
  if (new$DirectionCls is null) then 
    new$DirectionCls := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Region is null) then 
    new$Region := 0;
  END IF;
  if (new$MeansType is null) then 
    new$MeansType := 0;
  END IF;
  if (new$FinSource is null) then 
    new$FinSource := 0;
  END IF;
  if (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$Month01 is null) then 
    new$Month01 := 0;
  END IF;
  if (new$Month02 is null) then 
    new$Month02 := 0;
  END IF;
  if (new$Month03 is null) then 
    new$Month03 := 0;
  END IF;
  if (new$Month04 is null) then 
    new$Month04 := 0;
  END IF;
  if (new$Month05 is null) then 
    new$Month05 := 0;
  END IF;
  if (new$Month06 is null) then 
    new$Month06 := 0;
  END IF;
  if (new$Month07 is null) then 
    new$Month07 := 0;
  END IF;
  if (new$Month08 is null) then 
    new$Month08 := 0;
  END IF;
  if (new$Month09 is null) then 
    new$Month09 := 0;
  END IF;
  if (new$Month10 is null) then 
    new$Month10 := 0;
  END IF;
  if (new$Month11 is null) then 
    new$Month11 := 0;
  END IF;
  if (new$Month12 is null) then 
    new$Month12 := 0;
  END IF;
  if (new$Quarter1 is null) then 
    new$Quarter1 := 0;
  END IF;
  if (new$Quarter2 is null) then 
    new$Quarter2 := 0;
  END IF;
  if (new$Quarter3 is null) then 
    new$Quarter3 := 0;
  END IF;
  if (new$Quarter4 is null) then 
    new$Quarter4 := 0;
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$Month01Delta is null) then 
    new$Month01Delta := 0;
  END IF;
  if (new$Month02Delta is null) then 
    new$Month02Delta := 0;
  END IF;
  if (new$Month03Delta is null) then 
    new$Month03Delta := 0;
  END IF;
  if (new$Month04Delta is null) then 
    new$Month04Delta := 0;
  END IF;
  if (new$Month05Delta is null) then 
    new$Month05Delta := 0;
  END IF;
  if (new$Month06Delta is null) then 
    new$Month06Delta := 0;
  END IF;
  if (new$Month07Delta is null) then 
    new$Month07Delta := 0;
  END IF;
  if (new$Month08Delta is null) then 
    new$Month08Delta := 0;
  END IF;
  if (new$Month09Delta is null) then 
    new$Month09Delta := 0;
  END IF;
  if (new$Month10Delta is null) then 
    new$Month10Delta := 0;
  END IF;
  if (new$Month11Delta is null) then 
    new$Month11Delta := 0;
  END IF;
  if (new$Month12Delta is null) then 
    new$Month12Delta := 0;
  END IF;
  if (new$Quarter1Delta is null) then 
    new$Quarter1Delta := 0;
  END IF;
  if (new$Quarter2Delta is null) then 
    new$Quarter2Delta := 0;
  END IF;
  if (new$Quarter3Delta is null) then 
    new$Quarter3Delta := 0;
  END IF;
  if (new$Quarter4Delta is null) then 
    new$Quarter4Delta := 0;
  END IF;
  if (new$SummaDelta is null) then 
    new$SummaDelta := 0;
  END IF;
  if (new$SummaPreviousYear is null) then 
    new$SummaPreviousYear := 0;
  END IF;
  if (new$SummaFinPreviousYear is null) then 
    new$SummaFinPreviousYear := 0;
  END IF;
  if (new$SummaYear1 is null) then 
    new$SummaYear1 := 0;
  END IF;
  if (new$SummaYear2 is null) then 
    new$SummaYear2 := 0;
  END IF;
  if (new$SummaYear3 is null) then 
    new$SummaYear3 := 0;
  END IF;
  if (new$SummaYear4 is null) then 
    new$SummaYear4 := 0;
  END IF;
  if (new$SummaOtherYears is null) then 
    new$SummaOtherYears := 0;
  END IF;
  if (new$SummaYear1Delta is null) then 
    new$SummaYear1Delta := 0;
  END IF;
  if (new$SummaYear2Delta is null) then 
    new$SummaYear2Delta := 0;
  END IF;
  if (new$SummaYear3Delta is null) then 
    new$SummaYear3Delta := 0;
  END IF;
  if (new$SummaYear4Delta is null) then 
    new$SummaYear4Delta := 0;
  END IF;
  if (new$SummaOtherYearsDelta is null) then 
    new$SummaOtherYearsDelta := 0;
  END IF;
  /*   ,        */
  if (new$ProgIndex = 304 and new$RecordIndex is not null) then
    SELECT COUNT(*) INTO CNT$1
    from AgreementSteps s where (s.Id = new$RecordIndex and s.RecordIndex = new$AgreementRef) AND (ROWNUM = 1);
    if (not (CNT$1<> 0)) then
      RaiseException('Ex_WrongStep');
    END IF;
  END IF;
  /*       */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    if (new$ProgIndex in (304,314,317,318)) then
      BEGIN
        select a.BudgetRef       into new$BudgetRef from Agreements a
        where a.ID = new$AgreementRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    else 
      if (new$ProgIndex = 308) then
        BEGIN
          select e.BudgetRef
          into new$BudgetRef       from ExecutionDocumentsCaption e
          where e.ID = new$ExecutionRef
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
      END IF;
    END IF;
  END IF;
        
  /*    ,     ,      */
  if (new$AdjustmentRef is null) then
    select g_shared.nextval into new$InnerPromiseNum from dual;
  else
    /*      , ..     */
    if (new$Accepted = 0) then
      BEGIN
        select
        InnerPromiseNum 
        into PreviousInner$       from Paymentschedule
        where ID = new$AdjustmentRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    else
      BEGIN
        /*          */
        select
        InnerPromiseNum 
        into PreviousInner$       from Paymentschedule
        where ID = new$AdjustmentRef and LastAccepted = 1 and LastAdjustment = 1
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (PreviousInner$ is null) then
        RaiseException('EX_NotFindInnerNumber');    
      END IF;
    END IF;
    new$InnerPromiseNum := PreviousInner$;
      
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$ANumber is not null) then
    SELECT COUNT(                    id
    ) INTO CNT$2
    from
    PaymentSchedule ps
    where
    (                    (ps.ANumber = new$ANumber)
    and
    (ps.BudgetRef = new$BudgetRef)) AND (ROWNUM = 1);
    if ((CNT$2<> 0)) then
      RaiseException('ex_Promise_NumUQ');
    END IF;
  END IF;
  /*    */
  GETTARGETCLS(null, new$transfertcls, null, new$meanstype,
  new$targetcls,new$targetcls);     

-- - - - - - - - - - - - -
-- BI_1 (TR_PAYMENTSCHEDULE_BI_1)
-- Create 05.03.2004
-- Last update 29.12.2007
-- - - - - - - - - - - - -

/*   1.0*/
    if (new$Quarter1 = 0) then new$Quarter1 := new$Month01 + new$Month02 + new$Month03; end if;
    if (new$Quarter2 = 0) then new$Quarter2 := new$Month04 + new$Month05 + new$Month06; end if;
    if (new$Quarter3 = 0) then new$Quarter3 := new$Month07 + new$Month08 + new$Month09; end if;
    if (new$Quarter4 = 0) then new$Quarter4 := new$Month10 + new$Month11 + new$Month12; end if;
    new$SummaYear1 := new$Quarter1 + new$Quarter2 + new$Quarter3 + new$Quarter4;

-- - - - - - - - - - - - -
-- BI_10 (TR_PAYMENTSCHEDULE_BI_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
     
  /*    .*/
  if (new$InnerPromiseNum is null) then
    RaiseException('EX_BP_InnerNumsIsNull');
  END IF;
      
  /*    */
  select max(AdjustmentNumber)
  into Tmp1$         from PaymentSchedule 
  where (InnerPromiseNum = new$InnerPromiseNum)
  ;
  /*      ,   0*/
  if (Tmp1$ is null) then
    new$AdjustmentNumber := 0;
        
  else
    new$AdjustmentNumber := Tmp1$ + 1;
  END IF;
      
  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;
        
  else
    new$LastAdjustment := 1;
  END IF;
      
  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then 
    new$LastAccepted := 1;
        
  else
    new$LastAccepted := 0;
  END IF;
  /*     */
  if (new$AdjustmentRef is null) then
    /*       (    )*/        
    new$ParentNumber := null;
        
  else
    /*      -    */
    select count(ID), max(ANumber)
    into Tmp1$, AdjDocNum1$             from PaymentSchedule
    where (InnerPromiseNum = new$InnerPromiseNum) and (AcceptDate is not null)
    ;
    /*     ,  */    
    if (Tmp1$ = 0) then 
      RaiseException('EX_BP_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID) 
    into Tmp1$             from PaymentSchedule
    where (InnerPromiseNum = new$InnerPromiseNum) and (AcceptDate is null)
    ;
    if (Tmp1$ > 0) then 
      RaiseException('EX_BP_AdjustDuplicate');
    END IF;
    /* ,    ,    */        
    new$ParentNumber := AdjDocNum1$;
    /*   - ,  ,       */
    if (new$ProgIndex in (304, 314)) then
      BEGIN
        /*     */
        select a.InnerNumber
        into InnerNumber_child1$             from Agreements a
        where a.ID = new$AgreementRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN
        /*       */
        select a.InnerNumber
        into InnerNumber_parent1$             from PaymentSchedule ps
        left join Agreements a on (a.Id = ps.AgreementRef)
        where (ps.Id = new$AdjustmentRef)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*      */
      if (InnerNumber_parent1$ <> InnerNumber_child1$) then
        RaiseException('EX_PROMISE_ADJ_INCORRECT');        
      END IF;
    else 
      if (new$ProgIndex = 308) then
        BEGIN
          /*     */
          select edc.InnerNumber
          into InnerNumber_child1$             from ExecutionDocumentsCaption edc
          where edc.ID = new$ExecutionRef
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        BEGIN
          /*       */
          select edc.InnerNumber
          into InnerNumber_parent1$             from PaymentSchedule ps
          left join ExecutionDocumentsCaption edc on (edc.id=ps.ExecutionRef)
          where (ps.Id = new$AdjustmentRef)
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        /*      */
        if (InnerNumber_parent1$ <> InnerNumber_child1$) then
          RaiseException('EX_PROMISE_ADJ_INCORRECT');        
        END IF;
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_PAYMENTSCHEDULE_BI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*           */
  if (new$AdjustmentNumber > 0) then
    BEGIN
      select
      Month01, Month02, Month03, Month04, Month05, Month06,
      Month07, Month08, Month09, Month10, Month11, Month12,
      Quarter1, Quarter2, Quarter3, Quarter4, Summa,
      SummaYear1, SummaYear2, SummaYear3, SummaYear4, SummaOtherYears
      into
      M01$, M02$, M03$, M04$, M05$, M06$, M07$, M08$, M09$, M10$, M11$, M12$,
      Q1$, Q2$, Q3$, Q4$, S$, S1$, S2$, S3$, S4$, SOther$         from
      PaymentSchedule
      where
      ID = new$AdjustmentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    new$Month01Delta := new$Month01 - M01$;
    new$Month02Delta := new$Month02 - M02$;
    new$Month03Delta := new$Month03 - M03$;
    new$Month04Delta := new$Month04 - M04$;
    new$Month05Delta := new$Month05 - M05$;
    new$Month06Delta := new$Month06 - M06$;
    new$Month07Delta := new$Month07 - M07$;
    new$Month08Delta := new$Month08 - M08$;
    new$Month09Delta := new$Month09 - M09$;
    new$Month10Delta := new$Month10 - M10$;
    new$Month11Delta := new$Month11 - M11$;
    new$Month12Delta := new$Month12 - M12$;
    new$Quarter1Delta := new$Quarter1 - Q1$;
    new$Quarter2Delta := new$Quarter2 - Q2$;
    new$Quarter3Delta := new$Quarter3 - Q3$;
    new$Quarter4Delta := new$Quarter4 - Q4$;
    new$SummaDelta := new$Summa - S$;
    new$SummaYear1Delta := new$SummaYear1 - S1$;
    new$SummaYear2Delta := new$SummaYear2 - S2$;
    new$SummaYear3Delta := new$SummaYear3 - S3$;
    new$SummaYear4Delta := new$SummaYear4 - S4$;
    new$SummaOtherYearsDelta := new$SummaOtherYears - SOther$;

  else    /*        */
    new$Month01Delta := new$Month01;
    new$Month02Delta := new$Month02;
    new$Month03Delta := new$Month03;
    new$Month04Delta := new$Month04;
    new$Month05Delta := new$Month05;
    new$Month06Delta := new$Month06;
    new$Month07Delta := new$Month07;
    new$Month08Delta := new$Month08;
    new$Month09Delta := new$Month09;
    new$Month10Delta := new$Month10;
    new$Month11Delta := new$Month11;
    new$Month12Delta := new$Month12;
    new$Quarter1Delta := new$Quarter1;
    new$Quarter2Delta := new$Quarter2;
    new$Quarter3Delta := new$Quarter3;
    new$Quarter4Delta := new$Quarter4;
    new$SummaDelta := new$Summa;
    new$SummaYear1Delta := new$SummaYear1;
    new$SummaYear2Delta := new$SummaYear2;
    new$SummaYear3Delta := new$SummaYear3;
    new$SummaYear4Delta := new$SummaYear4;
    new$SummaOtherYearsDelta := new$SummaOtherYears;

  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_PAYMENTSCHEDULE_BI_200)
-- Create 06.08.2010
-- - - - - - - - - - - - -

  /*      */
  if (new$senderId is null) then
    new$senderIdKey := -1;
  else
    new$senderIdKey := new$senderId;
  end if;

  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  end if;

-- - - - - - - - - - - - -
-- BI_500 (TR_PAYMENTSCHEDULE_BI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_PAYMENTSCHEDULE (
    ID,
    ANUMBER,
    PARENTNUMBER,
    KFSR,
    KESR,
    KVSR,
    KCSR,
    KVR,
    MONTH01,
    MONTH02,
    MONTH03,
    MONTH04,
    MONTH05,
    MONTH06,
    MONTH07,
    MONTH08,
    MONTH09,
    MONTH10,
    MONTH11,
    MONTH12,
    SUMMA,
    REGION,
    SUBKESR,
    MEANSTYPE,
    FINSOURCE,
    FINTYPE,
    FACT,
    FACIALACC_CLS,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    ACCEPTDATE,
    LASTADJUSTMENT,
    ACCEPTED,
    LASTACCEPTED,
    PROMISETYPE,
    ADJUSTMENTREF,
    OLDNUMBER,
    SUMMAPREVIOUSYEAR,
    SUMMAFINPREVIOUSYEAR,
    QUARTER1,
    QUARTER2,
    QUARTER3,
    QUARTER4,
    RECORDINDEX,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DIRECTIONCLS,
    RVERSION,
    BUHOPERATIONCLS,
    MONTH01DELTA,
    MONTH02DELTA,
    MONTH03DELTA,
    MONTH04DELTA,
    MONTH05DELTA,
    MONTH06DELTA,
    MONTH07DELTA,
    MONTH08DELTA,
    MONTH09DELTA,
    MONTH10DELTA,
    MONTH11DELTA,
    MONTH12DELTA,
    QUARTER1DELTA,
    QUARTER2DELTA,
    QUARTER3DELTA,
    QUARTER4DELTA,
    SUMMADELTA,
    NOTE,
    FINYEAR,
    SUMMAYEAR1,
    SUMMAYEAR2,
    SUMMAYEAR3,
    SUMMAYEAR1DELTA,
    SUMMAYEAR2DELTA,
    SUMMAYEAR3DELTA,
    ASSIGNMENTKIND,
    TRANSFERTCLS,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    EXECUTIONREF,
    INNERPROMISENUM,
    ADJUSTMENTNUMBER,
    PROMISENUMBER,
    SUBSIDYCLS,
    AGREEMENTREF,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    PROGINDEX,
    INVESTOBJECT,
    SUMMAYEAR4,
    SUMMAOTHERYEARS,
    SUMMAYEAR4DELTA,
    SUMMAOTHERYEARSDELTA,
    CONTRACTCOSTSCLS,
    TARGETCLS
  ) VALUES (
    new$ID,
    new$ANUMBER,
    new$PARENTNUMBER,
    new$KFSR,
    new$KESR,
    new$KVSR,
    new$KCSR,
    new$KVR,
    new$MONTH01,
    new$MONTH02,
    new$MONTH03,
    new$MONTH04,
    new$MONTH05,
    new$MONTH06,
    new$MONTH07,
    new$MONTH08,
    new$MONTH09,
    new$MONTH10,
    new$MONTH11,
    new$MONTH12,
    new$SUMMA,
    new$REGION,
    new$SUBKESR,
    new$MEANSTYPE,
    new$FINSOURCE,
    new$FINTYPE,
    new$FACT,
    new$FACIALACC_CLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$ACCEPTDATE,
    new$LASTADJUSTMENT,
    new$ACCEPTED,
    new$LASTACCEPTED,
    new$PROMISETYPE,
    new$ADJUSTMENTREF,
    new$OLDNUMBER,
    new$SUMMAPREVIOUSYEAR,
    new$SUMMAFINPREVIOUSYEAR,
    new$QUARTER1,
    new$QUARTER2,
    new$QUARTER3,
    new$QUARTER4,
    new$RECORDINDEX,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$DIRECTIONCLS,
    new$RVERSION,
    new$BUHOPERATIONCLS,
    new$MONTH01DELTA,
    new$MONTH02DELTA,
    new$MONTH03DELTA,
    new$MONTH04DELTA,
    new$MONTH05DELTA,
    new$MONTH06DELTA,
    new$MONTH07DELTA,
    new$MONTH08DELTA,
    new$MONTH09DELTA,
    new$MONTH10DELTA,
    new$MONTH11DELTA,
    new$MONTH12DELTA,
    new$QUARTER1DELTA,
    new$QUARTER2DELTA,
    new$QUARTER3DELTA,
    new$QUARTER4DELTA,
    new$SUMMADELTA,
    new$NOTE,
    new$FINYEAR,
    new$SUMMAYEAR1,
    new$SUMMAYEAR2,
    new$SUMMAYEAR3,
    new$SUMMAYEAR1DELTA,
    new$SUMMAYEAR2DELTA,
    new$SUMMAYEAR3DELTA,
    new$ASSIGNMENTKIND,
    new$TRANSFERTCLS,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$EXECUTIONREF,
    new$INNERPROMISENUM,
    new$ADJUSTMENTNUMBER,
    new$PROMISENUMBER,
    new$SUBSIDYCLS,
    new$AGREEMENTREF,
    new$BUDALLOCATIONCLS,
    new$PAYPROMISECLS,
    new$PROGINDEX,
    new$INVESTOBJECT,
    new$SUMMAYEAR4,
    new$SUMMAOTHERYEARS,
    new$SUMMAYEAR4DELTA,
    new$SUMMAOTHERYEARSDELTA,
    new$CONTRACTCOSTSCLS,
    new$TARGETCLS);

-- - - - - - - - - - - - -
-- AI_10 (TR_PAYMENTSCHEDULE_AI_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  /*      */
  if ((new$AdjustmentRef is not null) and (new$LastAdjustment = 1)) then    
    update PaymentSchedule set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);            
    if (new$LastAccepted = 1) then
      update PaymentSchedule set
      LastAccepted = 0,
      RVersion = -1
      where (ID = new$AdjustmentRef);
        
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_PAYMENTSCHEDULE_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 113) and (RecordID = new$ID);

END;
/
-- CREATE TRIGGER TR_PAYMENTSCHEDULE_AU_10
CREATE OR REPLACE TRIGGER TR_PAYMENTSCHEDULE_IU
  INSTEAD OF UPDATE
  ON PAYMENTSCHEDULE
  FOR EACH ROW
DECLARE
  new$ID PAYMENTSCHEDULE.ID%TYPE := :NEW.ID;
  new$ANUMBER PAYMENTSCHEDULE.ANUMBER%TYPE := :NEW.ANUMBER;
  new$PARENTNUMBER PAYMENTSCHEDULE.PARENTNUMBER%TYPE := :NEW.PARENTNUMBER;
  new$KFSR PAYMENTSCHEDULE.KFSR%TYPE := :NEW.KFSR;
  new$KESR PAYMENTSCHEDULE.KESR%TYPE := :NEW.KESR;
  new$KVSR PAYMENTSCHEDULE.KVSR%TYPE := :NEW.KVSR;
  new$KCSR PAYMENTSCHEDULE.KCSR%TYPE := :NEW.KCSR;
  new$KVR PAYMENTSCHEDULE.KVR%TYPE := :NEW.KVR;
  new$MONTH01 PAYMENTSCHEDULE.MONTH01%TYPE := :NEW.MONTH01;
  new$MONTH02 PAYMENTSCHEDULE.MONTH02%TYPE := :NEW.MONTH02;
  new$MONTH03 PAYMENTSCHEDULE.MONTH03%TYPE := :NEW.MONTH03;
  new$MONTH04 PAYMENTSCHEDULE.MONTH04%TYPE := :NEW.MONTH04;
  new$MONTH05 PAYMENTSCHEDULE.MONTH05%TYPE := :NEW.MONTH05;
  new$MONTH06 PAYMENTSCHEDULE.MONTH06%TYPE := :NEW.MONTH06;
  new$MONTH07 PAYMENTSCHEDULE.MONTH07%TYPE := :NEW.MONTH07;
  new$MONTH08 PAYMENTSCHEDULE.MONTH08%TYPE := :NEW.MONTH08;
  new$MONTH09 PAYMENTSCHEDULE.MONTH09%TYPE := :NEW.MONTH09;
  new$MONTH10 PAYMENTSCHEDULE.MONTH10%TYPE := :NEW.MONTH10;
  new$MONTH11 PAYMENTSCHEDULE.MONTH11%TYPE := :NEW.MONTH11;
  new$MONTH12 PAYMENTSCHEDULE.MONTH12%TYPE := :NEW.MONTH12;
  new$SUMMA PAYMENTSCHEDULE.SUMMA%TYPE := :NEW.SUMMA;
  new$REGION PAYMENTSCHEDULE.REGION%TYPE := :NEW.REGION;
  new$SUBKESR PAYMENTSCHEDULE.SUBKESR%TYPE := :NEW.SUBKESR;
  new$MEANSTYPE PAYMENTSCHEDULE.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FINSOURCE PAYMENTSCHEDULE.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE PAYMENTSCHEDULE.FINTYPE%TYPE := :NEW.FINTYPE;
  new$FACT PAYMENTSCHEDULE.FACT%TYPE := :NEW.FACT;
  new$FACIALACC_CLS PAYMENTSCHEDULE.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$CREATERUSER PAYMENTSCHEDULE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYMENTSCHEDULE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PAYMENTSCHEDULE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PAYMENTSCHEDULE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF PAYMENTSCHEDULE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ACCEPTDATE PAYMENTSCHEDULE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$LASTADJUSTMENT PAYMENTSCHEDULE.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$ACCEPTED PAYMENTSCHEDULE.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED PAYMENTSCHEDULE.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$PROMISETYPE PAYMENTSCHEDULE.PROMISETYPE%TYPE := :NEW.PROMISETYPE;
  new$ADJUSTMENTREF PAYMENTSCHEDULE.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$OLDNUMBER PAYMENTSCHEDULE.OLDNUMBER%TYPE := :NEW.OLDNUMBER;
  new$SUMMAPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAPREVIOUSYEAR%TYPE := :NEW.SUMMAPREVIOUSYEAR;
  new$SUMMAFINPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAFINPREVIOUSYEAR%TYPE := :NEW.SUMMAFINPREVIOUSYEAR;
  new$QUARTER1 PAYMENTSCHEDULE.QUARTER1%TYPE := :NEW.QUARTER1;
  new$QUARTER2 PAYMENTSCHEDULE.QUARTER2%TYPE := :NEW.QUARTER2;
  new$QUARTER3 PAYMENTSCHEDULE.QUARTER3%TYPE := :NEW.QUARTER3;
  new$QUARTER4 PAYMENTSCHEDULE.QUARTER4%TYPE := :NEW.QUARTER4;
  new$RECORDINDEX PAYMENTSCHEDULE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CRYPTOSTATUS PAYMENTSCHEDULE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PAYMENTSCHEDULE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PAYMENTSCHEDULE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DIRECTIONCLS PAYMENTSCHEDULE.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$RVERSION PAYMENTSCHEDULE.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYMENTSCHEDULE.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MONTH01DELTA PAYMENTSCHEDULE.MONTH01DELTA%TYPE := :NEW.MONTH01DELTA;
  new$MONTH02DELTA PAYMENTSCHEDULE.MONTH02DELTA%TYPE := :NEW.MONTH02DELTA;
  new$MONTH03DELTA PAYMENTSCHEDULE.MONTH03DELTA%TYPE := :NEW.MONTH03DELTA;
  new$MONTH04DELTA PAYMENTSCHEDULE.MONTH04DELTA%TYPE := :NEW.MONTH04DELTA;
  new$MONTH05DELTA PAYMENTSCHEDULE.MONTH05DELTA%TYPE := :NEW.MONTH05DELTA;
  new$MONTH06DELTA PAYMENTSCHEDULE.MONTH06DELTA%TYPE := :NEW.MONTH06DELTA;
  new$MONTH07DELTA PAYMENTSCHEDULE.MONTH07DELTA%TYPE := :NEW.MONTH07DELTA;
  new$MONTH08DELTA PAYMENTSCHEDULE.MONTH08DELTA%TYPE := :NEW.MONTH08DELTA;
  new$MONTH09DELTA PAYMENTSCHEDULE.MONTH09DELTA%TYPE := :NEW.MONTH09DELTA;
  new$MONTH10DELTA PAYMENTSCHEDULE.MONTH10DELTA%TYPE := :NEW.MONTH10DELTA;
  new$MONTH11DELTA PAYMENTSCHEDULE.MONTH11DELTA%TYPE := :NEW.MONTH11DELTA;
  new$MONTH12DELTA PAYMENTSCHEDULE.MONTH12DELTA%TYPE := :NEW.MONTH12DELTA;
  new$QUARTER1DELTA PAYMENTSCHEDULE.QUARTER1DELTA%TYPE := :NEW.QUARTER1DELTA;
  new$QUARTER2DELTA PAYMENTSCHEDULE.QUARTER2DELTA%TYPE := :NEW.QUARTER2DELTA;
  new$QUARTER3DELTA PAYMENTSCHEDULE.QUARTER3DELTA%TYPE := :NEW.QUARTER3DELTA;
  new$QUARTER4DELTA PAYMENTSCHEDULE.QUARTER4DELTA%TYPE := :NEW.QUARTER4DELTA;
  new$SUMMADELTA PAYMENTSCHEDULE.SUMMADELTA%TYPE := :NEW.SUMMADELTA;
  new$NOTE PAYMENTSCHEDULE.NOTE%TYPE := :NEW.NOTE;
  new$FINYEAR PAYMENTSCHEDULE.FINYEAR%TYPE := :NEW.FINYEAR;
  new$SUMMAYEAR1 PAYMENTSCHEDULE.SUMMAYEAR1%TYPE := :NEW.SUMMAYEAR1;
  new$SUMMAYEAR2 PAYMENTSCHEDULE.SUMMAYEAR2%TYPE := :NEW.SUMMAYEAR2;
  new$SUMMAYEAR3 PAYMENTSCHEDULE.SUMMAYEAR3%TYPE := :NEW.SUMMAYEAR3;
  new$SUMMAYEAR1DELTA PAYMENTSCHEDULE.SUMMAYEAR1DELTA%TYPE := :NEW.SUMMAYEAR1DELTA;
  new$SUMMAYEAR2DELTA PAYMENTSCHEDULE.SUMMAYEAR2DELTA%TYPE := :NEW.SUMMAYEAR2DELTA;
  new$SUMMAYEAR3DELTA PAYMENTSCHEDULE.SUMMAYEAR3DELTA%TYPE := :NEW.SUMMAYEAR3DELTA;
  new$ASSIGNMENTKIND PAYMENTSCHEDULE.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$TRANSFERTCLS PAYMENTSCHEDULE.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SENDERIDKEY PAYMENTSCHEDULE.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY PAYMENTSCHEDULE.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXECUTIONREF PAYMENTSCHEDULE.EXECUTIONREF%TYPE := :NEW.EXECUTIONREF;
  new$INNERPROMISENUM PAYMENTSCHEDULE.INNERPROMISENUM%TYPE := :NEW.INNERPROMISENUM;
  new$ADJUSTMENTNUMBER PAYMENTSCHEDULE.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$PROMISENUMBER PAYMENTSCHEDULE.PROMISENUMBER%TYPE := :NEW.PROMISENUMBER;
  new$SUBSIDYCLS PAYMENTSCHEDULE.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$AGREEMENTREF PAYMENTSCHEDULE.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$BUDALLOCATIONCLS PAYMENTSCHEDULE.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS PAYMENTSCHEDULE.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$PROGINDEX PAYMENTSCHEDULE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$INVESTOBJECT PAYMENTSCHEDULE.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$SUMMAYEAR4 PAYMENTSCHEDULE.SUMMAYEAR4%TYPE := :NEW.SUMMAYEAR4;
  new$SUMMAOTHERYEARS PAYMENTSCHEDULE.SUMMAOTHERYEARS%TYPE := :NEW.SUMMAOTHERYEARS;
  new$SUMMAYEAR4DELTA PAYMENTSCHEDULE.SUMMAYEAR4DELTA%TYPE := :NEW.SUMMAYEAR4DELTA;
  new$SUMMAOTHERYEARSDELTA PAYMENTSCHEDULE.SUMMAOTHERYEARSDELTA%TYPE := :NEW.SUMMAOTHERYEARSDELTA;
  new$CONTRACTCOSTSCLS PAYMENTSCHEDULE.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS PAYMENTSCHEDULE.TARGETCLS%TYPE := :NEW.TARGETCLS;
--
  M01$ NUMBER;
  M02$ NUMBER;
  M03$ NUMBER;
  M04$ NUMBER;
  M05$ NUMBER;
  M06$ NUMBER;
  M07$ NUMBER;
  M08$ NUMBER;
  M09$ NUMBER;
  M10$ NUMBER;
  M11$ NUMBER;
  M12$ NUMBER;
  Q1$ NUMBER;
  Q2$ NUMBER;
  Q3$ NUMBER;
  Q4$ NUMBER;
  S$ NUMBER;
  S1$ NUMBER;
  S2$ NUMBER;
  S3$ NUMBER;
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  S4$ NUMBER;
  SOther$ NUMBER;
  previousAccept$ NUMBER(10);
  previousAcceptDate$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_PAYMENTSCHEDULE_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*   2.4*/
  /*    -*/
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  if (new$PromiseType is null) then
    new$PromiseType := 0;
  END IF;
  if (new$KFSR is null) then
    new$KFSR := 0;
  END IF;
  if (new$KESR is null) then
    new$KESR := 0;
  END IF;
  if (new$KVSR is null) then
    new$KVSR := 0;
  END IF;
  if (new$KCSR is null) then
    new$KCSR := 0;
  END IF;
  if (new$KVR is null) then
    new$KVR := 0;
  END IF;
  if (new$SubKESR is null) then
    new$SubKESR := 0;
  END IF;
  if (new$AssignmentKind is null) then
    new$AssignmentKind := 0;
  END IF;

  if (new$DirectionCls is null) then
    new$DirectionCls := 0;
  END IF;

  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$MeansType is null) then
    new$MeansType := 0;
  END IF;
  if (new$FinSource is null) then
    new$FinSource := 0;
  END IF;
  if (new$FinType is null) then
    new$FinType := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$Month01 is null) then
    new$Month01 := 0;
  END IF;
  if (new$Month02 is null) then
    new$Month02 := 0;
  END IF;
  if (new$Month03 is null) then
    new$Month03 := 0;
  END IF;
  if (new$Month04 is null) then
    new$Month04 := 0;
  END IF;
  if (new$Month05 is null) then
    new$Month05 := 0;
  END IF;
  if (new$Month06 is null) then
    new$Month06 := 0;
  END IF;
  if (new$Month07 is null) then
    new$Month07 := 0;
  END IF;
  if (new$Month08 is null) then
    new$Month08 := 0;
  END IF;
  if (new$Month09 is null) then
    new$Month09 := 0;
  END IF;
  if (new$Month10 is null) then
    new$Month10 := 0;
  END IF;
  if (new$Month11 is null) then
    new$Month11 := 0;
  END IF;
  if (new$Month12 is null) then
    new$Month12 := 0;
  END IF;
  if (new$Quarter1 is null) then
    new$Quarter1 := 0;
  END IF;
  if (new$Quarter2 is null) then
    new$Quarter2 := 0;
  END IF;
  if (new$Quarter3 is null) then
    new$Quarter3 := 0;
  END IF;
  if (new$Quarter4 is null) then
    new$Quarter4 := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$Month01Delta is null) then
    new$Month01Delta := 0;
  END IF;
  if (new$Month02Delta is null) then
    new$Month02Delta := 0;
  END IF;
  if (new$Month03Delta is null) then
    new$Month03Delta := 0;
  END IF;
  if (new$Month04Delta is null) then
    new$Month04Delta := 0;
  END IF;
  if (new$Month05Delta is null) then
    new$Month05Delta := 0;
  END IF;
  if (new$Month06Delta is null) then
    new$Month06Delta := 0;
  END IF;
  if (new$Month07Delta is null) then
    new$Month07Delta := 0;
  END IF;
  if (new$Month08Delta is null) then
    new$Month08Delta := 0;
  END IF;
  if (new$Month09Delta is null) then
    new$Month09Delta := 0;
  END IF;
  if (new$Month10Delta is null) then
    new$Month10Delta := 0;
  END IF;
  if (new$Month11Delta is null) then
    new$Month11Delta := 0;
  END IF;
  if (new$Month12Delta is null) then
    new$Month12Delta := 0;
  END IF;
  if (new$Quarter1Delta is null) then
    new$Quarter1Delta := 0;
  END IF;
  if (new$Quarter2Delta is null) then
    new$Quarter2Delta := 0;
  END IF;
  if (new$Quarter3Delta is null) then
    new$Quarter3Delta := 0;
  END IF;
  if (new$Quarter4Delta is null) then
    new$Quarter4Delta := 0;
  END IF;
  if (new$SummaDelta is null) then
    new$SummaDelta := 0;
  END IF;
  if (new$SummaPreviousYear is null) then
    new$SummaPreviousYear := 0;
  END IF;
  if (new$SummaFinPreviousYear is null) then
    new$SummaFinPreviousYear := 0;
  END IF;

  if (new$SummaYear1 is null) then
    new$SummaYear1 := 0;
  END IF;
  if (new$SummaYear2 is null) then
    new$SummaYear2 := 0;
  END IF;
  if (new$SummaYear3 is null) then
    new$SummaYear3 := 0;
  END IF;
  if (new$SummaYear4 is null) then
    new$SummaYear4 := 0;
  END IF;
  if (new$SummaOtherYears is null) then
    new$SummaOtherYears := 0;
  END IF;

  if (new$SummaYear1Delta is null) then
    new$SummaYear1Delta := 0;
  END IF;
  if (new$SummaYear2Delta is null) then
    new$SummaYear2Delta := 0;
  END IF;
  if (new$SummaYear3Delta is null) then
    new$SummaYear3Delta := 0;
  END IF;
  if (new$SummaYear4Delta is null) then
    new$SummaYear4Delta := 0;
  END IF;
  if (new$SummaOtherYearsDelta is null) then
    new$SummaOtherYearsDelta := 0;
  END IF;

  /*   ,        */
  if (new$ProgIndex = 304 and new$RecordIndex is not null and (:old.RecordIndex is null or :old.RecordIndex <> new$RecordIndex)) then
    SELECT COUNT(*) INTO CNT$1
    from AgreementSteps s where (s.Id = new$RecordIndex and s.RecordIndex = new$AgreementRef) AND (ROWNUM = 1);
    if (not (CNT$1<> 0)) then
      RaiseException('Ex_WrongStep');
    END IF;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      RaiseException('Ex_CantModufyBudget');
    END IF;
  END IF;
  if ((:old.ANumber is null) and (new$ANumber is not Null)) then
    SELECT COUNT(                    id
    ) INTO CNT$2
    from
    PaymentSchedule ps
    where
    (                    (ps.ANumber = new$ANumber)
    and
    (ps.BudgetRef = new$BudgetRef)) AND (ROWNUM = 1);
    if ((CNT$2<> 0)) then
      RaiseException('ex_Promise_NumUQ');
    END IF;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls);

-- - - - - - - - - - - - -
-- BU_1 (TR_PAYMENTSCHEDULE_BU_1)
-- Create 05.03.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  /*   1.0*/
    if (new$Quarter1 = 0) then new$Quarter1 := new$Month01 + new$Month02 + new$Month03; end if;
    if (new$Quarter2 = 0) then new$Quarter2 := new$Month04 + new$Month05 + new$Month06; end if;
    if (new$Quarter3 = 0) then new$Quarter3 := new$Month07 + new$Month08 + new$Month09; end if;
    if (new$Quarter4 = 0) then new$Quarter4 := new$Month10 + new$Month11 + new$Month12; end if;
    new$SummaYear1 := new$Quarter1 + new$Quarter2 + new$Quarter3 + new$Quarter4;

-- - - - - - - - - - - - -
-- BU_3 (TR_PAYMENTSCHEDULE_BU_3)
-- Create 03.12.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

    /*            */
    new$AdjustmentRef := :old.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_10 (TR_PAYMENTSCHEDULE_BU_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  /* ,      ,   */
  if ((new$ANumber <> :old.ANumber) or
  (new$AdjustmentRef <> :old.AdjustmentRef) or
  (new$InnerPromiseNum <> :old.InnerPromiseNum) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber)) then
    RaiseException('EX_AGR_ChangeInnerNums');
  END IF;
      
  /*   */
  if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and 
  ((new$Accepted = 1) or (new$AcceptDate is null))) then
    BEGIN
      /*             */
      select Accepted, AcceptDate
      into previousAccept$, previousAcceptDate$       from Paymentschedule
      where id=new$Adjustmentref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$Adjustmentref is not null and (previousAccept$ = 0 or previousAcceptDate$ is null)) then
      RaiseException('EX_RollbackCancel');
    END IF;
    new$LastAdjustment := 1;
        
  END IF;
  /*   ,     LastAccepted*/
  if ((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;
              
    else
      RaiseException('EX_BP_ChangeStateAdjust');
    END IF;
  END IF;
  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 0 and new$AcceptDate is not null and new$Accepted = 1) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;
              
    else
      RaiseException('EX_BP_ChangeStateAdjust');
    END IF;
  END IF;
      
  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;
              
    else
      RaiseException('EX_BP_ChangeStateAdjust');
    END IF;
  END IF;
      
  /*   ,     LastAdjustment*/
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment <> 1) then
      RaiseException('EX_BP_ChangeStateAdjust');
    else
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
              
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_PAYMENTSCHEDULE_BU_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*           */
  if (new$AdjustmentNumber > 0) then
    BEGIN
      select
      Month01, Month02, Month03, Month04, Month05, Month06,
      Month07, Month08, Month09, Month10, Month11, Month12,
      Quarter1, Quarter2, Quarter3, Quarter4, Summa,
      SummaYear1, SummaYear2, SummaYear3, SummaYear4, SummaOtherYears
      into
      M01$, M02$, M03$, M04$, M05$, M06$, M07$, M08$, M09$, M10$, M11$, M12$,
      Q1$, Q2$, Q3$, Q4$, S$, S1$, S2$, S3$, S4$, SOther$         from
      PaymentSchedule
      where
      ID = new$AdjustmentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    new$Month01Delta := new$Month01 - M01$;
    new$Month02Delta := new$Month02 - M02$;
    new$Month03Delta := new$Month03 - M03$;
    new$Month04Delta := new$Month04 - M04$;
    new$Month05Delta := new$Month05 - M05$;
    new$Month06Delta := new$Month06 - M06$;
    new$Month07Delta := new$Month07 - M07$;
    new$Month08Delta := new$Month08 - M08$;
    new$Month09Delta := new$Month09 - M09$;
    new$Month10Delta := new$Month10 - M10$;
    new$Month11Delta := new$Month11 - M11$;
    new$Month12Delta := new$Month12 - M12$;
    new$Quarter1Delta := new$Quarter1 - Q1$;
    new$Quarter2Delta := new$Quarter2 - Q2$;
    new$Quarter3Delta := new$Quarter3 - Q3$;
    new$Quarter4Delta := new$Quarter4 - Q4$;
    new$SummaDelta := new$Summa - S$;
    new$SummaYear1Delta := new$SummaYear1 - S1$;
    new$SummaYear2Delta := new$SummaYear2 - S2$;
    new$SummaYear3Delta := new$SummaYear3 - S3$;
    new$SummaYear4Delta := new$SummaYear4 - S4$;
    new$SummaOtherYearsDelta := new$SummaOtherYears - SOther$;

  else /*        */
    new$Month01Delta := new$Month01;
    new$Month02Delta := new$Month02;
    new$Month03Delta := new$Month03;
    new$Month04Delta := new$Month04;
    new$Month05Delta := new$Month05;
    new$Month06Delta := new$Month06;
    new$Month07Delta := new$Month07;
    new$Month08Delta := new$Month08;
    new$Month09Delta := new$Month09;
    new$Month10Delta := new$Month10;
    new$Month11Delta := new$Month11;
    new$Month12Delta := new$Month12;
    new$Quarter1Delta := new$Quarter1;
    new$Quarter2Delta := new$Quarter2;
    new$Quarter3Delta := new$Quarter3;
    new$Quarter4Delta := new$Quarter4;
    new$SummaDelta := new$Summa;
    new$SummaYear1Delta := new$SummaYear1;
    new$SummaYear2Delta := new$SummaYear2;
    new$SummaYear3Delta := new$SummaYear3;
    new$SummaYear4Delta := new$SummaYear4;
    new$SummaOtherYearsDelta := new$SummaOtherYears;

  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_PAYMENTSCHEDULE_BU_200)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*    */
  if (new$Accepted = 0 and new$AcceptDate is not null and :old.Accepted = 1) then
    /*   ,     
         *    ,      */
    FOR REC$1 IN (      select ffc.Reject_Cls  AS DocumentRejectCls from FacialFinDetail ffd
    left join FacialFinCaption ffc on (ffc.ID = ffd.RecordIndex)
    where SourcePromise = new$ANumber and SourceBudgetPromise = new$InnerPromiseNum
    or DestPromise = new$ANumber and DestBudgetPromise = new$InnerPromiseNum
    )
    LOOP
      if (REC$1.DocumentRejectCls is null) then
        RaiseException('Ex_BP_CannotReject');
      END IF;
    END LOOP;
    /* ,         */
    FOR REC$1 IN (      SELECT Count(ps_in.ID)  AS AdjCount FROM PaymentSchedule ps_in
    WHERE (ps_in.InnerPromiseNum = new$InnerPromiseNum)and(ps_in.AdjustmentNumber > new$AdjustmentNumber)
    and (ps_in.Accepted<>0)
    )
    LOOP
      if (REC$1.AdjCount > 0) then
        RaiseException('EX_BP_AdjustmentedCANNOTREJECT');
      END IF;
    END LOOP;
  END IF;
  /*   .       */
  if (new$Accepted = 1 and new$AcceptDate is null and :old.Accepted = 1 and :old.AcceptDate is not null) then
    SELECT COUNT(ffc.Reject_Cls ) INTO CNT$1
    from FacialFinDetail ffd
    left join FacialFinCaption ffc on (ffc.ID = ffd.RecordIndex)
    where ((SourcePromise = new$ANumber and SourceBudgetPromise = new$InnerPromiseNum
    or DestPromise = new$ANumber and DestBudgetPromise = new$InnerPromiseNum)
    and ffc.acceptdate is not null and ffc.Reject_cls is null) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_BP_NOTACCEPTED');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (tr_PaymentSchedule_BU_400)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$AgreementRef <> :old.AgreementRef or new$ExecutionRef <> :old.ExecutionRef) then
    RaiseException('EX_CANTCHANGECAPTIONREF');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_PAYMENTSCHEDULE_BU_700)
-- Create 14.10.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$RVersion is null) then
    new$RVersion := 1;
  elsif ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
    new$RVersion := :Old.RVersion;
  else
    new$RVersion := :Old.RVersion + 1;
  end if;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_PAYMENTSCHEDULE SET
    ID = new$ID,
    ANUMBER = new$ANUMBER,
    PARENTNUMBER = new$PARENTNUMBER,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVSR = new$KVSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    MONTH01 = new$MONTH01,
    MONTH02 = new$MONTH02,
    MONTH03 = new$MONTH03,
    MONTH04 = new$MONTH04,
    MONTH05 = new$MONTH05,
    MONTH06 = new$MONTH06,
    MONTH07 = new$MONTH07,
    MONTH08 = new$MONTH08,
    MONTH09 = new$MONTH09,
    MONTH10 = new$MONTH10,
    MONTH11 = new$MONTH11,
    MONTH12 = new$MONTH12,
    SUMMA = new$SUMMA,
    REGION = new$REGION,
    SUBKESR = new$SUBKESR,
    MEANSTYPE = new$MEANSTYPE,
    FINSOURCE = new$FINSOURCE,
    FINTYPE = new$FINTYPE,
    FACT = new$FACT,
    FACIALACC_CLS = new$FACIALACC_CLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    ACCEPTDATE = new$ACCEPTDATE,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    ACCEPTED = new$ACCEPTED,
    LASTACCEPTED = new$LASTACCEPTED,
    PROMISETYPE = new$PROMISETYPE,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    OLDNUMBER = new$OLDNUMBER,
    SUMMAPREVIOUSYEAR = new$SUMMAPREVIOUSYEAR,
    SUMMAFINPREVIOUSYEAR = new$SUMMAFINPREVIOUSYEAR,
    QUARTER1 = new$QUARTER1,
    QUARTER2 = new$QUARTER2,
    QUARTER3 = new$QUARTER3,
    QUARTER4 = new$QUARTER4,
    RECORDINDEX = new$RECORDINDEX,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DIRECTIONCLS = new$DIRECTIONCLS,
    RVERSION = new$RVERSION,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    MONTH01DELTA = new$MONTH01DELTA,
    MONTH02DELTA = new$MONTH02DELTA,
    MONTH03DELTA = new$MONTH03DELTA,
    MONTH04DELTA = new$MONTH04DELTA,
    MONTH05DELTA = new$MONTH05DELTA,
    MONTH06DELTA = new$MONTH06DELTA,
    MONTH07DELTA = new$MONTH07DELTA,
    MONTH08DELTA = new$MONTH08DELTA,
    MONTH09DELTA = new$MONTH09DELTA,
    MONTH10DELTA = new$MONTH10DELTA,
    MONTH11DELTA = new$MONTH11DELTA,
    MONTH12DELTA = new$MONTH12DELTA,
    QUARTER1DELTA = new$QUARTER1DELTA,
    QUARTER2DELTA = new$QUARTER2DELTA,
    QUARTER3DELTA = new$QUARTER3DELTA,
    QUARTER4DELTA = new$QUARTER4DELTA,
    SUMMADELTA = new$SUMMADELTA,
    NOTE = new$NOTE,
    FINYEAR = new$FINYEAR,
    SUMMAYEAR1 = new$SUMMAYEAR1,
    SUMMAYEAR2 = new$SUMMAYEAR2,
    SUMMAYEAR3 = new$SUMMAYEAR3,
    SUMMAYEAR1DELTA = new$SUMMAYEAR1DELTA,
    SUMMAYEAR2DELTA = new$SUMMAYEAR2DELTA,
    SUMMAYEAR3DELTA = new$SUMMAYEAR3DELTA,
    ASSIGNMENTKIND = new$ASSIGNMENTKIND,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    EXECUTIONREF = new$EXECUTIONREF,
    INNERPROMISENUM = new$INNERPROMISENUM,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    PROMISENUMBER = new$PROMISENUMBER,
    SUBSIDYCLS = new$SUBSIDYCLS,
    AGREEMENTREF = new$AGREEMENTREF,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    PAYPROMISECLS = new$PAYPROMISECLS,
    PROGINDEX = new$PROGINDEX,
    INVESTOBJECT = new$INVESTOBJECT,
    SUMMAYEAR4 = new$SUMMAYEAR4,
    SUMMAOTHERYEARS = new$SUMMAOTHERYEARS,
    SUMMAYEAR4DELTA = new$SUMMAYEAR4DELTA,
    SUMMAOTHERYEARSDELTA = new$SUMMAOTHERYEARSDELTA,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_10 (TR_PAYMENTSCHEDULE_AU_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  /*      */
  /*        */
  if ((new$AdjustmentRef is not null) and (new$LastAdjustment = 1)) then
    update PaymentSchedule set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);        
  END IF;
      
  /*              */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and ((:old.LastAdjustment = 1) or (new$LastAdjustment = 1))) then
    update PaymentSchedule set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment    */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and 
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update PaymentSchedule set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_PAYMENTSCHEDULE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (113, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=113) and (RecordId=new$ID);
  end if;

END;
/
-- CREATE TRIGGER TR_PAYMENTSCHEDULE_AD_10
CREATE OR REPLACE TRIGGER TR_PAYMENTSCHEDULE_ID
  INSTEAD OF DELETE
  ON PAYMENTSCHEDULE
  FOR EACH ROW
DECLARE
  SummInMonths$ NUMBER(15,2);
  cnt1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_PAYMENTSCHEDULE_BD)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*   6.0*/
  select count(ID) into cnt1$ from PaymentSchedule where (AdjustmentRef = :old.ID) ;
  if (cnt1$ > 0) then
    RaiseException('EX_Agr_CantDelAdjustmented');
  END IF;

  select count(ID)
  into cnt1$   from FacialFinDetail
  where (SourceBudgetPromise = :old.InnerPromiseNum and SourcePromise=:old.ANumber)
  or (DestBudgetPromise = :old.InnerPromiseNum and DestPromise=:old.ANumber)
  ;
  if (cnt1$ > 0) then
    RaiseException('ex_CantDeleteAgreement');
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_PAYMENTSCHEDULE
  WHERE Id = :old.id;

-- - - - - - - - - - - - -
-- AD_10 (TR_PAYMENTSCHEDULE_AD_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  /*   LastAdjustment     */
  if ((:old.AdjustmentRef is not null) and (:old.LastAdjustment = 1)) then
    update PaymentSchedule set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;
  /*   LastAccepted     */    
  if ((:old.AdjustmentRef is not null) and (:old.LastAccepted = 1)) then
    update PaymentSchedule set
    LastAccepted = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);        
  END IF;

-- - - - - - - - - - - - -
-- AD_500 (TR_PAYMENTSCHEDULE_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  SummInMonths$ := :old.Month01+:old.Month02+:old.Month03+:old.Month04+:old.Month05+
  :old.Month06+:old.Month07+:old.Month08+:old.Month09+:old.Month10+:old.Month11+:old.Month12;
  if ((SummInMonths$  < 0.005) and (SummInMonths$  > -0.005)) then
    SummInMonths$ := :old.SummaYear1;
  END IF;
  insert into DelRecIndexes(TableID, RecordID, DeleteDate, ProgIndex, SUMMA) values (113, :old.ID, SYSDATE, :old.ProgIndex, SummInMonths$);

END;
/
commit
/
-- drop trigger TR_PAYMENTSCHEDULE_BU_3
CREATE OR REPLACE TRIGGER TR_PAYMENTSCHEDULE_IU
  INSTEAD OF UPDATE
  ON PAYMENTSCHEDULE
  FOR EACH ROW
DECLARE
  new$ID PAYMENTSCHEDULE.ID%TYPE := :NEW.ID;
  new$ANUMBER PAYMENTSCHEDULE.ANUMBER%TYPE := :NEW.ANUMBER;
  new$PARENTNUMBER PAYMENTSCHEDULE.PARENTNUMBER%TYPE := :NEW.PARENTNUMBER;
  new$KFSR PAYMENTSCHEDULE.KFSR%TYPE := :NEW.KFSR;
  new$KESR PAYMENTSCHEDULE.KESR%TYPE := :NEW.KESR;
  new$KVSR PAYMENTSCHEDULE.KVSR%TYPE := :NEW.KVSR;
  new$KCSR PAYMENTSCHEDULE.KCSR%TYPE := :NEW.KCSR;
  new$KVR PAYMENTSCHEDULE.KVR%TYPE := :NEW.KVR;
  new$MONTH01 PAYMENTSCHEDULE.MONTH01%TYPE := :NEW.MONTH01;
  new$MONTH02 PAYMENTSCHEDULE.MONTH02%TYPE := :NEW.MONTH02;
  new$MONTH03 PAYMENTSCHEDULE.MONTH03%TYPE := :NEW.MONTH03;
  new$MONTH04 PAYMENTSCHEDULE.MONTH04%TYPE := :NEW.MONTH04;
  new$MONTH05 PAYMENTSCHEDULE.MONTH05%TYPE := :NEW.MONTH05;
  new$MONTH06 PAYMENTSCHEDULE.MONTH06%TYPE := :NEW.MONTH06;
  new$MONTH07 PAYMENTSCHEDULE.MONTH07%TYPE := :NEW.MONTH07;
  new$MONTH08 PAYMENTSCHEDULE.MONTH08%TYPE := :NEW.MONTH08;
  new$MONTH09 PAYMENTSCHEDULE.MONTH09%TYPE := :NEW.MONTH09;
  new$MONTH10 PAYMENTSCHEDULE.MONTH10%TYPE := :NEW.MONTH10;
  new$MONTH11 PAYMENTSCHEDULE.MONTH11%TYPE := :NEW.MONTH11;
  new$MONTH12 PAYMENTSCHEDULE.MONTH12%TYPE := :NEW.MONTH12;
  new$SUMMA PAYMENTSCHEDULE.SUMMA%TYPE := :NEW.SUMMA;
  new$REGION PAYMENTSCHEDULE.REGION%TYPE := :NEW.REGION;
  new$SUBKESR PAYMENTSCHEDULE.SUBKESR%TYPE := :NEW.SUBKESR;
  new$MEANSTYPE PAYMENTSCHEDULE.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FINSOURCE PAYMENTSCHEDULE.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE PAYMENTSCHEDULE.FINTYPE%TYPE := :NEW.FINTYPE;
  new$FACT PAYMENTSCHEDULE.FACT%TYPE := :NEW.FACT;
  new$FACIALACC_CLS PAYMENTSCHEDULE.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$CREATERUSER PAYMENTSCHEDULE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYMENTSCHEDULE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PAYMENTSCHEDULE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PAYMENTSCHEDULE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF PAYMENTSCHEDULE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ACCEPTDATE PAYMENTSCHEDULE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$LASTADJUSTMENT PAYMENTSCHEDULE.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$ACCEPTED PAYMENTSCHEDULE.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED PAYMENTSCHEDULE.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$PROMISETYPE PAYMENTSCHEDULE.PROMISETYPE%TYPE := :NEW.PROMISETYPE;
  new$ADJUSTMENTREF PAYMENTSCHEDULE.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$OLDNUMBER PAYMENTSCHEDULE.OLDNUMBER%TYPE := :NEW.OLDNUMBER;
  new$SUMMAPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAPREVIOUSYEAR%TYPE := :NEW.SUMMAPREVIOUSYEAR;
  new$SUMMAFINPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAFINPREVIOUSYEAR%TYPE := :NEW.SUMMAFINPREVIOUSYEAR;
  new$QUARTER1 PAYMENTSCHEDULE.QUARTER1%TYPE := :NEW.QUARTER1;
  new$QUARTER2 PAYMENTSCHEDULE.QUARTER2%TYPE := :NEW.QUARTER2;
  new$QUARTER3 PAYMENTSCHEDULE.QUARTER3%TYPE := :NEW.QUARTER3;
  new$QUARTER4 PAYMENTSCHEDULE.QUARTER4%TYPE := :NEW.QUARTER4;
  new$RECORDINDEX PAYMENTSCHEDULE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CRYPTOSTATUS PAYMENTSCHEDULE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PAYMENTSCHEDULE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PAYMENTSCHEDULE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DIRECTIONCLS PAYMENTSCHEDULE.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$RVERSION PAYMENTSCHEDULE.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYMENTSCHEDULE.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MONTH01DELTA PAYMENTSCHEDULE.MONTH01DELTA%TYPE := :NEW.MONTH01DELTA;
  new$MONTH02DELTA PAYMENTSCHEDULE.MONTH02DELTA%TYPE := :NEW.MONTH02DELTA;
  new$MONTH03DELTA PAYMENTSCHEDULE.MONTH03DELTA%TYPE := :NEW.MONTH03DELTA;
  new$MONTH04DELTA PAYMENTSCHEDULE.MONTH04DELTA%TYPE := :NEW.MONTH04DELTA;
  new$MONTH05DELTA PAYMENTSCHEDULE.MONTH05DELTA%TYPE := :NEW.MONTH05DELTA;
  new$MONTH06DELTA PAYMENTSCHEDULE.MONTH06DELTA%TYPE := :NEW.MONTH06DELTA;
  new$MONTH07DELTA PAYMENTSCHEDULE.MONTH07DELTA%TYPE := :NEW.MONTH07DELTA;
  new$MONTH08DELTA PAYMENTSCHEDULE.MONTH08DELTA%TYPE := :NEW.MONTH08DELTA;
  new$MONTH09DELTA PAYMENTSCHEDULE.MONTH09DELTA%TYPE := :NEW.MONTH09DELTA;
  new$MONTH10DELTA PAYMENTSCHEDULE.MONTH10DELTA%TYPE := :NEW.MONTH10DELTA;
  new$MONTH11DELTA PAYMENTSCHEDULE.MONTH11DELTA%TYPE := :NEW.MONTH11DELTA;
  new$MONTH12DELTA PAYMENTSCHEDULE.MONTH12DELTA%TYPE := :NEW.MONTH12DELTA;
  new$QUARTER1DELTA PAYMENTSCHEDULE.QUARTER1DELTA%TYPE := :NEW.QUARTER1DELTA;
  new$QUARTER2DELTA PAYMENTSCHEDULE.QUARTER2DELTA%TYPE := :NEW.QUARTER2DELTA;
  new$QUARTER3DELTA PAYMENTSCHEDULE.QUARTER3DELTA%TYPE := :NEW.QUARTER3DELTA;
  new$QUARTER4DELTA PAYMENTSCHEDULE.QUARTER4DELTA%TYPE := :NEW.QUARTER4DELTA;
  new$SUMMADELTA PAYMENTSCHEDULE.SUMMADELTA%TYPE := :NEW.SUMMADELTA;
  new$NOTE PAYMENTSCHEDULE.NOTE%TYPE := :NEW.NOTE;
  new$FINYEAR PAYMENTSCHEDULE.FINYEAR%TYPE := :NEW.FINYEAR;
  new$SUMMAYEAR1 PAYMENTSCHEDULE.SUMMAYEAR1%TYPE := :NEW.SUMMAYEAR1;
  new$SUMMAYEAR2 PAYMENTSCHEDULE.SUMMAYEAR2%TYPE := :NEW.SUMMAYEAR2;
  new$SUMMAYEAR3 PAYMENTSCHEDULE.SUMMAYEAR3%TYPE := :NEW.SUMMAYEAR3;
  new$SUMMAYEAR1DELTA PAYMENTSCHEDULE.SUMMAYEAR1DELTA%TYPE := :NEW.SUMMAYEAR1DELTA;
  new$SUMMAYEAR2DELTA PAYMENTSCHEDULE.SUMMAYEAR2DELTA%TYPE := :NEW.SUMMAYEAR2DELTA;
  new$SUMMAYEAR3DELTA PAYMENTSCHEDULE.SUMMAYEAR3DELTA%TYPE := :NEW.SUMMAYEAR3DELTA;
  new$ASSIGNMENTKIND PAYMENTSCHEDULE.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$TRANSFERTCLS PAYMENTSCHEDULE.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SENDERIDKEY PAYMENTSCHEDULE.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY PAYMENTSCHEDULE.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXECUTIONREF PAYMENTSCHEDULE.EXECUTIONREF%TYPE := :NEW.EXECUTIONREF;
  new$INNERPROMISENUM PAYMENTSCHEDULE.INNERPROMISENUM%TYPE := :NEW.INNERPROMISENUM;
  new$ADJUSTMENTNUMBER PAYMENTSCHEDULE.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$PROMISENUMBER PAYMENTSCHEDULE.PROMISENUMBER%TYPE := :NEW.PROMISENUMBER;
  new$SUBSIDYCLS PAYMENTSCHEDULE.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$AGREEMENTREF PAYMENTSCHEDULE.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$BUDALLOCATIONCLS PAYMENTSCHEDULE.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS PAYMENTSCHEDULE.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$PROGINDEX PAYMENTSCHEDULE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$INVESTOBJECT PAYMENTSCHEDULE.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$SUMMAYEAR4 PAYMENTSCHEDULE.SUMMAYEAR4%TYPE := :NEW.SUMMAYEAR4;
  new$SUMMAOTHERYEARS PAYMENTSCHEDULE.SUMMAOTHERYEARS%TYPE := :NEW.SUMMAOTHERYEARS;
  new$SUMMAYEAR4DELTA PAYMENTSCHEDULE.SUMMAYEAR4DELTA%TYPE := :NEW.SUMMAYEAR4DELTA;
  new$SUMMAOTHERYEARSDELTA PAYMENTSCHEDULE.SUMMAOTHERYEARSDELTA%TYPE := :NEW.SUMMAOTHERYEARSDELTA;
  new$CONTRACTCOSTSCLS PAYMENTSCHEDULE.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS PAYMENTSCHEDULE.TARGETCLS%TYPE := :NEW.TARGETCLS;
--
  M01$ NUMBER;
  M02$ NUMBER;
  M03$ NUMBER;
  M04$ NUMBER;
  M05$ NUMBER;
  M06$ NUMBER;
  M07$ NUMBER;
  M08$ NUMBER;
  M09$ NUMBER;
  M10$ NUMBER;
  M11$ NUMBER;
  M12$ NUMBER;
  Q1$ NUMBER;
  Q2$ NUMBER;
  Q3$ NUMBER;
  Q4$ NUMBER;
  S$ NUMBER;
  S1$ NUMBER;
  S2$ NUMBER;
  S3$ NUMBER;
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  S4$ NUMBER;
  SOther$ NUMBER;
  previousAccept$ NUMBER(10);
  previousAcceptDate$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_PAYMENTSCHEDULE_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*   2.4*/
  /*    -*/
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  if (new$PromiseType is null) then
    new$PromiseType := 0;
  END IF;
  if (new$KFSR is null) then
    new$KFSR := 0;
  END IF;
  if (new$KESR is null) then
    new$KESR := 0;
  END IF;
  if (new$KVSR is null) then
    new$KVSR := 0;
  END IF;
  if (new$KCSR is null) then
    new$KCSR := 0;
  END IF;
  if (new$KVR is null) then
    new$KVR := 0;
  END IF;
  if (new$SubKESR is null) then
    new$SubKESR := 0;
  END IF;
  if (new$AssignmentKind is null) then
    new$AssignmentKind := 0;
  END IF;

  if (new$DirectionCls is null) then
    new$DirectionCls := 0;
  END IF;

  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$MeansType is null) then
    new$MeansType := 0;
  END IF;
  if (new$FinSource is null) then
    new$FinSource := 0;
  END IF;
  if (new$FinType is null) then
    new$FinType := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$Month01 is null) then
    new$Month01 := 0;
  END IF;
  if (new$Month02 is null) then
    new$Month02 := 0;
  END IF;
  if (new$Month03 is null) then
    new$Month03 := 0;
  END IF;
  if (new$Month04 is null) then
    new$Month04 := 0;
  END IF;
  if (new$Month05 is null) then
    new$Month05 := 0;
  END IF;
  if (new$Month06 is null) then
    new$Month06 := 0;
  END IF;
  if (new$Month07 is null) then
    new$Month07 := 0;
  END IF;
  if (new$Month08 is null) then
    new$Month08 := 0;
  END IF;
  if (new$Month09 is null) then
    new$Month09 := 0;
  END IF;
  if (new$Month10 is null) then
    new$Month10 := 0;
  END IF;
  if (new$Month11 is null) then
    new$Month11 := 0;
  END IF;
  if (new$Month12 is null) then
    new$Month12 := 0;
  END IF;
  if (new$Quarter1 is null) then
    new$Quarter1 := 0;
  END IF;
  if (new$Quarter2 is null) then
    new$Quarter2 := 0;
  END IF;
  if (new$Quarter3 is null) then
    new$Quarter3 := 0;
  END IF;
  if (new$Quarter4 is null) then
    new$Quarter4 := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$Month01Delta is null) then
    new$Month01Delta := 0;
  END IF;
  if (new$Month02Delta is null) then
    new$Month02Delta := 0;
  END IF;
  if (new$Month03Delta is null) then
    new$Month03Delta := 0;
  END IF;
  if (new$Month04Delta is null) then
    new$Month04Delta := 0;
  END IF;
  if (new$Month05Delta is null) then
    new$Month05Delta := 0;
  END IF;
  if (new$Month06Delta is null) then
    new$Month06Delta := 0;
  END IF;
  if (new$Month07Delta is null) then
    new$Month07Delta := 0;
  END IF;
  if (new$Month08Delta is null) then
    new$Month08Delta := 0;
  END IF;
  if (new$Month09Delta is null) then
    new$Month09Delta := 0;
  END IF;
  if (new$Month10Delta is null) then
    new$Month10Delta := 0;
  END IF;
  if (new$Month11Delta is null) then
    new$Month11Delta := 0;
  END IF;
  if (new$Month12Delta is null) then
    new$Month12Delta := 0;
  END IF;
  if (new$Quarter1Delta is null) then
    new$Quarter1Delta := 0;
  END IF;
  if (new$Quarter2Delta is null) then
    new$Quarter2Delta := 0;
  END IF;
  if (new$Quarter3Delta is null) then
    new$Quarter3Delta := 0;
  END IF;
  if (new$Quarter4Delta is null) then
    new$Quarter4Delta := 0;
  END IF;
  if (new$SummaDelta is null) then
    new$SummaDelta := 0;
  END IF;
  if (new$SummaPreviousYear is null) then
    new$SummaPreviousYear := 0;
  END IF;
  if (new$SummaFinPreviousYear is null) then
    new$SummaFinPreviousYear := 0;
  END IF;

  if (new$SummaYear1 is null) then
    new$SummaYear1 := 0;
  END IF;
  if (new$SummaYear2 is null) then
    new$SummaYear2 := 0;
  END IF;
  if (new$SummaYear3 is null) then
    new$SummaYear3 := 0;
  END IF;
  if (new$SummaYear4 is null) then
    new$SummaYear4 := 0;
  END IF;
  if (new$SummaOtherYears is null) then
    new$SummaOtherYears := 0;
  END IF;

  if (new$SummaYear1Delta is null) then
    new$SummaYear1Delta := 0;
  END IF;
  if (new$SummaYear2Delta is null) then
    new$SummaYear2Delta := 0;
  END IF;
  if (new$SummaYear3Delta is null) then
    new$SummaYear3Delta := 0;
  END IF;
  if (new$SummaYear4Delta is null) then
    new$SummaYear4Delta := 0;
  END IF;
  if (new$SummaOtherYearsDelta is null) then
    new$SummaOtherYearsDelta := 0;
  END IF;

  /*   ,        */
  if (new$ProgIndex = 304 and new$RecordIndex is not null and (:old.RecordIndex is null or :old.RecordIndex <> new$RecordIndex)) then
    SELECT COUNT(*) INTO CNT$1
    from AgreementSteps s where (s.Id = new$RecordIndex and s.RecordIndex = new$AgreementRef) AND (ROWNUM = 1);
    if (not (CNT$1<> 0)) then
      RaiseException('Ex_WrongStep');
    END IF;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      RaiseException('Ex_CantModufyBudget');
    END IF;
  END IF;
  if ((:old.ANumber is null) and (new$ANumber is not Null)) then
    SELECT COUNT(                    id
    ) INTO CNT$2
    from
    PaymentSchedule ps
    where
    (                    (ps.ANumber = new$ANumber)
    and
    (ps.BudgetRef = new$BudgetRef)) AND (ROWNUM = 1);
    if ((CNT$2<> 0)) then
      RaiseException('ex_Promise_NumUQ');
    END IF;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls);

-- - - - - - - - - - - - -
-- BU_1 (TR_PAYMENTSCHEDULE_BU_1)
-- Create 05.03.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  /*   1.0*/
    if (new$Quarter1 = 0) then new$Quarter1 := new$Month01 + new$Month02 + new$Month03; end if;
    if (new$Quarter2 = 0) then new$Quarter2 := new$Month04 + new$Month05 + new$Month06; end if;
    if (new$Quarter3 = 0) then new$Quarter3 := new$Month07 + new$Month08 + new$Month09; end if;
    if (new$Quarter4 = 0) then new$Quarter4 := new$Month10 + new$Month11 + new$Month12; end if;
    new$SummaYear1 := new$Quarter1 + new$Quarter2 + new$Quarter3 + new$Quarter4;

-- - - - - - - - - - - - -
-- BU_10 (TR_PAYMENTSCHEDULE_BU_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  /* ,      ,   */
  if ((new$ANumber <> :old.ANumber) or
  (new$AdjustmentRef <> :old.AdjustmentRef) or
  (new$InnerPromiseNum <> :old.InnerPromiseNum) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber)) then
    RaiseException('EX_AGR_ChangeInnerNums');
  END IF;
      
  /*   */
  if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and 
  ((new$Accepted = 1) or (new$AcceptDate is null))) then
    BEGIN
      /*             */
      select Accepted, AcceptDate
      into previousAccept$, previousAcceptDate$       from Paymentschedule
      where id=new$Adjustmentref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$Adjustmentref is not null and (previousAccept$ = 0 or previousAcceptDate$ is null)) then
      RaiseException('EX_RollbackCancel');
    END IF;
    new$LastAdjustment := 1;
        
  END IF;
  /*   ,     LastAccepted*/
  if ((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;
              
    else
      RaiseException('EX_BP_ChangeStateAdjust');
    END IF;
  END IF;
  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 0 and new$AcceptDate is not null and new$Accepted = 1) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;
              
    else
      RaiseException('EX_BP_ChangeStateAdjust');
    END IF;
  END IF;
      
  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;
              
    else
      RaiseException('EX_BP_ChangeStateAdjust');
    END IF;
  END IF;
      
  /*   ,     LastAdjustment*/
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment <> 1) then
      RaiseException('EX_BP_ChangeStateAdjust');
    else
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
              
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_PAYMENTSCHEDULE_BU_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*           */
  if (new$AdjustmentNumber > 0) then
    BEGIN
      select
      Month01, Month02, Month03, Month04, Month05, Month06,
      Month07, Month08, Month09, Month10, Month11, Month12,
      Quarter1, Quarter2, Quarter3, Quarter4, Summa,
      SummaYear1, SummaYear2, SummaYear3, SummaYear4, SummaOtherYears
      into
      M01$, M02$, M03$, M04$, M05$, M06$, M07$, M08$, M09$, M10$, M11$, M12$,
      Q1$, Q2$, Q3$, Q4$, S$, S1$, S2$, S3$, S4$, SOther$         from
      PaymentSchedule
      where
      ID = new$AdjustmentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    new$Month01Delta := new$Month01 - M01$;
    new$Month02Delta := new$Month02 - M02$;
    new$Month03Delta := new$Month03 - M03$;
    new$Month04Delta := new$Month04 - M04$;
    new$Month05Delta := new$Month05 - M05$;
    new$Month06Delta := new$Month06 - M06$;
    new$Month07Delta := new$Month07 - M07$;
    new$Month08Delta := new$Month08 - M08$;
    new$Month09Delta := new$Month09 - M09$;
    new$Month10Delta := new$Month10 - M10$;
    new$Month11Delta := new$Month11 - M11$;
    new$Month12Delta := new$Month12 - M12$;
    new$Quarter1Delta := new$Quarter1 - Q1$;
    new$Quarter2Delta := new$Quarter2 - Q2$;
    new$Quarter3Delta := new$Quarter3 - Q3$;
    new$Quarter4Delta := new$Quarter4 - Q4$;
    new$SummaDelta := new$Summa - S$;
    new$SummaYear1Delta := new$SummaYear1 - S1$;
    new$SummaYear2Delta := new$SummaYear2 - S2$;
    new$SummaYear3Delta := new$SummaYear3 - S3$;
    new$SummaYear4Delta := new$SummaYear4 - S4$;
    new$SummaOtherYearsDelta := new$SummaOtherYears - SOther$;

  else /*        */
    new$Month01Delta := new$Month01;
    new$Month02Delta := new$Month02;
    new$Month03Delta := new$Month03;
    new$Month04Delta := new$Month04;
    new$Month05Delta := new$Month05;
    new$Month06Delta := new$Month06;
    new$Month07Delta := new$Month07;
    new$Month08Delta := new$Month08;
    new$Month09Delta := new$Month09;
    new$Month10Delta := new$Month10;
    new$Month11Delta := new$Month11;
    new$Month12Delta := new$Month12;
    new$Quarter1Delta := new$Quarter1;
    new$Quarter2Delta := new$Quarter2;
    new$Quarter3Delta := new$Quarter3;
    new$Quarter4Delta := new$Quarter4;
    new$SummaDelta := new$Summa;
    new$SummaYear1Delta := new$SummaYear1;
    new$SummaYear2Delta := new$SummaYear2;
    new$SummaYear3Delta := new$SummaYear3;
    new$SummaYear4Delta := new$SummaYear4;
    new$SummaOtherYearsDelta := new$SummaOtherYears;

  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_PAYMENTSCHEDULE_BU_200)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*    */
  if (new$Accepted = 0 and new$AcceptDate is not null and :old.Accepted = 1) then
    /*   ,     
         *    ,      */
    FOR REC$1 IN (      select ffc.Reject_Cls  AS DocumentRejectCls from FacialFinDetail ffd
    left join FacialFinCaption ffc on (ffc.ID = ffd.RecordIndex)
    where SourcePromise = new$ANumber and SourceBudgetPromise = new$InnerPromiseNum
    or DestPromise = new$ANumber and DestBudgetPromise = new$InnerPromiseNum
    )
    LOOP
      if (REC$1.DocumentRejectCls is null) then
        RaiseException('Ex_BP_CannotReject');
      END IF;
    END LOOP;
    /* ,         */
    FOR REC$1 IN (      SELECT Count(ps_in.ID)  AS AdjCount FROM PaymentSchedule ps_in
    WHERE (ps_in.InnerPromiseNum = new$InnerPromiseNum)and(ps_in.AdjustmentNumber > new$AdjustmentNumber)
    and (ps_in.Accepted<>0)
    )
    LOOP
      if (REC$1.AdjCount > 0) then
        RaiseException('EX_BP_AdjustmentedCANNOTREJECT');
      END IF;
    END LOOP;
  END IF;
  /*   .       */
  if (new$Accepted = 1 and new$AcceptDate is null and :old.Accepted = 1 and :old.AcceptDate is not null) then
    SELECT COUNT(ffc.Reject_Cls ) INTO CNT$1
    from FacialFinDetail ffd
    left join FacialFinCaption ffc on (ffc.ID = ffd.RecordIndex)
    where ((SourcePromise = new$ANumber and SourceBudgetPromise = new$InnerPromiseNum
    or DestPromise = new$ANumber and DestBudgetPromise = new$InnerPromiseNum)
    and ffc.acceptdate is not null and ffc.Reject_cls is null) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_BP_NOTACCEPTED');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (tr_PaymentSchedule_BU_400)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$AgreementRef <> :old.AgreementRef or new$ExecutionRef <> :old.ExecutionRef) then
    RaiseException('EX_CANTCHANGECAPTIONREF');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_PAYMENTSCHEDULE_BU_700)
-- Create 14.10.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$RVersion is null) then
    new$RVersion := 1;
  elsif ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
    new$RVersion := :Old.RVersion;
  else
    new$RVersion := :Old.RVersion + 1;
  end if;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_PAYMENTSCHEDULE SET
    ID = new$ID,
    ANUMBER = new$ANUMBER,
    PARENTNUMBER = new$PARENTNUMBER,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVSR = new$KVSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    MONTH01 = new$MONTH01,
    MONTH02 = new$MONTH02,
    MONTH03 = new$MONTH03,
    MONTH04 = new$MONTH04,
    MONTH05 = new$MONTH05,
    MONTH06 = new$MONTH06,
    MONTH07 = new$MONTH07,
    MONTH08 = new$MONTH08,
    MONTH09 = new$MONTH09,
    MONTH10 = new$MONTH10,
    MONTH11 = new$MONTH11,
    MONTH12 = new$MONTH12,
    SUMMA = new$SUMMA,
    REGION = new$REGION,
    SUBKESR = new$SUBKESR,
    MEANSTYPE = new$MEANSTYPE,
    FINSOURCE = new$FINSOURCE,
    FINTYPE = new$FINTYPE,
    FACT = new$FACT,
    FACIALACC_CLS = new$FACIALACC_CLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    ACCEPTDATE = new$ACCEPTDATE,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    ACCEPTED = new$ACCEPTED,
    LASTACCEPTED = new$LASTACCEPTED,
    PROMISETYPE = new$PROMISETYPE,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    OLDNUMBER = new$OLDNUMBER,
    SUMMAPREVIOUSYEAR = new$SUMMAPREVIOUSYEAR,
    SUMMAFINPREVIOUSYEAR = new$SUMMAFINPREVIOUSYEAR,
    QUARTER1 = new$QUARTER1,
    QUARTER2 = new$QUARTER2,
    QUARTER3 = new$QUARTER3,
    QUARTER4 = new$QUARTER4,
    RECORDINDEX = new$RECORDINDEX,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DIRECTIONCLS = new$DIRECTIONCLS,
    RVERSION = new$RVERSION,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    MONTH01DELTA = new$MONTH01DELTA,
    MONTH02DELTA = new$MONTH02DELTA,
    MONTH03DELTA = new$MONTH03DELTA,
    MONTH04DELTA = new$MONTH04DELTA,
    MONTH05DELTA = new$MONTH05DELTA,
    MONTH06DELTA = new$MONTH06DELTA,
    MONTH07DELTA = new$MONTH07DELTA,
    MONTH08DELTA = new$MONTH08DELTA,
    MONTH09DELTA = new$MONTH09DELTA,
    MONTH10DELTA = new$MONTH10DELTA,
    MONTH11DELTA = new$MONTH11DELTA,
    MONTH12DELTA = new$MONTH12DELTA,
    QUARTER1DELTA = new$QUARTER1DELTA,
    QUARTER2DELTA = new$QUARTER2DELTA,
    QUARTER3DELTA = new$QUARTER3DELTA,
    QUARTER4DELTA = new$QUARTER4DELTA,
    SUMMADELTA = new$SUMMADELTA,
    NOTE = new$NOTE,
    FINYEAR = new$FINYEAR,
    SUMMAYEAR1 = new$SUMMAYEAR1,
    SUMMAYEAR2 = new$SUMMAYEAR2,
    SUMMAYEAR3 = new$SUMMAYEAR3,
    SUMMAYEAR1DELTA = new$SUMMAYEAR1DELTA,
    SUMMAYEAR2DELTA = new$SUMMAYEAR2DELTA,
    SUMMAYEAR3DELTA = new$SUMMAYEAR3DELTA,
    ASSIGNMENTKIND = new$ASSIGNMENTKIND,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    EXECUTIONREF = new$EXECUTIONREF,
    INNERPROMISENUM = new$INNERPROMISENUM,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    PROMISENUMBER = new$PROMISENUMBER,
    SUBSIDYCLS = new$SUBSIDYCLS,
    AGREEMENTREF = new$AGREEMENTREF,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    PAYPROMISECLS = new$PAYPROMISECLS,
    PROGINDEX = new$PROGINDEX,
    INVESTOBJECT = new$INVESTOBJECT,
    SUMMAYEAR4 = new$SUMMAYEAR4,
    SUMMAOTHERYEARS = new$SUMMAOTHERYEARS,
    SUMMAYEAR4DELTA = new$SUMMAYEAR4DELTA,
    SUMMAOTHERYEARSDELTA = new$SUMMAOTHERYEARSDELTA,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_10 (TR_PAYMENTSCHEDULE_AU_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  /*      */
  /*        */
  if ((new$AdjustmentRef is not null) and (new$LastAdjustment = 1)) then
    update PaymentSchedule set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);        
  END IF;
      
  /*              */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and ((:old.LastAdjustment = 1) or (new$LastAdjustment = 1))) then
    update PaymentSchedule set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment    */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and 
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update PaymentSchedule set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_PAYMENTSCHEDULE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (113, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=113) and (RecordId=new$ID);
  end if;

END;
/
commit
/

-- #########################################################
-- #########################################################
-- UpdDocFields_13.10.00_Ora.sql
-- #########################################################
-- #########################################################


--  : 131000 - 131000.     04.06.2019 21:15:58.
CREATE OR REPLACE PROCEDURE ImportDocType (
   ID_               NUMBER,
   PROGINDEX_        NUMBER,
   NAME_             VARCHAR2,
   USESTATE_         NUMBER,
   DBTABLE_          VARCHAR2,
   NEEDEDS_          NUMBER,
   LOCKMASK_         NUMBER,
   DEFAULTACTIONMACROSNAME_ VARCHAR2,
   DOCUMENTKIND_     NUMBER,
   SHORTNAME_         VARCHAR2
) IS
   IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
     INTO IDExists$
     FROM DocumentTypes
    WHERE (ID = ID_);

  IF (IDExists$ = 0) THEN
     INSERT INTO DocumentTypes
                 (ID, PROGINDEX, NAME, USESTATE, DBTABLE, NEEDEDS, LOCKMASK, DEFAULTACTIONMACROSNAME, DOCUMENTKIND, SHORTNAME)
          VALUES (ID_, PROGINDEX_, NAME_, USESTATE_, DBTABLE_, NEEDEDS_, LOCKMASK_, DEFAULTACTIONMACROSNAME_, DOCUMENTKIND_, SHORTNAME_);
  else
      Update documenttypes set
        Name=Name_,
		    DBTABLE=DBTABLE_,
        LockMask=LockMask_,
        DEFAULTACTIONMACROSNAME=DEFAULTACTIONMACROSNAME_,
        DOCUMENTKIND=DOCUMENTKIND_,
        SHORTNAME=SHORTNAME_,
	      PROGINDEX=PROGINDEX_
      where (id=ID_)
        and (
          (Name<>Name_) or
          ((LockMask is null) and (LockMask_ is not null)) or
          ((LockMask is not null) and (LockMask_ is null)) or
          ((LockMask is not null) and (LockMask_ is not null) and (LockMask <> LockMask_)) or
          (DEFAULTACTIONMACROSNAME is null) or
          (DOCUMENTKIND<>DOCUMENTKIND_) or 
          (SHORTNAME is null) or 
          (SHORTNAME<>SHORTNAME_) or
          (PROGINDEX <> PROGINDEX_) or 
          ((DBTABLE is null) and (DBTABLE_ is not null)) or
          ((DBTABLE is not null) and (DBTABLE_ is null)) or
          ((DBTABLE is not null) and (DBTABLE_ is not null) and (DBTABLE <> DBTABLE_))
        );
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE UPDATEINTERFACES (
  CLS_   NUMBER,
  NOTE_  VARCHAR2,
  GUID_  VARCHAR2,
  PARAM_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT (ID)
   INTO IDEXISTS$
   FROM INTERFACES
  WHERE (GUID=GUID_);
  
  IF (IDExists$ = 0)  THEN
    INSERT INTO INTERFACES
      (CLS,NOTE,GUID,PARAM)
    VALUES
      (CLS_,NOTE_,GUID_,PARAM_);
  ELSE
    IF ((PARAM_ ='')OR(PARAM_ IS NULL)) THEN 
      UPDATE INTERFACES SET
        CLS = CLS_
      WHERE (GUID=GUID_) AND ((CLS<> CLS_)OR(CLS IS NULL));
    ELSE 
      UPDATE INTERFACES SET
        CLS = CLS_
      WHERE (GUID=GUID_) AND (PARAM=PARAM_) AND ((CLS<> CLS_)OR(CLS IS NULL));
    END IF;
  END IF;
END;
/

--   
CALL ImportDocType(200, 0, '  ()', 0, '', 0,0,'',30000,'') ;

CALL ImportDocType(201, 32, '   ()', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL ImportDocType(203, 261, '  ()', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL ImportDocType(204, 262, ' , ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL ImportDocType(205, 263, '', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'') ;

CALL ImportDocType(206, 268, '   ()', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'__') ;

CALL ImportDocType(210, 252, ' ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'') ;

CALL UpdateInterfaces(210, ' ', '{2EF0F811-E21F-4ADB-BC7E-A3A9B16059A4}', '') ;

CALL ImportDocType(211, 275, ' ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL UpdateInterfaces(211, ' ', '{AE8281A0-BE7F-4F3A-90BD-A7831E8D842F}', '') ;

CALL ImportDocType(301, 66, ' ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(302, 63, '  \', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(304, 64, '  ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(308, 67, ' ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL UpdateInterfaces(308, ' ', '{B50F2C63-9CF4-42C3-8062-E355EABD53E4}', '') ;

CALL ImportDocType(324, 76, ' ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(801, 57, ' ', 0, 'LimitNotifyCaption[RVERSION=RVERSION-1]', 0,34,'_',10100,'_') ;

CALL ImportDocType(1601, 224, ' ', 0, 'Promise_Caption', 0,-1,'_',10100,'') ;

CALL ImportDocType(1821, 0, '    ', 0, 'PayDocExchange', 0,-1,'',10200,'') ;

CALL UpdateInterfaces(1821, '    ', '{8BD77688-893C-421E-BF64-C39D4145BDB3}', '') ;

CALL ImportDocType(2501, 305, ' ', 0, 'Agreements', 0,-65537,'',10100,'') ;

CALL ImportDocType(2502, 304, ' ', 0, 'Agreements', 0,-65537,'',10100,'') ;

CALL ImportDocType(2503, 308, '  ', 0, 'ExecutionDocumentsCaption', 0,-65537,'',10100,'') ;

CALL ImportDocType(2504, 314, ' ', 0, 'Agreements', 0,-65537,'',10100,'') ;

CALL ImportDocType(2801, 0, '      ', 0, ' ', 0,-1,'',10200,'') ;

CALL ImportDocType(2802, 0, '  ', 0, ' ', 0,-1,'',10200,'') ;

CALL ImportDocType(3001, 230, '   ', 0, 'TenderCaption', 0,-65537,'',10100,'') ;

CALL ImportDocType(3002, 0, '', 0, 'TenderResultCaption', 0,0,'',3,'') ;

CALL ImportDocType(3003, 234, ' ', 0, 'TenderResultCaption', 0,-65537,'',10100,'') ;

CALL ImportDocType(3004, 0, ' ', 0, 'TenderProposal', 0,0,'',3,' ') ;

CALL ImportDocType(3005, 240, '-', 0, 'TenderCaption', 0,127,'',10100,'') ;

CALL ImportDocType(3006, 241, ' -', 0, 'TenderCaption', 0,-65537,'',10100,'') ;

CALL ImportDocType(3010, 242, ' ', 0, 'TenderCaption', 0,-1,'',10100,'') ;

CALL ImportDocType(3011, 243, '  ', 0, 'TenderCaption', 0,-1,'',10100,'') ;

CALL ImportDocType(3610, 550, '  ', 0, 'UTypedFormsCaption', 0,-1,'',10100,'5') ;

CALL ImportDocType(3701, 235, ' ', 0, 'TenderObjects', 0,-65537,'',10100,'') ;

CALL ImportDocType(3901, 0, '. ', 0, ' ', 0,-1,'',10200,'_') ;

CALL ImportDocType(4401, 251, ' ', 0, 'UnionNotifyCaption', 0,-1,'_',10100,'') ;

CALL UpdateInterfaces(4401, ' ', '{AB6937F7-A672-461D-A94C-808F4DCA4D71}', '') ;

CALL ImportDocType(4403, 254, ' ,', 0, 'UnionNotifyCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(4801, 528, ' ', 0, 'GeneralDocuments', 0,-1,'_',10100,'') ;

CALL ImportDocType(4901, 525, '   ', 0, 'DataPacket', 0,-1,'_',10100,'') ;

CALL ImportDocType(4902, 526, ' ', 0, '', 0,-1,'',10200,'') ;

CALL ImportDocType(4903, 527, ' ', 0, 'DataPacket', 0,-1,'_',10100,'') ;

CALL ImportDocType(5101, 0, '  ', 0, 'StoredAttributesCaption', 0,-1,'',10200,'') ;

CALL UpdateInterfaces(5101, '  ', '{12614FA4-D546-4C45-8946-43813CED6EBF}', '') ;

CALL ImportDocType(5201, 556, ' / ', 0, 'WritExecutionCaption', 0,-1,'',10100,'') ;

CALL UpdateInterfaces(5201, ' / ', '{623EE404-09D9-4069-9115-27974DB69AD1}', '') ;

CALL ImportDocType(5301, 0, '   ', 0, '', 0,-1,'',10200,'') ;

CALL UpdateInterfaces(5301, '   ', '{FF462FFC-4DA8-4A24-B2BA-0B6478238E00}', '') ;

CALL ImportDocType(5302, 0, ' ', 0, '', 0,0,'',10200,'') ;

CALL UpdateInterfaces(5302, ' ', '{A4B37143-4DD8-4BFF-9E80-ADF04718ED02}', '') ;

CALL ImportDocType(5303, 0, '   Web-', 0, '', 0,0,'',3,'') ;

CALL UpdateInterfaces(5303, '   Web-', '{E212ED5E-7AA3-4D6C-A124-547EDFA04D0A}', '') ;

CALL ImportDocType(5304, 0, '   ', 0, '', 0,0,'',3,'') ;

CALL UpdateInterfaces(5304, '   ', '{98E55E99-2055-4653-AB8D-A85913DDBF8A}', '') ;

CALL ImportDocType(5305, 0, '  c', 0, '', 0,0,'',3,'') ;

CALL UpdateInterfaces(5305, '  c', '{0C4B375D-F354-4967-9F8C-3AD9F72DA866}', '') ;

CALL ImportDocType(5306, 0, ' c  ', 0, '', 0,0,'',3,'') ;

CALL UpdateInterfaces(5306, ' c  ', '{5607E299-3CF3-4E11-AB66-FDCE93A1B540}', '') ;

CALL ImportDocType(5502, 313, '   ', 0, 'CorrectionCaption', 0,-1,'',10100,'_') ;

CALL ImportDocType(9709, 0, '   ', 0, 'TargetCls', 0,0,'',20100,'') ;

CALL ImportDocType(9816, 0, ' ', 0, 'MeansCLS', 0,0,'',20200,'') ;

CALL ImportDocType(9817, 0, '', 0, 'REFCLS', 0,0,'',20200,'') ;

CALL ImportDocType(9818, 0, '', 0, 'CURRENCYCLS', 0,0,'',20200,'') ;

CALL ImportDocType(9820, 0, '  ()', 0, 'ORG_CLS', 0,0,'',20200,'') ;

CALL ImportDocType(9821, 0, '  ', 0, 'ACC_CLS', 0,0,'',20200,'') ;

CALL ImportDocType(9822, 0, ' ', 0, 'GroupInf_CLS', 0,0,'',20200,'') ;

CALL ImportDocType(9823, 0, '', 0, 'GOSNI', 0,0,'',20200,'') ;

CALL ImportDocType(9826, 0, ' ', 0, 'BUDGETACCOUNTS', 0,0,'',20200,'') ;

CALL ImportDocType(9827, 0, '  ', 0, 'FinType', 0,0,'',20200,'') ;

CALL ImportDocType(9828, 0, '', 0, 'FACT', 0,0,'',20100,'') ;

CALL ImportDocType(9829, 0, '- ', 0, 'DocBase', 0,0,'',20200,'') ;

CALL ImportDocType(9834, 0, ' ', 0, 'ReportType', 0,0,'',20200,'') ;

CALL ImportDocType(9835, 0, '  (  )', 0, 'BUDGETTYPE', 0,0,'',20200,'') ;

CALL ImportDocType(9841, 0, ' ', 0, 'FACIALACC_CLS', 0,0,'',20200,'') ;

CALL ImportDocType(9842, 0, '2', 0, 'OKVED2', 0,0,'',20200,'2') ;

CALL ImportDocType(9843, 0, ' ', 0, 'PAYTYPECLS', 0,0,'',20200,'') ;

CALL ImportDocType(9844, 0, '  ', 0, 'Org_AccDefaults', 0,0,'',20200,'') ;

CALL ImportDocType(9845, 0, ' ', 0, 'PAYSYMBOLCLS', 0,0,'',20200,'') ;

CALL ImportDocType(9846, 0, ' ()', 0, 'BUHPAYMENTCLS', 0,0,'',20200,'') ;

CALL ImportDocType(9847, 0, ' ', 0, 'TYPEOPERATIONCLS', 0,0,'',20200,'') ;

CALL ImportDocType(9848, 0, ' ', 0, 'PAYDESTINATIONCLS', 0,0,'',20200,'') ;

CALL ImportDocType(9849, 0, ' ', 0, 'MEANSTYPE', 0,0,'',20200,'') ;

CALL ImportDocType(9850, 0, ' ', 0, 'RejectCLS', 0,0,'',20200,'') ;

CALL ImportDocType(9851, 0, ' ', 0, 'Error', 0,0,'',20200,'') ;

CALL ImportDocType(9852, 0, '   ', 0, 'InnerFinSource', 0,0,'',20100,'') ;

CALL ImportDocType(9853, 0, ' ', 0, 'REESTRTYPE', 0,0,'',20200,'') ;

CALL ImportDocType(9854, 0, '', 0, 'INVESTOBJECT', 0,0,'',20100,'') ;

CALL ImportDocType(9857, 0, ' ', 0, 'LOANTYPE', 0,0,'',20200,'') ;

CALL ImportDocType(9858, 0, ' ', 0, 'DEBTTYPE', 0,0,'',20200,'') ;

CALL ImportDocType(9859, 0, '', 0, 'DepartmentCLS', 0,0,'',20200,'') ;

CALL ImportDocType(9860, 0, ' ', 0, 'MEASUREMENTCLS', 0,0,'',20200,'') ;

CALL ImportDocType(9861, 0, ' ', 0, 'TenderObjects', 0,0,'',20200,'') ;

CALL ImportDocType(9862, 0, '', 0, 'OKATO', 0,0,'',20200,'') ;

CALL ImportDocType(9863, 0, ' ', 0, 'COLLATERALTYPE', 0,0,'',20200,'') ;

CALL ImportDocType(9864, 0, ' ', 0, 'PlanDocType', 0,0,'',20200,'') ;

CALL ImportDocType(9865, 0, ' ', 0, 'BuhAccPlan', 0,0,'',20100,'') ;

CALL ImportDocType(9867, 0, '2', 0, 'OKPD2', 0,0,'',20200,'2') ;

CALL ImportDocType(9868, 0, '    ', 0, 'KESR', 0,0,'',20100,'') ;

CALL ImportDocType(9869, 0, '', 0, 'DirectionCLS', 0,0,'',20100,'') ;

CALL ImportDocType(9870, 0, '  ', 0, 'ProgramCode', 0,0,'',20200,'') ;

CALL ImportDocType(9871, 0, ' ', 0, 'BuhOperationCls', 0,0,'',20200,'') ;

CALL ImportDocType(9872, 0, '', 0, 'BalanceCls', 0,0,'',20200,'') ;

CALL ImportDocType(9878, 0, '', 0, 'budgets_s', 0,0,'',20200,'') ;

CALL ImportDocType(9879, 0, ' ', 0, 'TargetCls', 0,0,'',20100,'') ;

CALL ImportDocType(9880, 0, '  ', 0, 'FundsSource', 0,0,'',20200,'') ;

CALL ImportDocType(9881, 0, '', 0, 'OKFS', 0,0,'',20200,'') ;

CALL ImportDocType(9882, 0, '', 0, 'OKOPF', 0,0,'',20200,'') ;

CALL ImportDocType(9883, 0, ' ', 0, 'Org_Type', 0,0,'',20200,'') ;

CALL ImportDocType(9884, 0, '  ', 0, 'TransfertCLS', 0,0,'',20100,'') ;

CALL ImportDocType(9885, 0, ' ', 0, 'AssignmentKind', 0,0,'',20200,'') ;

CALL ImportDocType(9886, 0, ' ', 0, 'AssignmentSource', 0,0,'',20200,'') ;

CALL ImportDocType(9887, 0, '', 0, 'VariantCls', 0,0,'',20200,'') ;

CALL ImportDocType(9888, 0, '  ', 0, 'OKP', 0,0,'',20200,'') ;

CALL ImportDocType(9889, 0, ' ', 0, 'SubsidyCls', 0,0,'',20100,'') ;

CALL ImportDocType(9890, 0, ' ', 0, 'BudAllocationCls', 0,0,'',20100,'') ;

CALL ImportDocType(9891, 0, '  ', 0, 'PayPromiseCls', 0,0,'',20100,'') ;

CALL ImportDocType(9892, 0, '   ()', 0, 'ARCHIVEDOCTYPE', 0,0,'',20100,'') ;

CALL ImportDocType(9894, 0, '    ', 0, 'COMMDIRECTIONEXPENCECLS', 0,0,'',20100,'') ;

CALL ImportDocType(9895, 0, '', 0, 'OKTMO', 0,0,'',20100,'') ;

CALL ImportDocType(9897, 0, '', 0, 'ContractCostsCls', 0,0,'',20100,'') ;

CALL ImportDocType(9898, 0, ' ', 0, 'PURCHASETYPE ', 0,0,'',20100,'') ;

CALL ImportDocType(9899, 0, ' ', 0, 'DBUsers', 0,0,'',20100,'') ;

CALL ImportDocType(9903, 0, ' ', 0, 'ORGANIZATIONS', 0,-1,'',10100,'_') ;

CALL ImportDocType(9904, 560, '  ', 0, 'CONTACTPERSONS', 0,0,'',10200,' ') ;

CALL ImportDocType(9905, 0, ' ', 0, ' ', 0,-1,'',10200,'_') ;

CALL ImportDocType(9908, 0, ' ', 0, '', 0,0,'',10200,'_') ;

CALL ImportDocType(9912, 0, ' ', 0, ' ', 0,-1,'',10200,'') ;

CALL ImportDocType(9913, 0, '', 0, '', 0,0,'',10200,'') ;

CALL ImportDocType(9914, 0, '  ', 0, '', 0,-1,'',10200,'') ;

CALL ImportDocType(9915, 0, '  ', 0, 'UnLockDates', 0,-1,'',10100,'') ;

CALL ImportDocType(9916, 0, ' ', 0, '', 0,0,'',10300,'') ;

CALL ImportDocType(9917, 0, ' ', 0, '', 0,0,'',10300,'') ;

CALL ImportDocType(9918, 0, '', 0, '', 0,0,'',10200,'') ;

CALL ImportDocType(9919, 0, ' ', 0, '', 0,0,'',10200,'') ;

CALL UpdateInterfaces(9919, ' ', '{88FA05A2-02A0-11D2-B26C-008048E689F8}', '') ;

CALL ImportDocType(9920, 0, '   ', 0, '', 0,0,'',10200,'') ;

CALL UpdateInterfaces(9920, '   ', '{2F5EDB5F-CC69-4F04-9C91-B457D92C75AC}', '') ;

CALL ImportDocType(9921, 0, '  ', 0, '', 0,0,'',10200,'') ;

CALL UpdateInterfaces(9921, '  ', '{61875F0C-17AA-44F1-80F0-B689371AFBDF}', '') ;

CALL ImportDocType(9922, 0, '  ', 0, '', 0,0,'',10200,'') ;

CALL UpdateInterfaces(9922, '  ', '{C9277BAB-1206-41DD-966D-5D86A9E75AB8}', '') ;

CALL ImportDocType(9923, 0, '  ', 0, '', 0,0,'',10200,'') ;

CALL UpdateInterfaces(9923, '  ', '{82245B63-9A83-41F5-8541-A77AAD1B6EAA}', '') ;

CALL ImportDocType(9924, 0, '  ', 0, '', 0,0,'',10200,'') ;

CALL UpdateInterfaces(9924, '  ', '{4C71385E-A42A-43D1-AEBB-807B3C86E76B}', '') ;

CALL ImportDocType(9925, 0, '  ', 0, 'Cards', 0,0,'',10200,'') ;

CALL UpdateInterfaces(9925, '  ', '{992D6D69-0DA8-490F-8F88-EA0EB3C78CF3}', '') ;

CALL ImportDocType(9926, 0, '   ', 0, 'WritNotifyCls ', 0,0,'',10200,'') ;

CALL UpdateInterfaces(9926, '   ', '{89CAEE9C-9516-4EE2-8A4B-CB0BFA9165AB}', '') ;

CALL ImportDocType(9927, 0, '  ', 0, 'RemoteClient', 0,0,'',10200,'') ;

CALL UpdateInterfaces(9927, '  ', '{60EFBA81-B436-11D6-8CA4-000021DDD8CD}', '') ;

CALL ImportDocType(9928, 0, '   ', 0, 'ClsCorrespondents', 0,0,'',10200,'') ;

CALL UpdateInterfaces(9928, '   ', '{C1FAE5FE-7817-4D46-858B-ACFA478BA485}', '') ;

CALL ImportDocType(9929, 0, '    ', 0, 'BudStruct', 0,0,'',10200,'') ;

CALL UpdateInterfaces(9929, '    ', '{B95FC8BB-D031-4122-B714-B6F41ACFA610}', '') ;

CALL ImportDocType(9930, 0, '   ', 0, 'AutoSanctionData', 0,0,'',10200,'') ;

CALL UpdateInterfaces(9930, '   ', '{23B8DC44-93C1-48C2-B2EB-DCAF31C23929}', '') ;

CALL ImportDocType(9931, 0, '   ', 0, 'ClsCorrespondents', 0,0,'',10200,'') ;

CALL UpdateInterfaces(9931, '   ', '{DCD828A5-5C9F-4446-ACA2-85F6B3BE0FD6}', '') ;

CALL ImportDocType(9932, 0, '  /  ', 0, 'BudStrLink', 0,0,'',10200,'') ;

CALL UpdateInterfaces(9932, '  /  ', '{9B39F873-9C5A-4856-A0B5-FDCFE2E8115A}', '') ;

DROP PROCEDURE ImportDocType
/

DROP PROCEDURE UPDATEINTERFACES
/



CREATE OR REPLACE PROCEDURE SELECTIONS_IMPORT(
  ID_ NUMBER,
  KIND_ NUMBER,
  NAME_ VARCHAR2,
  NOTE_ VARCHAR2,
  READONLY_ NUMBER,
  USEINDOC_ NUMBER,
  TABLENAME_ VARCHAR2,
  ALIAS_ VARCHAR2,
  TABLECODE_ NUMBER,
  NEEDGROUPONDB_ NUMBER,
  NEEDDISTINCT_ NUMBER,
  MASTER_ NUMBER,
  DISCRIMVALUE_ VARCHAR2,
  AVAILABLEINDEREF_ NUMBER,
  CACHETYPE_ NUMBER,
  FULLORMODINSREFRTIME_ NUMBER,
  DELETEREFRTIME_ NUMBER,
  FINDTIMEREFRESH_ NUMBER,
  ANNOTATION_ VARCHAR2,
  DEREFNAME_ VARCHAR2,
  GroupID_ NUMBER,
  IsLogged_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONS SET
      KIND = KIND_,
      NAME = NAME_,
      NOTE = NOTE_,
      READONLY = READONLY_,
      USEINDOC = USEINDOC_,
      TABLENAME = TABLENAME_,
      ALIAS = ALIAS_,
      TABLECODE = TABLECODE_,    
      NEEDGROUPONDB = NEEDGROUPONDB_,
      NEEDDISTINCT = NEEDDISTINCT_,
      MASTER = MASTER_,
      DISCRIMVALUE = DISCRIMVALUE_,
      AVAILABLEINDEREF = AVAILABLEINDEREF_,         
      CACHETYPE = CACHETYPE_,   
      FULLORMODINSREFRTIME = FULLORMODINSREFRTIME_,   
      DELETEREFRTIME = DELETEREFRTIME_,   
      FINDTIMEREFRESH = FINDTIMEREFRESH_,   
      ANNOTATION = ANNOTATION_,   
      DEREFNAME = DEREFNAME_,     
      GroupID = GroupID_, 
      IsLogged = IsLogged_  
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONS
      (ID, KIND, NAME, NOTE, READONLY, USEINDOC, TABLENAME, ALIAS, TABLECODE, NEEDGROUPONDB, NEEDDISTINCT, MASTER, DISCRIMVALUE,
      AVAILABLEINDEREF, CACHETYPE, FULLORMODINSREFRTIME, DELETEREFRTIME, FINDTIMEREFRESH, ANNOTATION, DEREFNAME, GroupID, IsLogged)
    VALUES
      (ID_, KIND_, NAME_, NOTE_, READONLY_, USEINDOC_, TABLENAME_, ALIAS_, TABLECODE_, NEEDGROUPONDB_, NEEDDISTINCT_, MASTER_, DISCRIMVALUE_,
      AVAILABLEINDEREF_, CACHETYPE_, FULLORMODINSREFRTIME_, DELETEREFRTIME_, FINDTIMEREFRESH_, ANNOTATION_, DEREFNAME_, GroupID_, IsLogged_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONSDETAIL_IMPORT(
  ID_ NUMBER,
  SELECTIONREF_ NUMBER,
  TABLEREF_ NUMBER,
  ALIAS_ VARCHAR2,
  JOINORDER_ NUMBER,
  JOINTYPE_ NUMBER,
  RELATIONTYPE_ NUMBER,
  JOINCONDITION_ VARCHAR2,
  DONTUSETABLELIMITS_ NUMBER,
  LIMITNAMESLIST_ VARCHAR2,
  QueryGroup_ NUMBER  
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONSDETAIL
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONSDETAIL SET
      SELECTIONREF = SELECTIONREF_,
      TABLEREF = TABLEREF_,
      ALIAS = ALIAS_,
      JOINORDER = JOINORDER_,
      JOINTYPE = JOINTYPE_,
      RELATIONTYPE = RELATIONTYPE_,
      JOINCONDITION = JOINCONDITION_,
      DONTUSETABLELIMITS = DONTUSETABLELIMITS_,
      LIMITNAMESLIST = LIMITNAMESLIST_,
      QueryGroup = QueryGroup_
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONSDETAIL
      (ID, SELECTIONREF, TABLEREF, ALIAS, JOINORDER, JOINTYPE, RELATIONTYPE, JOINCONDITION, DONTUSETABLELIMITS, LIMITNAMESLIST, QueryGroup)
    VALUES
      (ID_, SELECTIONREF_, TABLEREF_, ALIAS_, JOINORDER_, JOINTYPE_, RELATIONTYPE_, JOINCONDITION_, DONTUSETABLELIMITS_, LIMITNAMESLIST_, QueryGroup_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FIELDSINFO_IMPORT(
  ID_ NUMBER,
  FIELDKIND_ NUMBER,
  DESCRIPTIONLEVEL_ NUMBER,
  ANCESTORREF_ NUMBER,
  SELECTIONREF_ NUMBER,
  TABLEREF_ NUMBER,
  FIELDNAME_ VARCHAR2,
  DATATYPE_ NUMBER,
  SUBDATATYPE_ NUMBER,
  FIELDSIZE_ NUMBER,
  DISPLAYLABEL_ VARCHAR2,
  NOTE_ VARCHAR2,
  DEFAULTWIDTH_ NUMBER,
  EDITMASK_ VARCHAR2,
  DISPLAYFORMAT_ VARCHAR2,
  EDITFORMAT_ VARCHAR2,
  CANTEDIT_ NUMBER,
  NOVISUALIZE_ NUMBER,
  ENUMSREF_ NUMBER,
  REQUIRED_ NUMBER,
  FOREIGNKEY_ NUMBER,
  ONDELACTION_ NUMBER,
  PRIMARYKEY_ NUMBER,
  ISRVERSION_ NUMBER,
  LIMITPARAMNAMES_ VARCHAR2,
  FOLLOWORDER_ NUMBER,
  SORTDIRECTION_ NUMBER,
  SORTORDER_ NUMBER,
  AGRFUNCTION_ NUMBER,
  FLAGFIELDNAME_ NUMBER,
  FLAGDISPLAYLABEL_ NUMBER,
  FLAGNOTE_ NUMBER,
  FLAGDEFAULTWIDTH_ NUMBER,
  FLAGCANTEDIT_ NUMBER,
  FLAGNOVISUALIZE_ NUMBER,
  FLAGREQUIRED_ NUMBER,
  FLAGLIMITPARAMNAMES_ NUMBER,
  FLAGAGRFUNCTION_ NUMBER,
  ISTIMESTAMPFIELD_ NUMBER,
  ISBUDGET_ NUMBER,
  AVAILABLEINDEREF_ NUMBER,
  ANNOTATION_ VARCHAR2,
  ALIAS_ VARCHAR2,
  DEREFNAME_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM FIELDSINFO
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE FIELDSINFO SET
      FIELDKIND = FIELDKIND_,
      DESCRIPTIONLEVEL = DESCRIPTIONLEVEL_,
      ANCESTORREF = ANCESTORREF_,
      SELECTIONREF = SELECTIONREF_,
      TABLEREF = TABLEREF_,
      FIELDNAME = FIELDNAME_,
      DATATYPE = DATATYPE_,
      SUBDATATYPE = SUBDATATYPE_,
      FIELDSIZE = FIELDSIZE_,
      DISPLAYLABEL = DISPLAYLABEL_,
      NOTE = NOTE_,
      DEFAULTWIDTH = DEFAULTWIDTH_,
      EDITMASK = EDITMASK_,
      DISPLAYFORMAT = DISPLAYFORMAT_,
      EDITFORMAT = EDITFORMAT_,
      CANTEDIT = CANTEDIT_,
      NOVISUALIZE = NOVISUALIZE_,
      ENUMSREF = ENUMSREF_,
      REQUIRED = REQUIRED_,
      FOREIGNKEY = FOREIGNKEY_,
      ONDELACTION = ONDELACTION_,
      PRIMARYKEY = PRIMARYKEY_,
      ISRVERSION = ISRVERSION_,
      LIMITPARAMNAMES = LIMITPARAMNAMES_,
      FOLLOWORDER = FOLLOWORDER_,
      SORTDIRECTION = SORTDIRECTION_,
      SORTORDER = SORTORDER_,
      AGRFUNCTION = AGRFUNCTION_,
      FLAGFIELDNAME = FLAGFIELDNAME_,
      FLAGDISPLAYLABEL = FLAGDISPLAYLABEL_,
      FLAGNOTE = FLAGNOTE_,
      FLAGDEFAULTWIDTH = FLAGDEFAULTWIDTH_,
      FLAGCANTEDIT = FLAGCANTEDIT_,
      FLAGNOVISUALIZE = FLAGNOVISUALIZE_,
      FLAGREQUIRED = FLAGREQUIRED_,
      FLAGLIMITPARAMNAMES = FLAGLIMITPARAMNAMES_,
      FLAGAGRFUNCTION = FLAGAGRFUNCTION_,
      ISTIMESTAMPFIELD = ISTIMESTAMPFIELD_,
      ISBUDGET = ISBUDGET_,
      AVAILABLEINDEREF = AVAILABLEINDEREF_,
      ANNOTATION = ANNOTATION_,
      ALIAS = ALIAS_,
      DEREFNAME = DEREFNAME_
    WHERE ID = ID_;
  ELSE
    INSERT INTO FIELDSINFO
      (ID, FIELDKIND, DESCRIPTIONLEVEL, ANCESTORREF, SELECTIONREF, TABLEREF, FIELDNAME, DATATYPE, SUBDATATYPE,
       FIELDSIZE, DISPLAYLABEL, NOTE, DEFAULTWIDTH, EDITMASK, DISPLAYFORMAT, EDITFORMAT, CANTEDIT, NOVISUALIZE,
       ENUMSREF, REQUIRED, FOREIGNKEY, ONDELACTION, PRIMARYKEY, ISRVERSION, LIMITPARAMNAMES,
       FOLLOWORDER, SORTDIRECTION, SORTORDER, AGRFUNCTION, FLAGFIELDNAME, FLAGDISPLAYLABEL, FLAGNOTE,
       FLAGDEFAULTWIDTH, FLAGCANTEDIT, FLAGNOVISUALIZE, FLAGREQUIRED, FLAGLIMITPARAMNAMES, FLAGAGRFUNCTION,
       ISTIMESTAMPFIELD, ISBUDGET, AVAILABLEINDEREF, ANNOTATION, ALIAS, DEREFNAME)
    VALUES
      (ID_, FIELDKIND_, DESCRIPTIONLEVEL_, ANCESTORREF_, SELECTIONREF_, TABLEREF_, FIELDNAME_, DATATYPE_, SUBDATATYPE_,
       FIELDSIZE_, DISPLAYLABEL_, NOTE_, DEFAULTWIDTH_, EDITMASK_, DISPLAYFORMAT_, EDITFORMAT_, CANTEDIT_, NOVISUALIZE_,
       ENUMSREF_, REQUIRED_, FOREIGNKEY_, ONDELACTION_, PRIMARYKEY_, ISRVERSION_, LIMITPARAMNAMES_,
       FOLLOWORDER_, SORTDIRECTION_, SORTORDER_, AGRFUNCTION_, FLAGFIELDNAME_, FLAGDISPLAYLABEL_, FLAGNOTE_,
       FLAGDEFAULTWIDTH_, FLAGCANTEDIT_, FLAGNOVISUALIZE_, FLAGREQUIRED_, FLAGLIMITPARAMNAMES_, FLAGAGRFUNCTION_,
       ISTIMESTAMPFIELD_, ISBUDGET_, AVAILABLEINDEREF_, ANNOTATION_, ALIAS_, DEREFNAME_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONEVENTS_IMPORT(
  ID_ NUMBER,
  SELECTIONREF_ NUMBER,
  EVENTCODE_ NUMBER,
  SCRIPTNAME_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONEVENTS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONEVENTS SET
      SELECTIONREF = SELECTIONREF_,
      EVENTCODE = EVENTCODE_,
      SCRIPTNAME = SCRIPTNAME_
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONEVENTS
      (ID, SELECTIONREF, EVENTCODE, SCRIPTNAME)
    VALUES
      (ID_, SELECTIONREF_, EVENTCODE_, SCRIPTNAME_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FIELDSINFO_DELETE(
  ID_ NUMBER
) IS
BEGIN
  UPDATE DOCUMENTFIELDS SET
    FIELDINFOREF = NULL
  WHERE FIELDINFOREF = ID_;
  DELETE FROM FIELDSINFO FI
  WHERE FI.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONSDETAIL_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONSDETAIL SLD
  WHERE SLD.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONS SL
  WHERE SL.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONEVENTS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONEVENTS SE
  WHERE SE.ID = ID_;
END;
/

-- 
CALL FIELDSINFO_DELETE(20555) ;

CALL FIELDSINFO_DELETE(20556) ;

CALL FIELDSINFO_DELETE(20557) ;

CALL FIELDSINFO_DELETE(20558) ;

CALL FIELDSINFO_DELETE(20559) ;

CALL FIELDSINFO_DELETE(20560) ;

CALL FIELDSINFO_DELETE(20562) ;

CALL FIELDSINFO_DELETE(20563) ;

CALL FIELDSINFO_DELETE(20564) ;

CALL FIELDSINFO_DELETE(20565) ;

CALL FIELDSINFO_DELETE(20566) ;

CALL FIELDSINFO_DELETE(20567) ;

CALL FIELDSINFO_DELETE(20568) ;

CALL FIELDSINFO_DELETE(20569) ;

CALL FIELDSINFO_DELETE(20570) ;

CALL FIELDSINFO_DELETE(20571) ;

CALL FIELDSINFO_DELETE(20572) ;

CALL FIELDSINFO_DELETE(20573) ;

CALL FIELDSINFO_DELETE(20574) ;

CALL FIELDSINFO_DELETE(20575) ;

CALL FIELDSINFO_DELETE(20576) ;

CALL FIELDSINFO_DELETE(20577) ;

CALL FIELDSINFO_DELETE(20579) ;

CALL FIELDSINFO_DELETE(20580) ;

CALL FIELDSINFO_DELETE(20581) ;

CALL FIELDSINFO_DELETE(20582) ;

CALL FIELDSINFO_DELETE(20583) ;

CALL FIELDSINFO_DELETE(20584) ;

CALL FIELDSINFO_DELETE(20585) ;

CALL FIELDSINFO_DELETE(20586) ;

CALL FIELDSINFO_DELETE(20587) ;

CALL FIELDSINFO_DELETE(20588) ;

CALL FIELDSINFO_DELETE(20589) ;

CALL FIELDSINFO_DELETE(20590) ;

CALL FIELDSINFO_DELETE(44462) ;

CALL FIELDSINFO_DELETE(44463) ;

CALL FIELDSINFO_DELETE(44464) ;

CALL SELECTIONS_DELETE(20554) ;

CALL SELECTIONS_DELETE(20561) ;

CALL SELECTIONS_DELETE(20578) ;

CALL SELECTIONS_IMPORT(20428, 1, 'TREASUARYDOCSTATE', '.    ', 0, 0, 'TREASUARYDOCSTATE', 'TREASUARYDOCSTATE', 0, 0, 0, 1, '', 0, 0, 3, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(44587, 1, 'TARGETCLSDETAIL', '  ()', 0, 0, 'TARGETCLSDETAIL', 'TargetClsDetail', 33, 0, 0, 2, '', 1, 1, 3600, null, 5, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(20868, 1, 'STATE_OPENFIELDS', ',      ', 0, 0, 'STATE_OPENFIELDS', 'St_OF', 93, 0, 0, 2, '', 1, 0, 3, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(21876, 1, 'STATE_JUMPCONTROL', '     ', 0, 0, 'STATE_JUMPCONTROL', 'St_JC', 97, 0, 0, 2, '', 1, 0, 3, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(22727, 1, 'SUPDOCTYPECLS', '  ', 0, 0, 'SUPDOCTYPECLS', 'SupDTCls', 198, 0, 0, 2, '', 0, 0, 3, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(30656, 1, 'SIGNLOG', '.   ', 0, 0, 'SIGNLOG', 'SIGNLOG', 0, 0, 0, 2, '', 1, 0, 3, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(30657, 1, 'SIGNPARAMS', '.   ', 0, 0, 'SIGNPARAMS', 'SIGNPARAMS', 0, 0, 0, 2, '', 1, 0, 3, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(35045, 1, 'SIGNCERTIFICATE', ' ', 0, 0, 'SIGNCERTIFICATE', 'SIGNCERTIFICATE', 0, 0, 0, 2, '', 1, 0, -1, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(35046, 1, 'SIGNDOCUMENTSGROUP', '  ', 0, 0, 'SIGNDOCUMENTSGROUP', 'SIGNDOCUMENTSGROUP', 0, 0, 0, 2, '', 1, 0, -1, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(35047, 1, 'SIGNDOCUMENTSGROUPDETAIL', '  . ', 0, 0, 'SIGNDOCUMENTSGROUPDETAIL', 'SIGNDOCUMENTSGROUPDETAIL', 0, 0, 0, 2, '', 1, 0, -1, null, null, '', '', null, 0) ;

-- BUDGETS_S
CALL FIELDSINFO_IMPORT(44396, 0, 1, null, 16803, null, 'OKTMO', 3, 0, 0, '', '', 15, '', '', '', 0, 0, null, 0, 32820, 0, 0, 0, '', 16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- MEANSTYPE
CALL FIELDSINFO_IMPORT(44584, 0, 1, null, 17311, null, 'MEANSSOURCE', 3, 0, 2, ' ', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 15, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- EXECUTIONDOCUMENTSCAPTION
CALL FIELDSINFO_IMPORT(44569, 0, 1, null, 19736, null, 'AUTOSANCTION', 3, 0, 0, '  ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 57, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- TARGETCLS
CALL FIELDSINFO_IMPORT(44257, 0, 1, null, 22385, null, 'TRANSFERKVSR', 1, 0, 20, '   ', '', 10, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(22387, 0, 1, null, 22385, null, 'NAME', 1, 0, 2000, '', '', 60, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44258, 0, 1, null, 22385, null, 'TRANSFERKFSR', 1, 0, 20, '  ', '', 10, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44259, 0, 1, null, 22385, null, 'TRANSFERKCSR', 1, 0, 20, '  ', '', 10, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44260, 0, 1, null, 22385, null, 'TRANSFERKVR', 1, 0, 20, '  ', '', 10, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44615, 0, 1, null, 22385, null, 'CREATERUSER', 1, 0, 30, '()', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 33, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44616, 0, 1, null, 22385, null, 'UPDATERUSER', 1, 0, 30, '()', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 34, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44617, 0, 1, null, 22385, null, 'BUDGETREF', 3, 0, 0, '()', '', 11, '999', '', '', 0, 0, null, 1, 16803, 0, 0, 0, '', 41, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44618, 0, 1, null, 22385, null, 'SHORTNAME', 1, 0, 255, ' ', '', 60, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 28, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44619, 0, 1, null, 22385, null, 'RECEIVEKDVALUE', 1, 0, 20, '  ', '', 20, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 26, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44620, 0, 1, null, 22385, null, 'TRANSFERTKIND', 3, 0, 0, ' ', '', 11, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 36, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44621, 0, 1, null, 22385, null, 'INVESTOBJECT', 3, 0, 0, ' ', ' ', 11, '', '', '', 0, 0, null, 0, 38203, 0, 0, 0, '', 31, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44622, 0, 1, null, 22385, null, 'TRANSFERBUDGETREF', 3, 0, 0, '()', '', 11, '999', '', '', 0, 0, null, 1, 16803, 0, 0, 0, '', 41, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44623, 0, 1, null, 22385, null, 'LOWERBUDGETKD', 1, 0, 20, '  ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 26, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44624, 0, 1, null, 22385, null, 'PARENTTARGETCLS', 3, 0, 0, '  (   )', '  (   )', 12, '', '', '', 0, 0, null, 0, 22385, 0, 0, 0, '', 72, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44625, 0, 1, null, 22385, null, 'EXPORTINFK', 3, 0, 0, '   ', '', 10, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44626, 0, 1, null, 22385, null, 'OVERCOFINANCING', 3, 0, 0, ' (   )', ' (   )', 12, '', '', '', 0, 0, null, 0, 22385, 0, 0, 0, '', 72, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44627, 0, 1, null, 22385, null, 'BUDGETLEVEL', 3, 0, 0, '  ', '', 10, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44628, 0, 1, null, 22385, null, 'ISTRANSFERT', 3, 0, 0, ' ', '', 10, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44629, 0, 1, null, 22385, null, 'ISCOFINANCING', 3, 0, 0, '', '', 10, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- INVESTOBJECT
CALL FIELDSINFO_IMPORT(44429, 0, 1, null, 38203, null, 'INVESTDIRECTION', 3, 0, 0, ' ', '', 0, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 32, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44430, 0, 1, null, 38203, null, 'PROVIDINGPURPOSE', 15, 0, 10000, ' ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 33, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44431, 0, 1, null, 38203, null, 'APOWER', 1, 0, 255, '', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 34, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44432, 0, 1, null, 38203, null, 'DEVELOPERNAME', 1, 0, 2000, ' ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 35, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44433, 0, 1, null, 38203, null, 'DEVELOPSTARTDATE', 3, 0, 0, '  ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 36, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44434, 0, 1, null, 38203, null, 'DEVELOPENDDATE', 3, 0, 0, '  ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 37, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44435, 0, 1, null, 38203, null, 'DEVELOPCOST', 6, 0, 0, '  ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 38, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44436, 0, 1, null, 38203, null, 'TOTALCOST', 6, 0, 0, '  ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 39, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44437, 0, 1, null, 38203, null, 'COORDINATES', 1, 0, 255, ' ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 40, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44438, 0, 1, null, 38203, null, 'REGISTRYAGREEMENTNUMBER', 1, 0, 20, '   ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 41, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- AUTOSANCTIONDATA
CALL FIELDSINFO_IMPORT(44405, 0, 1, null, 39170, null, 'FINTYPE', 3, 0, 0, ' ', '  ', 5, '9.99', '', '', 0, 0, null, 0, 16955, 0, 0, 0, '', 45, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44406, 0, 1, null, 39170, null, 'DIRECTIONCLS', 3, 0, 0, '', '   ', 4, '999', '000', '000', 0, 0, null, 0, 21555, 0, 0, 0, '', 42, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44407, 0, 1, null, 39170, null, 'FACT', 3, 0, 0, '', ' ', 9, '99.99.99', '', '', 0, 0, null, 0, 16964, 0, 0, 0, '', 44, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44408, 0, 1, null, 39170, null, 'REGIONCLS', 3, 0, 0, '', ' ', 9, '99.99.99', '', '', 0, 0, null, 0, 16688, 0, 0, 0, '', 46, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44409, 0, 1, null, 39170, null, 'SUBKESR', 3, 0, 0, '', '   ', 10, '9.9.9', '', '', 0, 0, null, 0, 16915, 0, 0, 0, '', 43, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44410, 0, 1, null, 39170, null, 'SUBSIDYCLS', 3, 0, 0, '  ()', '', 12, '', '', '', 0, 0, null, 0, 26536, 0, 0, 0, '', 50, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44411, 0, 1, null, 39170, null, 'TARGETCLS', 3, 0, 0, '  ()', '   ', 12, '', '', '', 0, 0, null, 0, 22385, 0, 0, 0, '', 72, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44412, 0, 1, null, 39170, null, 'TRANSFERTCLS', 3, 0, 0, '   ()', '    ', 12, '', '', '', 0, 0, null, 0, 22773, 0, 0, 0, '', 52, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44422, 0, 1, null, 39170, null, 'CONTRACTCOSTSCLS', 3, 0, 0, '', '', 9, '', '', '', 0, 0, null, 0, 40457, 0, 0, 0, '', 47, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44423, 0, 1, null, 39170, null, 'INVESTOBJECT', 3, 0, 0, '', '', 0, '', '', '', 0, 0, null, 0, 38203, 0, 0, 0, '', 48, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44425, 0, 1, null, 39170, null, 'STOREDCONTENT', 1, 0, 0, '.  ', '', 4000, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 49, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44450, 0, 1, null, 39170, null, 'DOCTYPECLS', 3, 0, 0, '  ()', '', 10, '', '', '', 0, 0, null, 0, 16814, 0, 0, 0, '', 51, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- TARGETCLSDETAIL
CALL FIELDSINFO_IMPORT(44588, 0, 1, null, 44587, null, 'TRANSFERKCSR', 3, 0, 0, '  ', '', 11, '', '', '', 0, 0, null, 1, 16857, 0, 0, 0, '', 25, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44602, 0, 1, null, 44587, null, 'REGIONCLS', 3, 0, 0, ' ', ' ', 9, '99.99.99', '', '', 0, 0, null, 1, 16688, 0, 0, 0, '', 64, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44590, 0, 1, null, 44587, null, 'KESR', 3, 0, 0, '', '', 11, '', '', '', 0, 0, null, 1, 16871, 0, 0, 0, '', 27, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44591, 0, 1, null, 44587, null, 'TRANSFERKFSR', 3, 0, 0, '  ', '', 11, '', '', '', 0, 0, null, 1, 16844, 0, 0, 0, '', 28, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44592, 0, 1, null, 44587, null, 'TRANSFERKVR', 3, 0, 0, '  ', '', 11, '', '', '', 0, 0, null, 1, 16864, 0, 0, 0, '', 29, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44593, 0, 1, null, 44587, null, 'TRANSFERKVSR', 3, 0, 0, '   ', '', 11, '', '', '', 0, 0, null, 1, 16851, 0, 0, 0, '', 30, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44594, 0, 1, null, 44587, null, 'TARGETCLS', 3, 0, 0, '     ', '     ', 11, '', '', '', 2, 0, null, 1, 22385, 1, 0, 0, '', 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44595, 0, 1, null, 44587, null, 'MEANSTYPE', 3, 0, 0, ' ', '  ', 9, '99.99.99', '', '', 0, 0, null, 1, 17311, 0, 0, 0, '', 24, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44596, 0, 1, null, 44587, null, 'INVESTOBJECT', 3, 0, 0, ' ', ' ', 11, '', '', '', 0, 0, null, 0, 38203, 0, 0, 0, '', 31, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44597, 0, 1, null, 44587, null, 'FACT', 3, 0, 0, '', ' ', 9, '99.99.99', '', '', 0, 0, null, 1, 16964, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44598, 0, 1, null, 44587, null, 'FINTYPE', 3, 0, 0, ' ', '  ', 5, '9.99', '', '', 0, 0, null, 1, 16955, 0, 0, 0, '', 17, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44599, 0, 1, null, 44587, null, 'SUBKESR', 3, 0, 0, '', '', 10, '9.9.9', '', '', 0, 0, null, 1, 16915, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44600, 0, 1, null, 44587, null, 'OKTMO', 3, 0, 0, '', '', 15, '', '', '', 0, 0, null, 0, 32820, 0, 0, 0, '', 57, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44603, 0, 1, null, 44587, null, 'ASSIGNMENTKIND', 3, 0, 0, ' ', ' ', 9, '99.99.99', '', '', 0, 0, null, 1, 22976, 0, 0, 0, '', 73, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44604, 0, 1, null, 44587, null, 'BUDALLOCATIONCLS', 3, 0, 0, '  ', '  ', 9, '9999.999', '', '', 0, 0, null, 0, 27814, 0, 0, 0, '', 82, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44605, 0, 1, null, 44587, null, 'DIRECTIONCLS', 3, 0, 0, '', '   ', 4, '999', '', '', 0, 0, null, 1, 21555, 0, 0, 0, '', 50, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44606, 0, 1, null, 44587, null, 'PAYPROMISECLS', 3, 0, 0, '  ', '  ', 13, '999.999.99.9', '', '', 0, 0, null, 0, 27815, 0, 0, 0, '', 83, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44607, 0, 1, null, 44587, null, 'SUBSIDYCLS', 3, 0, 0, ' ', ' ', 12, '', '', '', 0, 0, null, 0, 26536, 0, 0, 0, '', 77, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44608, 0, 1, null, 44587, null, 'FUNDSSOURCE', 3, 0, 0, ' ', '  ', 11, '999.999.99', '', '', 0, 0, null, 1, 22632, 0, 0, 0, '', 48, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44609, 0, 1, null, 44587, null, 'CONTRACTCOSTSCLS', 3, 0, 0, '', '', 11, '9.9.9', '', '', 0, 0, null, 0, 40457, 0, 0, 0, '', 27, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44610, 0, 1, null, 44587, null, 'CREATEDATE', 11, 0, 0, ' ', '', 20, '99/99/9999', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 21, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44611, 0, 1, null, 44587, null, 'CREATERUSER', 1, 0, 30, '()', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 33, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44612, 0, 1, null, 44587, null, 'UPDATEDATE', 11, 0, 0, ' ', '', 20, '99/99/9999', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 22, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44613, 0, 1, null, 44587, null, 'UPDATERUSER', 1, 0, 30, '()', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 34, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44614, 0, 1, null, 44587, null, 'ID', 3, 0, 0, '', '', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44745, 0, 1, null, 44587, null, 'STARTDATE', 11, 0, 0, '   ', '   ', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44746, 0, 1, null, 44587, null, 'DELETEDATE', 11, 0, 0, ' ', ' ', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44747, 0, 1, null, 44587, null, 'EXTID', 1, 0, 50, '', '', 50, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44748, 0, 1, null, 44587, null, 'EXTOWNER', 1, 0, 50, '  ', '  ', 50, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44749, 0, 1, null, 44587, null, 'EXTSYNCDATE', 11, 0, 0, ',  ,  ', ',  ,  ', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44750, 0, 1, null, 44587, null, 'EXTROOTID', 1, 0, 50, ' ', ' ', 50, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44751, 0, 1, null, 44587, null, 'EXTVERSION', 3, 0, 0, '   ', '   ', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 15, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(44752, 0, 1, null, 44587, null, 'EXTVERSIONDATE', 11, 0, 0, '   ', '   ', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

--  
DROP PROCEDURE SELECTIONS_IMPORT
/

DROP PROCEDURE SELECTIONSDETAIL_IMPORT
/

DROP PROCEDURE FIELDSINFO_IMPORT
/

DROP PROCEDURE SELECTIONEVENTS_IMPORT
/

DROP PROCEDURE FIELDSINFO_DELETE
/

DROP PROCEDURE SELECTIONSDETAIL_DELETE
/

DROP PROCEDURE SELECTIONS_DELETE
/

DROP PROCEDURE SELECTIONEVENTS_DELETE
/

CREATE OR REPLACE PROCEDURE ImportDocCLS (
   ID_                 NUMBER,
   DOCTYPE_            NUMBER,
   DOCTYPENOTE_        VARCHAR2,
   TABLENAME_          VARCHAR2,
   TABLENAMEURM_       VARCHAR2,
   PRIMARYKEYNAME_     VARCHAR2,
   PRIMARYKEYNAMEURM_  VARCHAR2,
   LINKFIELDNAME_      VARCHAR2,
   LINKFIELDNAMEURM_   VARCHAR2,
   CLSTYPE_            NUMBER,
   SELECTIONREFBUDGET_ NUMBER,
   SELECTIONREFURM_    NUMBER,
   PROGINDEX_          NUMBER
) IS IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
   INTO IDExists$
   FROM DOCUMENTCLS
   WHERE (ID = ID_);

   IF (IDExists$ = 0) THEN
   INSERT INTO DOCUMENTCLS
   (ID, DOCTYPE, DOCTYPENOTE, TABLENAME, TABLENAMEURM, PRIMARYKEYNAME, PRIMARYKEYNAMEURM, LINKFIELDNAME, LINKFIELDNAMEURM, CLSTYPE, 
     SELECTIONREFBUDGET, SELECTIONREFURM, PROGINDEX)
   VALUES (ID_, DOCTYPE_, DOCTYPENOTE_, TABLENAME_, TABLENAMEURM_, PRIMARYKEYNAME_, PRIMARYKEYNAMEURM_, LINKFIELDNAME_, LINKFIELDNAMEURM_, CLSTYPE_, 
     SELECTIONREFBUDGET_, SELECTIONREFURM_, PROGINDEX_);
   ELSE
   UPDATE DOCUMENTCLS 
   SET
     DOCTYPENOTE = DOCTYPENOTE_,
     TABLENAME = TABLENAME_,
     TABLENAMEURM = TABLENAMEURM_,
     PRIMARYKEYNAME = PRIMARYKEYNAME_,
     PRIMARYKEYNAMEURM = PRIMARYKEYNAMEURM_,
     LINKFIELDNAME = LINKFIELDNAME_,
     LINKFIELDNAMEURM = LINKFIELDNAMEURM_,
     CLSTYPE = CLSTYPE_,
     SELECTIONREFBUDGET = SELECTIONREFBUDGET_,
     SELECTIONREFURM = SELECTIONREFURM_,
     PROGINDEX = PROGINDEX_
   WHERE  
    (ID = ID_)
    AND NOT (
            (
                    ((DOCTYPENOTE IS NOT NULL AND DOCTYPENOTE_ IS NOT NULL) AND
                       (UPPER (DOCTYPENOTE) = UPPER (DOCTYPENOTE_))
                    )
                    OR (DOCTYPENOTE IS NULL AND DOCTYPENOTE_ IS NULL)
                )    
        AND (UPPER (TABLENAME) = UPPER (TABLENAME_))    
        AND (
                    ((TABLENAMEURM IS NOT NULL AND TABLENAMEURM_ IS NOT NULL) AND
                       (UPPER (TABLENAMEURM) = UPPER (TABLENAMEURM_))
                    )
                    OR (TABLENAMEURM IS NULL AND TABLENAMEURM_ IS NULL)
                )    
        AND (UPPER (PRIMARYKEYNAME) = UPPER (PRIMARYKEYNAME_))
        AND (
                    ((PRIMARYKEYNAMEURM IS NOT NULL AND PRIMARYKEYNAMEURM_ IS NOT NULL) AND
                       (UPPER (PRIMARYKEYNAMEURM) = UPPER (PRIMARYKEYNAMEURM_))
                    )
                    OR (PRIMARYKEYNAMEURM IS NULL AND PRIMARYKEYNAMEURM_ IS NULL)
                )    
        AND (
                    ((LINKFIELDNAME IS NOT NULL AND LINKFIELDNAME_ IS NOT NULL) AND
                       (UPPER (LINKFIELDNAME) = UPPER (LINKFIELDNAME_))
                    )
                    OR (LINKFIELDNAME IS NULL AND LINKFIELDNAME_ IS NULL)
                )    
        AND (
                    ((LINKFIELDNAMEURM IS NOT NULL AND LINKFIELDNAMEURM_ IS NOT NULL) AND
                       (UPPER (LINKFIELDNAMEURM) = UPPER (LINKFIELDNAMEURM_))
                    )
                    OR (LINKFIELDNAMEURM IS NULL AND LINKFIELDNAMEURM_ IS NULL)
                )    
        AND (
                    ((CLSTYPE IS NOT NULL AND CLSTYPE_ IS NOT NULL) AND
                       (UPPER (CLSTYPE) = UPPER (CLSTYPE_))
                    )
                    OR (CLSTYPE IS NULL AND CLSTYPE_ IS NULL)
                ) 
        AND (
                    ((PROGINDEX IS NOT NULL AND PROGINDEX_ IS NOT NULL) AND
                       (PROGINDEX = PROGINDEX_)
                    )
                    OR (PROGINDEX IS NULL AND PROGINDEX_ IS NULL)
                )   
            );
   
   END IF;
END;
/

--   
CALL ImportDocCLS(10100, 101, '', 'FINDOCCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 223) ;

CALL ImportDocCLS(10101, 101, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, 223) ;

CALL ImportDocCLS(10102, 101, ' ', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10103, 101, ' ', 'DEBT', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10104, 101, ' %  ', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10105, 101, ' ', 'INCOMES32', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20100, 201, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 32) ;

CALL ImportDocCLS(20101, 201, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 32) ;

CALL ImportDocCLS(30100, 301, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 66) ;

CALL ImportDocCLS(30101, 301, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 66) ;

CALL ImportDocCLS(30200, 302, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 63) ;

CALL ImportDocCLS(30201, 302, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 63) ;

CALL ImportDocCLS(30300, 303, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 65) ;

CALL ImportDocCLS(30301, 303, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 65) ;

CALL ImportDocCLS(30400, 304, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 64) ;

CALL ImportDocCLS(30401, 304, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 64) ;

CALL ImportDocCLS(30500, 305, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 61) ;

CALL ImportDocCLS(30501, 305, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 61) ;

CALL ImportDocCLS(30600, 306, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 62) ;

CALL ImportDocCLS(30601, 306, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 62) ;

CALL ImportDocCLS(30700, 307, '', 'FACIALFINREESTR', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(31100, 311, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 68) ;

CALL ImportDocCLS(31101, 311, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 68) ;

CALL ImportDocCLS(31200, 312, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 69) ;

CALL ImportDocCLS(31201, 312, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 69) ;

CALL ImportDocCLS(31400, 314, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 70) ;

CALL ImportDocCLS(31401, 314, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 70) ;

CALL ImportDocCLS(31500, 315, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 71) ;

CALL ImportDocCLS(31501, 315, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 71) ;

CALL ImportDocCLS(992500, 9925, '', 'Cards', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992501, 9925, ' ', 'CARDSDETAIL_FACC', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(490300, 4903, '', 'DATAPACKET', ' ', 'ID', ' ', '', ' ', 0, null, null, 527) ;

CALL ImportDocCLS(32200, 322, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 73) ;

CALL ImportDocCLS(32201, 322, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 73) ;

CALL ImportDocCLS(32300, 323, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 75) ;

CALL ImportDocCLS(32301, 323, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 75) ;

CALL ImportDocCLS(32400, 324, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 76) ;

CALL ImportDocCLS(32401, 324, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 76) ;

CALL ImportDocCLS(40100, 401, '', 'LOANCREDIT', ' ', 'ID', ' ', '', ' ', 0, null, null, 130) ;

CALL ImportDocCLS(40101, 401, '', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 131) ;

CALL ImportDocCLS(40102, 401, ' ', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 137) ;

CALL ImportDocCLS(40103, 401, '', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 132) ;

CALL ImportDocCLS(40104, 401, ' %', 'LOANCREDITPERCENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 134) ;

CALL ImportDocCLS(40105, 401, '  %', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 138) ;

CALL ImportDocCLS(40106, 401, ' %', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 133) ;

CALL ImportDocCLS(40107, 401, ' %', 'PERCENTJOURNAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(40108, 401, '. ', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(40109, 401, '', 'COLLATERAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 340) ;

CALL ImportDocCLS(40110, 401, '.', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 341) ;

CALL ImportDocCLS(40111, 401, '', 'LOANCREDITCONTRACTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 342) ;

CALL ImportDocCLS(50100, 501, '', 'LOANCREDIT', ' ', 'ID', ' ', '', ' ', 0, null, null, 120) ;

CALL ImportDocCLS(50101, 501, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 121) ;

CALL ImportDocCLS(50102, 501, ' ', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 127) ;

CALL ImportDocCLS(50103, 501, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 122) ;

CALL ImportDocCLS(50104, 501, ' %', 'LOANCREDITPERCENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 124) ;

CALL ImportDocCLS(50105, 501, '  %', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 128) ;

CALL ImportDocCLS(50106, 501, ' %', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 123) ;

CALL ImportDocCLS(50107, 501, ' %', 'PERCENTJOURNAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(50108, 501, '', 'COLLATERAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 321) ;

CALL ImportDocCLS(70100, 701, '', 'FINDOCCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 23) ;

CALL ImportDocCLS(70101, 701, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 23) ;

CALL ImportDocCLS(70200, 702, '', 'PAYDOC32', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(70201, 702, '', 'PAYDOC32', ' ', 'ID', ' ', 'PARENTINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(70300, 703, '', 'FINDOCDETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, 36) ;

CALL ImportDocCLS(80100, 801, '', 'LIMITNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80101, 801, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 57) ;

CALL ImportDocCLS(80200, 802, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80300, 803, '', 'REQUESTFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80301, 803, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80400, 804, '', 'LIMITFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(90100, 901, '', 'QUOTESTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, 145) ;

CALL ImportDocCLS(90101, 901, '', 'INCOMES32', ' ', 'ID', ' ', 'RecordIndex', ' ', 0, null, null, 0) ;

CALL ImportDocCLS(90300, 903, '', 'QUOTESTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, 45) ;

CALL ImportDocCLS(90301, 903, '', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 45) ;

CALL ImportDocCLS(90500, 905, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 44) ;

CALL ImportDocCLS(90600, 906, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 41) ;

CALL ImportDocCLS(90601, 906, '', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 42) ;

CALL ImportDocCLS(120100, 1201, '', 'BUH_JOURNAL', ' ', 'ID', ' ', '', ' ', 0, null, null, 309) ;

CALL ImportDocCLS(150100, 1501, '', 'ORGOPERAT', ' ', 'ID', ' ', '', ' ', 0, null, null, 35) ;

CALL ImportDocCLS(160100, 1601, '', 'PROMISE_CAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(160101, 1601, '', 'PROMISE_DETAIL', ' ', 'ID', ' ', 'TITLE_REF', ' ', 0, null, null, 345) ;

CALL ImportDocCLS(160200, 1602, '', 'PROMISE_DETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(170100, 1701, '', 'REQUESTS', ' ', 'ID', ' ', '', ' ', 0, null, null, 222) ;

CALL ImportDocCLS(170200, 1702, '', 'REQUESTS', ' ', 'ID', ' ', '', ' ', 0, null, null, 221) ;

CALL ImportDocCLS(170201, 1702, '', 'REQUESTSPAYMENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(190100, 1901, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 264) ;

CALL ImportDocCLS(190101, 1901, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 264) ;

CALL ImportDocCLS(220100, 2201, '', 'BUDNOTIFY', 'BUDNOTIFY', 'ID', ' ', '', ' ', 0, null, null, 46) ;

CALL ImportDocCLS(220101, 2201, '', 'BUDGETDATA', 'BUDGETDATA', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 46) ;

CALL ImportDocCLS(280100, 2801, '', 'ACCSOPERTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(280101, 2801, '', 'PAYDOC32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 16) ;

CALL ImportDocCLS(280200, 2802, '', 'DFACCOUNTOPERATION', ' ', 'ID', ' ', '', ' ', 0, null, null, 50) ;

CALL ImportDocCLS(440100, 4401, '', 'UNIONNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 251) ;

CALL ImportDocCLS(440101, 4401, '', 'UNIONNOTIFYDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 251) ;

CALL ImportDocCLS(0, 0, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991304, 9913, ' ', 'STATICLINKS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(440300, 4403, '', 'UNIONNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 254) ;

CALL ImportDocCLS(440301, 4403, '', 'UNIONNOTIFYDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 254) ;

CALL ImportDocCLS(989500, 9895, ' ', 'OKTMO', 'OKTMO', 'id', 'id', '', '', 95, null, null, null) ;

CALL ImportDocCLS(990300, 9903, '', 'ORGANIZATIONS', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990301, 9903, ' ', 'ORG_ACCOUNTS', ' ', 'ID', ' ', 'ORG_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990302, 9903, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', 'ORG_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990500, 9905, '', 'ORGANIZATIONS', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(90200, 902, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 38) ;

CALL ImportDocCLS(20701, 207, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 272) ;

CALL ImportDocCLS(90700, 907, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(181200, 1812, '', 'ED_CorrectionCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181000, 1810, '', 'ED_OUTPAYDOC', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20700, 207, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 272) ;

CALL ImportDocCLS(181001, 1810, '', 'ED_DETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(992700, 9927, '', 'REMOTECLIENT', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(550100, 5501, '', 'CORRECTIONCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 312) ;

CALL ImportDocCLS(20801, 208, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 273) ;

CALL ImportDocCLS(30701, 307, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', 'REESTR_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21100, 211, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 275) ;

CALL ImportDocCLS(490100, 4901, '', 'DATAPACKET', ' ', 'ID', ' ', '', ' ', 0, null, null, 525) ;

CALL ImportDocCLS(992701, 9927, '  ', 'REMOTEREADRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(550101, 5501, '', 'CORRECTIONDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 312) ;

CALL ImportDocCLS(490301, 4903, '', 'ARCHIVEOPLOG', ' ', 'ID', ' ', 'DATAPACKETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(390100, 3901, '', 'DELOIN', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21101, 211, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 275) ;

CALL ImportDocCLS(992300, 9923, '', 'SIGNSCHEMECAPTION', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181201, 1812, '', 'ED_CorrectionDetail', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(550200, 5502, '', 'CORRECTIONCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 313) ;

CALL ImportDocCLS(20800, 208, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 273) ;

CALL ImportDocCLS(550201, 5502, '', 'CORRECTIONDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 313) ;

CALL ImportDocCLS(90000, 900, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992301, 9923, '', 'SIGNSCHEMEDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(991600, 9916, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992200, 9922, '', 'ARCHIVEDOCTYPE', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(90001, 900, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(390101, 3901, '', 'DELOEXEC', ' ', 'ID', ' ', 'DOCID', ' ', 0, null, null, null) ;

CALL ImportDocCLS(180700, 1807, '', 'PayDocExchange', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(21102, 211, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 275) ;

CALL ImportDocCLS(991700, 9917, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991200, 9912, '', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(181600, 1816, '', 'FacialFinCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(30800, 308, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 67) ;

CALL ImportDocCLS(250100, 2501, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', ' ', 0, null, null, 305) ;

CALL ImportDocCLS(21200, 212, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 276) ;

CALL ImportDocCLS(250101, 2501, '  ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 305) ;

CALL ImportDocCLS(30801, 308, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 67) ;

CALL ImportDocCLS(250200, 2502, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', ' ', 0, null, null, 304) ;

CALL ImportDocCLS(250201, 2502, ' ', 'AGREEMENTSTEPS', 'AGREEMENTSTEPS', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(988900, 9889, ' ', 'SubsidyCls', ' ', 'id', ' ', '', '', 89, null, null, null) ;

CALL ImportDocCLS(250202, 2502, '  ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'AGREEMENTREF', 'AGREEMENTREF', 0, null, null, 304) ;

CALL ImportDocCLS(988700, 9887, ' ', 'VariantCls', ' ', 'ID', ' ', '', '', 87, null, null, null) ;

CALL ImportDocCLS(520100, 5201, '', 'WritExecutionCaption', 'WritExecutionCaption', 'id', 'id', '', '', 0, null, null, 555) ;

CALL ImportDocCLS(990800, 9908, '', 'DocumentTypes', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(250300, 2503, '', 'EXECUTIONDOCUMENTSCAPTION', 'EXECUTIONDOCUMENTSCAPTION', 'ID', 'ID', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21201, 212, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 276) ;

CALL ImportDocCLS(250301, 2503, '', 'EXECUTIONDOCUMENTSDETAIL', 'EXECUTIONDOCUMENTSDETAIL', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(180500, 1805, '', 'BANKEXCH_MERDOC', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(20201, 202, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 260) ;

CALL ImportDocCLS(20301, 203, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 261) ;

CALL ImportDocCLS(20401, 204, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 262) ;

CALL ImportDocCLS(20501, 205, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 263) ;

CALL ImportDocCLS(20601, 206, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 268) ;

CALL ImportDocCLS(190201, 1902, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 215) ;

CALL ImportDocCLS(190301, 1903, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 265) ;

CALL ImportDocCLS(20000, 200, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190601, 1906, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 271) ;

CALL ImportDocCLS(20200, 202, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 260) ;

CALL ImportDocCLS(20300, 203, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 261) ;

CALL ImportDocCLS(20400, 204, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 262) ;

CALL ImportDocCLS(20500, 205, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 263) ;

CALL ImportDocCLS(20600, 206, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 268) ;

CALL ImportDocCLS(190200, 1902, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 215) ;

CALL ImportDocCLS(190300, 1903, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 265) ;

CALL ImportDocCLS(180501, 1805, '', 'ED_DETAIL', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(190600, 1906, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 271) ;

CALL ImportDocCLS(988400, 9884, ' ', 'TransfertCLS', ' ', 'ID', ' ', '', '', 84, null, null, null) ;

CALL ImportDocCLS(988800, 9888, ' ', 'OKP', ' ', 'ID', ' ', '', '', 88, null, null, null) ;

CALL ImportDocCLS(989900, 9899, ' ', 'DBUsers', ' ', 'ID', ' ', '', '', 201, null, null, null) ;

CALL ImportDocCLS(990801, 9908, ' ', 'DOCUMENTFIELDS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(361000, 3610, '', 'UTYPEDFORMSCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 550) ;

CALL ImportDocCLS(987200, 9872, ' ', 'BalanceCls', ' ', 'ID', ' ', '', '', 72, null, null, null) ;

CALL ImportDocCLS(984600, 9846, ' ', 'BUHPAYMENTCLS', ' ', 'ID', ' ', '', '', 46, null, null, null) ;

CALL ImportDocCLS(981800, 9818, ' ', 'CURRENCYCLS', ' ', 'ID', ' ', '', '', 18, null, null, null) ;

CALL ImportDocCLS(988500, 9885, ' ', 'AssignmentKind', ' ', 'ID', ' ', '', '', 85, null, null, null) ;

CALL ImportDocCLS(983500, 9835, ' ', 'BUDGETTYPE', ' ', 'ID', ' ', '', '', 35, null, null, null) ;

CALL ImportDocCLS(985800, 9858, ' ', 'DEBTTYPE', ' ', 'ID', ' ', '', '', 58, null, null, null) ;

CALL ImportDocCLS(988600, 9886, ' ', 'AssignmentSource', ' ', 'ID', ' ', ' ', ' ', 86, null, null, null) ;

CALL ImportDocCLS(988300, 9883, ' ', 'Org_Type', ' ', 'ID', ' ', '', '', 83, null, null, null) ;

CALL ImportDocCLS(986400, 9864, ' ', 'PlanDocType', ' ', 'ID', ' ', '', '', 64, null, null, null) ;

CALL ImportDocCLS(985700, 9857, ' ', 'LOANTYPE', ' ', 'ID', ' ', '', '', 57, null, null, null) ;

CALL ImportDocCLS(984300, 9843, ' ', 'PAYTYPECLS', ' ', 'ID', ' ', '', '', 43, null, null, null) ;

CALL ImportDocCLS(982300, 9823, ' ', 'GOSNI', ' ', 'ID', ' ', '', '', 23, null, null, null) ;

CALL ImportDocCLS(982200, 9822, ' ', 'GroupInf_CLS', ' ', 'ID', ' ', '', '', 22, null, null, null) ;

CALL ImportDocCLS(982900, 9829, ' ', 'DocBase', ' ', 'ID', ' ', '', '', 29, null, null, null) ;

CALL ImportDocCLS(981100, 9811, ' ', 'DocTypes', ' ', 'ID', ' ', '', '', 11, null, null, null) ;

CALL ImportDocCLS(986000, 9860, ' ', 'MEASUREMENTCLS', ' ', 'ID', ' ', '', '', 60, null, null, null) ;

CALL ImportDocCLS(988000, 9880, ' ', 'FundsSource', ' ', 'ID', ' ', '', '', 80, null, null, null) ;

CALL ImportDocCLS(985200, 9852, ' ', 'InnerFinSource', ' ', 'ID', ' ', '', '', 52, null, null, null) ;

CALL ImportDocCLS(981300, 9813, ' ', 'NOTIFYTYPES', ' ', 'ID', ' ', '', '', 13, null, null, null) ;

CALL ImportDocCLS(984500, 9845, ' ', 'PAYSYMBOLCLS', ' ', 'ID', ' ', '', '', 45, null, null, null) ;

CALL ImportDocCLS(980400, 9804, ' ', 'KVR', ' ', 'ID', ' ', '', '', 4, null, null, null) ;

CALL ImportDocCLS(980300, 9803, ' ', 'KVSR', ' ', 'ID', ' ', '', '', 3, null, null, null) ;

CALL ImportDocCLS(980900, 9809, ' ', 'KD', ' ', 'ID', ' ', '', '', 9, null, null, null) ;

CALL ImportDocCLS(984700, 9847, ' ', 'TYPEOPERATIONCLS', ' ', 'ID', ' ', '', '', 47, null, null, null) ;

CALL ImportDocCLS(986800, 9868, ' ', 'KESR', ' ', 'ID', ' ', '', '', 68, null, null, null) ;

CALL ImportDocCLS(987900, 9879, ' ', 'TargetCls', ' ', 'ID', ' ', '', '', 79, null, null, null) ;

CALL ImportDocCLS(985100, 9851, ' ', 'Error', ' ', 'ID', ' ', '', '', 51, null, null, null) ;

CALL ImportDocCLS(982100, 9821, ' ', 'ACC_CLS', ' ', 'ID', ' ', '', '', 21, null, null, null) ;

CALL ImportDocCLS(981400, 9814, ' ', 'KSHK', ' ', 'ID', ' ', '', '', 14, null, null, null) ;

CALL ImportDocCLS(980200, 9802, ' ', 'kfsr', ' ', 'ID', ' ', '', '', 2, null, null, null) ;

CALL ImportDocCLS(980500, 9805, ' ', 'KCSR', ' ', 'ID', ' ', '', '', 5, null, null, null) ;

CALL ImportDocCLS(984100, 9841, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', '', '', 41, null, null, null) ;

CALL ImportDocCLS(981500, 9815, ' ', 'VALUECLS', ' ', 'ID', ' ', '', '', 15, null, null, null) ;

CALL ImportDocCLS(982800, 9828, ' ', 'FACT', ' ', 'ID', ' ', '', '', 28, null, null, null) ;

CALL ImportDocCLS(984800, 9848, ' ', 'PAYDESTINATIONCLS', ' ', 'ID', ' ', '', '', 48, null, null, null) ;

CALL ImportDocCLS(986900, 9869, ' ', 'DirectionCLS', ' ', 'ID', ' ', '', '', 69, null, null, null) ;

CALL ImportDocCLS(986200, 9862, ' ', 'OKATO', ' ', 'ID', ' ', '', '', 62, null, null, null) ;

CALL ImportDocCLS(988200, 9882, ' ', 'OKOPF', ' ', 'ID', ' ', '', '', 82, null, null, null) ;

CALL ImportDocCLS(988100, 9881, ' ', 'OKFS', ' ', 'ID', ' ', '', '', 81, null, null, null) ;

CALL ImportDocCLS(981600, 9816, ' ', 'MeansCLS', ' ', 'ID', ' ', '', '', 16, null, null, null) ;

CALL ImportDocCLS(985900, 9859, ' ', 'DepartmentCLS', ' ', 'ID', ' ', '', '', 59, null, null, null) ;

CALL ImportDocCLS(986500, 9865, ' ', 'BuhAccPlan', ' ', 'ID', ' ', '', '', 65, null, null, null) ;

CALL ImportDocCLS(986100, 9861, ' ', 'TenderObjects', ' ', 'ID', ' ', '', '', 61, null, null, null) ;

CALL ImportDocCLS(985000, 9850, ' ', 'RejectCLS', ' ', 'ID', ' ', '', '', 50, null, null, null) ;

CALL ImportDocCLS(987000, 9870, ' ', 'ProgramCode', ' ', 'ID', ' ', '', '', 70, null, null, null) ;

CALL ImportDocCLS(981200, 9812, ' ', 'RegionCLS', ' ', 'ID', ' ', '', '', 12, null, null, null) ;

CALL ImportDocCLS(982600, 9826, ' ', 'BUDGETACCOUNTS', ' ', 'ID', ' ', '', '', 26, null, null, null) ;

CALL ImportDocCLS(981700, 9817, ' ', 'REFCLS', ' ', 'ID', ' ', '', '', 17, null, null, null) ;

CALL ImportDocCLS(981000, 9810, ' ', 'SubKD', ' ', 'ID', ' ', '', '', 10, null, null, null) ;

CALL ImportDocCLS(980600, 9806, ' ', 'SUBKCSR', ' ', 'ID', ' ', '', '', 6, null, null, null) ;

CALL ImportDocCLS(980800, 9808, ' ', 'KESRSubCode', ' ', 'ID', ' ', '', '', 8, null, null, null) ;

CALL ImportDocCLS(986300, 9863, ' ', 'COLLATERALTYPE', ' ', 'ID', ' ', '', '', 63, null, null, null) ;

CALL ImportDocCLS(982000, 9820, ' ', 'ORG_CLS', ' ', 'ID', ' ', '', '', 20, null, null, null) ;

CALL ImportDocCLS(983400, 9834, ' ', 'ReportType', ' ', 'ID', ' ', '', '', 34, null, null, null) ;

CALL ImportDocCLS(985300, 9853, ' ', 'REESTRTYPE', ' ', 'ID', ' ', '', '', 53, null, null, null) ;

CALL ImportDocCLS(984900, 9849, ' ', 'MEANSTYPE', ' ', 'ID', ' ', '', '', 49, null, null, null) ;

CALL ImportDocCLS(982700, 9827, ' ', 'FinType', ' ', 'ID', ' ', '', '', 27, null, null, null) ;

CALL ImportDocCLS(984400, 9844, ' ', 'Org_AccDefaults', ' ', 'ID', ' ', '', '', 44, null, null, null) ;

CALL ImportDocCLS(960100, 9601, ' ', 'ORGANIZATIONS', ' ', 'ID', ' ', '', '', 1000, null, null, null) ;

CALL ImportDocCLS(960200, 9602, ' ', 'ORG_ACCOUNTS', ' ', 'ID', ' ', '', '', 1001, null, null, null) ;

CALL ImportDocCLS(960400, 9604, ' ', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', '', '', 1003, null, null, null) ;

CALL ImportDocCLS(960300, 9603, ' ', 'BANKS', ' ', 'ID', ' ', '', '', 1002, null, null, null) ;

CALL ImportDocCLS(987100, 9871, ' ', 'BuhOperationCls', ' ', 'Id', ' ', '', '', 71, null, null, null) ;

CALL ImportDocCLS(987800, 9878, ' ', 'budgets_s', ' ', 'id', ' ', '', '', 78, null, null, null) ;

CALL ImportDocCLS(991400, 9914, '', 'DATAPACKETTYPES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991401, 9914, '', 'DATAPACKETCONTENT', ' ', 'ID', ' ', 'DATAPACKETTYPE', '', 0, null, null, null) ;

CALL ImportDocCLS(991500, 9915, '', 'UNLOCKDATES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991501, 9915, '', 'UNLOCKDATES', ' ', 'ID', ' ', 'ID', '', 0, null, null, null) ;

CALL ImportDocCLS(20001, 200, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(30000, 300, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(30001, 300, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190000, 1900, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190001, 1900, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(220000, 2200, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(220001, 2200, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(991300, 9913, '', 'INTERFACES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991301, 9913, '', 'Permissions', ' ', 'ID', ' ', 'INTERFACEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(991302, 9913, '', 'LinkType', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991303, 9913, ' ', ' ', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(490200, 4902, '', 'DATAPACKET', ' ', 'ID', ' ', '', ' ', 0, null, null, 526) ;

CALL ImportDocCLS(250400, 2504, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', '', 0, null, null, 314) ;

CALL ImportDocCLS(300100, 3001, '', 'TenderCaption', ' ', 'ID', ' ', '', '', 0, null, null, 230) ;

CALL ImportDocCLS(250401, 2504, '  ', 'AGREEMENTSTEPS', 'AGREEMENTSTEPS', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(250402, 2504, '   ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'AGREEMENTREF', 'AGREEMENTREF', 0, null, null, 304) ;

CALL ImportDocCLS(250403, 2504, '  ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(300600, 3006, '', 'TENDERCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 241) ;

CALL ImportDocCLS(250102, 2501, '  . ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 305) ;

CALL ImportDocCLS(70202, 702, '', 'PAYDOCEXCHANGE', ' ', 'ID', ' ', 'PAYDOCREF', '', 0, null, null, null) ;

CALL ImportDocCLS(170101, 1701, '', 'REQUESTSPAYMENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20900, 209, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 274) ;

CALL ImportDocCLS(300601, 3006, '  ', 'TENDERPRODUCT', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 241) ;

CALL ImportDocCLS(300602, 3006, '   ', 'TENDERCONTACTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300300, 3003, '', 'TenderResultCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(300101, 3001, ' ', 'TenderProduct', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 230) ;

CALL ImportDocCLS(300102, 3001, ' ', 'TenderLot', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300103, 3001, '   ', 'TENDERSOURCEORG', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300104, 3001, '   ', 'TENDERYARDSTICKS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300105, 3001, '   ', 'TENDERYARDSTICKS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300106, 3001, ' ', 'TENDERCONTACTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300107, 3001, '   ', 'TENDERSUPPLEMENTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300108, 3001, ',  ', 'TENDERSUPDOCUMENT', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(370100, 3701, '', 'TenderObjects', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(520101, 5201, '', 'WritExecutionDetail', 'WritExecutionDetail', 'id', 'id', 'RecordIndex', '', 0, null, null, 556) ;

CALL ImportDocCLS(20901, 209, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 274) ;

CALL ImportDocCLS(21000, 210, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 252) ;

CALL ImportDocCLS(21001, 210, ', ', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 252) ;

CALL ImportDocCLS(21002, 210, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 253) ;

CALL ImportDocCLS(991800, 9918, '', 'USERGENERATOR', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991801, 9918, '', 'USERGENERATORFIELDS', ' ', 'ID', ' ', 'GENREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992702, 9927, '   ', 'REMOTEINPUTRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(21202, 212, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 276) ;

CALL ImportDocCLS(990802, 9908, ' ', 'STATE_DOCSTATES', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(990803, 9908, '', 'STATE_JUMPS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(990804, 9908, '', 'STATE_ACTIONS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992703, 9927, '   ', 'REMOTECLIENTACCOUNT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(992000, 9920, '', 'BUHOPERATIONCLS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992001, 9920, '', 'BUHACCCORR', ' ', 'ID', ' ', 'BUHOPERATIONCLS', '', 0, null, null, null) ;

CALL ImportDocCLS(992100, 9921, '', 'BUDGETS_S', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992101, 9921, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', 'BUDGETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992102, 9921, ' ', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', 'BUDGETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(989000, 9890, ' ', 'BudAllocationCls', ' ', 'id', ' ', '', '', 90, null, null, null) ;

CALL ImportDocCLS(989100, 9891, ' ', 'PayPromiseCls', ' ', 'id', ' ', '', '', 91, null, null, null) ;

CALL ImportDocCLS(550300, 5503, '', 'ReplacementClsCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(550301, 5503, '   ', 'ReplacementClsDetail', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(550302, 5503, ' ', 'ReplacementClsDetailInfo', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(250302, 2503, ' ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'EXECUTIONREF', '', 0, null, null, 308) ;

CALL ImportDocCLS(181400, 1814, '', 'BANKEXCH_LS_KB', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(180900, 1809, '', 'BANKEXCH_SUBSTITUTION', 'BANKEXCH_SUBSTITUTION', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181500, 1815, '', 'BANKEXCH_KO_SALDO', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992900, 9929, '', 'BudStruct', 'BudStruct', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992201, 9922, '', 'ARCHIVEDOCPARAMS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(992400, 9924, '', 'SIGNS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(480101, 4801, '', 'GeneralDocsDetail', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992502, 9925, '', 'CARDSDETAIL_KESR', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(250203, 2502, ' ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 304) ;

CALL ImportDocCLS(250404, 2504, ' ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'RECORDINDEX', '', 0, null, null, 318) ;

CALL ImportDocCLS(520102, 5201, '2', 'WritExecutionNotify', 'WritExecutionNotify', 'id', 'id', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(989200, 9892, ' ', 'ArchiveDocType', ' ', 'id', ' ', '', '', 92, null, null, null) ;

CALL ImportDocCLS(480100, 4801, '', 'GeneralDocuments', ' ', 'ID', ' ', '', '', 0, null, null, 528) ;

CALL ImportDocCLS(992600, 9926, '', 'WritNotifyCls', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992601, 9926, '', 'WRITNOTIFYCLSDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(992602, 9926, ' ', 'WritNotifyClsPart', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(31600, 316, '', 'ManagerBid', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(20902, 209, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 274) ;

CALL ImportDocCLS(992704, 9927, '  + /', 'DUALRIGHTS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992705, 9927, ' ', 'REMOTEEDSRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(992706, 9927, ' ', 'REMOTEEDSRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(990400, 9904, '', 'CONTACTPERSONS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181601, 1816, '', 'FacialFinCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992707, 9927, '', 'SIGNCERTIFICATE', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992708, 9927, '  ', 'SIGNDOCUMENTSGROUP', ' ', 'ID', ' ', 'CLIENTREF', '', 0, null, null, null) ;

CALL ImportDocCLS(510100, 5101, '', 'StoredAttributesCaption', 'StoredAttributesCaption', 'id', 'id', '', '', 0, null, null, null) ;

CALL ImportDocCLS(510101, 5101, '', 'StoredAttributesDetail', 'StoredAttributesDetail', 'id', 'id', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(250405, 2504, ' ', 'EXECUTIONDOCUMENTSCAPTION', 'EXECUTIONDOCUMENTSCAPTION', 'ID', 'ID', 'AGREEMENTREF', '', 0, null, null, null) ;

CALL ImportDocCLS(993000, 9930, '', 'AUTOSANCTIONDATA', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(301000, 3010, '', 'TENDERCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 242) ;

CALL ImportDocCLS(970200, 9702, ' ', 'AnalyticalGroupIFS', 'AnalyticalGroupIFS', 'ID', 'ID', '', '', 102, null, null, null) ;

CALL ImportDocCLS(970100, 9701, ' ', 'AnalyticalGroupKD', 'AnalyticalGroupKD', 'ID', 'ID', '', '', 101, null, null, null) ;

CALL ImportDocCLS(181800, 1818, '', 'OOS_CONTRACT', 'OOS_CONTRACT', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(301100, 3011, '', 'TENDERCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 243) ;

CALL ImportDocCLS(301101, 3011, ' ', 'TENDERPRODUCT', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 243) ;

CALL ImportDocCLS(300500, 3005, '', 'TENDERCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 240) ;

CALL ImportDocCLS(181801, 1818, '', 'OOS_CONTRACT_FINANCES', 'OOS_CONTRACT_FINANCES', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(181802, 1818, '', 'OOS_CONTRACT_PRODUCTS', 'OOS_CONTRACT_PRODUCTS', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(181803, 1818, '', 'OOS_CONTRACTPROCEDURE', 'OOS_CONTRACTPROCEDURE', 'ID', 'ID', 'RegNum', 'RegNum', 0, null, null, null) ;

CALL ImportDocCLS(989700, 9897, ' ', 'ContractCostsCls', 'ContractCostsCls', 'id', 'id', '', '', 97, null, null, null) ;

CALL ImportDocCLS(960101, 9601, ' ', 'ORG_ACCOUNTS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(989800, 9898, ' ', 'PURCHASETYPE ', 'PURCHASETYPE ', 'id', 'id', '', '', 98, null, null, null) ;

CALL ImportDocCLS(21300, 213, '', 'BudNotify', 'BudNotify', 'ID', 'ID', '', '', 0, null, null, 277) ;

CALL ImportDocCLS(21301, 213, '', 'BudgetData', 'BudgetData', 'ID', 'ID', 'RecordIndex', '', 0, null, null, 277) ;

CALL ImportDocCLS(21400, 214, '', 'BudNotify', 'BudNotify', 'ID', 'ID', '', '', 0, null, null, 278) ;

CALL ImportDocCLS(21401, 214, '', 'BudgetData', 'BudgetData', 'ID', 'ID', 'RecordIndex', '', 0, null, null, 278) ;

CALL ImportDocCLS(993200, 9932, '', 'BudStrLink', 'BudStrLink', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(993201, 9932, '', 'BudStrLink', 'BudStrLink', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(21500, 215, '', 'BudNotify', 'BudNotify', 'ID', 'ID', '', '', 0, null, null, 279) ;

CALL ImportDocCLS(21501, 215, '', 'BudgetData', 'BudgetData', 'ID', 'ID', 'RecordIndex', '', 0, null, null, 279) ;

CALL ImportDocCLS(250204, 2502, ' ', 'EXECUTIONDOCUMENTSCAPTION', 'EXECUTIONDOCUMENTSCAPTION', 'ID', 'ID', 'AGREEMENTREF', '', 0, null, null, null) ;

CALL ImportDocCLS(181900, 1819, '', 'OOS_CONTRACT', 'OOS_CONTRACT', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181901, 1819, '', 'OOS_CONTRACT_FINANCES', 'OOS_CONTRACT_FINANCES', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(182000, 1820, '', 'OOS_CONTRACT', 'OOS_CONTRACT', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(182001, 1820, '', 'OOS_CONTRACT_FINANCES', 'OOS_CONTRACT_FINANCES', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(181804, 1818, '', 'OOS_ATTACHMENTS', 'OOS_ATTACHMENTS', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(250406, 2504, '', 'Suppliers', 'Suppliers', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(540200, 5402, '', 'EPBSExportLogCaption', 'EPBSExportLogCaption', 'id', 'id', '', '', 0, null, null, null) ;

CALL ImportDocCLS(540201, 5402, '', 'EPBSExportLogDetail', 'EPBSExportLogDetail', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(970900, 9709, ' ', 'TargetCls', ' ', 'ID', ' ', '', '', 109, null, null, null) ;

CALL ImportDocCLS(985400, 9854, ' ', 'InvestObject', ' ', 'ID', ' ', '', '', 54, null, null, null) ;

CALL ImportDocCLS(182100, 1821, '', 'PayDocExchange', 'PayDocExchange', 'ID', 'ID', '', '', 0, null, null, null) ;

DROP PROCEDURE ImportDocCLS
/

COMMIT WORK
/


CREATE OR REPLACE PROCEDURE ImportField (
   ID_                NUMBER,
   NAME_              VARCHAR2,
   ITFFIELDNAME_      VARCHAR2,
   NOTE_              VARCHAR2,
   TEMPLATEFIELD_     VARCHAR2,
   ISBUDGET_          NUMBER,
   DOCTYPEREF_        NUMBER,
   DETAILNUMBER_      NUMBER,
   ONLYREAD_          NUMBER,
   ReportFieldName_   VARCHAR2,
   KIND_	      NUMBER,
   FIELDINFOREF_      NUMBER,
   CONTAINERREF_      NUMBER, 
   ATTRFIELDKIND_     NUMBER,
   ATTRIBUTENAME_     VARCHAR2
) IS
   IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
     INTO IDExists$
     FROM DocumentFields
    WHERE (ID = ID_);

   IF (IDExists$ <> 0) THEN
      UPDATE DocumentFields
         SET NAME = NAME_,
             ITFFIELDNAME = ITFFIELDNAME_,
             NOTE = NOTE_,
             TEMPLATEFIELD = TEMPLATEFIELD_,
             ISBUDGET = ISBUDGET_,
             DOCTYPEREF = DOCTYPEREF_,
             DETAILNUMBER = DETAILNUMBER_,
             ONLYREAD = ONLYREAD_,
             ReportFieldName = ReportFieldName_,
			       FIELDINFOREF = FIELDINFOREF_, 
             CONTAINERREF = CONTAINERREF_, 
             ATTRFIELDKIND = ATTRFIELDKIND_,
             ATTRIBUTENAME = ATTRIBUTENAME_
       WHERE (ID = ID_)
         AND NOT (
                      (
                          (
                           (NAME IS NOT NULL AND NAME_ IS NOT NULL) AND
                           (UPPER (NAME) = UPPER (NAME_))
                          )
                       OR (NAME IS NULL AND NAME_ IS NULL)
                      )

                  AND (
                          (
                           (ITFFIELDNAME_ IS NOT NULL AND ITFFIELDNAME IS NOT NULL) AND
                           (UPPER (ITFFIELDNAME_) = UPPER (ITFFIELDNAME))
                          )
                       OR (ITFFIELDNAME_ IS NULL AND ITFFIELDNAME IS NULL)
                      )
                      
                  AND (
                          (
                           (NOTE IS NOT NULL AND NOTE_ IS NOT NULL) AND
                           (UPPER (NOTE) = UPPER (NOTE_))
                          )
                       OR (NOTE IS NULL AND NOTE_ IS NULL)
                      )
                  AND (UPPER (TEMPLATEFIELD) = UPPER (TEMPLATEFIELD_))
                  AND (
                          (
                           (ISBUDGET IS NOT NULL AND ISBUDGET_ IS NOT NULL) AND
                           (ISBUDGET = ISBUDGET_)
                          )
                       OR (ISBUDGET IS NULL AND ISBUDGET_ IS NULL)
                      )
                  AND (
                          (
                           (FIELDINFOREF IS NOT NULL AND FIELDINFOREF_ IS NOT NULL) AND
                           (FIELDINFOREF = FIELDINFOREF_)
                          )
                       OR (FIELDINFOREF IS NULL AND FIELDINFOREF_ IS NULL)
                      )
                  AND (
                          (
                           (CONTAINERREF IS NOT NULL AND CONTAINERREF_ IS NOT NULL) AND
                           (CONTAINERREF = CONTAINERREF_)
                          )
                       OR (CONTAINERREF IS NULL AND CONTAINERREF_ IS NULL)
                      )   
                  AND (
                          (
                           (ATTRFIELDKIND IS NOT NULL AND ATTRFIELDKIND_ IS NOT NULL) AND
                           (ATTRFIELDKIND = ATTRFIELDKIND_)
                          )
                       OR (ATTRFIELDKIND IS NULL AND ATTRFIELDKIND_ IS NULL)
                      )
                  AND (
                          (
                           (ATTRIBUTENAME_ IS NOT NULL AND ATTRIBUTENAME IS NOT NULL) AND
                           (UPPER (ATTRIBUTENAME_) = UPPER (ATTRIBUTENAME))
                          )
                       OR (ATTRIBUTENAME_ IS NULL AND ATTRIBUTENAME IS NULL)
                      )
                  AND (DOCTYPEREF = DOCTYPEREF_)
                  AND (DETAILNUMBER = DETAILNUMBER_)
                  AND (ONLYREAD = ONLYREAD_)
                  AND (
                          (
                           (ReportFieldName IS NOT NULL AND ReportFieldName_ IS NOT NULL) AND
                           (UPPER (ReportFieldName) = UPPER (ReportFieldName_))
                          )
                       OR (ReportFieldName IS NULL AND ReportFieldName_ IS NULL)
                      )
                 );
   ELSE
      INSERT INTO DocumentFields
                  (ID, NAME, ITFFIELDNAME, NOTE, TEMPLATEFIELD,
                   ISBUDGET, DOCTYPEREF, DETAILNUMBER, ONLYREAD, ReportFieldName, FIELDINFOREF, CONTAINERREF, ATTRFIELDKIND, ATTRIBUTENAME
                  )
           VALUES (ID_, NAME_, ITFFIELDNAME_, NOTE_, TEMPLATEFIELD_,
                   ISBUDGET_, DOCTYPEREF_, DETAILNUMBER_, ONLYREAD_, ReportFieldName_, FIELDINFOREF_, CONTAINERREF_, ATTRFIELDKIND_, ATTRIBUTENAME_
                  );
   END IF;

   FOR tab_rec IN (
                   SELECT ID
                     FROM DocumentFields
                    WHERE (ID <> ID_)
                      AND (DOCTYPEREF = DOCTYPEREF_)
                      AND (
                              (
                               (ISBUDGET IS NOT NULL AND ISBUDGET_ IS NOT NULL) AND
                               (ISBUDGET = ISBUDGET_)
                              )
                           OR (ISBUDGET IS NULL AND ISBUDGET_ IS NULL)
                          )
                      AND (DETAILNUMBER = DETAILNUMBER_)
              AND ( /*      ,       ,       */
                            (
                             ((ITFFIELDNAME_ IS NULL)or(ITFFIELDNAME_=' '))
                 and not((TEMPLATEFIELD_ IS NULL)or(TEMPLATEFIELD_=' '))
                 and(TEMPLATEFIELD is NOT null) and (UPPER(TEMPLATEFIELD)=UPPER(TEMPLATEFIELD_))
                            )
                    or (
                        not ((ITFFIELDNAME_ IS NULL) or (ITFFIELDNAME_=' '))
                                and (ITFFIELDNAME IS NOT NULL) and (UPPER(ITFFIELDNAME)=UPPER(ITFFIELDNAME_)))
                            )
                       )
   LOOP
      UPDATE State_OpenFields
         SET DOCFIELDREF = ID_
       WHERE (DOCFIELDREF = tab_rec.ID);

      UPDATE DOCLOCKFIELDS
         SET FIELDREF = ID_
       WHERE (FIELDREF = tab_rec.ID);

      UPDATE staticlinks
         SET PARENTFIELDREF = ID_
      WHERE (PARENTFIELDREF = tab_rec.ID);

      UPDATE staticlinks
         SET CHILDFIELDREF = ID_
      WHERE (CHILDFIELDREF = tab_rec.ID);

      DELETE FROM DocumentFields
            WHERE (ID = tab_rec.ID);
   END LOOP;
END;
/

CREATE OR REPLACE PROCEDURE DeleteFields (ID$ NUMBER) IS
BEGIN
  DELETE FROM State_OpenFields
  WHERE (docfieldref = ID$);
  DELETE FROM DOCLOCKFIELDS
  WHERE (fieldref = ID$);

  DELETE FROM STATE_JUMPCONTROL
  WHERE STATICLINKREF IN(SELECT ID FROM staticlinks
                           WHERE (PARENTFIELDREF=ID$)OR(CHILDFIELDREF=ID$));
  DELETE FROM staticlinks
  WHERE (PARENTFIELDREF=ID$)OR(CHILDFIELDREF=ID$);
  
  DELETE FROM DOCUMENTTEMPLATEFIELDS
  WHERE (FIELDS=ID$);

  DELETE FROM DocumentFields
  WHERE (id = ID$);
END;
/

CREATE OR REPLACE PROCEDURE INSERTCONST (
  PROGINDEX_     NUMBER,
  CONSTINDEX_    NUMBER,
  CONSTTYPE_     NUMBER,
  NOTE_          VARCHAR2,
  VARCHARVALUE_  VARCHAR2,
  DOUBLEVALUE_   NUMBER,
  INTVALUE_      INTEGER,
  EDITDOCCODE_   INTEGER
) IS
  IDEXISTS$ NUMBER;
BEGIN
  IF (CONSTTYPE_ = 3) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM IntConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO INTCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,INTVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE INTCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;    
  END IF;

  IF (CONSTTYPE_ = 8) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM VarcharConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO VARCHARCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,VARCHARVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE VARCHARCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;    
  END IF;

  IF (CONSTTYPE_ = 5) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM RealConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO REALCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,DOUBLEVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE REALCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;   
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DELETECONST (
  PROGINDEX_     NUMBER,
  CONSTINDEX_    NUMBER,
  CONSTTYPE_     NUMBER
) IS
BEGIN
  IF (CONSTTYPE_ = 3) THEN
    UPDATE IntConst
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);
  END IF;
  IF (CONSTTYPE_ = 8) THEN
    UPDATE VARCHARCONST
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_); 
  END IF;
  IF (CONSTTYPE_ = 5) THEN
    UPDATE REALCONST
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);
  END IF;
END;
/

--       
ALTER TRIGGER TR_INTCONST_BU_500 DISABLE
/

ALTER TRIGGER TR_VARCHARCONST_BU_500 DISABLE
/

ALTER TRIGGER TR_REALCONST_BU_500 DISABLE
/

--     
CALL DeleteFields(20101040) ;

CALL DeleteFields(20201011) ;

CALL DeleteFields(20301046) ;

CALL DeleteFields(20401011) ;

CALL DeleteFields(20400156) ;

CALL DeleteFields(20511120) ;

CALL DeleteFields(20501105) ;

CALL DeleteFields(20511121) ;

CALL DeleteFields(20501106) ;

CALL DeleteFields(20510120) ;

CALL DeleteFields(20500121) ;

CALL DeleteFields(20511122) ;

CALL DeleteFields(20501123) ;

CALL DeleteFields(20601041) ;

CALL DeleteFields(20701195) ;

CALL DeleteFields(20801117) ;

CALL DeleteFields(21011074) ;

CALL DeleteFields(30110045) ;

CALL DeleteFields(30200041) ;

CALL DeleteFields(30201070) ;

CALL DeleteFields(30210039) ;

CALL DeleteFields(30210050) ;

CALL DeleteFields(30211042) ;

CALL DeleteFields(30510044) ;

CALL DeleteFields(32401261) ;

CALL DeleteFields(80100052) ;

CALL DeleteFields(80101053) ;

CALL DeleteFields(300111019) ;

CALL DeleteFields(550110124) ;

CALL DeleteFields(550100120) ;

CALL DeleteFields(550200049) ;

CALL DeleteFields(550210150) ;

CALL DeleteFields(550200147) ;

CALL DeleteFields(985410042) ;

CALL DeleteFields(985410043) ;

CALL DeleteFields(985410044) ;

--  , (1)
CALL ImportField(10007, '', '{("")}', ' ', ' ', 1, 0, 0, 0, '', 0, null, 0, 0, '') ;

--   (), (1)
CALL ImportField(20011051, '', '{("")}', ' ()', ' ', 1, 200, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(20011052, '', '{("")}', '', ' ', 1, 200, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20011053, '()', '{("")}', '()', ' ', 1, 200, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20011054, '', '{("")}', '', ' ', 1, 200, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(20011055, ' ', '{("")}', ' ', ' ', 1, 200, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20011056, ' . ', '{("")}', '  ', ' ', 1, 200, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20011057, ' .  ()', '{("")}', '  ', ' ', 1, 200, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(20011058, ' ()', '{("")}', '', ' ', 1, 200, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(20011059, '', '{("")}', '', ' ', 1, 200, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20011060, ' ', '{("")}', '', ' ', 1, 200, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20011061, '  ', '{("")}', '', ' ', 1, 200, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20011062, '  ', '{("")}', '', ' ', 1, 200, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(20011063, '', '{("")}', '', ' ', 1, 200, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20011064, '', '{("")}', '', ' ', 1, 200, 1, 1, '', 0, null, 0, 0, '') ;

--    (), (1)
CALL ImportField(20110074, ' ', 'ProgIndex', 'ProgIndex', 'ProgIndex', 1, 201, 0, 1, '', 0, 17493, 0, 0, '') ;

CALL ImportField(20110091, ' /', 'FacialCodeEx', ' /', 'FacialAccClsFacialCodeEx', 1, 201, 0, 0, '', 0, 26617, 0, 0, '') ;

CALL ImportField(20111210, ' / ', 'FacialCodeEx', ' / ', 'DestFacialAccClsFacialCodeEx', 1, 201, 1, 0, '', 0, 26617, 0, 0, '') ;

--  (), (1)
CALL ImportField(20210002, ' ', 'OrgName', ' ', 'DestOrgName', 1, 202, 0, 0, '', 0, 16646, 0, 0, '') ;

CALL ImportField(20210017, ' ', 'ProgIndex', 'ProgIndex', 'ProgIndex', 1, 202, 0, 1, '', 0, 17493, 0, 0, '') ;

CALL ImportField(20210099, ' /', 'FacialCodeEx', ' / ', 'FacialAccClsFacialCodeEx', 1, 202, 0, 0, '', 0, 26617, 0, 0, '') ;

CALL ImportField(20211154, ' / ', 'FacialCodeEx', ' / ', 'DestFacialAccClsFacialCodeEx', 1, 202, 1, 0, '', 0, 26617, 0, 0, '') ;

--   (), (1)
CALL ImportField(20310002, ' ', 'OrgName', ' ', 'DestOrgName', 1, 203, 0, 0, '', 0, 16646, 0, 0, '') ;

CALL ImportField(20310017, ' ', 'ProgIndex', 'ProgIndex', 'ProgIndex', 1, 203, 0, 1, '', 0, 17493, 0, 0, '') ;

CALL ImportField(20310069, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 203, 0, 0, ',', 0, 36865, 0, 1, '') ;

CALL ImportField(20310081, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 203, 0, 1, ',', 0, 17473, 0, 1, '') ;

CALL ImportField(20310163, ' / ', 'FacialCodeEx', ' / ', 'FacialAccClsFacialCodeEx', 1, 203, 0, 0, '', 0, 26617, 0, 0, '') ;

CALL ImportField(20311088, ' / ', 'FacialCodeEx', ' / ', 'DestFacialAccClsFacialCodeEx', 1, 203, 1, 0, '', 0, 26617, 0, 0, '') ;

--  , , (1)
CALL ImportField(20410017, ' ', 'ProgIndex', 'ProgIndex', 'ProgIndex', 1, 204, 0, 1, '', 0, 17493, 0, 0, '') ;

CALL ImportField(20410069, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 204, 0, 0, ',', 0, 36865, 0, 1, '') ;

CALL ImportField(20410086, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 204, 0, 1, ',', 0, 17473, 0, 1, '') ;

CALL ImportField(20410107, ' / ', 'FacialCodeEx', ' / ', 'FacialAccClsFacialCodeEx', 1, 204, 0, 0, '', 0, 26617, 0, 0, '') ;

CALL ImportField(20411071, ' . ', 'FINTYPECODE', '  ', 'DestFINTYPECls', 1, 204, 1, 0, ',', 0, 36853, 0, 0, '') ;

CALL ImportField(20411116, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 204, 1, 1, ',', 0, 17425, 0, 0, '') ;

CALL ImportField(20411154, ' / ', 'FacialCodeEx', ' / ', 'DestFacialAccClsFacialCodeEx', 1, 204, 1, 0, '', 0, 26617, 0, 0, '') ;

-- , (1)
CALL ImportField(20511037, '', 'DirectionCLSCode', '', 'DestDirectionCLS', 1, 205, 1, 0, '', 0, 36861, 0, 1, '') ;

CALL ImportField(20511102, ' ()', 'DirectionCLS', ' ()', 'DestDirectionCLSKey', 1, 205, 1, 1, '', 0, 17450, 0, 1, '') ;

--    (), (1)
CALL ImportField(20610203, ' / ', 'FacialCodeEx', ' / ', 'FacialAccClsFacialCodeEx', 1, 206, 0, 0, '', 0, 26617, 0, 0, '') ;

CALL ImportField(20611098, ' / ', 'FacialCodeEx', ' / ', 'DestFacialAccClsFacialCodeEx', 1, 206, 1, 0, '', 0, 26617, 0, 0, '') ;

--   , (1)
CALL ImportField(20710175, ' / ', 'FacialCodeEx', ' / ', 'FacialAccClsFacialCodeEx', 1, 207, 0, 0, '', 0, 26617, 0, 0, '') ;

CALL ImportField(20711225, ' / ', 'FacialCodeEx', ' / ', 'DestFacialAccClsFacialCodeEx', 1, 207, 1, 0, '', 0, 26617, 0, 0, '') ;

--    , (1)
CALL ImportField(20810158, ' ', 'ClsType', ' ', 'ClsType', 1, 208, 0, 0, '', 0, 24698, 0, 0, '') ;

CALL ImportField(20810227, ' /', 'FacialCodeEx', ' / ', 'FacialAccClsFacialCodeEx', 1, 208, 0, 0, '', 0, 26617, 0, 0, '') ;

CALL ImportField(20811173, ' / ', 'FacialCodeEx', ' / ', 'DestFacialAccClsFacialCodeEx', 1, 208, 1, 0, '', 0, 26617, 0, 0, '') ;

--  , (1)
CALL ImportField(20910157, ' / ', 'FacialCodeEx', ' / ', 'FacialAccClsFacialCodeEx', 1, 209, 0, 0, '', 0, 26617, 0, 0, '') ;

CALL ImportField(20911158, ' / ', 'FacialCodeEx', ' / ', 'DestFacialAccClsFacialCodeEx', 1, 209, 1, 0, '', 0, 26617, 0, 0, '') ;

CALL ImportField(20912159, '', 'ContractCostsClsCode', '', ' ', 1, 209, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20912160, '', 'InvestObjectCode', '', ' ', 1, 209, 2, 0, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(21010073, ' / ', 'FacialCodeEx', ' / ', 'FacialAccClsFacialCodeEx', 1, 210, 0, 0, '', 0, 26617, 0, 0, '') ;

--  , (1)
CALL ImportField(21110073, ' / ', 'FacialCodeEx', ' / ', 'FacialAccClsFacialCodeEx', 1, 211, 0, 0, '', 0, 26617, 0, 0, '') ;

CALL ImportField(21111064, ' ', 'SubsidyClsCode', ' ', ' ', 1, 211, 1, 0, '', 0, 26641, 0, 1, '') ;

CALL ImportField(21111075, ' / ', 'FacialCodeEx', ' / ', 'DestFacialAccClsFacialCodeEx', 1, 211, 1, 0, '', 0, 26617, 0, 0, '') ;

CALL ImportField(21111079, '', 'InvestObjectCode', '', 'InvestObject', 1, 211, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(21111081, '', 'InvestObject', '', 'InvestObjectKey', 1, 211, 1, 1, '', 0, null, 0, 1, '') ;

CALL ImportField(21112031, '', 'KVSR', ' ()', 'DestKvsrKey', 1, 211, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21112033, ' ', 'SubsidyClsCode', ' ', ' ', 1, 211, 2, 0, '', 0, 26641, 0, 1, '') ;

CALL ImportField(21112065, '', 'KD', '', 'KD', 1, 211, 2, 1, '', 0, 25270, 0, 1, '') ;

CALL ImportField(21112066, '()', 'KDAGCode', '()', 'KDKESRCode', 1, 211, 2, 0, '', 0, 38908, 0, 1, '') ;

CALL ImportField(21112067, ' ()', 'KDKVSRCode', ' ()', 'KDKVSRCode', 1, 211, 2, 0, '', 0, 25472, 0, 1, '') ;

CALL ImportField(21112068, ' ()', 'ProgramCode', ' ()', 'ProgramCode', 1, 211, 2, 0, '', 0, 16834, 0, 1, '') ;

CALL ImportField(21112069, '.  ', 'SubKD', '.  ', 'SUBKD', 1, 211, 2, 1, '', 0, 25271, 0, 0, '') ;

CALL ImportField(21112070, ' ', 'KDValue', ' ', 'KDValue', 1, 211, 2, 1, '', 0, 16836, 0, 1, '') ;

CALL ImportField(21112071, ' ()', 'DescriptionCode', ' ()', 'DescriptionCode', 1, 211, 2, 0, '', 0, 16831, 0, 1, '') ;

CALL ImportField(21112076, ' ', 'BudAllocationClsCode', ' ', ' ', 1, 211, 2, 0, '', 0, 27825, 0, 0, '') ;

CALL ImportField(21112077, '  ', 'PayPromiseClsCode', '  ', ' ', 1, 211, 2, 0, '', 0, 27849, 0, 0, '') ;

CALL ImportField(21112078, '   ', 'PayPromiseCls', '   ()', ' ', 1, 211, 2, 1, '', 0, 27835, 0, 0, '') ;

CALL ImportField(21112080, '', 'InvestObjectCode', '', ' ', 1, 211, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21112082, '', 'InvestObject', '', ' ', 1, 211, 2, 1, '', 0, null, 0, 0, '') ;

--   , , (1)
CALL ImportField(21210066, ' / ', 'FacialCodeEx', ' / ', 'FacialAccClsFacialCodeEx', 1, 212, 0, 0, '', 0, 26617, 0, 0, '') ;

CALL ImportField(21211065, '', 'InvestObjectCode', '', 'InvestObject', 1, 212, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(21211067, '', 'InvestObject', '', 'InvestObjectKey', 1, 212, 1, 1, '', 0, null, 0, 1, '') ;

CALL ImportField(21211068, ' / ', 'FacialCodeEx', ' / ', 'DestFacialAccClsFacialCodeEx', 1, 212, 1, 0, '', 0, 26617, 0, 0, '') ;

CALL ImportField(21212031, '', 'KVSR', ' ()', 'DestKvsrKey', 1, 212, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21212062, ' ', 'BudAllocationClsCode', ' ', ' ', 1, 212, 2, 0, '', 0, 27825, 0, 0, '') ;

CALL ImportField(21212063, '  ', 'PayPromiseClsCode', '  ', ' ', 1, 212, 2, 0, '', 0, 27849, 0, 0, '') ;

CALL ImportField(21212064, '   ', 'PayPromiseCls', '   ()', ' ', 1, 212, 2, 1, '', 0, 27835, 0, 0, '') ;

CALL ImportField(21212066, '', 'InvestObjectCode', '', ' ', 1, 212, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21212068, '', 'InvestObject', '', ' ', 1, 212, 2, 1, '', 0, null, 0, 0, '') ;

--      , (1)
CALL ImportField(21310057, ' / ', 'FacialCodeEx', ' / ', 'FacialAccClsFacialCodeEx', 1, 213, 0, 0, '', 0, 26617, 0, 0, '') ;

CALL ImportField(21311059, ' / ', 'FacialCodeEx', ' / ', 'DestFacialAccClsFacialCodeEx', 1, 213, 1, 0, '', 0, 26617, 0, 0, '') ;

--   14 /, (1)
CALL ImportField(21410029, ' ', 'ProgIndex', 'ProgIndex', 'ProgIndex', 1, 214, 0, 1, '', 0, 17493, 0, 0, '') ;

CALL ImportField(21410047, ' / ', 'FacialCodeEx', ' / ', 'FacialAccClsFacialCodeEx', 1, 214, 0, 0, '', 0, 26617, 0, 0, '') ;

CALL ImportField(21411048, ' / ', 'FacialCodeEx', ' / ', 'DestFacialAccClsFacialCodeEx', 1, 214, 1, 0, '', 0, 26617, 0, 0, '') ;

--   14 /, (1)
CALL ImportField(21510029, ' ', 'ProgIndex', 'ProgIndex', 'ProgIndex', 1, 215, 0, 1, '', 0, 17493, 0, 0, '') ;

CALL ImportField(21510051, ' / ', 'FacialCodeEx', ' / ', 'FacialAccClsFacialCodeEx', 1, 215, 0, 0, '', 0, 26617, 0, 0, '') ;

CALL ImportField(21511052, ' / ', 'FacialCodeEx', ' / ', 'DestFacialAccClsFacialCodeEx', 1, 215, 1, 0, '', 0, 26617, 0, 0, '') ;

--   , (1)
CALL ImportField(30011054, '', '{("")}', '', ' ', 1, 300, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30011055, '', '{("")}', ' ()', ' ', 1, 300, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(30011056, '', '{("")}', '', ' ', 1, 300, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(30011057, '()', '{("")}', '()', ' ', 1, 300, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30011058, ' ', '{("")}', ' ', ' ', 1, 300, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30011059, ' . ', '{("")}', '  ', ' ', 1, 300, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30011060, ' .  ()', '{("")}', '  ', ' ', 1, 300, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(30011061, '', '{("")}', '', ' ', 1, 300, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30011062, ' ()', '{("")}', '', ' ', 1, 300, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(30011063, ' ', '{("")}', '', ' ', 1, 300, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30011064, ' ', '{("")}', '', ' ', 1, 300, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(30011065, '  ', '{("")}', '', ' ', 1, 300, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30011066, '  ', '{("")}', '', ' ', 1, 300, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(30011067, '', '{("")}', '', ' ', 1, 300, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30011068, '', '{("")}', '', ' ', 1, 300, 1, 1, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(30111005, ' .', 'SourceKESR', ' ', 'SourceKESRKey', 1, 301, 1, 1, 'SourceKESR,,', 0, 18868, 0, 0, '') ;

CALL ImportField(30111009, ' .', 'SourceSubKESR', ' ', 'SourceSubKESRKey', 1, 301, 1, 1, ',,SourceSubKESR', 0, 18889, 0, 0, '') ;

CALL ImportField(30111021, ' -', 'DestSubKESR', ' ', 'DestSubKESR,', 1, 301, 1, 1, 'DestSubKESR,', 0, 18898, 0, 0, '') ;

CALL ImportField(30111052, ' ( -)', 'DestIFS_DescriptionCode', '     ', ' ', 1, 301, 1, 0, '', 0, 17050, 0, 0, '') ;

CALL ImportField(30111053, ' ( .)', 'SourceIFS_DescriptionCode', '     ', ' ', 1, 301, 1, 0, '', 0, 17050, 0, 0, '') ;

CALL ImportField(30111061, ' .  ', 'SourceBudgetPromiseSONum', ' .  ', 'SourceBudgetPromiseSONum', 1, 301, 1, 1, '', 0, 19798, 0, 0, '') ;

CALL ImportField(30111062, ' .  ', 'SourceBudgetPromiseSODate', ' . ', 'SourceBudgetPromiseSODate', 1, 301, 1, 1, '', 0, 19799, 0, 0, '') ;

CALL ImportField(30111064, '  .  ', 'SourceBudgetPromiseSORNum', '  .  ', ' ', 1, 301, 1, 1, '', 0, 19830, 0, 0, '') ;

CALL ImportField(30111065, '. .  ', 'SourceBudgetPromiseSONote', '. .  ', 'SourceBudgetPromiseSONote', 1, 301, 1, 1, '', 0, 19821, 0, 0, '') ;

CALL ImportField(30111073, ' .  ', 'DestBudgetPromiseSONum', ' .  ', 'DestBudgetPromiseSONum', 1, 301, 1, 1, '', 0, 19798, 0, 0, '') ;

CALL ImportField(30111074, ' .  ', 'DestBudgetPromiseSODate', ' .  ', 'DestBudgetPromiseSODate', 1, 301, 1, 1, '', 0, 19799, 0, 0, '') ;

CALL ImportField(30111076, '  .  ', 'DestBudgetPromiseSORNum', '  .  ', 'DestBudgetPromiseSORNum', 1, 301, 1, 1, '', 0, 19830, 0, 0, '') ;

CALL ImportField(30111077, '. .  ', 'DestBudgetPromiseSONote', '. .  ', 'DestBudgetPromiseSONote', 1, 301, 1, 1, '', 0, 19821, 0, 0, '') ;

CALL ImportField(30111123, '', 'BUDGETREF', '', 'BudgetRef', 1, 301, 1, 1, '', 0, 18872, 0, 0, '') ;

CALL ImportField(30111156, '  .', 'SourceBudAllocationClsCode', '', 'SourceBudAllocationClsCode', 1, 301, 1, 0, ',', 0, 27825, 0, 0, '') ;

CALL ImportField(30111157, '   .', 'SourcePayPromiseClsCode', '', 'SourcePayPromiseClsCode', 1, 301, 1, 0, ',', 0, 27849, 0, 0, '') ;

CALL ImportField(30111160, '  .', 'SourceBudAllocationCls', '', 'SourceBudAllocationCls', 1, 301, 1, 1, ',', 0, 27844, 0, 0, '') ;

CALL ImportField(30111161, '   .', 'SourcePayPromiseCls', '', 'SourcePayPromiseCls', 1, 301, 1, 1, ',', 0, 27845, 0, 0, '') ;

CALL ImportField(30111171, '  ()', 'SourceInvestObject', ' ', 'SourceInvestObjectKey', 1, 301, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(30111172, '  ()', 'DestInvestObject', ' ', 'DestInvestObjectKey', 1, 301, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(30111173, ' ', 'SourceInvestObjectCode', ' ', 'SourceInvestObject', 1, 301, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30111174, ' ', 'DestInvestObjectCode', ' ', 'DestInvestObject', 1, 301, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30111213, ' -( -)', 'DestKESRCode', ' -( -)', 'DestKESR', 1, 301, 1, 0, ',DestKESRCode', 0, 43607, 0, 0, '') ;

CALL ImportField(30111215, ' -( -)', 'DestSubKESRCode', ' ( -)', 'DestSubKESR,', 1, 301, 1, 0, 'DestSubKESR,', 0, 43610, 0, 0, '') ;

--   \, (1)
CALL ImportField(30210077, '/   ', 'SourceFacialCode', '   ', 'SourceFacialAccClsFacialCode', 1, 302, 0, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(30210135, '   ', 'StimateID', '   ', 'StimateID', 1, 302, 0, 0, '', 0, 18999, 0, 0, '') ;

CALL ImportField(30211054, ' . ', 'SourceBudgetPromiseSONum', ' . ', 'SourceBudgetPromiseSONum', 1, 302, 1, 1, '', 0, 19798, 0, 0, '') ;

CALL ImportField(30211055, ' . ', 'SourceBudgetPromiseSODate', ' . ', 'SourceBudgetPromiseSODate', 1, 302, 1, 1, '', 0, 19799, 0, 0, '') ;

CALL ImportField(30211057, '  . ', 'SourceBudgetPromiseSORNum', '  . ', ' ', 1, 302, 1, 1, '', 0, 19830, 0, 0, '') ;

CALL ImportField(30211058, '. . ', 'SourceBudgetPromiseSONote', '. . ', 'SourceBudgetPromiseSONote', 1, 302, 1, 1, '', 0, 19821, 0, 0, '') ;

CALL ImportField(30211077, ' ()', 'SourceIFS_DescriptionCode', '  ( )', ' ', 1, 302, 1, 0, '', 0, 17050, 0, 0, '') ;

CALL ImportField(30211119, '', 'BUDGETREF', '', 'BudgetRef', 1, 302, 1, 1, '', 0, 18872, 0, 0, '') ;

CALL ImportField(30211132, '   ', 'StimateID', '   ', 'StimateId', 1, 302, 1, 1, '', 0, 18911, 0, 0, '') ;

--  (), (1)
CALL ImportField(30311020, ' ()', 'DestIFS_DescriptionCode', ' ', ' ', 1, 303, 1, 0, '', 0, 17050, 0, 0, '') ;

--   , (1)
CALL ImportField(30411055, ' . ', 'SourceBudgetPromiseSONum', ' . ', 'SourceBudgetPromiseSONum', 1, 304, 1, 1, '', 0, 19798, 0, 1, '') ;

CALL ImportField(30411056, ' . ', 'SourceBudgetPromiseSODate', ' . ', 'SourceBudgetPromiseSODate', 1, 304, 1, 1, '', 0, 19799, 0, 1, '') ;

CALL ImportField(30411058, '  . ', 'SourceBudgetPromiseSORNum', '  . ', ' ', 1, 304, 1, 1, '', 0, 19830, 0, 1, '') ;

CALL ImportField(30411059, '. . ', 'SourceBudgetPromiseSONote', '. . ', 'SourceBudgetPromiseSONote', 1, 304, 1, 1, '', 0, 19821, 0, 1, '') ;

CALL ImportField(30411078, ' ()', 'SourceIFS_DescriptionCode', '  ( )', ' ', 1, 304, 1, 0, '', 0, 17050, 0, 1, '') ;

CALL ImportField(30411112, '', 'BUDGETREF', '', 'BudgetRef', 1, 304, 1, 1, '', 0, 18872, 0, 0, '') ;

--   \, (1)
CALL ImportField(30511018, '', 'DestSubKESR', '', 'DestSUBKESRKey', 1, 305, 1, 1, '', 0, 18898, 0, 1, '') ;

CALL ImportField(30511046, ' ()', 'DestIFS_DescriptionCode', ' ( )', ' ', 1, 305, 1, 0, '', 0, 17050, 0, 1, '') ;

CALL ImportField(30511117, '', 'BUDGETREF', '', 'BudgetRef', 1, 305, 1, 1, '', 0, 18872, 0, 0, '') ;

--   , (1)
CALL ImportField(30610145, ' ', 'CardRefName', '  ', 'CardRefName', 1, 306, 0, 0, '', 0, 18939, 0, 0, '') ;

CALL ImportField(30611116, '', 'BUDGETREF', '', 'BudgetRef', 1, 306, 1, 1, '', 0, 18872, 0, 0, '') ;

--  , (1)
CALL ImportField(30810063, ' ', 'ClsType', '', 'CLSTYPE', 1, 308, 0, 1, '', 0, 19008, 0, 0, '') ;

CALL ImportField(30811045, ' .()', 'SOURCEKESR', ' .()', 'SourceKESRKey', 1, 308, 1, 1, ',', 0, 18868, 0, 1, '') ;

CALL ImportField(30811052, ' ', 'SourceSubKESR', ' .', 'SourceSUBKESRKey', 1, 308, 1, 1, ',', 0, 18889, 0, 1, '') ;

CALL ImportField(30811107, ' .  . ()', 'SourceFinType', '   ', 'SourceFINTYPECLSKey', 1, 308, 1, 1, ',,,', 0, 18893, 0, 1, '') ;

CALL ImportField(30811111, '  ()', 'SourceInvestObject', ' ', 'SourceInvestObjectKey', 1, 308, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(30811112, '  ()', 'DestInvestObject', ' ', 'DestInvestObjectKey', 1, 308, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(30811113, ' ', 'SourceInvestObjectCode', ' ', 'SourceInvestObject', 1, 308, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30811114, ' ', 'DestInvestObjectCode', ' ', 'DestInvestObject', 1, 308, 1, 0, '', 0, null, 0, 0, '') ;

--     , (1)
CALL ImportField(31211067, ' .  ', 'DestBudgetPromiseSONum', ' .  ', 'DestBudgetPromiseSONum', 1, 312, 1, 1, '', 0, 19798, 0, 0, '') ;

CALL ImportField(31211068, ' .  ', 'DestBudgetPromiseSODate', ' .  ', 'DestBudgetPromiseSODate', 1, 312, 1, 1, '', 0, 19799, 0, 0, '') ;

CALL ImportField(31211070, '  .  ', 'DestBudgetPromiseSORNum', '  .  ', 'DestBudgetPromiseSORNum', 1, 312, 1, 1, '', 0, 19830, 0, 0, '') ;

CALL ImportField(31211071, '. .  ', 'DestBudgetPromiseSONote', '. .  ', 'DestBudgetPromiseSONote', 1, 312, 1, 1, '', 0, 19821, 0, 0, '') ;

CALL ImportField(31211075, ' ()', 'DestIFS_DescriptionCode', '  ( )', ' ', 1, 312, 1, 0, '', 0, 17050, 0, 0, '') ;

CALL ImportField(31211112, '', 'BUDGETREF', '', 'BudgetRef', 1, 312, 1, 1, '', 0, 18872, 0, 0, '') ;

--    , (1)
CALL ImportField(31411055, ' .  ', 'SourceBudgetPromiseSONum', ' .  ', 'SourceBudgetPromiseSONum', 1, 314, 1, 1, '', 0, 19798, 0, 0, '') ;

CALL ImportField(31411056, ' . ', 'SourceBudgetPromiseSODate', ' . ', 'SourceBudgetPromiseSODate', 1, 314, 1, 1, '', 0, 19799, 0, 0, '') ;

CALL ImportField(31411058, '  .  ', 'SourceBudgetPromiseSORNum', '  .  ', ' ', 1, 314, 1, 1, '', 0, 19830, 0, 0, '') ;

CALL ImportField(31411059, '. .  ', 'SourceBudgetPromiseSONote', '. .  ', 'SourceBudgetPromiseSONote', 1, 314, 1, 1, '', 0, 19821, 0, 0, '') ;

CALL ImportField(31411075, ' ()', 'SourceIFS_DescriptionCode', ' ()', ' ', 1, 314, 1, 0, '', 0, 17050, 0, 0, '') ;

CALL ImportField(31411112, '', 'BUDGETREF', '', 'BudgetRef', 1, 314, 1, 1, '', 0, 18872, 0, 0, '') ;

--      , (1)
CALL ImportField(31511068, ' ', 'DestIFS', ' ', 'DestIFS', 1, 315, 1, 1, '', 0, 18921, 0, 0, '') ;

--  , (1)
CALL ImportField(32310052, '. c()', 'SOURCEACCOUNT', '. c()', 'SOURCEACCOUNT', 1, 323, 0, 1, ',', 0, 18956, 0, 1, '') ;

CALL ImportField(32311056, '', 'BUDGETREF', '', 'BudgetRef', 1, 323, 1, 1, '', 0, 18872, 0, 0, '') ;

CALL ImportField(32311157, '', 'DestInvestObject', '', 'DestInvestObjectKey', 1, 323, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(32311158, '', 'DestInvestObjectCode', '', 'DestInvestObject', 1, 323, 1, 0, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(32411066, '', 'BUDGETREF', '', 'BudgetRef', 1, 324, 1, 1, '', 0, 18872, 0, 0, '') ;

CALL ImportField(32411196, ' .  ()', 'DestFinType', '  ', 'DestFINTYPECLSKey', 1, 324, 1, 1, ',,', 0, 18902, 0, 1, '') ;

CALL ImportField(32411198, '', 'DestInvestObject', '', 'DestInvestObjectKey', 1, 324, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(32411199, '', 'DestInvestObjectCode', '', 'DestInvestObject', 1, 324, 1, 0, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(80110016, '', 'MONTH', '', 'MONTH', 1, 801, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(80111028, '', 'MONTH', '', 'MONTH', 1, 801, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(80111095, '', 'ContractCostsClsCode', '', 'ContractCostsCls', 1, 801, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(80111096, '', 'ContractCostsCls', '', 'ContractCostsClsKey', 1, 801, 1, 1, '', 0, null, 0, 1, '') ;

--   , (1)
CALL ImportField(90311014, ' ()', 'ProgramCode', '', 'ProgramCode', 1, 903, 1, 0, '', 0, 16834, 0, 0, '') ;

CALL ImportField(90311065, '', 'BudgetRef', '', 'BudgetRef', 1, 903, 1, 1, '', 0, 17687, 0, 0, '') ;

CALL ImportField(90311073, ' . ', 'NOTEEX', ' . ', 'EL_Note', 1, 903, 1, 1, '', 0, 17696, 0, 0, '') ;

CALL ImportField(90311093, '', 'InvestObject', '', 'InvestObjectKey', 1, 903, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(90311094, '', 'InvestObjectCode', '', 'InvestObject', 1, 903, 1, 0, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(160110080, '/ ', 'SUPPLIER_ACC_REF', '  ', 'SUPPLIER_ACC_REF', 1, 1601, 0, 0, '', 0, null, 0, 0, '') ;

--      , (1)
CALL ImportField(182010028, ' ', 'CR', ' ', ' ', 1, 1820, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182010029, ' ', 'DocumentBase', ' ', ' ', 1, 1820, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182011030, ' ', 'FacialAcc', ' ', ' ', 1, 1820, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182011031, '. ', 'AddCls', '. ', ' ', 1, 1820, 1, 0, '', 0, null, 0, 0, '') ;

--     , (1)
CALL ImportField(182110001, 'ID', 'ID', 'ID', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110002, '/', 'DocNumber', '  ', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110003, '  ', 'ReestrNumber', '  ', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110004, '', 'BudgetRef', '', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110005, ' ', 'SendBy', ' ', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110006, '   ', 'OrgAttrsCreateDate', '   ', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110007, ' ', 'DocumentDate', ' ', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110008, ' ', 'SendDate', ' ', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110009, ' ', 'AcceptDate', ' ', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110010, ' ', 'CreateDate', ' ', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110011, '', 'ID_ELS', ' ', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110012, '', 'ID_JKU', '', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110013, ' ', 'ElExch_PackageID', ' ', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110014, '  ', 'ID_All', '  ', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110015, '  . ', 'ElExch_PacketName', '  . ', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110016, '', 'INNA', '', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110017, ' ', 'INN', ' ', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110018, ' ', 'ConsumerINN', ' ', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110019, '  ', 'InfoPay', '  ', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110020, '', 'ID_IPD', '', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110021, '', 'KPPA', '', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110022, ' ', 'FacialAccCls', ' ', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110023, ' ', 'Note', ' ', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110024, '', 'NameA', '', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110025, ' ', 'Name', ' ', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110026, ' . ', 'FacialAcc_ClsName', ' . ', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110027, ' ', 'PayQueue', ' ', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110028, '', 'ParentSource', '', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110029, ' ', 'ElExch_Note', ' ', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110030, ' ', 'Reject_Cls', ' ', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110031, '', 'Status', '', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110032, '', 'Summa', '', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110033, '', 'AccA', '', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110034, '', 'UINCode', '', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110035, '  ', 'PaymentIdentifier', '  ', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182110036, '', 'ID_FIAS', '', ' ', 1, 1821, 0, 0, '', 0, null, 0, 0, '') ;

--  (), (1)
CALL ImportField(190110014, ' ', 'OrgName', ' ', 'DestOrgName', 1, 1901, 0, 0, '', 0, 16646, 0, 0, '') ;

CALL ImportField(190110074, ' ', 'ProgIndex', 'ProgIndex', 'ProgIndex', 1, 1901, 0, 1, '', 0, 17493, 0, 0, '') ;

--    (), (1)
CALL ImportField(190210020, ' ', 'ProgIndex', 'ProgIndex', 'ProgIndex', 1, 1902, 0, 1, '', 0, 17493, 0, 0, '') ;

--   (), (1)
CALL ImportField(220111047, '', 'BUDGETREF', '', 'BudgetRef', 1, 2201, 1, 1, '', 0, 17410, 0, 0, '') ;

--  , +(2)
CALL ImportField(250110023, ' ', 'protocolDocTypeText', ' ', ' ', 2, 2501, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250112005, '', 'KVR', '', 'KVRKey', 2, 2501, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(250112006, '', 'KCSR', '', 'KCSRKey', 2, 2501, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(250112007, '', 'KVSR', '', 'KVSRKey', 2, 2501, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(250112078, ' ', 'TargetCls', '  ()', 'TargetClsKey', 2, 2501, 2, 1, '', 0, 40887, 0, 0, '') ;

--  , +(2)
CALL ImportField(250210044, ' ', 'ExecuterAccName', '', 'ExecuterAccName', 2, 2502, 0, 0, '', 0, 17112, 0, 1, 'ExecuterAccRef') ;

CALL ImportField(250212026, '', 'KVSR', '', 'KVSRKey', 2, 2502, 2, 1, '', 0, null, 0, 1, 'KVSR') ;

CALL ImportField(250212027, '', 'KVR', '', 'KVRKey', 2, 2502, 2, 1, '', 0, null, 0, 1, 'KVR') ;

CALL ImportField(250212030, '', 'KCSR', '', 'KCSRKey', 2, 2502, 2, 1, '', 0, null, 0, 1, 'KCSR') ;

CALL ImportField(250212054, '', 'InvestObject', '', 'InvestObjectKey', 2, 2502, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(250212055, '', 'InvestObjectCode', '', 'InvestObject', 2, 2502, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250212092, '', 'Note', '', 'Note', 2, 2502, 2, 0, '', 0, 20297, 0, 1, 'Note') ;

CALL ImportField(250213009, '', 'Amount', '', 'Amount', 2, 2502, 3, 0, '', 0, null, 0, 1, 'Amount') ;

--   , +(2)
CALL ImportField(250310068, '.  ', 'StoredContent', '', 'StoredContent', 2, 2503, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(250310078, '   ()', 'AutoSanction', '', 'AutoSanction', 2, 2503, 0, 0, '', 0, null, 0, 1, 'AutoSanction') ;

CALL ImportField(250310079, '  ', 'AutoSanctionCode', '', ' ', 2, 2503, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250312049, '', 'InvestObject', '', 'InvestObjectKey', 2, 2503, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(250312050, '', 'InvestObjectCode', '', 'InvestObject', 2, 2503, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250312070, ' ()', 'KCSR', '', 'KCSRKey', 2, 2503, 2, 1, '', 0, 16858, 0, 1, 'KCSR') ;

CALL ImportField(250312071, ' ()', 'KVR', '', 'KVRKey', 2, 2503, 2, 1, '', 0, 16865, 0, 1, 'KVR') ;

CALL ImportField(250312073, ' ()', 'KVSR', '', 'KVSRKey', 2, 2503, 2, 1, '', 0, 16852, 0, 1, 'KVSR') ;

CALL ImportField(250312080, '', 'Note', '', 'Note', 2, 2503, 2, 0, '', 0, 20297, 0, 1, 'Note') ;

--  , +(2)
CALL ImportField(250410027, ' ', 'protocolDocTypeText', ' ', ' ', 2, 2504, 0, 0, '', 0, null, 0, 1, 'ProtocolDocType') ;

CALL ImportField(250412032, '', 'KVSR', '', 'KVSRKey', 2, 2504, 2, 1, '', 0, null, 0, 1, 'KVSR') ;

CALL ImportField(250412034, '', 'KVR', '', 'KVRKey', 2, 2504, 2, 1, '', 0, null, 0, 1, 'KVR') ;

CALL ImportField(250412038, '', 'KCSR', '', 'KCSRKey', 2, 2504, 2, 1, '', 0, null, 0, 1, 'KCSR') ;

CALL ImportField(250412053, '', 'InvestObject', '', 'InvestObjectKey', 2, 2504, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(250412054, '', 'InvestObjectCode', '', 'InvestObject', 2, 2504, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250412160, '  ()', 'FacialAcc_ClsEx', '  ()', 'FacialAcc_ClsEx', 2, 2504, 2, 0, '', 0, null, 0, 1, 'FacialCodeEx') ;

CALL ImportField(250414131, '', 'KVSR', '', 'KVSRKey', 2, 2504, 4, 1, '', 0, null, 0, 1, 'KVSR') ;

CALL ImportField(250414133, '', 'KVR', '', 'KVRKey', 2, 2504, 4, 1, '', 0, null, 0, 1, 'KVR') ;

CALL ImportField(250414137, '', 'KCSR', '', 'KCSRKey', 2, 2504, 4, 1, '', 0, null, 0, 1, 'KCSR') ;

--    , +(2)
CALL ImportField(300111038, '', 'KVSR', '', 'KVSRKey', 2, 3001, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(300111039, '', 'KVR', '', 'KVRKey', 2, 3001, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(300111042, '', 'KCSR', '', 'KCSRKey', 2, 3001, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(300111153, '   ', 'SummaOtherYears', '', 'SummaOtherYears', 2, 3001, 1, 0, '', 0, null, 0, 0, '') ;

--  -, +(2)
CALL ImportField(300611036, '', 'KVSR', '', 'KVSRKey', 2, 3006, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(300611038, '', 'KVR', '', 'KVRKey', 2, 3006, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(300611056, '', 'InvestObject', '', 'InvestObjectKey', 2, 3006, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300611057, '', 'InvestObjectCode', '', 'InvestObject', 2, 3006, 1, 0, '', 0, null, 0, 0, '') ;

--   , +(2)
CALL ImportField(301111025, '', 'KVSR', '', 'KVSRKey', 2, 3011, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(301111027, '', 'KVR', '', 'KVRKey', 2, 3011, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(301111043, '', 'InvestObject', '', 'InvestObjectKey', 2, 3011, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301111044, '', 'InvestObjectCode', '', 'InvestObject', 2, 3011, 1, 0, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(440111052, ' ', 'CLSTYPE', ' ', 'CLSTYPE', 1, 4401, 1, 1, '', 0, 21720, 0, 0, '') ;

CALL ImportField(440111070, '', 'InvestObject', '', 'InvestObjectKey', 1, 4401, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(440111071, '', 'InvestObjectCode', '', 'InvestObject', 1, 4401, 1, 0, '', 0, null, 0, 0, '') ;

--  / , (1)
CALL ImportField(520110014, ' ', 'PROGINDEX', ' ', 'PROGINDEX', 1, 5201, 0, 1, '', 0, 25417, 0, 0, '') ;

CALL ImportField(520111009, '', 'KCSR', '', 'KCSRKey', 1, 5201, 1, 1, '', 0, null, 0, 1, '') ;

CALL ImportField(520111013, '', 'KVR', '', 'KVRKey', 1, 5201, 1, 1, '', 0, null, 0, 1, '') ;

CALL ImportField(520111015, '', 'KVSR', '', 'KVSRKey', 1, 5201, 1, 1, '', 0, null, 0, 1, '') ;

CALL ImportField(520111062, '', 'InvestObject', '', 'InvestObjectKey', 1, 5201, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(520111063, '', 'InvestObjectCode', '', 'InvestObject', 1, 5201, 1, 0, '', 0, null, 0, 0, '') ;

--  / , +(2)
CALL ImportField(520110060, '-', 'DestOrgName', '', ' ', 2, 5201, 0, 0, '', 0, null, 0, 0, '') ;

--    , (1)
CALL ImportField(550110099, '( )', 'AdminAcceptorInn', '( )', 'AdminAcceptorInn', 1, 5501, 0, 0, '', 0, 22895, 0, 0, '') ;

CALL ImportField(550110100, '( )', 'AdminAcceptorInn20', '( )', 'AdminAcceptorInn20', 1, 5501, 0, 0, '', 0, 22896, 0, 0, '') ;

CALL ImportField(550111125, ' . ', 'BudgetPromiseSODate', ' . ', 'BudgetPromiseSODate', 1, 5501, 1, 1, '', 0, 19799, 0, 1, '') ;

CALL ImportField(550111127, ' . ', 'BudgetPromiseSONum', ' . ', 'BudgetPromiseSONum', 1, 5501, 1, 1, '', 0, 19798, 0, 1, '') ;

CALL ImportField(550111129, '  . ', 'BudgetPromiseSORNum', '  . ', 'BudgetPromiseSORNum', 1, 5501, 1, 1, '', 0, 19830, 0, 1, '') ;

CALL ImportField(550111158, ' ', 'BudAllocationClsCode', '', 'BudAllocationClsCode', 1, 5501, 1, 0, '', 0, 27825, 0, 0, '') ;

CALL ImportField(550111160, '  ', 'PayPromiseClsCode', '', 'PayPromiseClsCode', 1, 5501, 1, 0, '', 0, 27849, 0, 0, '') ;

CALL ImportField(550111166, '', 'InvestObject', '', 'InvestObjectKey', 1, 5501, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(550111167, '', 'InvestObjectCode', '', 'InvestObject', 1, 5501, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(550111190, ' ', 'BudgetPromiseAgrSumma', ' ', 'BudgetPromiseAgrSumma', 1, 5501, 1, 1, '', 0, null, 0, 1, '') ;

--    , (1)
CALL ImportField(550210099, '( )', 'AdminAcceptorInn', '( )', 'AdminAcceptorInn', 1, 5502, 0, 0, '', 0, 22895, 0, 0, '') ;

CALL ImportField(550210100, '( )', 'AdminAcceptorInn20', '( )', 'AdminAcceptorInn20', 1, 5502, 0, 0, '', 0, 22896, 0, 0, '') ;

CALL ImportField(550211137, ' ', 'BudAllocationClsCode', '', 'BudAllocationClsCode', 1, 5502, 1, 0, '', 0, 27825, 0, 0, '') ;

CALL ImportField(550211139, '  ', 'PayPromiseClsCode', '', 'PayPromiseClsCode', 1, 5502, 1, 0, '', 0, 27849, 0, 0, '') ;

CALL ImportField(550211145, '', 'InvestObject', '', 'InvestObjectKey', 1, 5502, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(550211146, '', 'InvestObjectCode', '', 'InvestObject', 1, 5502, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(550211152, ' . ', 'BudgetPromiseSODate', ' . ', 'BudgetPromiseSODate', 1, 5502, 1, 1, '', 0, 19799, 0, 1, '') ;

CALL ImportField(550211154, ' . ', 'BudgetPromiseSONum', ' . ', 'BudgetPromiseSONum', 1, 5502, 1, 1, '', 0, 19798, 0, 1, '') ;

CALL ImportField(550211155, '  . ', 'BudgetPromiseSORNum', '  . ', 'BudgetPromiseSORNum', 1, 5502, 1, 1, '', 0, 19830, 0, 1, '') ;

CALL ImportField(550211203, ' ', 'BudgetPromiseAgrSumma', ' ', 'BudgetPromiseAgrSumma', 1, 5502, 1, 1, '', 0, null, 0, 1, '') ;

--    , (1)
CALL ImportField(970910006, ' (  )', 'DELETEDATE', '', ' ', 1, 9709, 0, 0, '', 0, 27865, 0, 0, '') ;

CALL ImportField(970910007, '   ', 'STARTDATE', '', ' ', 1, 9709, 0, 0, '', 0, 27866, 0, 0, '') ;

CALL ImportField(970910008, '', '_FAVORITE', '', ' ', 1, 9709, 0, 0, '', 0, null, 0, 0, '') ;

--    , +(2)
CALL ImportField(970910001, ' ', 'CREATEDATE', '', ' ', 2, 9709, 0, 1, '', 0, 22388, 0, 0, '') ;

CALL ImportField(970910002, '', 'ID', '', ' ', 2, 9709, 0, 0, '', 0, 22386, 0, 0, '') ;

CALL ImportField(970910003, '', 'NAME', '', ' ', 2, 9709, 0, 0, '', 0, 22387, 0, 0, '') ;

CALL ImportField(970910004, ' ', 'UPDATEDATE', '', ' ', 2, 9709, 0, 1, '', 0, 22389, 0, 0, '') ;

CALL ImportField(970910005, ' ', 'STRCODE', '', ' ', 2, 9709, 0, 0, '', 0, 22390, 0, 0, '') ;

CALL ImportField(970910009, ' ', 'ShortName', '', ' ', 2, 9709, 0, 0, '', 0, 44618, 0, 0, '') ;

CALL ImportField(970910010, '', 'BudgetRef', '', ' ', 2, 9709, 0, 0, '', 0, 44617, 0, 0, '') ;

CALL ImportField(970910011, ' -  ', 'TransferBudgetRef', '', ' ', 2, 9709, 0, 0, '', 0, 44622, 0, 0, '') ;

CALL ImportField(970910012, ' ', 'TransfertKind', '', ' ', 2, 9709, 0, 0, '', 0, 44620, 0, 0, '') ;

CALL ImportField(970910013, '', 'TransferKCSR', '', ' ', 2, 9709, 0, 0, '', 0, 44259, 0, 0, '') ;

CALL ImportField(970910015, '', 'TransferKFSR', '', ' ', 2, 9709, 0, 0, '', 0, 44258, 0, 0, '') ;

CALL ImportField(970910016, '', 'TransferKVR', '', ' ', 2, 9709, 0, 0, '', 0, 44260, 0, 0, '') ;

CALL ImportField(970910017, ' ', 'TransferKVSR', '', ' ', 2, 9709, 0, 0, '', 0, 44257, 0, 0, '') ;

CALL ImportField(970910018, ' ', 'ParentTargetCls', '', ' ', 2, 9709, 0, 1, '', 0, 44624, 0, 0, '') ;

CALL ImportField(970910019, ' ', 'ParentTargetClsCode', '', ' ', 2, 9709, 0, 0, '', 0, 22390, 0, 0, '') ;

CALL ImportField(970910020, '', 'CREATERUSER', '', ' ', 2, 9709, 0, 1, '', 0, 44615, 0, 0, '') ;

CALL ImportField(970910021, '', 'UPDATERUSER', '', ' ', 2, 9709, 0, 1, '', 0, 44616, 0, 0, '') ;

CALL ImportField(970910022, '   ', 'LowerBudgetKD', '', ' ', 2, 9709, 0, 0, '', 0, 44623, 0, 0, '') ;

CALL ImportField(970910023, '   ', 'ReceiveKDValue', '', ' ', 2, 9709, 0, 0, '', 0, 44619, 0, 0, '') ;

CALL ImportField(970910024, '', 'InvestObjectCode', '', ' ', 2, 9709, 0, 0, '', 0, 38205, 0, 0, '') ;

CALL ImportField(970910025, '', 'InvestObject', '', ' ', 2, 9709, 0, 1, '', 0, 44621, 0, 0, '') ;

CALL ImportField(970910026, '', 'OverCofinancingCode', '', ' ', 2, 9709, 0, 0, '', 0, 22390, 0, 0, '') ;

CALL ImportField(970910027, '', 'OverCofinancing', '', ' ', 2, 9709, 0, 1, '', 0, 44626, 0, 0, '') ;

CALL ImportField(970910028, '', 'IsCofinancing', '', ' ', 2, 9709, 0, 0, '', 0, 44629, 0, 0, '') ;

CALL ImportField(970910029, '  (.)', 'Detail_CREATEDATE', '', ' ', 2, 9709, 0, 1, '', 0, 44610, 0, 0, '') ;

CALL ImportField(970910030, '  (.)', 'Detail_UPDATEDATE', '', ' ', 2, 9709, 0, 1, '', 0, 44612, 0, 0, '') ;

CALL ImportField(970910031, ' (.)', 'Detail_CREATERUSER', '', ' ', 2, 9709, 0, 1, '', 0, 44611, 0, 0, '') ;

CALL ImportField(970910032, ' (.)', 'Detail_UPDATERUSER', '', ' ', 2, 9709, 0, 1, '', 0, 44613, 0, 0, '') ;

CALL ImportField(970910033, '  (.)', 'Detail_AssignmentKind', '  ', ' ', 2, 9709, 0, 0, '', 0, 44603, 0, 0, '') ;

CALL ImportField(970910034, '  (.)', 'Detail_BudAllocationCls', '', ' ', 2, 9709, 0, 1, '', 0, 44604, 0, 0, '') ;

CALL ImportField(970910035, '  (.)', 'Detail_BudAllocationClsCode', '', ' ', 2, 9709, 0, 0, '', 0, 27825, 0, 0, '') ;

CALL ImportField(970910036, ' (.)', 'Detail_ContractCostsCls', '', ' ', 2, 9709, 0, 1, '', 0, 44609, 0, 0, '') ;

CALL ImportField(970910037, ' (.)', 'Detail_ContractCostsClsCode', '', ' ', 2, 9709, 0, 0, '', 0, 40459, 0, 0, '') ;

CALL ImportField(970910038, ' (.)', 'Detail_DirectionCLS', '', ' ', 2, 9709, 0, 1, '', 0, 44605, 0, 0, '') ;

CALL ImportField(970910039, ' (.)', 'Detail_DirectionCLSCode', '', ' ', 2, 9709, 0, 0, '', 0, 36861, 0, 0, '') ;

CALL ImportField(970910040, ' .  () (.)', 'Detail_FINTYPE', '  ', ' ', 2, 9709, 0, 1, '', 0, 44598, 0, 0, '') ;

CALL ImportField(970910041, ' .  (.)', 'Detail_FINTYPECODE', '  ', ' ', 2, 9709, 0, 0, '', 0, 36853, 0, 0, '') ;

CALL ImportField(970910042, ' (.)', 'Detail_TransferKCSR', '', ' ', 2, 9709, 0, 1, '', 0, 44588, 0, 0, '') ;

CALL ImportField(970910043, ' (.)', 'Detail_TransferKCSRCode', '', ' ', 2, 9709, 0, 0, '', 0, 25462, 0, 0, '') ;

CALL ImportField(970910044, ' (.)', 'Detail_Kesr', '', ' ', 2, 9709, 0, 1, '', 0, 44590, 0, 0, '') ;

CALL ImportField(970910045, ' (.)', 'Detail_KESRCODE', '', ' ', 2, 9709, 0, 0, '', 0, 43607, 0, 0, '') ;

CALL ImportField(970910046, ' (.)', 'Detail_TransferKFSR', '', ' ', 2, 9709, 0, 0, '', 0, 44591, 0, 0, '') ;

CALL ImportField(970910047, ' (.)', 'Detail_TransferKVR', '', ' ', 2, 9709, 0, 1, '', 0, 44592, 0, 0, '') ;

CALL ImportField(970910048, ' (.)', 'Detail_TransferKVRCode', '', ' ', 2, 9709, 0, 0, '', 0, 25467, 0, 0, '') ;

CALL ImportField(970910049, ' (.)', 'Detail_TransferKVSR', '', ' ', 2, 9709, 0, 1, '', 0, 44593, 0, 0, '') ;

CALL ImportField(970910050, ' (.)', 'Detail_TransferKVSRCode', '', ' ', 2, 9709, 0, 0, '', 0, 25472, 0, 0, '') ;

CALL ImportField(970910051, ' (.)', 'Detail_SubKesr', '', ' ', 2, 9709, 0, 1, '', 0, 44599, 0, 0, '') ;

CALL ImportField(970910052, ' (.)', 'Detail_SubKesrCode', '', ' ', 2, 9709, 0, 0, '', 0, 43610, 0, 0, '') ;

CALL ImportField(970910053, '  (.)', 'Detail_SubsidyCls', ' ', ' ', 2, 9709, 0, 1, '', 0, 44607, 0, 0, '') ;

CALL ImportField(970910054, '  (.)', 'Detail_SubsidyClsCode', ' ', ' ', 2, 9709, 0, 0, '', 0, 26641, 0, 0, '') ;

CALL ImportField(970910055, '  (.)', 'Detail_FundsSource', ' ', ' ', 2, 9709, 0, 0, '', 0, 44608, 0, 0, '') ;

CALL ImportField(970910056, ' (.)', 'Detail_InvestObjectCode', '', ' ', 2, 9709, 0, 0, '', 0, 38205, 0, 0, '') ;

CALL ImportField(970910057, ' (.)', 'Detail_InvestObject', '', ' ', 2, 9709, 0, 1, '', 0, 44596, 0, 0, '') ;

CALL ImportField(970910058, '   (.)', 'Detail_PayPromiseCls', '  ', ' ', 2, 9709, 0, 1, '', 0, 44606, 0, 0, '') ;

CALL ImportField(970910059, '   (.)', 'Detail_PayPromiseClsCode', '  ', ' ', 2, 9709, 0, 0, '', 0, 27849, 0, 0, '') ;

CALL ImportField(970910060, ' (.)', 'Detail_FACT', '', ' ', 2, 9709, 0, 1, '', 0, 44597, 0, 0, '') ;

CALL ImportField(970910061, ' (.)', 'Detail_FACTCODE', '', ' ', 2, 9709, 0, 0, '', 0, 36863, 0, 0, '') ;

CALL ImportField(970910062, ' (.)', 'Detail_OKTMO', '', ' ', 2, 9709, 0, 1, '', 0, 44600, 0, 0, '') ;

CALL ImportField(970910063, ' (.)', 'Detail_OKTMOCode', '', ' ', 2, 9709, 0, 0, '', 0, 32822, 0, 0, '') ;

CALL ImportField(970910064, '  (.)', 'Detail_RegionCls', '', ' ', 2, 9709, 0, 0, '', 0, 44602, 0, 0, '') ;

CALL ImportField(970910065, '  (.)', 'Detail_MeansType', ' ', ' ', 2, 9709, 0, 0, '', 0, 44595, 0, 0, '') ;

CALL ImportField(970910066, '  (  )', 'Detail_TargetCls', '  (  )', ' ', 2, 9709, 0, 1, '', 0, 44594, 0, 0, '') ;

CALL ImportField(970910067, ' (  )', 'Detail_DELETEDATE', '', ' ', 2, 9709, 0, 0, '', 0, 44745, 0, 0, '') ;

CALL ImportField(970910068, '   ', 'Detail_STARTDATE', '', ' ', 2, 9709, 0, 0, '', 0, 44746, 0, 0, '') ;

--   , +(2)
CALL ImportField(982710006, 'ID', 'ID', '', ' ', 2, 9827, 0, 0, '', 0, 16956, 0, 0, '') ;

CALL ImportField(982710010, '', 'CODE', '', ' ', 2, 9827, 0, 1, '', 0, 36853, 0, 0, '') ;

--  , +(2)
CALL ImportField(984910015, ' ', 'MEANSTYPE', '', ' ', 2, 9849, 0, 1, '', 0, 44584, 0, 0, '') ;

-- , +(2)
CALL ImportField(985410029, '', 'KVSRCODE', '', ' ', 2, 9854, 0, 0, '', 0, 25472, 0, 0, '') ;

CALL ImportField(985410032, ' ', 'InvestDirection', '', ' ', 2, 9854, 0, 0, '', 0, 44429, 0, 0, '') ;

CALL ImportField(985410033, ' ', 'ProvidingPurpose', '', ' ', 2, 9854, 0, 0, '', 0, 44430, 0, 0, '') ;

CALL ImportField(985410034, '', 'APower', '', ' ', 2, 9854, 0, 0, '', 0, 44431, 0, 0, '') ;

CALL ImportField(985410035, ' ', 'DeveloperName', '', ' ', 2, 9854, 0, 0, '', 0, 44432, 0, 0, '') ;

CALL ImportField(985410036, '  ', 'DevelopStartDate', '', ' ', 2, 9854, 0, 0, '', 0, 44433, 0, 0, '') ;

CALL ImportField(985410037, '  ', 'DevelopEndDate', '', ' ', 2, 9854, 0, 0, '', 0, 44434, 0, 0, '') ;

CALL ImportField(985410038, '  ', 'DevelopCost', '', ' ', 2, 9854, 0, 0, '', 0, 44435, 0, 0, '') ;

CALL ImportField(985410039, '  ', 'TotalCost', '', ' ', 2, 9854, 0, 0, '', 0, 44436, 0, 0, '') ;

CALL ImportField(985410040, ' ', 'Coordinates', '', ' ', 2, 9854, 0, 0, '', 0, 44437, 0, 0, '') ;

CALL ImportField(985410041, '   ', 'RegistryAgreementNumber', '', ' ', 2, 9854, 0, 0, '', 0, 44438, 0, 0, '') ;

CALL ImportField(985410045, '', 'ID', '', ' ', 2, 9854, 0, 0, '', 0, 38204, 0, 0, '') ;

--  , (1)
CALL ImportField(987910006, ' (  )', 'DELETEDATE', '', ' ', 1, 9879, 0, 0, '', 0, 27865, 0, 0, '') ;

CALL ImportField(987910007, '   ', 'STARTDATE', '', ' ', 1, 9879, 0, 0, '', 0, 27866, 0, 0, '') ;

CALL ImportField(987910008, '', '_FAVORITE', '', ' ', 1, 9879, 0, 0, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(987910001, ' ', 'CREATEDATE', '', ' ', 2, 9879, 0, 1, '', 0, 22388, 0, 0, '') ;

CALL ImportField(987910002, '', 'ID', '', ' ', 2, 9879, 0, 0, '', 0, 22386, 0, 0, '') ;

CALL ImportField(987910003, '', 'NAME', '', ' ', 2, 9879, 0, 0, '', 0, 22387, 0, 0, '') ;

CALL ImportField(987910004, ' ', 'UPDATEDATE', '', ' ', 2, 9879, 0, 1, '', 0, 22389, 0, 0, '') ;

CALL ImportField(987910005, ' ', 'STRCODE', '', ' ', 2, 9879, 0, 0, '', 0, 22390, 0, 0, '') ;

CALL ImportField(987910009, ' ', 'ShortName', '', ' ', 2, 9879, 0, 0, '', 0, 44618, 0, 0, '') ;

CALL ImportField(987910010, '', 'BudgetRef', '', ' ', 2, 9879, 0, 0, '', 0, 44617, 0, 0, '') ;

CALL ImportField(987910011, ' -  ', 'TransferBudgetRef', '', ' ', 2, 9879, 0, 0, '', 0, 44622, 0, 0, '') ;

CALL ImportField(987910012, ' ', 'TransfertKind', '', ' ', 2, 9879, 0, 0, '', 0, 44620, 0, 0, '') ;

CALL ImportField(987910013, '', 'TransferKCSR', '', ' ', 2, 9879, 0, 0, '', 0, 44259, 0, 0, '') ;

CALL ImportField(987910015, '', 'TransferKFSR', '', ' ', 2, 9879, 0, 0, '', 0, 44258, 0, 0, '') ;

CALL ImportField(987910016, '', 'TransferKVR', '', ' ', 2, 9879, 0, 0, '', 0, 44260, 0, 0, '') ;

CALL ImportField(987910017, ' ', 'TransferKVSR', '', ' ', 2, 9879, 0, 0, '', 0, 44257, 0, 0, '') ;

CALL ImportField(987910018, ' ', 'ParentTargetCls', '', ' ', 2, 9879, 0, 1, '', 0, 44624, 0, 0, '') ;

CALL ImportField(987910019, ' ', 'ParentTargetClsCode', '', ' ', 2, 9879, 0, 0, '', 0, 22390, 0, 0, '') ;

CALL ImportField(987910020, '', 'CREATERUSER', '', ' ', 2, 9879, 0, 1, '', 0, 44615, 0, 0, '') ;

CALL ImportField(987910021, '', 'UPDATERUSER', '', ' ', 2, 9879, 0, 1, '', 0, 44616, 0, 0, '') ;

CALL ImportField(987910022, '   ', 'LowerBudgetKD', '', ' ', 2, 9879, 0, 0, '', 0, 44623, 0, 0, '') ;

CALL ImportField(987910023, '   ', 'ReceiveKDValue', '', ' ', 2, 9879, 0, 0, '', 0, 44619, 0, 0, '') ;

CALL ImportField(987910024, '', 'InvestObjectCode', '', ' ', 2, 9879, 0, 0, '', 0, 38205, 0, 0, '') ;

CALL ImportField(987910025, '', 'InvestObject', '', ' ', 2, 9879, 0, 1, '', 0, 44621, 0, 0, '') ;

CALL ImportField(987910026, '', 'OverCofinancingCode', '', ' ', 2, 9879, 0, 0, '', 0, 22390, 0, 0, '') ;

CALL ImportField(987910027, '', 'OverCofinancing', '', ' ', 2, 9879, 0, 1, '', 0, 44626, 0, 0, '') ;

CALL ImportField(987910028, '', 'IsCofinancing', '', ' ', 2, 9879, 0, 0, '', 0, 44629, 0, 0, '') ;

--   , +(2)
CALL ImportField(988410021, '', 'TRANSFERKESR', '', ' ', 2, 9884, 0, 0, '', 0, 25339, 0, 0, '') ;

CALL ImportField(988410044, '', 'TRANSFERKESRCODE', '', ' ', 2, 9884, 0, 0, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(991610225, ' \       ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0, '') ;

CALL InsertConst(32, 47, 3, ' \       ', '', 0, 0, 9916) ;

CALL ImportField(991610226, ' \    ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0, '') ;

CALL InsertConst(32, 48, 3, ' \    ', '', 0, 0, 9916) ;

CALL ImportField(991610227, ' \        ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0, '') ;

CALL InsertConst(32, 49, 3, ' \        ', '', 0, 0, 9916) ;

--   , (1)
CALL ImportField(992110004, '', 'OKTMO', '', ' ', 1, 9921, 0, 0, '', 0, null, 0, 0, '') ;

--    , +(2)
CALL ImportField(993010027, ' ', 'FINTYPE', '', ' ', 2, 9930, 0, 0, '', 0, 44405, 0, 0, '') ;

CALL ImportField(993010028, '', 'FACT', '', ' ', 2, 9930, 0, 0, '', 0, 44407, 0, 0, '') ;

CALL ImportField(993010029, '', 'SUBKESR', '', ' ', 2, 9930, 0, 0, '', 0, 44409, 0, 0, '') ;

CALL ImportField(993010030, '', 'REGIONCLS', '', ' ', 2, 9930, 0, 0, '', 0, 44408, 0, 0, '') ;

CALL ImportField(993010031, '  ()', 'SUBSIDYCLS', '', ' ', 2, 9930, 0, 0, '', 0, 44410, 0, 0, '') ;

CALL ImportField(993010032, '  ()', 'TARGETCLS', '', ' ', 2, 9930, 0, 0, '', 0, 44411, 0, 0, '') ;

CALL ImportField(993010033, '', 'DIRECTIONCLS', '', ' ', 2, 9930, 0, 0, '', 0, 44406, 0, 0, '') ;

CALL ImportField(993010034, '   ()', 'TRANSFERTCLS', '', ' ', 2, 9930, 0, 0, '', 0, 44412, 0, 0, '') ;

CALL ImportField(993010035, '', 'CONTRACTCOSTSCLS', '', ' ', 2, 9930, 0, 0, '', 0, 44422, 0, 0, '') ;

CALL ImportField(993010036, '', 'INVESTOBJECT', '', ' ', 2, 9930, 0, 0, '', 0, 44423, 0, 0, '') ;

CALL ImportField(993010037, '.  ', 'STOREDCONTENT', '', ' ', 2, 9930, 0, 0, '', 0, 44425, 0, 0, '') ;

CALL ImportField(993010038, '  ()', 'DOCTYPECLS', '', ' ', 2, 9930, 0, 0, '', 0, 44450, 0, 0, '') ;

--       
ALTER TRIGGER TR_INTCONST_BU_500 ENABLE
/

ALTER TRIGGER TR_VARCHARCONST_BU_500 ENABLE
/

ALTER TRIGGER TR_REALCONST_BU_500 ENABLE
/

DROP PROCEDURE ImportField
/

/*      */
ALTER TRIGGER TR_DOCUMENTFIELDS_BU_500 DISABLE
/

Update TB_DocumentFields df
set documentcls=doctyperef*100+detailnumber
where (detailnumber<100)and(documentcls is null)
 and(exists(select dc.id from documentcls dc where id=df.doctyperef*100+df.detailnumber))
/

ALTER TRIGGER TR_DOCUMENTFIELDS_BU_500 ENABLE
/

DROP PROCEDURE DeleteFields
/

DROP PROCEDURE InsertConst
/

DROP PROCEDURE DELETECONST
/




CREATE OR REPLACE PROCEDURE DOCLOCK_IMPORT(
  NAME_              VARCHAR2,
  LOCKMASK_          NUMBER,
  DOCREF_            NUMBER,
  DETAILNUM_         NUMBER,
  RUNPOS_            NUMBER,
  LOCKACTION_        NUMBER,
  USERIGHTS_        NUMBER,
  FORMULA_           VARCHAR2,
  FORDELETE_         NUMBER,
  ISSYSTEM_          NUMBER,
  NOTE_              VARCHAR2,
  FORINSERT_         NUMBER,
  VALIDATEMESSAGE_ VARCHAR2,
  VALIDATELEVEL_   NUMBER,
  VALIDATEFILTER_  VARCHAR2,
  ISBUDGET_ NUMBER)
IS
  DOCLOCKID$ Number(10);
BEGIN
   BEGIN
     SELECT ID
     INTO DOCLOCKID$
     FROM DOCLOCK
     WHERE (DOCREF = DOCREF_) AND(DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
   EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DOCLOCKID$ := NULL;  
   END;
   
   IF (DOCLOCKID$ is not null) THEN
     IF (ISSYSTEM_ = 3) THEN
       UPDATE DOCLOCK SET
         NAME = NAME_,
         LOCKMASK = LOCKMASK_,
         DOCREF = DOCREF_,
         DETAILNUM = DETAILNUM_,
         RUNPOS = RUNPOS_,
         LOCKACTION = LOCKACTION_,
         FORMULA = FORMULA_,
         FORDELETE = FORDELETE_,
         ISSYSTEM = ISSYSTEM_,
         NOTE = NOTE_,
         FORINSERT = FORINSERT_,
         VALIDATEMESSAGE = VALIDATEMESSAGE_,
         VALIDATELEVEL = VALIDATELEVEL_,
         VALIDATEFILTER = VALIDATEFILTER_,
         ISBUDGET = ISBUDGET_,
         USERIGHTS = USERIGHTS_
       WHERE ID = DOCLOCKID$;  
     ELSE
       UPDATE DOCLOCK SET
         NAME = NAME_,
         LOCKMASK = LOCKMASK_,
         DOCREF = DOCREF_,
         DETAILNUM = DETAILNUM_,
         RUNPOS = RUNPOS_,
         LOCKACTION = LOCKACTION_,
         FORMULA = FORMULA_,
         FORDELETE = FORDELETE_,
         ISSYSTEM = ISSYSTEM_,
         NOTE = NOTE_,
         FORINSERT = FORINSERT_,
         VALIDATEMESSAGE = VALIDATEMESSAGE_,
         VALIDATELEVEL = VALIDATELEVEL_,
         VALIDATEFILTER = VALIDATEFILTER_,
         ISBUDGET = ISBUDGET_
       WHERE ID = DOCLOCKID$;    
     END IF;  
   ELSE
     INSERT INTO DOCLOCK
       (ISBUDGET,NAME,LOCKMASK,DOCREF,DETAILNUM,RUNPOS,LOCKACTION,USERIGHTS,FORMULA,FORDELETE,ISSYSTEM,NOTE,FORINSERT,VALIDATEMESSAGE,VALIDATELEVEL,VALIDATEFILTER)
     VALUES
       (ISBUDGET_,NAME_,LOCKMASK_,DOCREF_,DETAILNUM_,RUNPOS_,LOCKACTION_,USERIGHTS_,FORMULA_,FORDELETE_,ISSYSTEM_,NOTE_,FORINSERT_,VALIDATEMESSAGE_,VALIDATELEVEL_,VALIDATEFILTER_);
   END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCKFIELDS_INSERTFIELD(
  NAME_      VARCHAR2,
  DOCREF_    NUMBER,
  DETAILNUM_ NUMBER,
  FIELDREF_  NUMBER,
  ISBUDGET_ NUMBER)
IS
  NID$ NUMBER(10);
  cnt$ number(10);
BEGIN
  BEGIN
    SELECT ID
    INTO NID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      NID$ := NULL;  
  END;

  IF (NID$ is not null) THEN
    CNT$ := 0;
    SELECT count(ID)
    into cnt$
    FROM DOCLOCKFIELDS
    WHERE (DOCLOCKREF = NID$) AND (FIELDREF = FIELDREF_) ;
    
    IF (cnt$ = 0) THEN
      INSERT INTO DOCLOCKFIELDS
        (DOCLOCKREF,FIELDREF,ISSYSTEM)
      VALUES
        (NID$,FIELDREF_,1);
    ELSE
      UPDATE DOCLOCKFIELDS SET
        ISSYSTEM = 1
      WHERE (DOCLOCKREF = NID$) AND (FIELDREF = FIELDREF_) ;
    END IF;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCK_DELETE(NAME_ VARCHAR2, DOCREF_ NUMBER, DETAILNUM_ NUMBER, ISBUDGET_ NUMBER) IS
   DOCLOCKID$ NUMBER(10);
BEGIN
  BEGIN
    SELECT ID
    INTO DOCLOCKID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      DOCLOCKID$ := NULL;
  END;

  IF (DOCLOCKID$ is not null) THEN
    DELETE FROM DOCLOCK
    WHERE ID = DOCLOCKID$;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCKFIELDS_DELETE(NAME_ VARCHAR2, DOCREF_ NUMBER, DETAILNUM_ NUMBER, CANCHANGEFIELDS_ NUMBER, ISBUDGET_ NUMBER) IS
   DOCLOCKID$ NUMBER(10);
BEGIN
  BEGIN
    SELECT ID
    INTO DOCLOCKID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION  
    WHEN NO_DATA_FOUND THEN
      DOCLOCKID$ := NULL;
  END;  

  IF (DOCLOCKID$ is not null) THEN
    DELETE FROM DOCLOCKFIELDS
    WHERE (DOCLOCKREF = DOCLOCKID$) AND ((ISSYSTEM = 1) OR ((ISSYSTEM = 0) AND (CANCHANGEFIELDS_ = 0) ));
  END IF;
END;
/

-- 
CALL DOCLOCK_DELETE('    ',301, 1, 1) ;

CALL DOCLOCK_DELETE('     ',301, 1, 1) ;

CALL DOCLOCK_DELETE('     , ',2502, 2, 1) ;

CALL DOCLOCK_DELETE('     , ',2503, 2, 1) ;

CALL DOCLOCK_DELETE('     , ',2504, 2, 1) ;

CALL DOCLOCK_IMPORT('    ',0,200,1,0,11,0,' ( in (205, 209, 211, 212, 213, 214, 215))',0,1,'      ',0,'     ',null,'([970910066] is null) 
(([970910066] is not null)  (([970910049] = 0)  (.[20011018] = 0)  (.[20011024] = [970910050])) 
(([970910046] = 0)  (.[20011020] = 0)  (.[20011020] = [970910046])) 
(([970910047] = 0)  (.[20011019] = 0)  (.[20011023] = [970910048])) 
(([970910042] = 0)  (.[20011022] = 0)  (.[20011025] = [970910043])) 
(([970910044] = 0)  (.[20011021] = 0)  (.[20011050] = [970910045])) 
(([970910065] = 0)  (.[20011027] = 0)  (.[20011027] = [970910065])) 
(([970910056] = "")  (.[20011052] = "")  (.[20011052] = [970910056])) 
(([970910060] = 0)  (.[20011036] = 0)  (.[20011035] = [970910061])) 
(([970910051] = 0)  (.[20011054] = 0)  (.[20011053] = [970910052])) 
(([970910064] = 0)  (.[20011055] = 0)  (.[20011055] = [970910064])) 
(([970910040] = 0)  (.[20011057] = 0)  (.[20011056] = [970910041])) 
(([970910038] = 0)  (.[20011058] = 0)  (.[20011059] = [970910039]))   
(([970910054] = "")  (.[20011014] = "")  (.[20011014] = [970910054])) 
(([970910033] = 0)  (.[20011034] = 0)  (.[20011034] = [970910033])) 
(([970910035] = "")  (.[20011060] = "")  (.[20011060] = [970910035])) 
(([970910059] = "")  (.[20011061] = "")  (.[20011061] = [970910059]))  
(([970910037] = "")  (.[20011063] = "")  (.[20011063] = [970910037])))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 200, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('    ',200,1,20011043,1) ;

CALL DOCLOCK_IMPORT('   ',0,204,0,0,11,0,'',0,1,'    .    ()   ,         01.08.00  01.11.99   01.02.00  01.03.99',0,'  .    ,  () , (),   ,   ',null,'([960110035] between 10800 and 11199)([960110035] between 10200 and 10399)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 204, 0, 0, 1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',204,0,20410039,1) ;

CALL DOCLOCK_IMPORT('   / ()',0,204,0,0,11,0,'',0,1,'  - \ (). -          01.08.00  01.11.99   01.02.00  01.03.99',0,'-     ,  () , (),   ,   ',null,'(("..",[984110031]) between 10800 and 11199)(("..",[984110031]) between 10200 and 10399)',1) ;

CALL DOCLOCKFIELDS_DELETE('   / ()', 204, 0, 0, 1) ;

--  "\  "
CALL DOCLOCKFIELDS_INSERTFIELD('   / ()',204,0,20410034,1) ;

CALL DOCLOCK_IMPORT('    ',0,205,1,0,11,0,'',0,1,'      ',0,'     ',null,'([970910066] is null) 
(([970910066] is not null)  (([970910049] = 0)  (.[20511023] = 0)  (.[20511093] = [970910050])) 
(([970910046] = 0)  (.[20511031] = 0)  (.[20511031] = [970910046])) 
(([970910047] = 0)  (.[20511022] = 0)  (.[20511092] = [970910048])) 
(([970910042] = 0)  (.[20511032] = 0)  (.[20511090] = [970910043])) 
(([970910044] = 0)  (.[20511033] = 0)  (.[20511118] = [970910045])) 
(([970910065] = 0)  (.[20511068] = 0)  (.[20511068] = [970910065])) 
(([970910056] = "")  (.[20511105] = "")  (.[20511105] = [970910056])) 
(([970910060] = 0)  (.[20511103] = 0)  (.[20511036] = [970910061])) 
(([970910051] = 0)  (.[20511065] = 0)  (.[20511119] = [970910052])) 
(([970910064] = 0)  (.[20511047] = 0)  (.[20511047] = [970910064])) 
(([970910040] = 0)  (.[20511101] = 0)  (.[20511069] = [970910041])) 
(([970910038] = 0)  (.[20511102] = 0)  (.[20511037] = [970910039]))   
(([970910033] = 0)  (.[20511012] = 0)  (.[20511012] = [970910033])) 
(([970910035] = "")  (.[20511096] = "")  (.[20511096] = [970910035])) 
(([970910059] = "")  (.[20511097] = "")  (.[20511097] = [970910059]))  
(([970910037] = "")  (.[20511108] = "")  (.[20511108] = [970910037])))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 205, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('    ',205,1,20511112,1) ;

CALL DOCLOCK_IMPORT('    ',0,209,2,0,11,0,'',0,1,'      ',0,'     ',null,'([970910066] is null) 
(([970910066] is not null)  (([970910049] = 0)  (.[20912039] = 0)  (.[20912020] = [970910050])) 
(([970910046] = 0)  (.[20912018] = 0)  (.[20912018] = [970910046])) 
(([970910047] = 0)  (.[20912038] = 0)  (.[20912019] = [970910048])) 
(([970910042] = 0)  (.[20912037] = 0)  (.[20912016] = [970910043])) 
(([970910044] = 0)  (.[20912017] = 0)  (.[20912155] = [970910045])) 
(([970910065] = 0)  (.[20912021] = 0)  (.[20912021] = [970910065])) 
(([970910056] = "")  (.[20912160] = "")  (.[20912160] = [970910056])) 
(([970910060] = 0)  (.[20912041] = 0)  (.[20912009] = [970910061])) 
(([970910051] = 0)  (.[20912027] = 0)  (.[20912156] = [970910052])) 
(([970910064] = 0)  (.[20912025] = 0)  (.[20912025] = [970910064])) 
(([970910040] = 0)  (.[20912043] = 0)  (.[20912010] = [970910041])) 
(([970910038] = 0)  (.[20912042] = 0)  (.[20912006] = [970910039]))   
(([970910054] = "")  (.[20912040] = "")  (.[20912040] = [970910054])) 
(([970910033] = 0)  (.[20912001] = 0)  (.[20912001] = [970910033])) 
(([970910035] = "")  (.[20912045] = "")  (.[20912045] = [970910035])) 
(([970910059] = "")  (.[20912046] = "")  (.[20912046] = [970910059]))  
(([970910037] = "")  (.[20912159] = "")  (.[20912159] = [970910037])))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 209, 2, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('    ',209,2,20912047,1) ;

CALL DOCLOCK_IMPORT('    ',0,211,2,0,11,0,'',0,1,'      ',0,'     ',null,'([970910066] is null) 
(([970910066] is not null)  (([970910049] = 0)  (.[21112031] = 0)  (.[21112019] = [970910050])) 
(([970910046] = 0)  (.[21112017] = 0)  (.[21112017] = [970910046])) 
(([970910047] = 0)  (.[21112030] = 0)  (.[21112018] = [970910048])) 
(([970910042] = 0)  (.[21112032] = 0)  (.[21112015] = [970910043])) 
(([970910044] = 0)  (.[21112016] = 0)  (.[21112058] = [970910045])) 
(([970910065] = 0)  (.[21112020] = 0)  (.[21112020] = [970910065])) 
(([970910056] = "")  (.[21112080] = "")  (.[21112080] = [970910056])) 
(([970910060] = 0)  (.[21112034] = 0)  (.[21112008] = [970910061])) 
(([970910051] = 0)  (.[21112026] = 0)  (.[21112062] = [970910052])) 
(([970910064] = 0)  (.[21112024] = 0)  (.[21112024] = [970910064])) 
(([970910040] = 0)  (.[21112036] = 0)  (.[21112009] = [970910041])) 
(([970910038] = 0)  (.[21112035] = 0)  (.[21112005] = [970910039]))   
(([970910054] = "")  (.[21112033] = "")  (.[21112033] = [970910054])) 
(([970910033] = 0)  (.[21112004] = 0)  (.[21112004] = [970910033])) 
(([970910035] = "")  (.[21112076] = "")  (.[21112076] = [970910035])) 
(([970910059] = "")  (.[21112077] = "")  (.[21112077] = [970910059]))  
(([970910037] = "")  (.[21112049] = "")  (.[21112049] = [970910037])))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 211, 2, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('    ',211,2,21112052,1) ;

CALL DOCLOCK_IMPORT('    ',0,212,2,0,11,0,'',0,1,'      ',0,'     ',null,'([970910066] is null) 
(([970910066] is not null)  (([970910049] = 0)  (.[21212031] = 0)  (.[21212019] = [970910050])) 
(([970910046] = 0)  (.[21212017] = 0)  (.[21212017] = [970910046])) 
(([970910047] = 0)  (.[21212030] = 0)  (.[21212018] = [970910048])) 
(([970910042] = 0)  (.[21212032] = 0)  (.[21212015] = [970910043])) 
(([970910044] = 0)  (.[21212016] = 0)  (.[21212057] = [970910045])) 
(([970910065] = 0)  (.[21212020] = 0)  (.[21212020] = [970910065])) 
(([970910056] = "")  (.[21212066] = "")  (.[21212066] = [970910056])) 
(([970910060] = 0)  (.[21212034] = 0)  (.[21212008] = [970910061])) 
(([970910051] = 0)  (.[21212026] = 0)  (.[21212061] = [970910052])) 
(([970910064] = 0)  (.[21212024] = 0)  (.[21212024] = [970910064])) 
(([970910040] = 0)  (.[21212036] = 0)  (.[21212009] = [970910041])) 
(([970910038] = 0)  (.[21212035] = 0)  (.[21212005] = [970910039]))   
(([970910054] = "")  (.[21212033] = "")  (.[21212033] = [970910054])) 
(([970910033] = 0)  (.[21212004] = 0)  (.[21212004] = [970910033])) 
(([970910035] = "")  (.[21212062] = "")  (.[21212062] = [970910035])) 
(([970910059] = "")  (.[21212063] = "")  (.[21212063] = [970910059]))  
(([970910037] = "")  (.[21212050] = "")  (.[21212050] = [970910037])))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 212, 2, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('    ',212,2,21212053,1) ;

CALL DOCLOCK_IMPORT('    ',0,300,1,0,11,0,' ( in (306, 307, 311, 312, 314, 315))',0,1,'      ',0,'     ',null,'([970910066] is null) 
(([970910066] is not null)  (([970910049] = 0)  (.[30011026] = 0)  (.[30011033] = [970910050])) 
(([970910046] = 0)  (.[30011029] = 0)  (.[30011029] = [970910046])) 
(([970910047] = 0)  (.[30011028] = 0)  (.[30011032] = [970910048])) 
(([970910042] = 0)  (.[30011027] = 0)  (.[30011031] = [970910043])) 
(([970910044] = 0)  (.[30011030] = 0)  (.[30011053] = [970910045])) 
(([970910065] = 0)  (.[30011035] = 0)  (.[30011035] = [970910065])) 
(([970910056] = "")  (.[30011054] = "")  (.[30011054] = [970910056])) 
(([970910060] = 0)  (.[30011044] = 0)  (.[30011043] = [970910061])) 
(([970910051] = 0)  (.[30011056] = 0)  (.[30011057] = [970910052])) 
(([970910064] = 0)  (.[30011058] = 0)  (.[30011058] = [970910064])) 
(([970910040] = 0)  (.[30011060] = 0)  (.[30011059] = [970910041])) 
(([970910038] = 0)  (.[30011062] = 0)  (.[30011061] = [970910039]))   
(([970910054] = "")  (.[30011022] = "")  (.[30011022] = [970910054])) 
(([970910035] = "")  (.[30011063] = "")  (.[30011063] = [970910035])) 
(([970910059] = "")  (.[30011065] = "")  (.[30011065] = [970910059]))  
(([970910037] = "")  (.[30011067] = "")  (.[30011067] = [970910037])))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 300, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('    ',300,1,30011047,1) ;

CALL DOCLOCK_IMPORT('  .   ',0,301,1,0,11,0,'',0,3,'  .    ',0,'   .    ',null,'((.[30110110] = 0)  ([986810009] = 1)) 
((.[30110110] = 1)  ([986810008] = 1)) 
((.[30110110] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('  .   ', 301, 1, 0, 1) ;

--  " -"
CALL DOCLOCKFIELDS_INSERTFIELD('  .   ',301,1,30111017,1) ;

CALL DOCLOCK_IMPORT('    ',0,301,1,0,11,0,'',0,1,'      ',0,'     ',null,'([970910066] is null) 
(([970910066] is not null)  (([970910049] = 0)  (.[30111020] = 0)  (.[30111143] = [970910050])) 
(([970910046] = 0)  (.[30111018] = 0)  (.[30111018] = [970910046])) 
(([970910047] = 0)  (.[30111016] = 0)  (.[30111142] = [970910048])) 
(([970910042] = 0)  (.[30111019] = 0)  (.[30111140] = [970910043])) 
(([970910044] = 0)  (.[30111017] = 0)  (.[30111213] = [970910045])) 
(([970910065] = 0)  (.[30111023] = 0)  (.[30111023] = [970910065])) 
(([970910056] = "")  (.[30111174] = "")  (.[30111174] = [970910056])) 
(([970910060] = 0)  (.[30111163] = 0)  (.[30111022] = [970910061])) 
(([970910051] = 0)  (.[30111021] = 0)  (.[30111215] = [970910052])) 
(([970910064] = 0)  (.[30111101] = 0)  (.[30111101] = [970910064])) 
(([970910040] = 0)  (.[30111167] = 0)  (.[30111024] = [970910041])) 
(([970910038] = 0)  (.[30111165] = 0)  (.[30111030] = [970910039]))   
(([970910054] = "")  (.[30111150] = "")  (.[30111150] = [970910054])) 
(([970910035] = "")  (.[30111154] = "")  (.[30111154] = [970910035])) 
(([970910059] = "")  (.[30111155] = "")  (.[30111155] = [970910059]))  
(([970910037] = "")  (.[30111175] = "")  (.[30111175] = [970910037])))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 301, 1, 0, 1) ;

--  "  -"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',301,1,30111193,1) ;

CALL DOCLOCK_IMPORT('    ',0,308,1,0,11,0,'',0,1,'      ',0,'     ',null,'([970910066] is null) 
(([970910066] is not null)  (([970910049] = 0)  (.[30811073] = 0)  (.[30811074] = [970910050])) 
(([970910046] = 0)  (.[30811070] = 0)  (.[30811070] = [970910046])) 
(([970910047] = 0)  (.[30811071] = 0)  (.[30811072] = [970910048])) 
(([970910042] = 0)  (.[30811067] = 0)  (.[30811068] = [970910043])) 
(([970910044] = 0)  (.[30811069] = 0)  (.[30811254] = [970910045])) 
(([970910065] = 0)  (.[30811024] = 0)  (.[30811024] = [970910065])) 
(([970910056] = "")  (.[30811114] = "")  (.[30811114] = [970910056])) 
(([970910060] = 0)  (.[30811104] = 0)  (.[30811016] = [970910061])) 
(([970910051] = 0)  (.[30811027] = 0)  (.[30811256] = [970910052])) 
(([970910064] = 0)  (.[30811026] = 0)  (.[30811026] = [970910064])) 
(([970910040] = 0)  (.[30811108] = 0)  (.[30811018] = [970910041])) 
(([970910038] = 0)  (.[30811106] = 0)  (.[30811008] = [970910039]))   
(([970910054] = "")  (.[30811082] = "")  (.[30811082] = [970910054])) 
(([970910035] = "")  (.[30811085] = "")  (.[30811085] = [970910035])) 
(([970910059] = "")  (.[30811086] = "")  (.[30811086] = [970910059]))  
(([970910037] = "")  (.[30811115] = "")  (.[30811115] = [970910037])))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 308, 1, 0, 1) ;

--  "  -"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',308,1,30811120,1) ;

CALL DOCLOCK_IMPORT('      ',0,322,0,0,11,0,'',0,3,'',0,'',null,'([984110014] <> "")',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 322, 0, 0, 1) ;

--  "/ "
CALL DOCLOCKFIELDS_INSERTFIELD('      ',322,0,32210005,1) ;

CALL DOCLOCK_IMPORT('     ',0,1820,0,0,12,3,'',0,1,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 1820, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',1820,0,182010029,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',1820,0,182010028,1) ;

CALL DOCLOCK_IMPORT('  .   ',0,1820,1,0,12,3,'',0,1,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  .   ', 1820, 1, 0, 1) ;

--  ". "
CALL DOCLOCKFIELDS_INSERTFIELD('  .   ',1820,1,182011031,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  .   ',1820,1,182011030,1) ;

CALL DOCLOCK_IMPORT('     , ',0,2502,2,0,11,0,'("_._",[250212035])    ("_._",[250212035])  ("_.",[250212035])',0,1,' \ ,         2,3,4,7,8;    \ ,       5,6,9;   \        7  8.',0,'         ',null,'(("_._",.[250212035])
 (([984910001] between 2  4)([984910001] between 7  8)))

(("_.",.[250212035])
 ([984910001] between 7  8))

(("_._",.[250212035])
 (([984910001] between 5  6)([984910001] = 9)))',2) ;

CALL DOCLOCKFIELDS_DELETE('     , ', 2502, 2, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     , ',2502,2,250212025,2) ;

CALL DOCLOCK_IMPORT('  ',0,2503,0,0,11,0,'',0,3,'',0,'',null,'(([981110005] = 0)  ([981110007] > 0))  ([981110007] <> 6)',2) ;

CALL DOCLOCKFIELDS_DELETE('  ', 2503, 0, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2503,0,250310030,2) ;

CALL DOCLOCK_IMPORT('      ',0,2503,0,0,11,0,'(".",[250310049])   (".",[250310049])',0,3,'            ,  / 25.03 :       ,         ,  ,  ',0,'        ,  ,  ',null,' ([981110007] = 3  [981110007] = 4  [981110007] = 5)',2) ;

CALL DOCLOCKFIELDS_DELETE('      ', 2503, 0, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('      ',2503,0,250310030,2) ;

CALL DOCLOCK_IMPORT('  ',0,2503,2,0,12,0,'(50,52,3) = 1',0,3,'',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE('  ', 2503, 2, 0, 2) ;

--  "    "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2503,2,250312054,2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2503,2,250312055,2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2503,2,250312002,2) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2503,2,250312028,2) ;

--  "    "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2503,2,250312075,2) ;

CALL DOCLOCK_IMPORT('     , ',0,2503,2,0,11,0,'("_._",[250312005])    ("_._",[250312005])  ("_.",[250312005])',0,1,' \ ,         2,3,4,7,8;    \ ,       5,6,9;   \        7  8.',0,'         ',null,'(("_._",.[250312005])
 (([984910001] between 2  4)([984910001] between 7  8)))

(("_.",.[250312005])
 ([984910001] between 7  8))

(("_._",.[250312005])
 (([984910001] between 5  6)([984910001] = 9)))',2) ;

CALL DOCLOCKFIELDS_DELETE('     , ', 2503, 2, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     , ',2503,2,250312015,2) ;

CALL DOCLOCK_IMPORT('   ',0,2504,0,0,10,0,'((".DOCTYPES.REGISTRATIONTYPE",[250410094]) = 6)   ([250410086] is not null)',0,1,'',0,'  ',0,'',2) ;

CALL DOCLOCKFIELDS_DELETE('   ', 2504, 0, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',2504,0,250410086,2) ;

CALL DOCLOCK_IMPORT(' ',0,2504,0,0,10,0,'((".DOCTYPES.REGISTRATIONTYPE",[250410094]) = 6)   ([250410049] is not null)',0,1,'',0,'  ',0,'',2) ;

CALL DOCLOCKFIELDS_DELETE(' ', 2504, 0, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',2504,0,250410049,2) ;

CALL DOCLOCK_IMPORT('   ',0,2504,0,0,10,0,'((".DOCTYPES.REGISTRATIONTYPE",[250410094]) = 6)   ([250410083] is not null)',0,1,'',0,'  ',0,'',2) ;

CALL DOCLOCKFIELDS_DELETE('   ', 2504, 0, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',2504,0,250410083,2) ;

CALL DOCLOCK_IMPORT('  ',0,2504,0,0,10,0,'((".DOCTYPES.REGISTRATIONTYPE",[250410094]) = 6)   ([250410084] is not null)',0,1,'',0,'  ',0,'',2) ;

CALL DOCLOCKFIELDS_DELETE('  ', 2504, 0, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2504,0,250410084,2) ;

CALL DOCLOCK_IMPORT('     , ',0,2504,2,0,11,0,'("_._",[250412043])    ("_._",[250412043])  ("_.",[250412043])',0,1,' \ ,         2,3,4,7,8;    \ ,       5,6,9;   \        7  8.',0,'         ',null,'(("_._",.[250412043])
 (([984910001] between 2  4)([984910001] between 7  8)))

(("_.",.[250412043])
 ([984910001] between 7  8))

(("_._",.[250412043])
 (([984910001] between 5  6)([984910001] = 9)))',2) ;

CALL DOCLOCKFIELDS_DELETE('     , ', 2504, 2, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     , ',2504,2,250412030,2) ;

CALL DOCLOCK_IMPORT('  ',0,5201,0,0,12,0,'(5201, "") <> 0',0,3,'',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE('  ', 5201, 0, 0, 2) ;

--  "-"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',5201,0,520110060,2) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('  ',5201,0,520110047,2) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',5201,0,520110046,2) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',5201,0,520110045,2) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',5201,0,520110044,2) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',5201,0,520110039,2) ;

CALL DOCLOCK_IMPORT('   ()',1048576,5501,1,0,5,0,'([550111092] = 315)  ([550110007] is not null)',0,3,'     ,        .     .      .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   ()', 5501, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ()',5501,1,550111077,1) ;

CALL DOCLOCK_IMPORT('   ()',2097152,5502,1,0,5,0,'([550211092] = 315)  ([550210007] is not null)',0,3,'     ,        .     .      .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   ()', 5502, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ()',5502,1,550211077,1) ;

DROP PROCEDURE DOCLOCK_IMPORT      
/

DROP PROCEDURE DocLockFields_InsertField
/

DROP PROCEDURE DOCLOCK_DELETE
/

DROP PROCEDURE DOCLOCKFIELDS_DELETE
/

CREATE OR REPLACE PROCEDURE LINKTYPE_DELETE(
  NAME_         VARCHAR2,
  TEMPLATECLS_  NUMBER,
  PARENTDOCCLS_ NUMBER,
  CHILDDOCCLS_  NUMBER) IS
BEGIN
  FOR tab_rec in (SELECT id FROM LINKTYPE LT
  WHERE (((NAME_ <> '') or (NAME_ is not null)) and (LT.NAME = NAME_)) or 
    (((NAME_ = '') or (NAME_ is null)) and (LT.TEMPLATECLS = TEMPLATECLS_ AND LT.PARENTDOCCLS = PARENTDOCCLS_ AND LT.CHILDDOCCLS = CHILDDOCCLS_)))    
  LOOP
    UPDATE STATE_JUMPCONTROL SET
      REFERENCEREF = NULL
    WHERE REFERENCEREF = tab_rec.id;
    DELETE FROM REPLACEMENTCLSDETAIL WHERE LINKID IN (SELECT ID FROM LINKRECORDS
      WHERE LINKTYPEREF = tab_rec.id);
    DELETE FROM LINKRECORDS
      WHERE LINKTYPEREF = tab_rec.id;
    DELETE FROM LINKTYPE LT
      WHERE LT.ID = tab_rec.id;
  END LOOP;     
END;
/

CREATE OR REPLACE PROCEDURE LINKTYPE_IMPORT(
   ID_                    NUMBER,
   NAME_                  VARCHAR2,
   TEMPLATECLS_           NUMBER,
   PARENTDOCCLS_          NUMBER,
   CHILDDOCCLS_           NUMBER,
   LINKCOMMENT_           VARCHAR2,
   BLOCKPARENT_           NUMBER,
   BLOCKCHILD_            NUMBER,
   CANDELBLOCKPARENT_     NUMBER,
   CANDELBLOCKCHILD_      NUMBER,
   PARENTPICTURETYPE_     NUMBER,
   PARENTPICTURENAME_     VARCHAR2,
   CHILDPICTURETYPE_      NUMBER,
   CHILDPICTURENAME_      VARCHAR2,
   PICTURECOLLECTIONNAME_ VARCHAR2,
   URMUSE_                NUMBER,
   DELMACROSNAME_         VARCHAR2,
   NEEDDELCHILD_          NUMBER,
   LINKKIND_              NUMBER
) IS
   CNT$ NUMBER(10);
BEGIN
   /*          ,     */
   /*  ,   , ,  ,     */
   IF (
   ((TEMPLATECLS_ is not null)and(TEMPLATECLS_<>0))or(Name_ is not null))   
   THEN
     FOR tab_rec in(SELECT id FROM LINKTYPE LT WHERE 
		 (id<>ID_)	
         and(((TEMPLATECLS_ is not null)and(TEMPLATECLS_<>0)and(LT.TEMPLATECLS = TEMPLATECLS_)
         and (LT.PARENTDOCCLS = PARENTDOCCLS_) and (LT.CHILDDOCCLS = CHILDDOCCLS_))
         or((Name_ is not null)and(lt.Name=Name_))))
     LOOP
        /*             */    
        DELETE FROM LINKRECORDS WHERE LINKTYPEREF = -10;  
        DELETE FROM TB_LINKTYPE WHERE ID = -10;
        DELETE FROM DOCUMENTCLS WHERE ID = -10;
        DELETE FROM DOCUMENTTYPES WHERE ID = -10;
        INSERT INTO DOCUMENTTYPES(ID, PROGINDEX) VALUES(-10, -10);
        INSERT INTO DOCUMENTCLS(ID, DOCTYPE, TABLENAME, TABLENAMEURM, PRIMARYKEYNAME, PRIMARYKEYNAMEURM)
           VALUES(-10, -10, ' ', ' ', ' ', ' ');
        INSERT INTO LINKTYPE(ID, PARENTDOCCLS, CHILDDOCCLS, NAME) VALUES(-10, -10, -10, ' ');
        UPDATE STATE_JUMPCONTROL SET
           REFERENCEREF = -10
        WHERE
           REFERENCEREF = tab_rec.id;
        UPDATE LINKRECORDS SET
           LINKTYPEREF = -10
        WHERE
           LINKTYPEREF = tab_rec.id;
        DELETE FROM TB_LINKTYPE WHERE ID = tab_rec.Id;
     END LOOP;
   end if;
   /*      */ 
   SELECT count(*) into CNT$
      FROM LINKTYPE LT WHERE LT.ID = ID_;
   IF (CNT$ = 0)    
   THEN
      INSERT INTO LINKTYPE
       (ID,NAME,TEMPLATECLS,PARENTDOCCLS, CHILDDOCCLS, LINKCOMMENT, BLOCKPARENT,BLOCKCHILD,CANDELBLOCKPARENT,
        CANDELBLOCKCHILD, PARENTPICTURETYPE,PARENTPICTURENAME,CHILDPICTURETYPE,CHILDPICTURENAME,
        PICTURECOLLECTIONNAME,URMUSE,DELMACROSNAME,NEEDDELCHILD,LINKKIND)
      VALUES
       (ID_,NAME_,TEMPLATECLS_, PARENTDOCCLS_, CHILDDOCCLS_, LINKCOMMENT_, BLOCKPARENT_,BLOCKCHILD_,CANDELBLOCKPARENT_,
        CANDELBLOCKCHILD_, PARENTPICTURETYPE_,PARENTPICTURENAME_,CHILDPICTURETYPE_,CHILDPICTURENAME_,
        PICTURECOLLECTIONNAME_,URMUSE_,DELMACROSNAME_,NEEDDELCHILD_,LINKKIND_);
   ELSE
      UPDATE LINKTYPE SET
         NAME = NAME_,
         TEMPLATECLS = TEMPLATECLS_,
         PARENTDOCCLS = PARENTDOCCLS_,
         CHILDDOCCLS = CHILDDOCCLS_,
         LINKCOMMENT = LINKCOMMENT_,
         BLOCKPARENT = BLOCKPARENT_,
         BLOCKCHILD = BLOCKCHILD_,
         CANDELBLOCKPARENT = CANDELBLOCKPARENT_,
         CANDELBLOCKCHILD = CANDELBLOCKCHILD_,
         PARENTPICTURETYPE = PARENTPICTURETYPE_,
         PARENTPICTURENAME = PARENTPICTURENAME_,
         CHILDPICTURETYPE = CHILDPICTURETYPE_,
         CHILDPICTURENAME = CHILDPICTURENAME_,
         PICTURECOLLECTIONNAME = PICTURECOLLECTIONNAME_,
         URMUSE = URMUSE_,
         DELMACROSNAME = DELMACROSNAME_,
         NEEDDELCHILD = NEEDDELCHILD_,
         LINKKIND = LINKKIND_
      WHERE ID = ID_;
   END IF;      
   
   /*      ,      */
   UPDATE STATE_JUMPCONTROL SET
     REFERENCEREF = ID_
   WHERE
     REFERENCEREF = -10;
   UPDATE LINKRECORDS SET
      LINKTYPEREF = ID_
   WHERE
      LINKTYPEREF = -10;
   /*   */  
   DELETE FROM TB_LINKTYPE WHERE ID = -10;
   DELETE FROM DOCUMENTCLS WHERE ID = -10;
   DELETE FROM DOCUMENTTYPES WHERE ID = -10;
END;
/

--  
CALL LINKTYPE_IMPORT(30303600,'->',null,30201,32301,'',1,0,0,1,1,'',1,'','',0,'',1,0) ;

CALL LINKTYPE_IMPORT(30303700,'_->_',null,30200,32300,'',1,0,0,1,1,'',1,'','',0,'',1,0) ;

CALL LINKTYPE_IMPORT(30304200,'->',null,30501,30201,'      ',1,0,0,0,1,'',1,'','',0,'',0,2) ;

CALL LINKTYPE_IMPORT(24902200,'->',null,20101,490100,'       ',0,0,0,0,1,'',1,'','',0,'',0,0) ;

CALL LINKTYPE_IMPORT(554800100,'',null,550100,480100,'       ',0,0,0,0,1,'',1,'','1616',1,'',0,0) ;

CALL LINKTYPE_IMPORT(554800200,'',null,550200,480100,'       ',0,0,0,0,1,'',1,'','1616',1,'',0,0) ;

DROP PROCEDURE LINKTYPE_DELETE
/

DROP PROCEDURE LINKTYPE_IMPORT
/

CREATE OR REPLACE PROCEDURE STATICLINK_DELETE(ID_ NUMBER) IS
BEGIN
  DELETE FROM STATICLINKS SL
  WHERE SL.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE STATICLINK_IMPORT(
  ID_             NUMBER,
  NAME_           VARCHAR2,
  PARENTFIELDREF_ NUMBER,
  CHILDFIELDREF_  NUMBER,
  LINKKIND_      NUMBER,
  ParentDelAction_ NUMBER
) IS
  FINDID$ NUMBER;
  FINDNEWID$ NUMBER;
  IDExists$ NUMBER;
BEGIN
  /*     ID,    CHILDFIELDREF,PARENTFIELDREF. 
   ,     ,    ID.       ID  , 
   (  )     id ,      */
  BEGIN
    SELECT
      SL.ID
    INTO FINDID$
    FROM 
      STATICLINKS SL
    WHERE (SL.CHILDFIELDREF = CHILDFIELDREF_) AND (SL.PARENTFIELDREF = PARENTFIELDREF_) AND (SL.ID <> ID_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      FINDID$ := NULL;
  END;
  
  IF (FINDID$ IS NOT NULL) THEN
  /*   ID         */

    SELECT COUNT (ID)
      INTO IDExists$
      FROM STATE_JUMPCONTROL
    WHERE (STATICLINKREF = FINDID$);

    IF (IDExists$ > 0) THEN

      BEGIN
        SELECT
          SL.ID
        INTO FINDNEWID$
        FROM 
          STATICLINKS SL
        WHERE (SL.ID = ID_);
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
          FINDNEWID$ := NULL;
      END;
 
      IF (FINDNEWID$ IS NULL) THEN
        INSERT INTO STATICLINKS
         (ID,NAME,PARENTFIELDREF,CHILDFIELDREF,LINKKIND,ParentDelAction)
        VALUES
          (ID_,NAME_,CHILDFIELDREF_,PARENTFIELDREF_,1,ParentDelAction_);
      END IF;        
      UPDATE STATE_JUMPCONTROL
        SET STATICLINKREF = ID_
      WHERE (STATICLINKREF = FINDID$);

      DELETE FROM STATICLINKS  
      WHERE ID=FINDID$;
    ELSE   
      BEGIN
        SELECT
          SL.ID
        INTO FINDNEWID$
        FROM
          STATICLINKS SL
        WHERE (SL.ID = ID_);
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
          FINDNEWID$ := NULL;
      END;
      IF (FINDNEWID$ IS NULL) THEN
        UPDATE STATICLINKS
        SET ID=ID_
        WHERE ID=FINDID$;
      ELSE
        DELETE FROM STATICLINKS
        WHERE ID=FINDID$;
      END IF;
    END IF;
      
  END IF; /*  id  */
  
  /*       ( ), 
   ,            CHILDFIELDREF.
   ,        1( )*/
  IF (LINKKIND_=0) THEN
    UPDATE STATICLINKS
    SET LINKKIND=1  
    WHERE (CHILDFIELDREF = CHILDFIELDREF_) AND (ID <> ID_) AND (LINKKIND=0);
  END IF;    
  
  /*        id.  ,   .  ,   */
  BEGIN
    SELECT SL.ID
      INTO FINDID$
      FROM
        STATICLINKS SL
      WHERE
        (SL.ID = ID_);
  EXCEPTION
      WHEN NO_DATA_FOUND THEN
        FINDID$ := NULL;
  END;
  IF (FINDID$ IS NOT NULL) THEN
    UPDATE STATICLINKS SET
      NAME           = NAME_,
      PARENTFIELDREF = PARENTFIELDREF_,
      CHILDFIELDREF  = CHILDFIELDREF_,
      LINKKIND       = LINKKIND_,
      ParentDelAction = ParentDelAction_
      WHERE ID = ID_;
  ELSE
    INSERT INTO STATICLINKS
     (ID,NAME,PARENTFIELDREF,CHILDFIELDREF,LINKKIND,ParentDelAction)
    VALUES
      (ID_,NAME_,PARENTFIELDREF_,CHILDFIELDREF_,LINKKIND_,ParentDelAction_);
  END IF;      

END;
/

--  
CALL STATICLINK_DELETE(999800400) ;

CALL STATICLINK_DELETE(999901700) ;

CALL STATICLINK_DELETE(990338400) ;

CALL STATICLINK_DELETE(990338000) ;

CALL STATICLINK_DELETE(990338100) ;

CALL STATICLINK_DELETE(990338600) ;

CALL STATICLINK_DELETE(990338700) ;

CALL STATICLINK_DELETE(990338900) ;

CALL STATICLINK_DELETE(990339200) ;

CALL STATICLINK_DELETE(990339100) ;

CALL STATICLINK_DELETE(990339500) ;

CALL STATICLINK_DELETE(990339700) ;

CALL STATICLINK_DELETE(990339900) ;

CALL STATICLINK_DELETE(990232100) ;

CALL STATICLINK_DELETE(990232300) ;

CALL STATICLINK_DELETE(990232500) ;

CALL STATICLINK_DELETE(990232700) ;

CALL STATICLINK_DELETE(990232900) ;

CALL STATICLINK_DELETE(990233000) ;

CALL STATICLINK_DELETE(990233200) ;

CALL STATICLINK_DELETE(990233400) ;

CALL STATICLINK_DELETE(990233600) ;

CALL STATICLINK_DELETE(990233700) ;

CALL STATICLINK_DELETE(990234000) ;

CALL STATICLINK_DELETE(990234200) ;

CALL STATICLINK_DELETE(992203500) ;

CALL STATICLINK_DELETE(990337800) ;

CALL STATICLINK_DELETE(990232000) ;

CALL STATICLINK_DELETE(990803300) ;

CALL STATICLINK_DELETE(990803500) ;

CALL STATICLINK_DELETE(990803600) ;

CALL STATICLINK_DELETE(990908300) ;

CALL STATICLINK_DELETE(990908500) ;

CALL STATICLINK_DELETE(990908700) ;

CALL STATICLINK_DELETE(990908800) ;

CALL STATICLINK_DELETE(992503000) ;

CALL STATICLINK_DELETE(992503100) ;

CALL STATICLINK_DELETE(992503200) ;

CALL STATICLINK_DELETE(992503300) ;

CALL STATICLINK_DELETE(993002900) ;

CALL STATICLINK_DELETE(993003000) ;

CALL STATICLINK_DELETE(993003100) ;

CALL STATICLINK_DELETE(994402400) ;

CALL STATICLINK_DELETE(994402600) ;

CALL STATICLINK_DELETE(995201000) ;

CALL STATICLINK_DELETE(995504500) ;

CALL STATICLINK_DELETE(995504700) ;

CALL STATICLINK_DELETE(995505000) ;

CALL STATICLINK_DELETE(990235400) ;

CALL STATICLINK_DELETE(990235600) ;

CALL STATICLINK_DELETE(990235800) ;

CALL STATICLINK_DELETE(992504300) ;

CALL STATICLINK_IMPORT(979800100,'.TARGETCLS->.ID',970910002,984910004,0,0) ;

CALL STATICLINK_IMPORT(979900100,'.TARGETCLS->.ID',970910002,988410029,0,0) ;

CALL STATICLINK_IMPORT(995505400,'_.1.INVESTOBJECT()->.ID',985410045,550111166,0,0) ;

CALL STATICLINK_IMPORT(995505600,'_.1.INVESTOBJECT()->.ID',985410045,550211145,0,0) ;

CALL STATICLINK_IMPORT(995201400,'.1.INVESTOBJECT()->.ID',985410045,520111062,0,0) ;

CALL STATICLINK_IMPORT(990909000,'_.1.INVESTOBJECT()->.ID',985410045,90311093,0,0) ;

CALL STATICLINK_IMPORT(990909200,'_.INVESTOBJECT()->.ID',985410045,90510044,0,0) ;

CALL STATICLINK_IMPORT(990909400,'_.INVESTOBJECT()->.ID',985410045,90710056,0,0) ;

CALL STATICLINK_IMPORT(990237400,'_.1.INVESTOBJECT()->.ID',985410045,20111186,0,0) ;

CALL STATICLINK_IMPORT(990341900,'.1.SOURCEINVESTOBJECT()->.ID',985410045,30211156,0,0) ;

CALL STATICLINK_IMPORT(990342200,'.1.SOURCEINVESTOBJECT()->.ID',985410045,30411145,0,0) ;

CALL STATICLINK_IMPORT(990342400,'.1.DESTINVESTOBJECT()->.ID',985410045,30511146,0,0) ;

CALL STATICLINK_IMPORT(990342600,'.1.DESTINVESTOBJECT()->.ID',985410045,30611148,0,0) ;

CALL STATICLINK_IMPORT(990343200,'_.1.SOURCEINVESTOBJECT()->.ID',985410045,31111107,0,0) ;

CALL STATICLINK_IMPORT(990343400,'_.1.DESTINVESTOBJECT()->.ID',985410045,31211142,0,0) ;

CALL STATICLINK_IMPORT(990343600,'_.1.SOURCEINVESTOBJECT()->.ID',985410045,31411142,0,0) ;

CALL STATICLINK_IMPORT(990343700,'_.1.DESTINVESTOBJECT()->.ID',985410045,31511098,0,0) ;

CALL STATICLINK_IMPORT(990344100,'.1.DESTINVESTOBJECT()->.ID',985410045,32311157,0,0) ;

CALL STATICLINK_IMPORT(990344300,'.1.DESTINVESTOBJECT()->.ID',985410045,32411198,0,0) ;

CALL STATICLINK_IMPORT(990343900,'.1.SOURCEINVESTOBJECT()->.ID',985410045,32211090,0,0) ;

CALL STATICLINK_IMPORT(990342000,'.1.DESTINVESTOBJECT()->.ID',985410045,30311095,0,0) ;

CALL STATICLINK_IMPORT(994402800,'.1.INVESTOBJECT()->.ID',985410045,440111070,0,0) ;

CALL STATICLINK_IMPORT(994403000,'.1.INVESTOBJECT()->.ID',985410045,440311067,0,0) ;

CALL STATICLINK_IMPORT(992504600,'.2.INVESTOBJECT()->.ID',985410045,250212054,0,0) ;

CALL STATICLINK_IMPORT(992504700,'.2.INVESTOBJECT()->.ID',985410045,250312049,0,0) ;

CALL STATICLINK_IMPORT(992504800,'.2.INVESTOBJECT()->.ID',985410045,250412053,0,0) ;

CALL STATICLINK_IMPORT(993004300,'.1.INVESTOBJECT()->.ID',985410045,300111098,0,0) ;

CALL STATICLINK_IMPORT(993004400,'.1.INVESTOBJECT()->.ID',985410045,300611056,0,0) ;

CALL STATICLINK_IMPORT(990342900,'.1.SOURCEINVESTOBJECT->.ID',985410045,30811111,0,0) ;

CALL STATICLINK_IMPORT(990343000,'.1.DESTINVESTOBJECT->.ID',985410045,30811112,0,0) ;

CALL STATICLINK_IMPORT(990341600,'.1.SOURCEINVESTOBJECT->.ID',985410045,30111171,0,0) ;

CALL STATICLINK_IMPORT(990341700,'.1.DESTINVESTOBJECT->.ID',985410045,30111172,0,0) ;

CALL STATICLINK_IMPORT(990237500,'_.1.INVESTOBJECT()->.ID',985410045,20211109,0,0) ;

CALL STATICLINK_IMPORT(990237600,'_.1.INVESTOBJECT()->.ID',985410045,20311099,0,0) ;

CALL STATICLINK_IMPORT(990237700,'_.1.INVESTOBJECT()->.ID',985410045,20411119,0,0) ;

CALL STATICLINK_IMPORT(990237800,'.1.INVESTOBJECT()->.ID',985410045,20511106,0,0) ;

CALL STATICLINK_IMPORT(990237900,'__.1.INVESTOBJECT()->.ID',985410045,20611187,0,0) ;

CALL STATICLINK_IMPORT(990238000,'_.1.INVESTOBJECT()->.ID',985410045,20711187,0,0) ;

CALL STATICLINK_IMPORT(990238100,'__.1.INVESTOBJECT()->.ID',985410045,20811188,0,0) ;

CALL STATICLINK_IMPORT(970300900,'.1.SOURCETARGETCLS()->.ID',970910002,30211184,0,0) ;

CALL STATICLINK_IMPORT(993004500,'.1.INVESTOBJECT()->.ID',985410045,301111043,0,0) ;

CALL STATICLINK_IMPORT(992504500,'.ID->.ID',993010001,250310049,0,0) ;

CALL STATICLINK_IMPORT(990238200,'.1.INVESTOBJECT()->.ID',985410045,21011053,0,0) ;

CALL STATICLINK_IMPORT(990238300,'.2.INVESTOBJECT()->.ID',985410045,21012065,0,0) ;

CALL STATICLINK_IMPORT(970300300,'.1.SOURCETARGETCLS()->.ID',970910002,30111191,0,0) ;

CALL STATICLINK_IMPORT(970300400,'.1.DESTTARGETCLS()->.ID',970910002,30111193,0,0) ;

CALL STATICLINK_IMPORT(970300700,'.1.DESTTARGETCLS()->.ID',970910002,30311111,0,0) ;

CALL STATICLINK_IMPORT(970300800,'.1.SOURCETARGETCLS()->.ID',970910002,30411150,0,0) ;

CALL STATICLINK_IMPORT(970301100,'.1.DESTTARGETCLS()->.ID',970910002,30511151,0,0) ;

CALL STATICLINK_IMPORT(970301400,'.1.DESTTARGETCLS()->.ID',970910002,30811120,0,0) ;

CALL STATICLINK_IMPORT(970301300,'.1.SOURCETARGETCLS(,)->.ID',970910002,30811122,0,0) ;

CALL STATICLINK_IMPORT(970301700,'.1.SOURCETARGETCLS()->.ID',970910002,32211096,0,0) ;

CALL STATICLINK_IMPORT(970301900,'.1.DESTTARGETCLS()->.ID',970910002,32311169,0,0) ;

CALL STATICLINK_IMPORT(970302100,'.1.DESTTARGETCLS()->.ID',970910002,32411209,0,0) ;

CALL STATICLINK_IMPORT(970200200,'_.1.TARGETCLS()->.ID',970910002,20111200,0,0) ;

CALL STATICLINK_IMPORT(970200400,'_.1.TARGETCLS()->.ID',970910002,20211116,0,0) ;

CALL STATICLINK_IMPORT(970200600,'_.1.TARGETCLS()->.ID',970910002,20311104,0,0) ;

CALL STATICLINK_IMPORT(970200800,'_.1.TARGETCLS()->.ID',970910002,20411125,0,0) ;

CALL STATICLINK_IMPORT(970201000,'.1.TARGETCLS()->.ID',970910002,20511112,0,0) ;

CALL STATICLINK_IMPORT(970201100,'__.1.TARGETCLS()->.ID',970910002,20611191,0,0) ;

CALL STATICLINK_IMPORT(970201300,'__.1.TARGETCLS()->.ID',970910002,20811192,0,0) ;

CALL STATICLINK_IMPORT(970201500,'_.2.TARGETCLS()->.ID',970910002,20912047,0,0) ;

CALL STATICLINK_IMPORT(970201700,'.1.TARGETCLS()->.ID',970910002,21011054,0,0) ;

CALL STATICLINK_IMPORT(970201800,'.2.TARGETCLS()->.ID',970910002,21012066,0,0) ;

CALL STATICLINK_IMPORT(970202100,'_.2.TARGETCLS()->.ID',970910002,21112052,0,1) ;

CALL STATICLINK_IMPORT(970202300,'_.2.TARGETCLS()->.ID',970910002,21212053,0,1) ;

CALL STATICLINK_IMPORT(972200000,'_.1.TARGETCLS()->.ID',970910002,220111084,0,0) ;

CALL STATICLINK_IMPORT(970300100,'.1.->.ID',970910002,30011047,0,1) ;

CALL STATICLINK_IMPORT(970200100,'.1.->.ID',970910002,20011043,0,1) ;

CALL STATICLINK_IMPORT(970800000,'_.1.TARGETCLS()->.ID',970910002,80111086,0,0) ;

CALL STATICLINK_IMPORT(970800200,'_.TARGETCLS()->.ID',970910002,80210045,0,0) ;

CALL STATICLINK_IMPORT(970800300,'_.1.TARGETCLS()->.ID',970910002,80311058,0,0) ;

CALL STATICLINK_IMPORT(970900000,'.1.{("")}()->.ID',970910002,90011010,0,0) ;

CALL STATICLINK_IMPORT(970900200,'_.1.TARGETCLS()->.ID',970910002,90311097,0,0) ;

CALL STATICLINK_IMPORT(970900400,'_.TARGETCLS()->.ID',970910002,90510053,0,0) ;

CALL STATICLINK_IMPORT(970900500,'_.TARGETCLS()->.ID',970910002,90710061,0,0) ;

CALL STATICLINK_IMPORT(972500000,'.2.TARGETCLS->.ID',970910002,250112078,0,1) ;

CALL STATICLINK_IMPORT(972500100,'.2.TARGETCLS->.ID',970910002,250212063,0,1) ;

CALL STATICLINK_IMPORT(972500200,'.2.TARGETCLS->.ID',970910002,250312058,0,1) ;

CALL STATICLINK_IMPORT(972500300,'.2.TARGETCLS->.ID',970910002,250412110,0,1) ;

CALL STATICLINK_IMPORT(973000000,'.1.TARGETCLS->.ID',970910002,300111105,0,1) ;

CALL STATICLINK_IMPORT(973000100,'.1.TARGETCLS->.ID',970910002,300611068,0,1) ;

CALL STATICLINK_IMPORT(973000200,'.1.TARGETCLS->.ID',970910002,301111053,0,1) ;

CALL STATICLINK_IMPORT(974400000,'.1.TARGETCLS()->.ID',970910002,440111073,0,0) ;

CALL STATICLINK_IMPORT(974400200,'.1.TARGETCLS()->.ID',970910002,440311070,0,0) ;

CALL STATICLINK_IMPORT(975200000,'.1.TARGETCLS()->.ID',970910002,520111081,0,0) ;

CALL STATICLINK_IMPORT(975500000,'_.1.TARGETCLS()->.ID',970910002,550111172,0,0) ;

CALL STATICLINK_IMPORT(975500200,'_.1.TARGETCLS()->.ID',970910002,550211160,0,0) ;

CALL STATICLINK_IMPORT(975500400,'.1.TARGETCLS()->.ID',970910002,550311067,0,0) ;

CALL STATICLINK_IMPORT(970202600,'.1.TARGETCLS()->.ID',970910002,21311006,0,0) ;

CALL STATICLINK_IMPORT(970202800,'__.1.TARGETCLS()->.ID',970910002,21411006,0,0) ;

CALL STATICLINK_IMPORT(970203000,'__.1.TARGETCLS()->.ID',970910002,21511006,0,0) ;

CALL STATICLINK_IMPORT(972500400,'.4.TARGETCLS->.ID',970910002,250414140,0,0) ;

CALL STATICLINK_IMPORT(980232200,'_.2.KD()->.ID',980910006,21112065,0,0) ;

CALL STATICLINK_IMPORT(980232300,'_.2.SUBKD()->.ID',981010006,21112069,0,0) ;

CALL STATICLINK_IMPORT(999903900,'.INVESTOBJECT->.ID',985410045,993010036,0,0) ;

CALL STATICLINK_IMPORT(990236400,'.1.->.ID',985410045,20011051,0,1) ;

DROP PROCEDURE STATICLINK_DELETE
/

DROP PROCEDURE STATICLINK_IMPORT
/

CREATE OR REPLACE PROCEDURE FILTERS_DELETE(ID_ NUMBER) IS
BEGIN
  DELETE FROM STATE_JUMPCONTROL
  WHERE STATE_JUMPCONTROL.FILTERCODE = ID_;
  UPDATE STATE_ACTIONJUMPS SAJ
  SET SAJ.FILTERCODE = NULL, SAJ.OPTIONS = NULL
  WHERE SAJ.FILTERCODE = ID_;
  DELETE FROM State_Filter SF
  WHERE SF.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE FILTERS_IMPORT(
  ID_ NUMBER,
  Name_ VARCHAR2,
  Note_ VARCHAR2,
  FilterValue_ VARCHAR2,
  FilterFormat_ NUMBER,
  FilterActive_ NUMBER,
  IsBudget_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM State_Filter
  WHERE (ID = ID_);
  IF (IDExists$ = 0) THEN
  INSERT INTO State_Filter
    (ID,NAME,Note,FilterValue,FilterFormat,FilterActive,IsBudget)
  VALUES
    (ID_,NAME_,Note_,FilterValue_,FilterFormat_,FilterActive_,IsBudget_);
  ELSE
    UPDATE State_Filter SET
      NAME = NAME_,
      Note = Note_,
      FilterValue = FilterValue_,
      FilterFormat = FilterFormat_,
      FilterActive = FilterActive_,
      IsBudget = IsBudget_
    WHERE ID = ID_;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FILTERS_IMPORTURM(
  ID_ NUMBER,
  Name_ VARCHAR2,
  Note_ VARCHAR2,
  FilterValueURM_ VARCHAR2,
  FilterFormat_ NUMBER,
  FilterActive_ NUMBER,
  IsBudget_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM State_Filter
  WHERE (ID = ID_);
  IF (IDExists$ = 0) THEN
  INSERT INTO State_Filter
    (ID,NAME,Note,FilterValueURM,FilterFormat,FilterActive,IsBudget)
  VALUES
    (ID_,NAME_,Note_,FilterValueURM_,FilterFormat_,FilterActive_,IsBudget_);
  ELSE
    UPDATE State_Filter SET
      NAME = NAME_,
      Note = Note_,
      FilterValueURM = FilterValueURM_,
      FilterFormat = FilterFormat_,
      FilterActive = FilterActive_,
      IsBudget = IsBudget_
    WHERE ID = ID_;
  END IF;
END;
/

-- 
DROP PROCEDURE FILTERS_DELETE
/

DROP PROCEDURE FILTERS_IMPORT
/

DROP PROCEDURE FILTERS_IMPORTURM
/

CREATE OR REPLACE PROCEDURE STATUSICONS_IMPORT(
  ID_ NUMBER,
  NOTE_ VARCHAR2,
  DOCREF_ NUMBER,
  DETAILNUM_ NUMBER,
  ICONNAME_ VARCHAR2,
  ISSYSTEM_ NUMBER,
  ICONPOS_ NUMBER,
  RUNPOS_ NUMBER,
  RESERVEPOS_ NUMBER,
  ICONHINT_ VARCHAR2,
  ICONKIND_ NUMBER,
  LOCKMASK_ NUMBER,
  FORMULA_ VARCHAR2,
  ISBUDGET_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM STATUSICONS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE STATUSICONS SET
      NOTE = NOTE_,
      DOCREF = DOCREF_,
      DETAILNUM = DETAILNUM_,
      ICONNAME = ICONNAME_,
      ISSYSTEM = ISSYSTEM_,
      ICONPOS = ICONPOS_,
      RUNPOS = RUNPOS_,
      RESERVEPOS = RESERVEPOS_,
      ICONHINT = ICONHINT_,
      ICONKIND = ICONKIND_,
      LOCKMASK = LOCKMASK_,
      ISBUDGET = ISBUDGET_,
      FORMULA = FORMULA_
    WHERE ID = ID_;
  ELSE
    INSERT INTO STATUSICONS
      (ISBUDGET, ID, NOTE, DOCREF, DETAILNUM, ICONNAME, ISSYSTEM, ICONPOS, RUNPOS, RESERVEPOS, ICONHINT, ICONKIND, LOCKMASK, FORMULA)
    VALUES
      (ISBUDGET_, ID_, NOTE_, DOCREF_, DETAILNUM_, ICONNAME_, ISSYSTEM_, ICONPOS_, RUNPOS_, RESERVEPOS_, ICONHINT_, ICONKIND_, LOCKMASK_, FORMULA_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE STATUSICONS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM STATUSICONS SI
  WHERE SI.ID = ID_;
END;
/

--  
CALL STATUSICONS_IMPORT(45093,'',0,0,'',1,0,0,0,'',0,0,'',1) ;

CALL STATUSICONS_IMPORT(45019,' ,   ',1821,0,'',1,1,1,0,'[182110029]',0,0,'([182110029])',1) ;

DROP PROCEDURE STATUSICONS_IMPORT
/

DROP PROCEDURE STATUSICONS_DELETE
/


CREATE OR REPLACE PROCEDURE ENUMS_IMPORT(NAME_ VARCHAR2,FACIALACCCLS_ NUMBER) IS
  IDEXISTS$ NUMBER;
BEGIN
  SELECT COUNT(ID) INTO IDEXISTS$ FROM ENUMS WHERE NAME = NAME_;
  IF (IDEXISTS$ > 1) THEN
      DELETE FROM ENUMS E1
      WHERE (E1.NAME = NAME_) AND (E1.ID > (SELECT MIN(E2.ID) FROM ENUMS E2 WHERE E2.NAME = NAME_));
  END IF;
  IF (IDEXISTS$ > 0) THEN
    UPDATE ENUMS SET
      FACIALACCCLS = FACIALACCCLS_,
      ISSYSTEM = 1
    WHERE NAME = NAME_;
  ELSE
    INSERT INTO ENUMS
      (NAME,FACIALACCCLS,ISSYSTEM)    
    VALUES
      (NAME_,FACIALACCCLS_,1);
  END IF;    
END;
/

CREATE OR REPLACE PROCEDURE ENUMVALUES_IMPORT(ENUMNAME_ VARCHAR2,NAME_ VARCHAR2,VAL_ NUMBER) IS
  IDENUM$ NUMBER;
  IDEXISTS$ NUMBER;
BEGIN
  BEGIN
    SELECT ID INTO IDENUM$ FROM ENUMS WHERE NAME = ENUMNAME_;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      IDENUM$ := NULL;
  END;  
  IF (IDENUM$ IS NOT NULL) THEN
    SELECT COUNT(ID) INTO IDEXISTS$ FROM ENUMVALUES WHERE ENUMREF = IDENUM$ AND VAL = VAL_;
    IF (IDEXISTS$ > 1) THEN
      DELETE FROM ENUMVALUES EV1
      WHERE (EV1.ENUMREF = IDENUM$) AND (EV1.VAL = VAL_) AND
        (EV1.ID > (SELECT MIN(EV2.ID) FROM ENUMVALUES EV2 WHERE EV2.ENUMREF = IDENUM$ AND EV2.VAL = VAL_));
    END IF;
    IF (IDEXISTS$ > 0) THEN
      UPDATE ENUMVALUES SET
        NAME = NAME_
      WHERE ENUMREF = IDENUM$ AND VAL = VAL_;
    ELSE
      INSERT INTO ENUMVALUES
        (VAL,NAME,ENUMREF)  
      VALUES
        (VAL_,NAME_,IDENUM$);
    END IF;    
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE ENUMS_DELETE(NAME_ VARCHAR2) IS
BEGIN
  DELETE FROM ENUMS WHERE NAME = NAME_;
END;
/

CREATE OR REPLACE PROCEDURE ENUMVALUES_DELETE(ENUMNAME_ VARCHAR2,VAL_ NUMBER) IS
  IDENUM$ NUMBER;
BEGIN
  BEGIN
    SELECT ID INTO IDENUM$ FROM ENUMS WHERE NAME = ENUMNAME_;
  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       IDENUM$ := NULL;  
  END;
  IF (IDENUM$ IS NOT NULL) THEN
    DELETE FROM ENUMVALUES WHERE (VAL = VAL_) AND (ENUMREF = IDENUM$);
  END IF;  
END;
/

-- 
CALL ENUMVALUES_DELETE('',0) ;

CALL ENUMVALUES_IMPORT('','  ',527) ;

CALL ENUMS_IMPORT('',null) ;

CALL ENUMVALUES_IMPORT('','',0) ;

CALL ENUMVALUES_IMPORT('','',1) ;

CALL ENUMVALUES_IMPORT('','',2) ;

CALL ENUMVALUES_IMPORT('',' ',3) ;

CALL ENUMVALUES_IMPORT('',' ',4) ;

CALL ENUMVALUES_IMPORT('',' ',5) ;

CALL ENUMVALUES_IMPORT('',' ',6) ;

CALL ENUMS_IMPORT('',null) ;

CALL ENUMVALUES_IMPORT('',' ',0) ;

CALL ENUMVALUES_IMPORT('','',1) ;

CALL ENUMVALUES_IMPORT('','- ',2) ;

CALL ENUMVALUES_IMPORT('',',      ',3) ;

CALL ENUMVALUES_IMPORT('',' ',4) ;

CALL ENUMVALUES_IMPORT('','',5) ;

CALL ENUMS_IMPORT('',null) ;

CALL ENUMVALUES_IMPORT('',' ',1) ;

CALL ENUMVALUES_IMPORT('','   ',2) ;

CALL ENUMVALUES_IMPORT('','  ',3) ;

CALL ENUMVALUES_IMPORT('',' ',4) ;

CALL ENUMVALUES_IMPORT('',' ',5) ;

CALL ENUMS_IMPORT('',null) ;

CALL ENUMVALUES_IMPORT('','  ',0) ;

CALL ENUMVALUES_IMPORT('','',1) ;

CALL ENUMVALUES_IMPORT('','',2) ;

CALL ENUMVALUES_IMPORT('',' ',3) ;

CALL ENUMVALUES_IMPORT('','',4) ;

DROP PROCEDURE ENUMS_IMPORT
/

DROP PROCEDURE ENUMVALUES_IMPORT
/

DROP PROCEDURE ENUMS_DELETE
/

DROP PROCEDURE ENUMVALUES_DELETE
/

--      
INSERT INTO DFUCHANGELOG (VersionID, BEGINUPDATECODE, ENDUPDATECODE, LASTUPDATEDFU, ISBUDGET, INCLUDEDEL, INCLUDEBLOCKS, INCLUDEDOCS, SCRIPTCREATOR, SCRIPTCREATEDATE, NOTE) VALUES (2797, 131000, 131000, TO_DATE('04.06.2019 21:15:58', 'DD.MM.YYYY HH24:MI:SS'), 1, 1, ',    ,  , ,  , ,  , , ', '00.00, 01.01, 02.00, 02.01, 02.02, 02.03, 02.04, 02.05, 02.06, 02.07, 02.08, 02.09, 02.10, 02.11, 02.12, 02.13, 02.14, 02.15, 03.00, 03.01, 03.02, 03.03, 03.04, 03.05, 03.06, 03.07, 03.08, 03.11, 03.12, 03.14, 03.15, 03.16, 03.22, 03.23, 03.24, 04.01, 05.01, 07.01, 07.02, 07.03, 08.01, 08.02, 08.03, 08.04, 09.00, 09.01, 09.02, 09.03, 09.05, 09.06, 09.07, 12.01, 15.01, 16.01, 16.02, 17.01, 17.02, 18.05, 18.07, 18.09, 18.10, 18.12, 18.13, 18.14, 18.15, 18.16, 18.18, 18.19, 18.20, 18.21, 19.00, 19.01, 19.02, 19.03, 19.06, 22.00, 22.01, 25.01, 25.02, 25.03, 25.04, 28.01, 28.02, 30.01, 30.02, 30.03, 30.04, 30.05, 30.06, 30.10, 30.11, 36.10, 37.01, 39.01, 44.01, 44.03, 48.01, 49.01, 49.02, 49.03, 51.01, 52.01, 53.01, 53.02, 53.03, 53.04, 53.05, 53.06, 54.01, 54.02, 55.01, 55.02, 55.03, 96.01, 96.02, 96.03, 96.04, 97.01, 97.02, 97.09, 98.02, 98.03, 98.04, 98.05, 98.06, 98.08, 98.09, 98.10, 98.11, 98.12, 98.13, 98.14, 98.15, 98.16, 98.17, 98.18, 98.20, 98.21, 98.22, 98.23, 98.26, 98.27, 98.28, 98.29, 98.34, 98.35, 98.41, 98.42, 98.43, 98.44, 98.45, 98.46, 98.47, 98.48, 98.49, 98.50, 98.51, 98.52, 98.53, 98.54, 98.57, 98.58, 98.59, 98.60, 98.61, 98.62, 98.63, 98.64, 98.65, 98.67, 98.68, 98.69, 98.70, 98.71, 98.72, 98.78, 98.79, 98.80, 98.81, 98.82, 98.83, 98.84, 98.85, 98.86, 98.87, 98.88, 98.89, 98.90, 98.91, 98.92, 98.94, 98.95, 98.97, 98.98, 98.99, 99.03, 99.04, 99.05, 99.08, 99.12, 99.13, 99.14, 99.15, 99.16, 99.17, 99.18, 99.19, 99.20, 99.21, 99.22, 99.23, 99.24, 99.25, 99.26, 99.27, 99.28, 99.29, 99.30, 99.31, 99.32', 'MALINOVKIN/malinovkin', TO_DATE('04.06.2019 21:22:14', 'DD.MM.YYYY HH24:MI:SS'), '') ;

COMMIT WORK
/



-- #########################################################
-- #########################################################
-- DBVersion.sql
-- #########################################################
-- #########################################################

INSERT INTO DataBaseVersion(VERSION, Major, Minor, AComment)
  VALUES ('13.10.00', 1310, 00, ' 13.1')
/

COMMIT WORK
/

-- #########################################################
-- #########################################################
-- Index_Fix.sql
-- #########################################################
-- #########################################################

--      INDX
DECLARE
  CURSOR C$ IS
    select INDEX_NAME from DBA_INDEXES
    where OWNER = SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA')
      and TABLESPACE_NAME <> 'INDX'
      and INDEX_TYPE LIKE '%NORMAL%';
  CNT$ NUMBER(10);    
BEGIN
  BEGIN
    select count(*) into CNT$ from V$TABLESPACE
    where name = 'INDX';
  EXCEPTION
    WHEN OTHERS THEN
      CNT$ := 1;
  END;
  IF CNT$ = 1 THEN
    FOR R$ IN C$ LOOP
      EXECUTE IMMEDIATE 'ALTER INDEX ' || R$.INDEX_NAME || ' REBUILD TABLESPACE INDX';
    END LOOP;
  END IF;
END;
/

-- #########################################################
-- #########################################################
-- compile_scr.sql
-- #########################################################
-- #########################################################

--      , 
--  -  
--  DBMS_UTILITY.COMPILE_SCHEMA(user, TRUE);

DECLARE
  CURSOR C$ IS
    SELECT 'ALTER ' || object_type || ' ' || owner || '.' || object_name || ' COMPILE' AS str,
      object_type, object_name
    FROM SYS.ALL_OBJECTS
    WHERE owner = SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA')
      AND object_type IN ('VIEW', 'PROCEDURE', 'TRIGGER')
      AND status = 'INVALID'
      AND object_name not like 'BIN$%'
    ORDER BY DECODE(object_type, 'VIEW', 1, 'PROCEDURE', 2, 'TRIGGER', 3), object_name;
  S VARCHAR2(100);
BEGIN
  FOR R$ IN C$ LOOP
    BEGIN
      S := R$.object_type || ' ' || R$.object_name;
      EXECUTE IMMEDIATE R$.str;
    EXCEPTION
      WHEN OTHERS THEN 
        --DBMS_OUTPUT.PUT_LINE(S);
        RAISE_APPLICATION_ERROR(-20000, '    ' || S);
    END;
  END LOOP;
END;
/

-- #########################################################
-- #########################################################
-- dbms_stats_scr.sql
-- #########################################################
-- #########################################################

ALTER SESSION SET NLS_NUMERIC_CHARACTERS='.,'
/

BEGIN
  DBMS_STATS.GATHER_SCHEMA_STATS(
    SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA'),
    DBMS_STATS.AUTO_SAMPLE_SIZE,
    false,
    'FOR ALL COLUMNS SIZE AUTO',
    cascade=>TRUE
  );
END;
/

exit
